@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -22,16 +22,21 @@
 //
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-#include <TGUI/TGUI.hpp>
-#include <TGUI/Backend/GLFW-OpenGL3.hpp>
-
-// Optional: include (modern) OpenGL functions via TGUI (which you can call AFTER creating the Gui object)
-// This will include a built-in GLAD header that defines all functions that exist in OpenGL 4.6 (and GLES 3.2)
-//#include <TGUI/Backend/Renderer/OpenGL.hpp>
-
 #define GLFW_INCLUDE_NONE // Don't let GLFW include an OpenGL extention loader
 #include <GLFW/glfw3.h>
 
+#if TGUI_BUILD_CXX20_MODULE
+    import tgui;
+    import tgui.backend.glfw_opengl3;
+#else
+    #include <TGUI/TGUI.hpp>
+    #include <TGUI/Backend/GLFW-OpenGL3.hpp>
+
+    // Optional: include (modern) OpenGL functions via TGUI (which you can call AFTER creating the Gui object)
+    // This will include a built-in GLAD header that defines all functions that exist in OpenGL 4.6 (and GLES 3.2)
+    //#include <TGUI/Backend/Renderer/OpenGL.hpp>
+#endif
+
 bool runExample(tgui::BackendGui& gui);
 
 // We don't put this code in main() to make sure that all TGUI resources are destroyed before destroying GLFW
