@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -22,8 +22,15 @@
 //
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-#include <TGUI/TGUI.hpp>
-#include <TGUI/Backend/SFML-Graphics.hpp>
+#include <SFML/Graphics.hpp>
+
+#if TGUI_BUILD_CXX20_MODULE
+    import tgui;
+    import tgui.backend.sfml_graphics;
+#else
+    #include <TGUI/TGUI.hpp>
+    #include <TGUI/Backend/SFML-Graphics.hpp>
+#endif
 
 bool runExample(tgui::BackendGui& gui);
 
