@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -22,51 +22,27 @@
 //
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-
 #ifndef TGUI_GUI_BUILDER_GUI_BUILDER_HPP
 #define TGUI_GUI_BUILDER_GUI_BUILDER_HPP
 
 #include <TGUI/Config.hpp>
 
-// There are still issues with including std headers after importing the TGUI module (if TGUI_BUILD_AS_CXX_MODULE is 1),
-// so we include all std headers that are needed in the source files up here. This only works because this header file is
-// the first one to be included in both Form.cpp and GuiBuilder.cpp
 #include <cassert>
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <functional>
-    #include <algorithm>
-    #include <iostream>
-    #include <fstream>
-    #include <sstream>
-    #include <vector>
-    #include <memory>
-    #include <string>
-    #include <thread> // this_thread::sleep_for
-    #include <cctype> // isdigit
-    #include <cmath> // max
-    #include <stack>
-    #include <array>
-    #include <map>
-    #include <set>
-
-    #ifdef TGUI_SYSTEM_LINUX
-        #include <cstdio> // FILENAME_MAX
-    #endif
-#endif
+#include <functional>
+#include <sstream>
+#include <vector>
+#include <memory>
+#include <map>
 
 #ifdef TGUI_SYSTEM_LINUX
+    #include <cstdio> // FILENAME_MAX
     #include <sys/types.h> // ssize_t
     #include <unistd.h> // readlink
 #endif
 
-#if TGUI_BUILD_AS_CXX_MODULE
-    import tgui;
-    import tgui.default_backend_window;
-#else
-    #include <TGUI/TGUI.hpp>
-    #include <TGUI/Filesystem.hpp>
-    #include <TGUI/DefaultBackendWindow.hpp>
-#endif
+#include <TGUI/TGUI.hpp>
+#include <TGUI/Filesystem.hpp>
+#include <TGUI/DefaultBackendWindow.hpp>
 
 #include "WidgetProperties/WidgetProperties.hpp"
 #include "Form.hpp"
@@ -128,8 +104,8 @@ private:
     bool loadForm(tgui::String filename, bool loadingFromFile = true);
     void displayErrorMessage(const tgui::String& error);
     tgui::ChildWindow::Ptr openWindowWithFocus(tgui::ChildWindow::Ptr window = tgui::ChildWindow::create());
-    TGUI_NODISCARD tgui::String getDefaultFilename() const;
-    tgui::String widgetPtrToStrId(const tgui::Widget::Ptr& widget) const;
+    TGUI_NODISCARD static tgui::String getDefaultFilename();
+    static tgui::String widgetPtrToStrId(const tgui::Widget::Ptr& widget);
 
     void copyWidgetRecursive(std::vector<CopiedWidget>& copiedWidgetList, const std::shared_ptr<WidgetInfo>& widgetInfo);
     void pasteWidgetRecursive(const CopiedWidget& copiedWidget, tgui::Container* parent);
