@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -22,13 +22,12 @@
 //
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-
 #ifndef TGUI_GUI_BUILDER_CHAT_BOX_PROPERTIES_HPP
 #define TGUI_GUI_BUILDER_CHAT_BOX_PROPERTIES_HPP
 
 #include "WidgetProperties.hpp"
 
-struct ChatBoxProperties : WidgetProperties
+struct ChatBoxProperties : public WidgetProperties
 {
     // TODO: Scrollbar renderer
 
