@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -22,13 +22,12 @@
 //
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-
 #ifndef TGUI_GUI_BUILDER_CHILD_WINDOW_PROPERTIES_HPP
 #define TGUI_GUI_BUILDER_CHILD_WINDOW_PROPERTIES_HPP
 
 #include "WidgetProperties.hpp"
 
-struct ChildWindowProperties : WidgetProperties
+struct ChildWindowProperties : public WidgetProperties
 {
     void updateProperty(const tgui::Widget::Ptr& widget, const tgui::String& property, const tgui::String& value) const override
     {
@@ -94,7 +93,6 @@ struct ChildWindowProperties : WidgetProperties
         return pair;
     }
 
-
 private:
 
     TGUI_NODISCARD static unsigned int deserializeTitleButtons(const tgui::String& value)
