@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -22,16 +22,11 @@
 //
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-
 #ifndef TGUI_GUI_BUILDER_WIDGET_PROPERTIES_HPP
 #define TGUI_GUI_BUILDER_WIDGET_PROPERTIES_HPP
 
-#include <TGUI/Config.hpp>
-#if TGUI_BUILD_AS_CXX_MODULE
-    import tgui;
-#else
-    #include <TGUI/TGUI.hpp>
-#endif
+#include <TGUI/TGUI.hpp>
+#include <iostream>
 
 using PropertyValueMap = std::map<tgui::String, std::pair<tgui::String, tgui::String>>;
 using PropertyValueMapPair = std::pair<PropertyValueMap, PropertyValueMap>;
@@ -85,7 +80,7 @@ struct WidgetProperties
         pairs["NavigationDown"] = {"String", widget->getNavigationDown() ? widget->getNavigationDown()->getWidgetName() : U""};
         pairs["NavigationLeft"] = {"String", widget->getNavigationLeft() ? widget->getNavigationLeft()->getWidgetName() : U""};
         pairs["NavigationRight"] = {"String", widget->getNavigationRight() ? widget->getNavigationRight()->getWidgetName() : U""};
-        pairs["MouseCursor"] = {"Enum{Arrow,Text,Hand,SizeLeft,SizeRight,SizeTop,SizeBottom,SizeBottomRight,SizeTopLeft,SizeBottomLeft,SizeTopRight,Cross,Help,NotAllowed}", serializeMouseCursor(widget->getMouseCursor())};
+        pairs["MouseCursor"] = {"Enum{Arrow,Text,Hand,SizeLeft,SizeRight,SizeTop,SizeBottom,SizeBottomRight,SizeTopLeft,SizeBottomLeft,SizeTopRight,Cross,Help,NotAllowed,Move}", serializeMouseCursor(widget->getMouseCursor())};
         pairs["IgnoreMouseEvents"] = {"Bool", tgui::Serializer::serialize(widget->getIgnoreMouseEvents())};
         try
         {
@@ -96,7 +91,6 @@ struct WidgetProperties
             pairs["UserData"] = {"String", ""};
         }
 
-
         PropertyValueMap rendererPairs;
         const auto renderer = widget->getSharedRenderer();
         rendererPairs["Opacity"] = {"Float", tgui::String::fromNumber(renderer->getOpacity())};
@@ -106,7 +100,6 @@ struct WidgetProperties
         return {pairs, rendererPairs};
     }
 
-
     TGUI_NODISCARD static bool parseBoolean(tgui::String str, bool defaultValue)
     {
         str = str.trim().toLower();
@@ -205,6 +198,8 @@ struct WidgetProperties
             return tgui::Cursor::Type::Help;
         else if (value == "notallowed")
             return tgui::Cursor::Type::NotAllowed;
+        else if (value == "move")
+            return tgui::Cursor::Type::Move;
         else
             return tgui::Cursor::Type::Arrow;
     }
@@ -226,6 +221,7 @@ struct WidgetProperties
             case tgui::Cursor::Type::Crosshair:       return "Crosshair";
             case tgui::Cursor::Type::Help:            return "Help";
             case tgui::Cursor::Type::NotAllowed:      return "NotAllowed";
+            case tgui::Cursor::Type::Move:            return "Move";
             default:                                  return "Arrow";
         }
     }
