@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -29,17 +29,15 @@
 
 #include <TGUI/Config.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <type_traits>
-    #include <utility>
-    #include <typeinfo>
+#include <type_traits>
+#include <utility>
+#include <typeinfo>
 
-    #if TGUI_COMPILED_WITH_CPP_VER >= 17
-        #include <any>
-    #endif
+#if TGUI_COMPILED_WITH_CPP_VER >= 17
+    #include <any>
 #endif
 
-TGUI_MODULE_EXPORT namespace tgui
+namespace tgui
 {
 #if TGUI_COMPILED_WITH_CPP_VER >= 17
     using Any = std::any;
