@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -28,18 +28,13 @@
 #include <TGUI/Backend/Renderer/OpenGL3/BackendTextureOpenGL3.hpp>
 #include <TGUI/Backend/Renderer/OpenGL3/BackendRenderTargetOpenGL3.hpp>
 #include <TGUI/Backend/Renderer/OpenGL3/CanvasOpenGL3.hpp>
+#include <TGUI/Backend/Renderer/BackendRenderer.hpp>
 
-#if !TGUI_BUILD_AS_CXX_MODULE
-    #include <TGUI/Backend/Renderer/BackendRenderer.hpp>
-#endif
-
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <memory>
-#endif
+#include <memory>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-TGUI_MODULE_EXPORT namespace tgui
+namespace tgui
 {
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     /// @brief Backend renderer that uses OpenGL 3 or 4 (depending on the loaded OpenGL context that you have to provide)
@@ -65,7 +60,7 @@ TGUI_MODULE_EXPORT namespace tgui
         /// backend->setRenderer(std::make_shared<BackendRendererOpenGL3>(glfwGetProcAddress));
         /// @endcode
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        BackendRendererOpenGL3(ContextLoadFuncType contextLoadFunction);
+        explicit BackendRendererOpenGL3(ContextLoadFuncType contextLoadFunction);
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Helper constructor so that you can pass SDL_GL_GetProcAddress without needing to cast the type
@@ -73,7 +68,7 @@ TGUI_MODULE_EXPORT namespace tgui
         ///
         /// @param contextLoadFunction  Function that gets the address of an OpenGL function
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        BackendRendererOpenGL3(SDLContextLoadFuncType contextLoadFunction);
+        explicit BackendRendererOpenGL3(SDLContextLoadFuncType contextLoadFunction);
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Creates a new empty texture object
