@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -26,14 +26,11 @@
 #define TGUI_BACKEND_RENDER_TARGET_SDL_HPP
 
 #include <TGUI/Backend/Renderer/SDL_Renderer/BackendTextureSDL.hpp>
-
-#if !TGUI_BUILD_AS_CXX_MODULE
-    #include <TGUI/Backend/Renderer/BackendRenderTarget.hpp>
-#endif
+#include <TGUI/Backend/Renderer/BackendRenderTarget.hpp>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-TGUI_MODULE_EXPORT namespace tgui
+namespace tgui
 {
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     /// @brief Render target implementation that makes use of SDL_Renderer
@@ -45,7 +42,7 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Default constructor
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        BackendRenderTargetSDL(SDL_Renderer* renderer);
+        explicit BackendRenderTargetSDL(SDL_Renderer* renderer);
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Select the color that will be used by clearScreen
