@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -30,13 +30,11 @@
     #error "TGUI wasn't build with the SDL_GLES2 backend"
 #endif
 
-#if !TGUI_BUILD_AS_CXX_MODULE
-    #include <TGUI/Backend/Window/SDL/BackendSDL.hpp>
-    #include <TGUI/Backend/Renderer/GLES2/BackendRendererGLES2.hpp>
-    #include <TGUI/Backend/Font/FreeType/BackendFontFreeType.hpp>
-#endif
+#include <TGUI/Backend/Window/SDL/BackendSDL.hpp>
+#include <TGUI/Backend/Renderer/GLES2/BackendRendererGLES2.hpp>
+#include <TGUI/Backend/Font/FreeType/BackendFontFreeType.hpp>
 
-TGUI_MODULE_EXPORT namespace tgui
+namespace tgui
 {
     inline namespace SDL_GLES2
     {
