@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -34,15 +34,13 @@
 #include <TGUI/Backend/Renderer/BackendTexture.hpp>
 #include <TGUI/Backend/Renderer/BackendRenderer.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <cstdint>
-    #include <memory>
-    #include <set>
-#endif
+#include <cstdint>
+#include <memory>
+#include <set>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-TGUI_MODULE_EXPORT namespace tgui
+namespace tgui
 {
     class Sprite;
     class Backend;
@@ -79,7 +77,6 @@ TGUI_MODULE_EXPORT namespace tgui
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     TGUI_API std::shared_ptr<Backend> getBackend();
 
-
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     /// @brief Base class for the backend
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -171,7 +168,7 @@ TGUI_MODULE_EXPORT namespace tgui
         ///
         /// @see setFontScale
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        float getFontScale() const;
+        TGUI_NODISCARD float getFontScale() const;
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes the look of a certain mouse cursor by using a bitmap
