@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -31,14 +31,12 @@
 #include <TGUI/Cursor.hpp>
 #include <TGUI/TwoFingerScrollDetect.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <chrono>
-    #include <stack>
-#endif
+#include <chrono>
+#include <stack>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-TGUI_MODULE_EXPORT namespace tgui
+namespace tgui
 {
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     /// @brief Base class for the Gui
@@ -161,7 +159,7 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Draws all the widgets that were added to the gui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        virtual void draw();
+        virtual void draw(); // TGUI_NEXT: Remove from base class, as some backends require parameters
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the internal container of the Gui
@@ -339,6 +337,18 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD Widget::Ptr getWidgetBelowMouseCursor(Vector2i mousePos, bool recursive) const;
 
+        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+        /// @brief Returns the mouse position of the last mouse event that was handled by the gui
+        ///
+        /// @return Last handled mouse position. In most situations this will the same as the current mouse position on the window.
+        ///
+        /// @warning This function returns a value in pixel coordinates. You will need to call mapPixelToCoords to convert it
+        ///          into the coordinate system used by the gui (which is different if its view or viewport was changed).
+        ///
+        /// @since TGUI 1.8
+        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+        TGUI_NODISCARD Vector2i getLastMousePosition() const;
+
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Focuses the next widget in the gui
         ///
@@ -467,7 +477,7 @@ TGUI_MODULE_EXPORT namespace tgui
         ///
         /// @throw Exception when file could not be opened for writing
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        void saveWidgetsToFile(const String& filename);
+        void saveWidgetsToFile(const String& filename) const;
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Loads the child widgets from a string stream
@@ -598,6 +608,15 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         virtual void updateTextCursorPosition(FloatRect inputRect, Vector2f caretPos);
 
+        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+        /// @brief Checks the state for one of the modifier keys
+        ///
+        /// @param modifierKey  The modifier key of which the state is being queried
+        ///
+        /// @return Whether queries modifier key is being pressed
+        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+        TGUI_NODISCARD virtual bool isKeyboardModifierPressed(Event::KeyModifier modifierKey) const; // TGUI_NEXT: Pure virtual
+
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes whether using the arrow keys can be used to navigate between widgets
         ///
@@ -639,6 +658,13 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         virtual void updateContainerSize();
 
+        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+        // Used when the NumLock is off to translate keypad key events to key events for text cursor navigation.
+        // The key parameter should be a value from Numpad0 to Numpad9 and the output is the key code that corresponds to the
+        // wanted functionality (e.g. for Numpad0 we return the Insert key). Unknown is returned for Numpad5.
+        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+        static Event::KeyboardKey translateKeypadKey(Event::KeyboardKey key);
+
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     public:
 
@@ -659,6 +685,7 @@ TGUI_MODULE_EXPORT namespace tgui
         bool m_tooltipPossible = false;
         Vector2f m_toolTipRelativePos;
         Vector2i m_lastMousePos;
+        std::uintptr_t m_trackedFingerId = 0;
         TwoFingerScrollDetect m_twoFingerScroll;
 
         Vector2i m_framebufferSize;
