@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -30,11 +30,9 @@
 #include <TGUI/Texture.hpp>
 #include <TGUI/Outline.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <unordered_map>
-    #include <memory>
-    #include <set>
-#endif
+#include <unordered_map>
+#include <memory>
+#include <set>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -66,7 +64,7 @@ namespace dev
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     /// Layout alignment for automatically setting the position and (part of) the size of a component
-    enum class AlignLayout
+    enum class AlignLayout : std::uint8_t
     {
         None,       //!< Position and size need to be manually set. This is the default.
         Top,        //!< Places the component on on the top and sets its width to the area between Leftmost and Rightmost aligned components. Height needs to be manually set.
@@ -81,7 +79,7 @@ namespace dev
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     /// Position alignment of a component within its parent
-    enum class PositionAlignment
+    enum class PositionAlignment : std::uint8_t
     {
         None,        //!< Place the component at the manually set position. This is the default.
         TopLeft,     //!< Place the component in the upper left corner of its parent
@@ -156,7 +154,7 @@ namespace dev
 
             const std::uint64_t baseIndex = m_propertyData & 0xFFFFFFFFFFFF0000;
             const std::uint64_t oldBaseIndex = other.m_propertyData & 0xFFFFFFFFFFFF0000;
-            const std::uint16_t oldStoredStates = static_cast<std::uint16_t>(other.m_propertyData & 0xFFFF);
+            const auto oldStoredStates = static_cast<std::uint16_t>(other.m_propertyData & 0xFFFF);
 
             std::uint16_t total = 0;
             std::uint8_t bitIndex = 0;
@@ -252,7 +250,7 @@ namespace dev
         TGUI_NODISCARD const ValueType& getValue(ComponentState state = ComponentState::Normal) const
         {
             const std::uint64_t baseIndex = m_propertyData & 0xFFFFFFFFFFFF0000;
-            const std::uint16_t storedStates = static_cast<std::uint16_t>(m_propertyData & 0xFFFF);
+            const auto storedStates = static_cast<std::uint16_t>(m_propertyData & 0xFFFF);
 
             // If we don't have a value for any state then we can just return the default value
             if (storedStates == 0)
@@ -306,12 +304,11 @@ namespace dev
                 // is e.g. a value for both Normal and Disabled state and the widget is enabled.
                 return m_globalValues.at(baseIndex + static_cast<std::uint8_t>(ComponentState::Normal));
             }
-            else
-            {
-                // We don't have any relevant values, so return the default value. It is possible to pass here while storedStates > 0 when
-                // there is e.g. only a value for the Disabled state and the widget is enabled.
-                return m_defaultValue;
-            }
+
+            // We don't have any relevant values, so return the default value. It is possible to
+            // pass here while storedStates > 0 when there is e.g. only a value for the Disabled
+            // state and the widget is enabled.
+            return m_defaultValue;
         }
 
         TGUI_NODISCARD std::uint64_t connectCallback(std::function<void()> func)
@@ -321,7 +318,7 @@ namespace dev
 
         void disconnectCallback(std::uint64_t id)
         {
-            return MessageBroker::unsubscribe(id);
+            MessageBroker::unsubscribe(id);
         }
 
     private:
@@ -329,7 +326,7 @@ namespace dev
         void unsetValueImpl()
         {
             const std::uint64_t baseIndex = m_propertyData & 0xFFFFFFFFFFFF0000;
-            const std::uint16_t storedStates = static_cast<std::uint16_t>(m_propertyData & 0xFFFF);
+            const auto storedStates = static_cast<std::uint16_t>(m_propertyData & 0xFFFF);
 
             std::uint16_t total = 0;
             std::uint8_t bitIndex = 0;
@@ -427,8 +424,7 @@ namespace dev
         TGUI_NODISCARD virtual std::shared_ptr<Component> clone() const = 0;
 
     protected:
-
-        friend void swap(Component& first, Component& second);
+        friend void swap(Component& first, Component& second) noexcept;
 
     protected:
 
@@ -463,7 +459,7 @@ namespace dev
 
         TGUI_NODISCARD std::shared_ptr<Component> clone() const override;
 
-        friend void swap(GroupComponent& first, GroupComponent& second);
+        friend void swap(GroupComponent& first, GroupComponent& second) noexcept;
 
     protected:
 
@@ -480,7 +476,7 @@ namespace dev
     {
     public:
 
-        BackgroundComponent(StylePropertyBackground* backgroundStyle);
+        explicit BackgroundComponent(StylePropertyBackground* backgroundStyle);
 
         ~BackgroundComponent() override;
 
@@ -542,7 +538,7 @@ namespace dev
     {
     public:
 
-        TextComponent(StylePropertyText* textStyle);
+        explicit TextComponent(StylePropertyText* textStyle);
 
         ~TextComponent() override;
 
@@ -600,7 +596,7 @@ namespace dev
     {
     public:
 
-        ImageComponent(StyleProperty<Texture>* textureStyle);
+        explicit ImageComponent(StyleProperty<Texture>* textureStyle);
 
         ~ImageComponent() override;
 
@@ -637,34 +633,38 @@ namespace dev
         {
             if (active)
                 return ComponentState::DisabledActive;
-            else
-                return ComponentState::Disabled;
+
+            return ComponentState::Disabled;
         }
-        else if (focused)
+
+        if (focused)
         {
             if (active)
             {
                 if (hover)
                     return ComponentState::FocusedActiveHover;
-                else
-                    return ComponentState::FocusedActive;
+
+                return ComponentState::FocusedActive;
             }
-            else if (hover)
+
+            if (hover)
                 return ComponentState::FocusedHover;
-            else
-                return ComponentState::Focused;
+
+            return ComponentState::Focused;
         }
-        else if (active)
+
+        if (active)
         {
             if (hover)
                 return ComponentState::ActiveHover;
-            else
-                return ComponentState::Active;
+
+            return ComponentState::Active;
         }
-        else if (hover)
+
+        if (hover)
             return ComponentState::Hover;
-        else
-            return ComponentState::Normal;
+
+        return ComponentState::Normal;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
