@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -27,13 +27,9 @@
 
 #include <TGUI/Widget.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <list>
-#endif
-
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-TGUI_MODULE_EXPORT namespace tgui
+namespace tgui
 {
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     /// @brief Container widget
@@ -63,12 +59,12 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Copy constructor
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        Container(const Container& copy);
+        Container(const Container& other);
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Move constructor
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        Container(Container&& copy) noexcept;
+        Container(Container&& other) noexcept;
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Destructor
@@ -208,7 +204,7 @@ TGUI_MODULE_EXPORT namespace tgui
         ///
         /// @throw Exception when file could not be opened for writing
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        void saveWidgetsToFile(const String& filename);
+        void saveWidgetsToFile(const String& filename) const;
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Loads the child widgets from a string stream
@@ -605,7 +601,7 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         // Transform the mouse position for the child widget based its origin, rotation and scaling.
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        TGUI_NODISCARD Vector2f transformMousePos(const Widget::Ptr& widget, Vector2f mousePos) const;
+        TGUI_NODISCARD static Vector2f transformMousePos(const Widget::Ptr& widget, Vector2f mousePos);
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         // Finishes adding a widget to the container
@@ -662,7 +658,7 @@ TGUI_MODULE_EXPORT namespace tgui
         /// @param initRenderer Should the renderer be initialized? Should be true unless a derived class initializes it.
         /// @see create
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        RootContainer(const char* typeName = StaticWidgetType, bool initRenderer = true);
+        explicit RootContainer(const char* typeName = StaticWidgetType, bool initRenderer = true);
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Focus or unfocus the widget
