@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -28,13 +28,11 @@
 #include <TGUI/Config.hpp>
 #include <TGUI/Vector2.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <cstdint>
-#endif
+#include <cstdint>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-TGUI_MODULE_EXPORT namespace tgui
+namespace tgui
 {
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     /// @brief Class that allows the cursor to be changed
@@ -63,7 +61,8 @@ TGUI_MODULE_EXPORT namespace tgui
             SizeVertical,           //!< Vertical double arrow cursor
             Crosshair,              //!< Crosshair cursor
             Help,                   //!< Help cursor
-            NotAllowed              //!< Action not allowed cursor
+            NotAllowed,             //!< Action not allowed cursor
+            Move,                   //!< Move cursor / omnidirectional resize cursor. Usually displayed as a grabbing hand on macOS.
         };
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
