@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -22,17 +22,14 @@
 //
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-
 #ifndef TGUI_DURATION_HPP
 #define TGUI_DURATION_HPP
 
 #include <TGUI/Config.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <cstdint>
-    #include <chrono>
-    #include <type_traits>
-#endif
+#include <cstdint>
+#include <chrono>
+#include <type_traits>
 
 #if TGUI_HAS_WINDOW_BACKEND_SFML
     #include <SFML/System/Time.hpp>
@@ -40,7 +37,7 @@
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-TGUI_MODULE_EXPORT namespace tgui
+namespace tgui
 {
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     /// @brief Wrapper for durations
@@ -64,7 +61,6 @@ TGUI_MODULE_EXPORT namespace tgui
         {
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Creates the duration from any kind of std::chrono::duration
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -74,7 +70,6 @@ TGUI_MODULE_EXPORT namespace tgui
         {
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Creates the duration from a given amount of milliseconds
         /// @param milliseconds  Amount of milliseconds to store in the duration
@@ -84,7 +79,6 @@ TGUI_MODULE_EXPORT namespace tgui
         {
         }
 
-
 #if TGUI_HAS_WINDOW_BACKEND_SFML
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Creates the duration from an sf::Time instance
@@ -103,7 +97,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return static_cast<float>(static_cast<double>(m_duration.count()) / 1000000000.0);
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Convert the duration to std::chrono::nanoseconds
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -112,7 +105,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return m_duration;
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Convert the duration to std::chrono::duration
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -225,7 +217,6 @@ TGUI_MODULE_EXPORT namespace tgui
 
     constexpr Duration& operator-=(Duration& lhs, const Duration& rhs)
     {
-
         return lhs = lhs - rhs;
     }
 
@@ -259,4 +250,3 @@ TGUI_MODULE_EXPORT namespace tgui
 
 #endif // TGUI_DURATION_HPP
 
-
