@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -29,16 +29,14 @@
 #include <TGUI/Vector2.hpp>
 #include <TGUI/AbsoluteOrRelativeValue.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <type_traits>
-    #include <functional>
-    #include <memory>
-    #include <string>
-#endif
+#include <type_traits>
+#include <functional>
+#include <memory>
+#include <string>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-TGUI_MODULE_EXPORT namespace tgui
+namespace tgui
 {
     class BackendGui;
     class Widget;
@@ -89,7 +87,7 @@ TGUI_MODULE_EXPORT namespace tgui
         Right,      //!< Places the widget on the right side and sets its height to the area between Top and Bottom aligned components. Width needs to be manually set.
         Bottom,     //!< Places the widget on on the bottom and sets its width to the area between Leftmost and Rightmost aligned components. Height needs to be manually set.
         Leftmost,   //!< Places the widget on the left side and sets height to 100%. Width needs to be manually set. Same as Left alignment if no widget uses Top or Bottom alignment.
-        Rightmost,  //!< Places the widget on the right side and sets height to 100%. Width needs to be manually set. Same as Left alignment if no widget uses Top or Bottom alignment.
+        Rightmost,  //!< Places the widget on the right side and sets height to 100%. Width needs to be manually set. Same as Right alignment if no widget uses Top or Bottom alignment.
         Fill        //!< Sets the position and size to fill the entire area that isn't already taken by components with the other AutoLayout values.
     };
 
