@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -22,7 +22,6 @@
 //
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-
 #ifndef TGUI_THEME_HPP
 #define TGUI_THEME_HPP
 
@@ -31,7 +30,7 @@
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-TGUI_MODULE_EXPORT namespace tgui
+namespace tgui
 {
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     /// @brief This class can be used to manage the widget renderers
@@ -44,7 +43,6 @@ TGUI_MODULE_EXPORT namespace tgui
         using Ptr = std::shared_ptr<Theme>; //!< Shared widget pointer
         using ConstPtr = std::shared_ptr<const Theme>; //!< Shared constant widget pointer
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Constructs the theme class, with an optional theme file to load
         ///
@@ -52,7 +50,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         Theme(const String& primary = "");
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Copy constructor
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -78,7 +75,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         Theme& operator=(Theme&&) noexcept;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Constructs a new theme, with an optional theme file to load
         ///
@@ -91,7 +87,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD static Theme::Ptr create(const String& primary = "");
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes the primary theme loader parameter
         ///
@@ -102,7 +97,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void load(const String& primary);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Replaced this theme with another one, while updating all connected widgets to the new renderers
         ///
@@ -115,7 +109,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void replace(const Theme& otherTheme);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Gets data for the renderers
         ///
@@ -127,7 +120,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD std::shared_ptr<RendererData> getRenderer(const String& id);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Gets data for the renderers
         ///
@@ -139,7 +131,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD std::shared_ptr<RendererData> getRendererNoThrow(const String& id);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the value of a global property in the theme
         ///
@@ -149,7 +140,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD ObjectConverter getGlobalProperty(const String& property);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Manually adds a renderer data to the theme
         ///
@@ -161,7 +151,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void addRenderer(const String& id, std::shared_ptr<RendererData> renderer);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Manually removes a renderer to the theme
         ///
@@ -171,14 +160,12 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         bool removeRenderer(const String& id);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the primary theme loader parameter
         /// @return Primary parameter for the theme loader (filename of the theme file in DefaultThemeLoader)
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD const String& getPrimary() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes the function that will load the widget theme data
         ///
@@ -186,7 +173,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         static void setThemeLoader(std::shared_ptr<BaseThemeLoader> themeLoader);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the function that is currently being used to load the widget theme data
         ///
@@ -194,7 +180,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD static std::shared_ptr<BaseThemeLoader> getThemeLoader();
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Sets the theme class that widgets use by default
         ///
@@ -207,7 +192,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         static void setDefault(const String& primary = "");
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Sets the theme class that widgets use by default
         ///
@@ -215,13 +199,11 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         static void setDefault(std::shared_ptr<Theme> theme);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Resets the theme that widgets use by default
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         static void setDefault(std::nullptr_t);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns a pointer to the theme class that widgets use by default
         ///
@@ -232,7 +214,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD static std::shared_ptr<Theme> getDefault();
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Inform the theme that a custom renderer class inherits its properties from an existing renderer
         ///
@@ -241,7 +222,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         static void addRendererInheritanceParent(const String& widgetType, const String& parentType);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the parent type of a widget
         /// @param widgetType  Type name of the derived widget
@@ -250,7 +230,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD static String getRendererInheritanceParent(const String& widgetType);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Inform the theme that a custom renderer has subwidgets that need a default value
         ///
@@ -260,7 +239,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         static void addRendererDefaultSubwidget(const String& widgetType, const String& property, const String& propertyWidgetType);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the defaulted subwidgets that a renderer has
         /// @param widgetType  Type name of the widget of which we are looking up the properties
@@ -269,7 +247,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD static std::map<String, String> getRendererDefaultSubwidgets(const String& widgetType);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Inform the theme that a custom renderer has properties that can use a default value from the global properties
         ///
@@ -279,7 +256,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         static void addRendererInheritedGlobalProperty(const String& widgetType, const String& property, const String& globalProperty);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the properties which a renderer inherits from the global theme properties
         /// @param widgetType  Type name of the widget of which we are looking up the properties
@@ -288,7 +264,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD static std::map<String, String> getRendererInheritedGlobalProperties(const String& widgetType);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     protected:
 
