@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -22,16 +22,14 @@
 //
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-
 #ifndef TGUI_TREE_VIEW_RENDERER_HPP
 #define TGUI_TREE_VIEW_RENDERER_HPP
 
-
 #include <TGUI/Renderers/WidgetRenderer.hpp>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-TGUI_MODULE_EXPORT namespace tgui
+namespace tgui
 {
     class TGUI_API TreeViewRenderer : public WidgetRenderer
     {
@@ -39,7 +37,6 @@ TGUI_MODULE_EXPORT namespace tgui
 
         using WidgetRenderer::WidgetRenderer;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes the size of the borders
         /// @param borders  Size of the borders
@@ -52,7 +49,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD Borders getBorders() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes the padding of the tree view
         /// @param padding  The padding width and height
@@ -65,7 +61,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD Padding getPadding() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes the background color of the tree view
         /// @param color  The new background color
@@ -78,7 +73,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD Color getBackgroundColor() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes the color of the borders
         /// @param color  The new border color
@@ -91,7 +85,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD Color getBorderColor() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes the color of the text
         /// @param color  The new text color
@@ -104,7 +97,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD Color getTextColor() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes the color of the text of the item below the mouse
         /// @param color  The new hover text color
@@ -117,7 +109,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD Color getTextColorHover() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes the color of the text from the selected item
         /// @param color  The new selected text color
@@ -130,7 +121,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD Color getSelectedTextColor() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes the color of the text of the selected item when it is below the mouse
         /// @param color  The new hover text color
@@ -143,7 +133,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD Color getSelectedTextColorHover() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes the background color of the selected item
         /// @param color  The new selected item background color
@@ -156,7 +145,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD Color getSelectedBackgroundColor() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes the background color used for the item below the mouse
         /// @param color  The new hover background color
@@ -169,7 +157,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD Color getBackgroundColorHover() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes the background color used for the selected item when the mouse hovers over it
         /// @param backgroundColor  The new selected hover background color
@@ -182,7 +169,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD Color getSelectedBackgroundColorHover() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Sets the renderer data of the scrollbar
         /// @param scrollbarRendererData  Data about how the scrollbar should look
@@ -195,7 +181,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD std::shared_ptr<RendererData> getScrollbar() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Sets the wanted width of the scrollbar
         /// @param scrollbarWidth  Requested scrollbar width or 0 to use the default width (texture size if using textures)
@@ -208,7 +193,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD float getScrollbarWidth() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes the background image of the tree view
         ///
@@ -218,7 +202,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void setTextureBackground(const Texture& texture);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the background image of the tree view
         ///
@@ -226,7 +209,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD const Texture& getTextureBackground() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes the image used in front of an expanded item
         ///
@@ -244,7 +226,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD const Texture& getTextureBranchExpanded() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes the image used in front of a collapsed item
         ///
@@ -262,7 +243,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD const Texture& getTextureBranchCollapsed() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes the image used in front of a lead item
         ///
@@ -278,7 +258,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD const Texture& getTextureLeaf() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     };
 
