@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -22,7 +22,6 @@
 //
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-
 #ifndef TGUI_SIGNAL_HPP
 #define TGUI_SIGNAL_HPP
 
@@ -35,21 +34,19 @@
 #include <TGUI/Animation.hpp>
 #include <TGUI/Filesystem.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <unordered_map>
-    #include <type_traits>
-    #include <functional>
-    #include <typeindex>
-    #include <memory>
-    #include <vector>
-    #include <deque>
-#endif
+#include <unordered_map>
+#include <type_traits>
+#include <functional>
+#include <typeindex>
+#include <memory>
+#include <vector>
+#include <deque>
 
 #undef MessageBox  // windows.h defines MessageBox when NOMB isn't defined before including windows.h
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-TGUI_MODULE_EXPORT namespace tgui
+namespace tgui
 {
     class Widget;
     class ChildWindow;
@@ -67,7 +64,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         virtual ~Signal() = default;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Constructor
         ///
@@ -81,31 +77,26 @@ TGUI_MODULE_EXPORT namespace tgui
                 m_parameters.resize(1 + extraParameters);
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Copy constructor which will not copy the signal handlers
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         Signal(const Signal& other);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Default move constructor
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         Signal(Signal&& other) noexcept = default;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Copy assignment operator which will not copy the signal handlers
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         Signal& operator=(const Signal& other);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Default move assignment operator
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         Signal& operator=(Signal&& other) noexcept = default;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Connects a signal handler that will be called when this signal is emitted
         ///
@@ -120,7 +111,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return connect(func, args...);
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Connects a signal handler that will be called when this signal is emitted
         ///
@@ -145,7 +135,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return id;
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Connects a signal handler that will be called when this signal is emitted
         ///
@@ -161,7 +150,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return connect([func, name=m_name, args...](){ invokeFunc(func, args..., getWidget(), name); });
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Disconnect a signal handler from this signal
         ///
@@ -171,13 +159,11 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         bool disconnect(unsigned int id);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Disconnect all signal handler from this signal
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void disconnectAll();
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Call all connected signal handlers
         ///
@@ -187,7 +173,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         bool emit(const Widget* widget);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the name given to the signal
         ///
@@ -198,7 +183,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return m_name;
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes whether this signal calls the connected functions when triggered
         ///
@@ -212,7 +196,6 @@ TGUI_MODULE_EXPORT namespace tgui
             m_enabled = enabled;
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns whether this signal calls the connected functions when triggered
         ///
@@ -226,7 +209,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return m_enabled;
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     protected:
 
@@ -235,7 +217,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         static std::shared_ptr<Widget> getWidget();
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Turns the void* parameters back into its original type right before calling the callback function
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -245,7 +226,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return *static_cast<const std::decay_t<Type>*>(m_parameters[paramIndex]);
         }
 
-
 #if defined(__cpp_lib_invoke) && (__cpp_lib_invoke >= 201411L)
         template <typename Func, typename... Args>
         static void invokeFunc(Func&& func, Args&&... args)
@@ -253,7 +233,7 @@ TGUI_MODULE_EXPORT namespace tgui
             std::invoke(std::forward<Func>(func), std::forward<Args>(args)...);
         }
 #else
-        // std::invoke only exists in c++17 so we use our own implementation to support c++14 compilers
+        // std::invoke only exists in C++17 so we use our own implementation to support C++14 compilers
         template <typename Func, typename... Args, typename std::enable_if_t<std::is_member_pointer<std::decay_t<Func>>::value>* = nullptr>
         static void invokeFunc(Func&& func, Args&&... args)
         {
@@ -267,7 +247,6 @@ TGUI_MODULE_EXPORT namespace tgui
         }
 #endif
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     protected:
 
@@ -279,7 +258,6 @@ TGUI_MODULE_EXPORT namespace tgui
         static std::deque<const void*> m_parameters;
     };
 
-
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     /// @brief Signal to which the user can subscribe to get callbacks from
     ///
@@ -299,7 +277,6 @@ TGUI_MODULE_EXPORT namespace tgui
         {
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Connects a signal handler that will be called when this signal is emitted
         ///
@@ -314,7 +291,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return connect(func, args...);
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Connects a signal handler that will be called when this signal is emitted
         ///
@@ -329,7 +305,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return Signal::connect(func, args...);
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Connects a signal handler that will be called when this signal is emitted
         ///
@@ -344,7 +319,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return Signal::connect([=]{ invokeFunc(func, args..., dereferenceParam<T>(1)); });
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Call all connected signal handlers
         ///
@@ -363,7 +337,6 @@ TGUI_MODULE_EXPORT namespace tgui
         }
     };
 
-
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     /// @brief Signal to which the user can subscribe to get callbacks from
     ///
@@ -383,7 +356,6 @@ TGUI_MODULE_EXPORT namespace tgui
         {
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Connects a signal handler that will be called when this signal is emitted
         ///
@@ -398,7 +370,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return connect(func, args...);
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Connects a signal handler that will be called when this signal is emitted
         ///
@@ -413,7 +384,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return Signal::connect(func, args...);
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Connects a signal handler that will be called when this signal is emitted
         ///
@@ -428,7 +398,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return Signal::connect([=]{ invokeFunc(func, args..., dereferenceParam<T1>(1), dereferenceParam<T2>(2)); });
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Call all connected signal handlers
         ///
@@ -459,7 +428,6 @@ TGUI_MODULE_EXPORT namespace tgui
     using SignalFloatRect = SignalTyped<FloatRect>; //!< Signal with one "FloatRect" as optional unbound parameter
     using SignalRange = SignalTyped2<float, float>; //!< Signal with two floats as optional unbound parameters
 
-
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     /// @brief Signal to which the user can subscribe to get callbacks from
     ///
@@ -478,7 +446,6 @@ TGUI_MODULE_EXPORT namespace tgui
         {
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Connects a signal handler that will be called when this signal is emitted
         ///
@@ -493,7 +460,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return connect(func, args...);
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Connects a signal handler that will be called when this signal is emitted
         ///
@@ -508,7 +474,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return Signal::connect(func, args...);
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Connects a signal handler that will be called when this signal is emitted
         ///
@@ -523,7 +488,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return Signal::connect([=]{ invokeFunc(func, args..., dereferenceChildWindow()); });
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Call all connected signal handlers
         ///
@@ -531,8 +495,7 @@ TGUI_MODULE_EXPORT namespace tgui
         ///
         /// @return True when a callback function was executed, false when there weren't any connected callback functions
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        bool emit(ChildWindow* param);
-
+        bool emit(ChildWindow* childWindow);
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     private:
@@ -542,11 +505,9 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         static std::shared_ptr<ChildWindow> dereferenceChildWindow();
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     };
 
-
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     /// @brief Signal to which the user can subscribe to get callbacks from
     ///
@@ -567,7 +528,6 @@ TGUI_MODULE_EXPORT namespace tgui
         {
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Connects a signal handler that will be called when this signal is emitted
         ///
@@ -582,7 +542,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return connect(func, args...);
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Connects a signal handler that will be called when this signal is emitted
         ///
@@ -597,7 +556,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return Signal::connect(func, args...);
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Connects a signal handler that will be called when this signal is emitted
         ///
@@ -612,7 +570,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return Signal::connect([=]{ invokeFunc(func, args..., dereferenceParam<int>(1)); });
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Connects a signal handler that will be called when this signal is emitted
         ///
@@ -627,7 +584,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return Signal::connect([=]{ invokeFunc(func, args..., dereferenceParam<String>(2)); });
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Connects a signal handler that will be called when this signal is emitted
         ///
@@ -642,7 +598,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return Signal::connect([=]{ invokeFunc(func, args..., dereferenceParam<String>(2), dereferenceParam<String>(3)); });
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Call all connected signal handlers
         ///
@@ -655,11 +610,9 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         bool emit(const Widget* widget, int index, const String& item, const String& id);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     };
 
-
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     /// @brief Signal to which the user can subscribe to get callbacks from
     ///
@@ -681,7 +634,6 @@ TGUI_MODULE_EXPORT namespace tgui
             Signal{std::move(name), 3}
         { }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Connects a signal handler that will be called when this signal is emitted
         ///
@@ -696,7 +648,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return connect(func, args...);
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Connects a signal handler that will be called when this signal is emitted
         ///
@@ -711,7 +662,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return Signal::connect(func, args...);
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Connects a signal handler that will be called when this signal is emitted
         ///
@@ -726,7 +676,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return Signal::connect([=] { invokeFunc(func, args..., dereferenceParam<int>(1)); });
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Connects a signal handler that will be called when this signal is emitted
         ///
@@ -741,7 +690,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return Signal::connect([=] { invokeFunc(func, args..., dereferencePanel()); });
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Connects a signal handler that will be called when this signal is emitted
         ///
@@ -756,7 +704,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return Signal::connect([=] { invokeFunc(func, args..., dereferenceParam<String>(3)); });
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Connects a signal handler that will be called when this signal is emitted
         ///
@@ -771,7 +718,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return Signal::connect([=] { invokeFunc(func, args..., dereferenceParam<int>(1), dereferencePanel()); });
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Connects a signal handler that will be called when this signal is emitted
         ///
@@ -786,7 +732,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return Signal::connect([=] { invokeFunc(func, args..., dereferencePanel(), dereferenceParam<String>(3)); });
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Connects a signal handler that will be called when this signal is emitted
         ///
@@ -801,7 +746,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return Signal::connect([=] { invokeFunc(func, args..., dereferenceParam<int>(1), dereferencePanel(), dereferenceParam<String>(3)); });
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Call all connected signal handlers
         ///
@@ -814,7 +758,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         bool emit(const Widget* widget, int index, const std::shared_ptr<Panel>& panel, const String& id);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     private:
 
@@ -823,7 +766,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         static std::shared_ptr<Panel> dereferencePanel();
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     };
 
@@ -928,7 +870,6 @@ TGUI_MODULE_EXPORT namespace tgui
         bool emit(const Widget* widget, const std::vector<Filesystem::Path>& paths);
     };
 
-
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     /// @brief Signal to which the user can subscribe to get callbacks from
     ///
@@ -949,7 +890,6 @@ TGUI_MODULE_EXPORT namespace tgui
         {
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Connects a signal handler that will be called when this signal is emitted
         ///
@@ -964,7 +904,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return connect(func, args...);
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Connects a signal handler that will be called when this signal is emitted
         ///
@@ -979,7 +918,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return Signal::connect(func, args...);
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Connects a signal handler that will be called when this signal is emitted
         ///
@@ -994,7 +932,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return Signal::connect([=]{ invokeFunc(func, args..., dereferenceParam<ShowEffectType>(1)); });
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Connects a signal handler that will be called when this signal is emitted
         ///
@@ -1009,7 +946,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return Signal::connect([=]{ invokeFunc(func, args..., dereferenceParam<bool>(2)); });
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Connects a signal handler that will be called when this signal is emitted
         ///
@@ -1024,7 +960,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return Signal::connect([=]{ invokeFunc(func, args..., dereferenceParam<ShowEffectType>(1), dereferenceParam<bool>(2)); });
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Call all connected signal handlers
         ///
@@ -1036,11 +971,9 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         bool emit(const Widget* widget, ShowEffectType type, bool visible);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     };
 
-
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     /// @brief Signal to which the user can subscribe to get callbacks from
     ///
@@ -1059,7 +992,6 @@ TGUI_MODULE_EXPORT namespace tgui
         {
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Connects a signal handler that will be called when this signal is emitted
         ///
@@ -1074,7 +1006,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return connect(func, args...);
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Connects a signal handler that will be called when this signal is emitted
         ///
@@ -1089,7 +1020,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return Signal::connect(func, args...);
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Connects a signal handler that will be called when this signal is emitted
         ///
@@ -1104,7 +1034,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return Signal::connect([=]{ invokeFunc(func, args..., dereferenceParam<AnimationType>(1)); });
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Call all connected signal handlers
         ///
@@ -1115,11 +1044,9 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         bool emit(const Widget* widget, AnimationType type);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     };
 
-
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     /// @brief Signal to which the user can subscribe to get callbacks from
     ///
@@ -1139,7 +1066,6 @@ TGUI_MODULE_EXPORT namespace tgui
         {
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Connects a signal handler that will be called when this signal is emitted
         ///
@@ -1154,7 +1080,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return connect(func, args...);
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Connects a signal handler that will be called when this signal is emitted
         ///
@@ -1169,7 +1094,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return Signal::connect(func, args...);
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Connects a signal handler that will be called when this signal is emitted
         ///
@@ -1184,7 +1108,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return Signal::connect([=]{ invokeFunc(func, args..., dereferenceParam<String>(1)); });
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Connects a signal handler that will be called when this signal is emitted
         ///
@@ -1199,7 +1122,6 @@ TGUI_MODULE_EXPORT namespace tgui
             return Signal::connect([=]{ invokeFunc(func, args..., dereferenceParam<std::vector<String>>(2)); });
         }
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Call all connected signal handlers
         ///
@@ -1211,7 +1133,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         bool emit(const Widget* widget, const String& item, const std::vector<String>& fullItem);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     };
 
