@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -29,17 +29,15 @@
 #include <TGUI/StringView.hpp>
 #include <TGUI/Utf.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <string>
-    #include <vector>
-    #include <cstring>
-    #include <locale>
-    #include <iomanip>
-    #include <ostream>
-    #include <sstream>
-    #include <type_traits>
-    #include <initializer_list>
-#endif
+#include <string>
+#include <vector>
+#include <cstring>
+#include <locale>
+#include <iomanip>
+#include <ostream>
+#include <sstream>
+#include <type_traits>
+#include <initializer_list>
 
 #if TGUI_HAS_WINDOW_BACKEND_SFML
     #include <SFML/System/String.hpp>
@@ -47,7 +45,7 @@
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-TGUI_MODULE_EXPORT namespace tgui
+namespace tgui
 {
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     /// @brief Checks if a character is a whitespace character (e.g. space, tab, carriage return, line feed, ...)
@@ -77,7 +75,6 @@ TGUI_MODULE_EXPORT namespace tgui
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     TGUI_NODISCARD TGUI_API bool isDigit(char32_t character);
 
-
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     /// @brief Wrapper class to store strings
     ///
@@ -441,7 +438,11 @@ TGUI_MODULE_EXPORT namespace tgui
 #if TGUI_HAS_WINDOW_BACKEND_SFML
         // This constructor has to be explicit or it will cause MSVC to no longer compile code that performs sf::String + std::string
         explicit String(const sf::String& str)
+    #if SFML_VERSION_MAJOR >= 3
+            : m_string{str.toUtf32()}
+    #else
             : m_string{reinterpret_cast<const char32_t*>(str.toUtf32().c_str())}
+    #endif
         {
         }
 
@@ -752,7 +753,7 @@ TGUI_MODULE_EXPORT namespace tgui
         void resize(std::size_t count, char16_t ch);
         void resize(std::size_t count, char32_t ch);
 
-        void swap(String& other);
+        void swap(String& other) noexcept;
 
         TGUI_NODISCARD bool contains(char c) const noexcept;
         TGUI_NODISCARD bool contains(wchar_t c) const noexcept;
@@ -1216,7 +1217,7 @@ TGUI_MODULE_EXPORT namespace tgui
     TGUI_API std::wistream& operator>>(std::wistream& os, String& str);
 
     // UTF-8 function are defined in the header so that they can be enabled/disabled based on
-    // the compiler settings without having to recompile TGUI with a different c++ standard.
+    // the compiler settings without having to recompile TGUI with a different C++ standard.
 #if defined(__cpp_lib_char8_t) && (__cpp_lib_char8_t >= 201811L)
     inline String::String(const std::u8string& str) :
         m_string(utf::convertUtf8toUtf32(str.begin(), str.end()))
