@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -34,21 +34,16 @@
 #include <TGUI/Color.hpp>
 #include <TGUI/Rect.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <functional>
-#endif
+#include <functional>
 
-#if TGUI_HAS_RENDERER_BACKEND_SFML_GRAPHICS && !TGUI_BUILD_AS_CXX_MODULE
-    namespace sf
-    {
-        class Texture;
-        class Shader;
-    }
+#if TGUI_HAS_RENDERER_BACKEND_SFML_GRAPHICS
+    #include <SFML/Graphics/Texture.hpp>
+    #include <SFML/Graphics/Shader.hpp>
 #endif
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-TGUI_MODULE_EXPORT namespace tgui
+namespace tgui
 {
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     /// @brief Texture wrapper that internally reuses resources when multiple Texture objects are loaded from the same file
@@ -311,6 +306,33 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD UIntRect getMiddleRect() const;
 
+        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+        /// @brief Sets whether the corners of the image can still scale with the image size when 9-slice scaling is used
+        ///
+        /// @param scaled  Should the corners be scaled?
+        ///
+        /// @since TGUI 1.10
+        ///
+        /// @warning This property only has an effect if 9-slice scaling is used, which is only when a Middle rect is set.
+        ///
+        /// If this property is set to false (default), then 9-slice scaling happens in the traditional way: the corners always
+        /// keep their size while the rest of the image is stretched. When this property is set to true, the smallest value of
+        /// width or height will determine the scale of the entire image (including the corners) and then the image is scaled
+        /// with 9-slice scaling in one direction (depending on whether width or height is the largest).
+        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+        void setScaledNineSlice(bool scaled);
+
+        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+        /// @brief Returns whether the corners of the image can still scale with the image size when 9-slice scaling is used
+        ///
+        /// @return Should the corners be scaled?
+        ///
+        /// @since TGUI 1.10
+        ///
+        /// @see setScaledNineSlice
+        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+        TGUI_NODISCARD bool getScaledNineSlice() const;
+
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Checks if a certain pixel is transparent
         ///
@@ -434,7 +456,8 @@ TGUI_MODULE_EXPORT namespace tgui
 
         UIntRect m_partRect;
         UIntRect m_middleRect;
-        String  m_id;
+        String   m_id;
+        bool     m_scaledNineSlice = false;
 
         CallbackFunc m_copyCallback;
         CallbackFunc m_destructCallback;
