@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -27,14 +27,12 @@
 
 #include <TGUI/Vector2.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <cstdint>
-    #include <unordered_map>
-#endif
+#include <cstdint>
+#include <unordered_map>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-TGUI_MODULE_EXPORT namespace tgui
+namespace tgui
 {
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     /// @internal
@@ -50,13 +48,13 @@ TGUI_MODULE_EXPORT namespace tgui
         /// @param x         X position of the finger on the window
         /// @param y         Y position of the finger on the window
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        void reportFingerDown(std::intptr_t fingerId, float x, float y);
+        void reportFingerDown(std::uintptr_t fingerId, float x, float y);
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Informs the detector that a touching finger has moved
         /// @param fingerId  Id for the finger that was passed to reportFingerDown when the touch began
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        void reportFingerUp(std::intptr_t fingerId);
+        void reportFingerUp(std::uintptr_t fingerId);
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Informs the detector that a finger stopped touching
@@ -64,7 +62,7 @@ TGUI_MODULE_EXPORT namespace tgui
         /// @param x         X position of the finger on the window
         /// @param y         Y position of the finger on the window
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        void reportFingerMotion(std::intptr_t fingerId, float x, float y);
+        void reportFingerMotion(std::uintptr_t fingerId, float x, float y);
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns whether two fingers are currently being held down and we have detected it as a scroll event
@@ -98,7 +96,7 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     private:
 
-        std::unordered_map<std::intptr_t, Vector2f> m_fingerPositions;
+        std::unordered_map<std::uintptr_t, Vector2f> m_fingerPositions;
         Vector2f m_initialCentroidPosition;
         Vector2f m_lastCentroidPosition;
         bool m_trackingActive = true; // When three fingers touch, we stop trying to detect scrolling until all fingers are released again
