@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -27,9 +27,7 @@
 
 #include <TGUI/Config.hpp>
 #if TGUI_COMPILED_WITH_CPP_VER >= 17
-    #if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-        #include <variant>
-    #endif
+    #include <variant>
 #else
     #include <TGUI/Any.hpp>
     #include <TGUI/Exception.hpp>
@@ -37,7 +35,7 @@
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-TGUI_MODULE_EXPORT namespace tgui
+namespace tgui
 {
 /*
 #if TGUI_COMPILED_WITH_CPP_VER < 17
@@ -83,7 +81,7 @@ TGUI_MODULE_EXPORT namespace tgui
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     /// @internal
-    /// @brief Wrapper around std::variant which will fall back to a custom Any class in c++14 mode
+    /// @brief Wrapper around std::variant which will fall back to a custom Any class in C++14 mode
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 #if TGUI_COMPILED_WITH_CPP_VER >= 17
     template <typename... Types>
