@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -30,13 +30,11 @@
 #include <TGUI/Rect.hpp>
 #include <TGUI/Text.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <regex>
-#endif
+#include <regex>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-TGUI_MODULE_EXPORT namespace tgui
+namespace tgui
 {
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     /// @brief Edit box widget
@@ -76,13 +74,12 @@ TGUI_MODULE_EXPORT namespace tgui
         /// @param initRenderer Should the renderer be initialized? Should be true unless a derived class initializes it.
         /// @see create
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        EditBox(const char* typeName = StaticWidgetType, bool initRenderer = true);
+        explicit EditBox(const char* typeName = StaticWidgetType, bool initRenderer = true);
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Creates a new edit box widget
         ///
         /// @return The new edit box
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD static EditBox::Ptr create();
 
@@ -92,7 +89,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /// @param editBox  The other edit box
         ///
         /// @return The new edit box
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD static EditBox::Ptr copy(const EditBox::ConstPtr& editBox);
 
@@ -114,7 +110,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /// @brief Changes the size of the edit box
         ///
         /// @param size  The new size of the edit box
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void setSize(const Layout2d& size) override;
         using Widget::setSize;
@@ -146,7 +141,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /// @brief Returns the text inside the edit box. This text is not affected by the password character
         ///
         /// @return The text of the edit box
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD const String& getText() const;
 
@@ -156,7 +150,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /// This text is not affected by the password character.
         ///
         /// @param text  The new default text
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void setDefaultText(const String& text);
 
@@ -166,7 +159,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /// This text is not affected by the password character.
         ///
         /// @return The default text of the edit box
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD const String& getDefaultText() const;
 
@@ -177,7 +169,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /// @param length Amount of character to select
         ///
         /// When no parameters are provided, the entire text is selected.
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void selectText(std::size_t start = 0, std::size_t length = String::npos);
 
@@ -185,7 +176,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /// @brief Returns the text that you currently have selected. This text is not affected by the password character
         ///
         /// @return The selected text of the edit box
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD String getSelectedText() const;
 
@@ -207,7 +197,6 @@ TGUI_MODULE_EXPORT namespace tgui
         ///
         /// @return  The password character that is currently being used.
         ///          When no password character is used then this function returns 0
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD char32_t getPasswordCharacter() const;
 
@@ -217,7 +206,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /// @param maxChars  The new character limit. Set it to 0 to disable the limit
         ///
         /// This character limit is disabled by default.
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void setMaximumCharacters(unsigned int maxChars);
 
@@ -228,7 +216,6 @@ TGUI_MODULE_EXPORT namespace tgui
         ///         The function will return 0 when there is no limit
         ///
         /// There is no character limit by default.
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD unsigned int getMaximumCharacters() const;
 
@@ -236,7 +223,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /// @brief Changes the text alignment
         ///
         /// @param alignment  The new text alignment
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void setAlignment(HorizontalAlignment alignment);
 
@@ -244,7 +230,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /// @brief Gets the current text alignment
         ///
         /// @return Text alignment
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD HorizontalAlignment getAlignment() const;
 
@@ -256,7 +241,6 @@ TGUI_MODULE_EXPORT namespace tgui
         ///
         /// When set to true, you will no longer be able to add text when the edit box is full.
         /// The default value is false.
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_DEPRECATED("Use setTextWidthLimited instead") void limitTextWidth(bool limitWidth = true);
 #endif
@@ -277,7 +261,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /// @brief Checks if the text width is limited to the size of the edit box
         ///
         /// @return Is the text width limit or not
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD bool isTextWidthLimited() const;
 
@@ -288,7 +271,6 @@ TGUI_MODULE_EXPORT namespace tgui
         ///
         /// When the edit box is read-only, you can no longer delete characters and type text.
         /// Selecting text, copying text and even calling the setText function will still work.
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void setReadOnly(bool readOnly = true);
 
@@ -299,7 +281,6 @@ TGUI_MODULE_EXPORT namespace tgui
         ///
         /// When the edit box is read-only, you can no longer delete characters and type text.
         /// Selecting text, copying text and even calling the setText function will still work.
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD bool isReadOnly() const;
 
@@ -307,7 +288,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /// @brief Sets the blinking caret to after a specific character
         ///
         /// @param charactersBeforeCaret  The new position
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void setCaretPosition(std::size_t charactersBeforeCaret);
 
@@ -315,7 +295,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /// @brief Returns after which character the blinking cursor is currently located
         ///
         /// @return Characters before the caret
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD std::size_t getCaretPosition() const;
 
@@ -341,7 +320,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /// @brief Returns the regex to which the text is matched
         ///
         /// @return Regex to match the text with on every text change
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD const String& getInputValidator() const;
 
@@ -413,7 +391,6 @@ TGUI_MODULE_EXPORT namespace tgui
         ///
         /// @param target Render target to draw to
         /// @param states Current render states
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void draw(BackendRenderTarget& target, RenderStates states) const override;
 
@@ -435,7 +412,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /// @brief Function called when one of the properties of the renderer is changed
         ///
         /// @param property  Name of the property that was changed
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void rendererChanged(const String& property) override;
 
@@ -509,7 +485,7 @@ TGUI_MODULE_EXPORT namespace tgui
         // Updates m_selEnd with a new value and emits the onCaretPositionChange signal
         // @param newValue the value to assign to m_selEnd.
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        void updateSelEnd(const std::size_t newValue);
+        void updateSelEnd(std::size_t newValue);
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Emits the onReturnOrUnfocus signal.
@@ -522,12 +498,22 @@ TGUI_MODULE_EXPORT namespace tgui
     private:
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        // Handles "Backspace" key press
+        // Handles "Ctrl+Backspace" key press (or equivalent on macOS)
+        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+        void deleteWordLeft();
+
+        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+        // Handles "Ctrl+Delete" key press (or equivalent on macOS)
+        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+        void deleteWordRight();
+
+        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+        // Handles "Backspace" key press (when Ctrl isn't being pressed, otherwise deleteWordLeft is called)
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void backspaceKeyPressed();
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        // Handles "Delete" key press
+        // Handles "Delete" key press (when Ctrl isn't being pressed, otherwise deleteWordRight is called)
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void deleteKeyPressed();
 
@@ -649,6 +635,7 @@ TGUI_MODULE_EXPORT namespace tgui
         Color   m_caretColorHoverCached;
         Color   m_caretColorFocusedCached;
         Color   m_selectedTextBackgroundColorCached;
+        float   m_roundedBorderRadiusCached = 0;
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     private:
