@@ -31,7 +31,7 @@
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-TGUI_MODULE_EXPORT namespace tgui
+namespace tgui
 {
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     /// @brief Edit box slider widget
@@ -53,7 +53,7 @@ TGUI_MODULE_EXPORT namespace tgui
         /// @param initRenderer Should the renderer be initialized? Should be true unless a derived class initializes it.
         /// @see create
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        EditBoxSlider(const char* typeName = StaticWidgetType, bool initRenderer = true);
+        explicit EditBoxSlider(const char* typeName = StaticWidgetType, bool initRenderer = true);
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Copy constructor
@@ -270,7 +270,7 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         // Checks whether a value lies between the minimum and maximum
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        bool inRange(const float value) const;
+        bool inRange(float value) const;
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         // Updates the text in the edit box
