@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -25,7 +25,6 @@
 #ifndef TGUI_FILE_DIALOG_HPP
 #define TGUI_FILE_DIALOG_HPP
 
-#include <TGUI/CopiedSharedPtr.hpp>
 #include <TGUI/Widgets/Label.hpp>
 #include <TGUI/Widgets/Button.hpp>
 #include <TGUI/Widgets/EditBox.hpp>
@@ -35,14 +34,13 @@
 #include <TGUI/Widgets/Panel.hpp>
 #include <TGUI/Renderers/FileDialogRenderer.hpp>
 #include <TGUI/Filesystem.hpp>
+#include <TGUI/Config.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <tuple>
-#endif
+#include <tuple>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-TGUI_MODULE_EXPORT namespace tgui
+namespace tgui
 {
     class FileDialogIconLoader;
 
@@ -76,7 +74,7 @@ TGUI_MODULE_EXPORT namespace tgui
         /// @param initRenderer Should the renderer be initialized? Should be true unless a derived class initializes it.
         /// @see create
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        FileDialog(const char* typeName = StaticWidgetType, bool initRenderer = true);
+        explicit FileDialog(const char* typeName = StaticWidgetType, bool initRenderer = true);
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Creates a new file dialog widget
@@ -508,7 +506,7 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         // Check if the name of a new folder is valid
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        bool isValidFolderName(const String& name);
+        TGUI_NODISCARD static bool isValidFolderName(const String& name);
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         // Initializes the widget pointers after copying or loading the dialog
