@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -27,13 +27,11 @@
 
 #include <TGUI/Container.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <unordered_map>
-#endif
+#include <unordered_map>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-TGUI_MODULE_EXPORT namespace tgui
+namespace tgui
 {
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -52,7 +50,7 @@ TGUI_MODULE_EXPORT namespace tgui
         /// Where in the cell is the widget located?
         /// The widget is centered by default.
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        enum class Alignment
+        enum class Alignment : std::uint8_t
         {
             Center,      //!< Center the widget in the cell
             UpperLeft,   //!< Draw the widget in the upper left corner of the cell
@@ -72,7 +70,7 @@ TGUI_MODULE_EXPORT namespace tgui
         /// @param initRenderer Should the renderer be initialized? Should be true unless a derived class initializes it.
         /// @see create
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        Grid(const char* typeName = StaticWidgetType, bool initRenderer = true);
+        explicit Grid(const char* typeName = StaticWidgetType, bool initRenderer = true);
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Creates a new grid widget
