@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -29,13 +29,11 @@
 #include <TGUI/Renderers/ScrollbarRenderer.hpp>
 #include <TGUI/CopiedSharedPtr.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <chrono>
-#endif
+#include <chrono>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-TGUI_MODULE_EXPORT namespace tgui
+namespace tgui
 {
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     /// @brief Scrollbar widget
@@ -50,7 +48,7 @@ TGUI_MODULE_EXPORT namespace tgui
         static constexpr const char StaticWidgetType[] = "Scrollbar"; //!< Type name of the widget
 
         /// @brief Defines when the scrollbar shows up
-        enum class Policy
+        enum class Policy : std::uint8_t
         {
             Automatic,  //!< Show the scrollbar only when needed (default)
             Always,     //!< Always show the scrollbar, even when the contents fits
@@ -64,7 +62,7 @@ TGUI_MODULE_EXPORT namespace tgui
         /// @param initRenderer Should the renderer be initialized? Should be true unless a derived class initializes it.
         /// @see create
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        Scrollbar(const char* typeName = StaticWidgetType, bool initRenderer = true);
+        explicit Scrollbar(const char* typeName = StaticWidgetType, bool initRenderer = true);
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Creates a new scrollbar widget
@@ -385,7 +383,7 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     protected:
 
-        enum class Part
+        enum class Part : std::uint8_t
         {
             None,
             Track,
@@ -466,7 +464,7 @@ TGUI_MODULE_EXPORT namespace tgui
         /// @brief Default constructor
         /// @param orientation  Whether the scrollbar lies horizontally or vertically
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        ScrollbarChildWidget(Orientation orientation = Orientation::Vertical); // TGUI_NEXT: No more default option
+        explicit ScrollbarChildWidget(Orientation orientation = Orientation::Vertical); // TGUI_NEXT: No more default option
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns whether the left mouse button has been pressed on top of the thumb of the scrollbar
