@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -22,18 +22,16 @@
 //
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-
 #ifndef TGUI_TAB_CONTAINER_HPP
 #define TGUI_TAB_CONTAINER_HPP
 
-
 #include <TGUI/SubwidgetContainer.hpp>
 #include <TGUI/Widgets/Tabs.hpp>
 #include <TGUI/Widgets/Panel.hpp>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-TGUI_MODULE_EXPORT namespace tgui
+namespace tgui
 {
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     /// @brief TabContainer widget
@@ -52,17 +50,15 @@ TGUI_MODULE_EXPORT namespace tgui
 
         static constexpr const char StaticWidgetType[] = "TabContainer"; //!< Type name of the widget
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Enumeration of the tab alignments for tabs
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        enum class TabAlign
+        enum class TabAlign : std::uint8_t
         {
             Top    = 0,      //!< Tabs are above panels
             Bottom = 1 << 0  //!< Tabs are below panels
         };
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @internal
         /// @brief Constructor
@@ -70,33 +66,28 @@ TGUI_MODULE_EXPORT namespace tgui
         /// @param initRenderer Should the renderer be initialized? Should be true unless a derived class initializes it.
         /// @see create
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        TabContainer(const char* typeName = StaticWidgetType, bool initRenderer = true);
-
+        explicit TabContainer(const char* typeName = StaticWidgetType, bool initRenderer = true);
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Copy constructor
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TabContainer(const TabContainer& copy);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Move constructor
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TabContainer(TabContainer&& copy) noexcept;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Overload of copy assignment operator
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TabContainer& operator= (const TabContainer& right);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Overload of move assignment operator
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TabContainer& operator= (TabContainer&& right) noexcept;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Creates a new tab container widget
         ///
@@ -104,7 +95,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD static TabContainer::Ptr create(const Layout2d& size = { "100%", "100%" });
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Makes a copy of another tab container
         ///
@@ -114,7 +104,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD static TabContainer::Ptr copy(const TabContainer::ConstPtr& tabContainer);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the renderer of tabs part of widget
         /// @return Temporary pointer to the renderer that may be shared with other widgets using the same renderer
@@ -129,7 +118,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD TabsRenderer* getTabsRenderer();
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes the size of the tab container
         ///
@@ -138,7 +126,6 @@ TGUI_MODULE_EXPORT namespace tgui
         void setSize(const Layout2d& size) override;
         using Container::setSize;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes the height of tabs part of the widget
         ///
@@ -146,7 +133,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void setTabsHeight(const Layout& height);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Adds a new tab and corresponding panel
         ///
@@ -157,7 +143,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         Panel::Ptr addTab(const String& name, bool select = true);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Inserts a new tab and panel somewhere between the existing ones
         ///
@@ -169,7 +154,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         Panel::Ptr insertTab(std::size_t index, const String& name, bool select = true);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Removes a tab and its corresponding panel, given the text of the tab
         ///
@@ -181,7 +165,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         bool removeTab(const String& text);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Removes a tab and its corresponding panel with a given index
         ///
@@ -193,7 +176,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         bool removeTab(std::size_t index);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Sets selection to panel
         ///
@@ -201,7 +183,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void select(std::size_t index);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the number of holded panels
         ///
@@ -209,7 +190,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD std::size_t getPanelCount() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns index of the specified panel
         ///
@@ -219,7 +199,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD int getIndex(const Panel::Ptr& panel);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the selected panel or nullptr
         ///
@@ -227,7 +206,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD Panel::Ptr getSelected() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns index of the selected panel
         ///
@@ -235,7 +213,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD int getSelectedIndex() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the panel with given index
         ///
@@ -244,7 +221,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD Panel::Ptr getPanel(int index) const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns internal tabs widget
         ///
@@ -252,7 +228,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD Tabs::Ptr getTabs() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Gets the text of one of the tabs
         ///
@@ -261,7 +236,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD String getTabText(std::size_t index) const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes the text of one of the tabs
         ///
@@ -272,7 +246,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         bool changeTabText(std::size_t index, const String& text);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes the alignment of the tabs
         ///
@@ -283,7 +256,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void setTabAlignment(TabAlign align);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the alignment of the tabs
         ///
@@ -291,7 +263,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD TabAlign getTabAlignment() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes the tab fixed size for fixed size alignment
         ///
@@ -303,7 +274,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void setTabFixedSize(float fixedSize);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the tab fixed size for fixed size alignment, default is 0.0f
         ///
@@ -311,7 +281,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD float getTabFixedSize() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns whether the mouse position (which is relative to the parent widget) lies on top of the widget
         ///
@@ -319,7 +288,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD bool isMouseOnWidget(Vector2f pos) const override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     protected:
 
@@ -334,25 +302,21 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD Signal& getSignal(String signalName) override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Makes a copy of the widget
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD Widget::Ptr clone() const override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Saves the widget as a tree of nodes in order to save it to a file
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD std::unique_ptr<DataIO::Node> save(SavingRenderersMap& renderers) const override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Loads the widget from a tree of nodes
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void load(const std::unique_ptr<DataIO::Node>& node, const LoadingRenderersMap& renderers) override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     private:
 
@@ -362,7 +326,6 @@ TGUI_MODULE_EXPORT namespace tgui
 
         void layoutPanel(const Panel::Ptr& panel); // Helper function that sets position of a panel according to the tab alignment
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     public:
 
@@ -373,7 +336,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /// Selection changing can be vetoed if to set second parameter to false in handler.
         SignalTyped2<int, bool*> onSelectionChanging = {"SelectionChanging"};
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     private:
 
