@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -25,19 +25,18 @@
 #ifndef TGUI_TREE_VIEW_HPP
 #define TGUI_TREE_VIEW_HPP
 
-#include <TGUI/CopiedSharedPtr.hpp>
 #include <TGUI/Widgets/Scrollbar.hpp>
 #include <TGUI/Renderers/TreeViewRenderer.hpp>
 #include <TGUI/Text.hpp>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-TGUI_MODULE_EXPORT namespace tgui
+namespace tgui
 {
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     /// @brief Tree view widget
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-    class TGUI_API TreeView : public Widget
+    class TGUI_API TreeView : public Widget, public DualScrollbarChildInterface
     {
     public:
 
@@ -71,7 +70,7 @@ TGUI_MODULE_EXPORT namespace tgui
         /// @param initRenderer Should the renderer be initialized? Should be true unless a derived class initializes it.
         /// @see create
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        TreeView(const char* typeName = StaticWidgetType, bool initRenderer = true);
+        explicit TreeView(const char* typeName = StaticWidgetType, bool initRenderer = true);
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         // Copy constructor
@@ -223,6 +222,83 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD std::vector<String> getSelectedItem() const;
 
+        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+        /// @brief Returns the item currently below the mouse cursor
+        /// @return Hierarchy of items, identifying the node below the mouse, or an empty list when the mouse isn't on any item
+        /// @since TGUI 1.5
+        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+        TGUI_NODISCARD std::vector<String> getHoveredItem() const;
+
+        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+        /// @brief Sets the index of an item, based on the items that share the same parent
+        ///
+        /// @param hierarchy  Hierarchy of items, with the last element being the leaf item
+        /// @param index      The index that the item should have, when only looking at items where only the last element of the
+        ///                   hierarchy is different. Passing a number that is too high will just move the item to the back,
+        ///                   as if you passed to maximum valid number. Passing 0 moves the item to the front.
+        ///
+        /// @return True if the hierarchy matched an item in the tree view, false otherwise.
+        ///
+        /// @see getItemIndexInParent
+        ///
+        /// @since TGUI 1.5
+        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+        bool setItemIndexInParent(const std::vector<String>& hierarchy, std::size_t index);
+
+        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+        /// @brief Returns the index of an item, based on the items that share the same parent
+        ///
+        /// @param hierarchy  Hierarchy of items, with the last element being the leaf item
+        ///
+        /// @return The index of the item identified by the hierarchy, when only looking at items where only the last element
+        ///         of the hierarchy is different. Returns -1 if the hierarchy parameter didn't match an item in the tree view.
+        ///
+        /// In the following example, both A, A1 and B1 would have index 0, while B and A2 would have index 1.
+        /// @code
+        /// A
+        ///   A1
+        ///   A2
+        /// B
+        ///   B1
+        /// @endcode
+        ///
+        /// @since TGUI 1.5
+        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+        int getItemIndexInParent(const std::vector<String>& hierarchy) const;
+
+        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+        /// @brief Moves one item and its children from one location in the hierarchy to a completely different location
+        ///
+        /// @param oldHierarchy  The item that needs to be moved
+        /// @param newHierarchy  The new location of the item
+        ///
+        /// @return True if the node was moved, false if oldHierarchy wasn't found or newHierarchy without the last element wasn't found
+        ///
+        /// Example. Suppose you have the following tree:
+        /// @code
+        /// A
+        ///   A1
+        ///     A1_1
+        ///     A1_2
+        ///   A2
+        /// B
+        ///   B1
+        /// @endcode
+        /// Calling changeItemHierarchy({"A", "A1"}, {"B", "X"}) will result in the following tree:
+        /// @code
+        /// A
+        ///   A2
+        /// B
+        ///   B1
+        ///   X
+        ///     A1_1
+        ///     A1_2
+        /// @endcode
+        ///
+        /// @since TGUI 1.5
+        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+        bool changeItemHierarchy(const std::vector<String>& oldHierarchy, const std::vector<String>& newHierarchy);
+
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the node in the tree view at a given hierarchy
         ///
@@ -260,14 +336,14 @@ TGUI_MODULE_EXPORT namespace tgui
         ///
         /// @param value  New value of the vertical scrollbar
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        void setVerticalScrollbarValue(unsigned int value);
+        TGUI_DEPRECATED("Use getVerticalScrollbar()->setValue(value) instead") void setVerticalScrollbarValue(unsigned int value);
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the thumb position of the vertical scrollbar
         ///
         /// @return Value of the vertical scrollbar
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        TGUI_NODISCARD unsigned int getVerticalScrollbarValue() const;
+        TGUI_DEPRECATED("Use getVerticalScrollbar()->getValue() instead") TGUI_NODISCARD unsigned int getVerticalScrollbarValue() const;
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the maximum thumb position of the vertical scrollbar
@@ -276,21 +352,21 @@ TGUI_MODULE_EXPORT namespace tgui
         ///
         /// @since TGUI 1.4
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        TGUI_NODISCARD unsigned int getVerticalScrollbarMaxValue() const;
+        TGUI_DEPRECATED("Use getVerticalScrollbar()->getMaxValue() instead") TGUI_NODISCARD unsigned int getVerticalScrollbarMaxValue() const;
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes the thumb position of the horizontal scrollbar
         ///
         /// @param value  New value of the horizontal scrollbar
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        void setHorizontalScrollbarValue(unsigned int value);
+        TGUI_DEPRECATED("Use getHorizontalScrollbar()->setValue(value) instead") void setHorizontalScrollbarValue(unsigned int value);
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the thumb position of the horizontal scrollbar
         ///
         /// @return Value of the horizontal scrollbar
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        TGUI_NODISCARD unsigned int getHorizontalScrollbarValue() const;
+        TGUI_DEPRECATED("Use getHorizontalScrollbar()->getValue() instead") TGUI_NODISCARD unsigned int getHorizontalScrollbarValue() const;
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the maximum thumb position of the horizontal scrollbar
@@ -299,7 +375,7 @@ TGUI_MODULE_EXPORT namespace tgui
         ///
         /// @since TGUI 1.4
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        TGUI_NODISCARD unsigned int getHorizontalScrollbarMaxValue() const;
+        TGUI_DEPRECATED("Use getHorizontalScrollbar()->getMaxValue() instead") TGUI_NODISCARD unsigned int getHorizontalScrollbarMaxValue() const;
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns whether the mouse position (which is relative to the parent widget) lies on top of the widget
@@ -408,6 +484,14 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void updateTextSize() override;
 
+        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+        /// @brief Called when the policy of one of the scrollbars has been changed calling either
+        ///        getVerticalScrollbar()->setPolicy(...) or getHorizontalScrollbar()->setPolicy(...)
+        ///
+        /// @param orientation  Vertical or Horizontal depending on which scrollbar triggered the callback
+        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+        void scrollbarPolicyChanged(Orientation orientation) override;
+
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         // Returns the size without the borders
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -436,7 +520,7 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @internal
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        void createNode(std::vector<std::shared_ptr<Node>>& menus, Node* parent, const String& text);
+        void createNode(std::vector<std::shared_ptr<Node>>& nodes, Node* parent, const String& text);
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @internal
@@ -485,7 +569,7 @@ TGUI_MODULE_EXPORT namespace tgui
         SignalItemHierarchy onDoubleClick = {"DoubleClicked"}; //!< A leaf node was double clicked. Optional parameter: selected node
         SignalItemHierarchy onExpand = {"Expanded"};           //!< A branch node was expanded in the tree view. Optional parameter: expanded node
         SignalItemHierarchy onCollapse = {"Collapsed"};        //!< A branch node was collapsed in the tree view. Optional parameter: collapsed node
-        SignalItemHierarchy onRightClick = {"RightClicked"};   //!< A node was right clicked. Optional parameter: node below mouse
+        SignalItemHierarchy onRightClick = {"RightClicked"};   //!< Right mouse button was pressed on top of a node. Optional parameter: node below mouse
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     protected:
@@ -502,9 +586,6 @@ TGUI_MODULE_EXPORT namespace tgui
 
         Vector2f m_iconBounds;
 
-        CopiedSharedPtr<ScrollbarChildWidget> m_verticalScrollbar;
-        CopiedSharedPtr<ScrollbarChildWidget> m_horizontalScrollbar;
-
         bool m_possibleDoubleClick = false;
         int m_doubleClickNodeIndex = -1;
 
