@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -23,17 +23,12 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
 #include <TGUI/Backend/Font/Raylib/BackendFontRaylib.hpp>
-
-#if !TGUI_BUILD_AS_CXX_MODULE
-    #include <TGUI/Backend/Window/Backend.hpp>
-#endif
+#include <TGUI/Backend/Window/Backend.hpp>
 
 #include <raylib.h>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <numeric>
-    #include <cmath>
-#endif
+#include <numeric>
+#include <cmath>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -89,12 +84,22 @@ namespace tgui
             return true;
 
         int codePointInt = static_cast<int>(codePoint);
+#if (RAYLIB_VERSION_MAJOR > 5) || (RAYLIB_VERSION_MAJOR == 5 && RAYLIB_VERSION_MINOR >= 6)
+        int glyphCount;
+        GlyphInfo* glyphsInfo = LoadFontData(m_fileContents.get(), static_cast<int>(m_fileSize), static_cast<int>(scaledTextSize), &codePointInt, 1, FONT_DEFAULT, &glyphCount);
+        if (!glyphsInfo)
+            return false;
+
+        const bool glyphHasBitmap = glyphCount > 0 ? (glyphsInfo[0].image.data != nullptr) : false;
+        UnloadFontData(glyphsInfo, glyphCount);
+#else
         GlyphInfo* glyphsInfo = LoadFontData(m_fileContents.get(), static_cast<int>(m_fileSize), static_cast<int>(scaledTextSize), &codePointInt, 1, FONT_DEFAULT);
         if (!glyphsInfo)
             return false;
 
         const bool glyphHasBitmap = (glyphsInfo[0].image.data != nullptr);
         UnloadFontData(glyphsInfo, 1);
+#endif
         return glyphHasBitmap;
     }
 
@@ -103,6 +108,30 @@ namespace tgui
     int BackendFontRaylib::estimateFontSize(unsigned int scaledTextSize)
     {
         std::array<int, 3> codePoints = {{'a', 'g', 0x00CA}};
+#if (RAYLIB_VERSION_MAJOR > 5) || (RAYLIB_VERSION_MAJOR == 5 && RAYLIB_VERSION_MINOR >= 6)
+        int glyphCount;
+        GlyphInfo* glyphsInfo = LoadFontData(m_fileContents.get(), static_cast<int>(m_fileSize), static_cast<int>(scaledTextSize),
+                                             codePoints.data(), static_cast<int>(codePoints.size()), FONT_DEFAULT, &glyphCount);
+        if (!glyphsInfo)
+            return static_cast<int>(scaledTextSize);
+
+        int ascent;
+        if (glyphCount > 0 && glyphsInfo[glyphCount-1].value == 0x00CA && glyphsInfo[glyphCount-1].image.height) // height of capital e-circumflex
+            ascent = glyphsInfo[glyphCount-1].image.height;
+        else if (glyphCount > 0 && glyphsInfo[0].value == 'a' && glyphsInfo[0].image.height) // height of "a"
+            ascent = glyphsInfo[0].image.height + glyphsInfo[0].offsetY;
+        else // Fall back to just using font size
+            ascent = static_cast<int>(scaledTextSize);
+
+        int descent = 0;
+        for (int i = 0; i < glyphCount; ++i)
+        {
+            if (glyphsInfo[i].image.height)
+                descent = std::max(descent, glyphsInfo[i].image.height + glyphsInfo[i].offsetY - ascent);
+        }
+
+        UnloadFontData(glyphsInfo, static_cast<int>(codePoints.size()));
+#else
         GlyphInfo* glyphsInfo = LoadFontData(m_fileContents.get(), static_cast<int>(m_fileSize), static_cast<int>(scaledTextSize),
                                              codePoints.data(), static_cast<int>(codePoints.size()), FONT_DEFAULT);
         if (!glyphsInfo)
@@ -121,6 +150,7 @@ namespace tgui
             descent = glyphsInfo[1].image.height + glyphsInfo[1].offsetY - ascent;
 
         UnloadFontData(glyphsInfo, static_cast<int>(codePoints.size()));
+#endif
 
         if ((ascent == 0) || (descent == 0))
             return static_cast<int>(scaledTextSize);
@@ -145,10 +175,48 @@ namespace tgui
         {
             m_correctedTextSizes[scaledTextSize] = estimateFontSize(scaledTextSize);
 
-            std::array<int, 97> codePoints;
-            std::iota(codePoints.begin(), codePoints.begin() + 96, 32); // Fill the array with codepoints 32-126
-            codePoints[96] = 0x00CA; // capital e-circumflex to estimate font ascent
+            std::array<int, 96> codePoints;
+            std::iota(codePoints.begin(), codePoints.begin() + 95, 32); // Fill the array with codepoints 32-126
+            codePoints[95] = 0x00CA; // capital e-circumflex to estimate font ascent
 
+#if (RAYLIB_VERSION_MAJOR > 5) || (RAYLIB_VERSION_MAJOR == 5 && RAYLIB_VERSION_MINOR >= 6)
+            int glyphCount;
+            GlyphInfo* glyphsInfo = LoadFontData(m_fileContents.get(), static_cast<int>(m_fileSize),
+                                                 static_cast<int>(m_correctedTextSizes[scaledTextSize]),
+                                                 codePoints.data(), static_cast<int>(codePoints.size()), FONT_DEFAULT, &glyphCount);
+            if (glyphsInfo)
+            {
+                // Raylib has no way of getting the font ascent and only provides a character offset from the top instead of the baseline.
+                // So we try to figure out what the ascent is by getting the height of the capital e-circumflex glyph. If this glyph does
+                // not exist in the font then we will use the height of the "a" glyph plus the offset from the top position.
+                int ascentE = 0;
+                int ascentA = 0;
+                for (int i = 0; i < glyphCount; ++i)
+                {
+                    if (glyphsInfo[i].value == 0x00CA && glyphsInfo[i].image.height)
+                        ascentE = glyphsInfo[i].image.height;
+                    else if (glyphsInfo[i].value == 'a' && glyphsInfo[i].image.height)
+                        ascentA = glyphsInfo[i].image.height + glyphsInfo[i].offsetY;
+                }
+
+                if (ascentE > 0)
+                    m_cachedAscents[scaledTextSize] = ascentE;
+                else if (ascentA > 0)
+                    m_cachedAscents[scaledTextSize] = ascentA;
+                else // Fall back to just using font size
+                    m_cachedAscents[scaledTextSize] = static_cast<int>(scaledTextSize);
+
+                for (std::size_t i = 0; i < static_cast<std::size_t>(glyphCount); ++i)
+                    loadGlyph(glyphsInfo[i], static_cast<char32_t>(codePoints[i]), scaledTextSize, bold, scaledOutlineThickness);
+
+                UnloadFontData(glyphsInfo, glyphCount);
+            }
+            else // We couldn't load the glyphs
+            {
+                m_cachedAscents[scaledTextSize] = static_cast<int>(scaledTextSize);
+                m_glyphs.insert({constructGlyphKey(U'a', scaledTextSize, bold, scaledOutlineThickness), FontGlyph()});
+            }
+#else
             GlyphInfo* glyphsInfo = LoadFontData(m_fileContents.get(), static_cast<int>(m_fileSize),
                                                  static_cast<int>(m_correctedTextSizes[scaledTextSize]),
                                                  codePoints.data(), static_cast<int>(codePoints.size()), FONT_DEFAULT);
@@ -157,8 +225,8 @@ namespace tgui
                 // Raylib has no way of getting the font ascent and only provides a character offset from the top instead of the baseline.
                 // So we try to figure out what the ascent is by getting the height of the capital e-circumflex glyph. If this glyph does
                 // not exist in the font then we will use the height of the "a" glyph plus the offset from the top position.
-                if (glyphsInfo[96].image.height) // height of capital e-circumflex
-                    m_cachedAscents[scaledTextSize] = glyphsInfo[96].image.height;
+                if (glyphsInfo[95].image.height) // height of capital e-circumflex
+                    m_cachedAscents[scaledTextSize] = glyphsInfo[95].image.height;
                 else if (glyphsInfo[97-32].image.height) // height of "a"
                     m_cachedAscents[scaledTextSize] = glyphsInfo[97-32].image.height + glyphsInfo[97-32].offsetY;
                 else // Fall back to just using font size
@@ -174,6 +242,7 @@ namespace tgui
                 m_cachedAscents[scaledTextSize] = static_cast<int>(scaledTextSize);
                 m_glyphs.insert({constructGlyphKey(U'a', scaledTextSize, bold, scaledOutlineThickness), FontGlyph()});
             }
+#endif
 
             // It's possible that we just loaded the glyph that we were searching for
             const auto retryIt = m_glyphs.find(glyphKey);
@@ -182,12 +251,27 @@ namespace tgui
         }
 
         int codePointInt = static_cast<int>(codePoint);
+#if (RAYLIB_VERSION_MAJOR > 5) || (RAYLIB_VERSION_MAJOR == 5 && RAYLIB_VERSION_MINOR >= 6)
+        int glyphCount;
+        GlyphInfo* glyphsInfo = LoadFontData(m_fileContents.get(), static_cast<int>(m_fileSize), static_cast<int>(m_correctedTextSizes[scaledTextSize]), &codePointInt, 1, FONT_DEFAULT, &glyphCount);
+        if (!glyphsInfo || glyphCount == 0)
+        {
+            // If the glyph couldn't be loaded then it's undefined whether the LoadFontData returns a nullptr (because it calls calloc with 0 objects).
+            // In the unlikely event that we only get in this branch because glyphCount is 0 then we must call UnloadFontData. Otherwise it's a no-op.
+            UnloadFontData(glyphsInfo, glyphCount);
+            return m_glyphs.insert({glyphKey, FontGlyph()}).first->second;
+        }
+
+        FontGlyph glyph = loadGlyph(glyphsInfo[0], codePoint, scaledTextSize, bold, scaledOutlineThickness);
+        UnloadFontData(glyphsInfo, glyphCount);
+#else
         GlyphInfo* glyphsInfo = LoadFontData(m_fileContents.get(), static_cast<int>(m_fileSize), static_cast<int>(m_correctedTextSizes[scaledTextSize]), &codePointInt, 1, FONT_DEFAULT);
         if (!glyphsInfo)
             return m_glyphs.insert({glyphKey, FontGlyph()}).first->second;
 
         FontGlyph glyph = loadGlyph(glyphsInfo[0], codePoint, scaledTextSize, bold, scaledOutlineThickness);
         UnloadFontData(glyphsInfo, 1);
+#endif
         return glyph;
     }
 
@@ -211,7 +295,7 @@ namespace tgui
 
     float BackendFontRaylib::getFontHeight(unsigned int characterSize)
     {
-        return getAscent(characterSize) + getDescent(characterSize);
+        return getAscent(characterSize) - getDescent(characterSize);
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -232,10 +316,11 @@ namespace tgui
     float BackendFontRaylib::getDescent(unsigned int characterSize)
     {
         // Raylib doesn't provide a method to access the descent of the font.
-        // We extract the descent by examining the 'g' glyph, assuming it exists.
+        // We extract the descent by examining the 'g' and '_' glyphs, assuming it exists.
         const unsigned int scaledTextSize = static_cast<unsigned int>(characterSize * m_fontScale);
-        const FontGlyph& glyph = getGlyph(U'g', scaledTextSize, false);
-        return glyph.bounds.height + glyph.bounds.top;
+        const FontGlyph& glyphG = getGlyph(U'g', scaledTextSize, false);
+        const FontGlyph& glyphUnderscore = getGlyph(U'_', scaledTextSize, false);
+        return std::min(-glyphG.bounds.height - glyphG.bounds.top, -glyphUnderscore.bounds.height - glyphUnderscore.bounds.top);
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
