@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -26,29 +26,24 @@
 #include <TGUI/Backend/Renderer/BackendText.hpp>
 #include <TGUI/Widget.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <array>
-    #include <cmath>
+#include <algorithm>
+#include <array>
+#include <cmath>
 
-    #if defined(__cpp_lib_math_constants) && (__cpp_lib_math_constants >= 201907L)
-        #include <numbers>
-    #endif
+#if defined(__cpp_lib_math_constants) && (__cpp_lib_math_constants >= 201907L)
+    #include <numbers>
 #endif
 
-/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-
-namespace tgui
+namespace
 {
-    /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-
-    TGUI_NODISCARD static std::vector<Vector2f> drawCircleHelperGetPoints(unsigned int nrPoints, float radius, float offset)
+    TGUI_NODISCARD std::vector<tgui::Vector2f> drawCircleHelperGetPoints(unsigned int nrPoints, float radius, float offset)
     {
 #if defined(__cpp_lib_math_constants) && (__cpp_lib_math_constants >= 201907L)
         const float twoPi = 2.f * std::numbers::pi_v<float>;
 #else
         const float twoPi = 2.f * 3.14159265359f;
 #endif
-        std::vector<Vector2f> points;
+        std::vector<tgui::Vector2f> points;
         points.reserve(nrPoints);
 
         for (unsigned int i = 0; i < nrPoints; ++i)
@@ -62,7 +57,7 @@ namespace tgui
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-    TGUI_NODISCARD static std::vector<Vector2f> drawRoundedRectHelperGetPoints(unsigned int nrCornerPoints, const Vector2f& size, float radius, float offset)
+    TGUI_NODISCARD std::vector<tgui::Vector2f> drawRoundedRectHelperGetPoints(unsigned int nrCornerPoints, const tgui::Vector2f& size, float radius, float offset)
     {
         assert(nrCornerPoints != 0);
 
@@ -71,7 +66,7 @@ namespace tgui
 #else
         const float twoPi = 2.f * 3.14159265359f;
 #endif
-        std::vector<Vector2f> points;
+        std::vector<tgui::Vector2f> points;
         points.reserve(nrCornerPoints * 4);
 
         const unsigned int nrPointsInCircle = 4 * (nrCornerPoints - 1);
@@ -109,18 +104,18 @@ namespace tgui
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-    static void drawBordersAroundShape(BackendRenderTarget* renderTarget, const RenderStates& states,
-                                       const std::vector<Vector2f>& outerPoints, const std::vector<Vector2f>& innerPoints, const Color& color)
+    void drawBordersAroundShape(tgui::BackendRenderTarget* renderTarget, const tgui::RenderStates& states,
+                                const std::vector<tgui::Vector2f>& outerPoints, const std::vector<tgui::Vector2f>& innerPoints, const tgui::Color& color)
     {
         TGUI_ASSERT(outerPoints.size() == innerPoints.size(), "Inner and outer ring of cicle border should have the same amount of points");
 
         // Create the vertices
-        std::vector<Vertex> vertices;
+        std::vector<tgui::Vertex> vertices;
         vertices.reserve(outerPoints.size() + innerPoints.size());
         for (const auto& point : outerPoints)
-            vertices.emplace_back(point, Vertex::Color(color));
+            vertices.emplace_back(point, tgui::Vertex::Color(color));
         for (const auto& point : innerPoints)
-            vertices.emplace_back(point, Vertex::Color(color));
+            vertices.emplace_back(point, tgui::Vertex::Color(color));
 
         // Create the indices
         std::vector<unsigned int> indices;
@@ -147,14 +142,17 @@ namespace tgui
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-    static void drawInnerShape(BackendRenderTarget* renderTarget, const RenderStates& states, const std::vector<Vector2f>& points, const Vector2f& centerPoint, const Color& color)
+    void drawInnerShape(tgui::BackendRenderTarget* renderTarget, const tgui::RenderStates& states, const std::vector<tgui::Vector2f>& points, const tgui::Vector2f& centerPoint, const tgui::Color& color)
     {
+        if (points.empty())
+            return;
+
         // Create the vertices (one point in the middle of the circle and the others as provided in the 'points' parameter)
-        std::vector<Vertex> vertices;
+        std::vector<tgui::Vertex> vertices;
         vertices.reserve(1 + points.size());
-        vertices.emplace_back(centerPoint, Vertex::Color(color));
+        vertices.emplace_back(centerPoint, tgui::Vertex::Color(color));
         for (const auto& point : points)
-            vertices.emplace_back(point, Vertex::Color(color));
+            vertices.emplace_back(point, tgui::Vertex::Color(color));
 
         // Create the indices
         std::vector<unsigned int> indices;
@@ -167,10 +165,15 @@ namespace tgui
         }
         indices.back() = 1; // Last index was one too far and should use the first point again, to close the circle
 
-        // Draw the triangles
+               // Draw the triangles
         renderTarget->drawVertexArray(states, vertices.data(), vertices.size(), indices.data(), indices.size(), nullptr);
     }
+} // anonymous namespace
 
+/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+
+namespace tgui
+{
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     void BackendRenderTarget::setView(FloatRect view, FloatRect viewport, Vector2f targetSize)
@@ -424,7 +427,7 @@ namespace tgui
     void BackendRenderTarget::drawCircle(const RenderStates& states, float size, const Color& backgroundColor, float borderThickness, const Color& borderColor)
     {
         const float radius = size / 2.f;
-        const unsigned int nrPoints = static_cast<unsigned int>(std::ceil((radius + std::abs(borderThickness)) * 4));
+        const auto nrPoints = static_cast<unsigned int>(std::ceil((radius + std::abs(borderThickness)) * 4));
         if (borderThickness > 0)
         {
             const std::vector<Vector2f>& outerPoints = drawCircleHelperGetPoints(nrPoints, radius + borderThickness, -borderThickness);
@@ -454,10 +457,7 @@ namespace tgui
                                                    float radius, const Borders& borders, const Color& borderColor)
     {
         // Radius can never be larger than half the width or height
-        if (radius > size.x / 2)
-            radius = size.x / 2;
-        if (radius > size.y / 2)
-            radius = size.y / 2;
+        radius = std::min({radius, size.x / 2, size.y / 2});
 
         const unsigned int nrCornerPoints = std::max(1u, static_cast<unsigned int>(std::ceil(radius * 2)));
         const std::vector<Vector2f>& outerPoints = drawRoundedRectHelperGetPoints(nrCornerPoints, size, radius, 0);
@@ -467,10 +467,7 @@ namespace tgui
         {
             radius = std::max(0.f, radius - borderWidth);
             const Vector2f innerSize = {std::max(0.f, size.x - 2*borderWidth), std::max(0.f, size.y - 2*borderWidth)};
-            if (radius > innerSize.x / 2)
-                radius = innerSize.x / 2;
-            if (radius > innerSize.y / 2)
-                radius = innerSize.y / 2;
+            radius = std::min({radius, innerSize.x / 2, innerSize.y / 2});
 
             const std::vector<Vector2f>& innerPoints = drawRoundedRectHelperGetPoints(nrCornerPoints, innerSize, radius, borderWidth);
 
