@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -24,9 +24,8 @@
 
 #include <TGUI/Backend/Renderer/BackendText.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <cmath>
-#endif
+#include <algorithm>
+#include <cmath>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -195,8 +194,7 @@ namespace tgui
         if (!m_font)
             return {};
 
-        if (index > m_string.length())
-            index = m_string.length();
+        index = std::min(index, m_string.length());
 
         const bool isBold           = static_cast<unsigned int>(m_style) & TextStyle::Bold;
         const float whitespaceWidth = m_font->getGlyph(U' ', m_characterSize, isBold).advance;
@@ -222,6 +220,7 @@ namespace tgui
                 case ' ':  position.x += whitespaceWidth;             continue;
                 case '\t': position.x += whitespaceWidth * 4;         continue;
                 case '\n': position.y += lineSpacing; position.x = 0; continue;
+                default:                                              break;
             }
 
             // For regular characters, add the advance offset of the glyph
@@ -367,6 +366,8 @@ namespace tgui
                         x = 0;
                         y += lineSpacing;
                         break;
+                    default:
+                        break;
                 }
 
                 // Next glyph, no need to create a quad for whitespace
@@ -378,8 +379,8 @@ namespace tgui
             {
                 const auto& glyph = m_font->getGlyph(curChar, m_characterSize, isBold, m_outlineThickness);
 
-                float top    = glyph.bounds.top;
-                float right  = glyph.bounds.left + glyph.bounds.width;
+                const float top   = glyph.bounds.top;
+                const float right = glyph.bounds.left + glyph.bounds.width;
 
                 // Add the outline glyph to the vertices
                 addGlyphQuad(*m_outlineVertices, {x, y}, vertexOutlineColor, glyph, fontScale, italicShear);
@@ -431,8 +432,8 @@ namespace tgui
         const Vector2u textureSize = m_font->getTextureSize(m_characterSize);
         if ((textureSize.x > 0) && (textureSize.y > 0))
         {
-            const float textureWidth = static_cast<float>(textureSize.x);
-            const float textureHeight = static_cast<float>(textureSize.y);
+            const auto textureWidth = static_cast<float>(textureSize.x);
+            const auto textureHeight = static_cast<float>(textureSize.y);
 
             for (auto& vertex : *m_vertices)
             {
