@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -23,16 +23,11 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
 #include <TGUI/Backend/Renderer/Raylib/BackendRenderTargetRaylib.hpp>
+#include <TGUI/Backend/Renderer/BackendText.hpp>
+#include <TGUI/Backend/Window/Backend.hpp>
+#include <TGUI/Container.hpp>
 
-#if !TGUI_BUILD_AS_CXX_MODULE
-    #include <TGUI/Backend/Renderer/BackendText.hpp>
-    #include <TGUI/Backend/Window/Backend.hpp>
-    #include <TGUI/Container.hpp>
-#endif
-
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <numeric>
-#endif
+#include <numeric>
 
 #include <rlgl.h>
 
