@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -24,10 +24,7 @@
 
 #include <TGUI/Backend/Renderer/Raylib/CanvasRaylib.hpp>
 #include <TGUI/Backend/Renderer/Raylib/BackendRendererRaylib.hpp>
-
-#if !TGUI_BUILD_AS_CXX_MODULE
-    #include <TGUI/Backend/Window/Backend.hpp>
-#endif
+#include <TGUI/Backend/Window/Backend.hpp>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -79,7 +76,7 @@ namespace tgui
     {
         if (this != &right)
         {
-            ClickableWidget::operator=(right);
+            CanvasBase::operator=(right);
             setSize(right.getSize());
         }
 
@@ -109,7 +106,7 @@ namespace tgui
 
     void CanvasRaylib::setSize(const Layout2d& size)
     {
-        Widget::setSize(size);
+        CanvasBase::setSize(size);
         const Vector2f newSize = getSize();
 
         if ((newSize.x > 0) && (newSize.y > 0))
