@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -24,17 +24,12 @@
 
 #include <TGUI/extlibs/IncludeSDL.hpp>
 #include <TGUI/Backend/Renderer/SDL_GPU/BackendRenderTargetSDLGPU.hpp>
+#include <TGUI/Backend/Renderer/BackendText.hpp>
+#include <TGUI/Backend/Window/Backend.hpp>
+#include <TGUI/Container.hpp>
 
-#if !TGUI_BUILD_AS_CXX_MODULE
-    #include <TGUI/Backend/Renderer/BackendText.hpp>
-    #include <TGUI/Backend/Window/Backend.hpp>
-    #include <TGUI/Container.hpp>
-#endif
-
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <numeric>
-    #include <cmath>
-#endif
+#include <numeric>
+#include <cmath>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -454,6 +449,7 @@ namespace tgui
         pipelineCreateInfo.vertex_input_state.vertex_attributes = vertexAttributes.data();
         pipelineCreateInfo.vertex_input_state.num_vertex_attributes = static_cast<std::uint32_t>(vertexAttributes.size());
         pipelineCreateInfo.primitive_type = SDL_GPU_PRIMITIVETYPE_TRIANGLELIST;
+        pipelineCreateInfo.rasterizer_state.enable_depth_clip = true; // Select depth clip because depth clamp has limited support on Android devices
         pipelineCreateInfo.target_info.has_depth_stencil_target = false;
         pipelineCreateInfo.target_info.color_target_descriptions = colorTargetDescriptions.data();
         pipelineCreateInfo.target_info.num_color_targets = static_cast<std::uint32_t>(colorTargetDescriptions.size());
