@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -26,9 +26,7 @@
 #include <TGUI/Backend/Renderer/SFML-Graphics/BackendTextureSFML.hpp>
 #include <TGUI/Backend/Renderer/SFML-Graphics/BackendRenderTargetSFML.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <array>
-#endif
+#include <array>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -74,7 +72,7 @@ namespace tgui
     {
         if (this != &right)
         {
-            ClickableWidget::operator=(right);
+            CanvasBase::operator=(right);
             m_customView = right.m_customView;
             setSize(right.getSize());
         }
@@ -88,7 +86,7 @@ namespace tgui
     {
         if (this != &right)
         {
-            ClickableWidget::operator=(std::move(right));
+            CanvasBase::operator=(std::move(right));
             m_customView = std::move(right.m_customView);
 
 #if SFML_VERSION_MAJOR >= 3
@@ -116,15 +114,14 @@ namespace tgui
     {
         if (canvas)
             return std::static_pointer_cast<CanvasSFML>(canvas->clone());
-        else
-            return nullptr;
+        return nullptr;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     void CanvasSFML::setSize(const Layout2d& size)
     {
-        Widget::setSize(size);
+        CanvasBase::setSize(size);
         const Vector2f newSize = getSize();
 
         if ((newSize.x > 0) && (newSize.y > 0))
@@ -299,7 +296,7 @@ namespace tgui
         }
 
         static_assert(sizeof(Vertex) == sizeof(sf::Vertex), "Size of sf::Vertex has to match with tgui::Vertex for optimization to work");
-        const sf::Vertex* sfmlVertices = reinterpret_cast<const sf::Vertex*>(triangleVertices.get());
+        const auto* sfmlVertices = reinterpret_cast<const sf::Vertex*>(triangleVertices.get());
         m_renderTexture.draw(sfmlVertices, indices.size(), sf::PrimitiveType::Triangles, statesSFML);
     }
 
