@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -109,8 +109,7 @@ namespace tgui
     {
         if (m_fontBackend)
             return {static_cast<const unsigned char*>(defaultFontBytes), sizeof(defaultFontBytes)};
-        else
-            return {};
+        return {};
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -131,9 +130,9 @@ namespace tgui
             sprite->updateVertices();
 
         // Update the size of all texts in all widgets
-        for (auto& gui : m_guis)
+        for (const auto& gui : m_guis)
         {
-            for (auto& widget : gui->getWidgets())
+            for (const auto& widget : gui->getWidgets())
                 widget->updateTextSize();
         }
     }
