@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -24,13 +24,10 @@
 
 #include <TGUI/Backend/Window/GLFW/BackendGuiGLFW.hpp>
 #include <TGUI/Backend/Window/GLFW/BackendGLFW.hpp>
+#include <TGUI/Timer.hpp>
 
-#if !TGUI_BUILD_AS_CXX_MODULE
-    #include <TGUI/Timer.hpp>
-
-    #ifdef TGUI_SYSTEM_WINDOWS
-        #include <TGUI/WindowsIMM.hpp>
-    #endif
+#ifdef TGUI_SYSTEM_WINDOWS
+    #include <TGUI/WindowsIMM.hpp>
 #endif
 
 #define GLFW_INCLUDE_NONE // Don't let GLFW include an OpenGL extention loader
