@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -25,14 +25,12 @@
 #include <TGUI/Backend/Window/Raylib/BackendGuiRaylib.hpp>
 #include <TGUI/Backend/Window/Raylib/BackendRaylib.hpp>
 
-#if !TGUI_BUILD_AS_CXX_MODULE
-    #ifdef TGUI_SYSTEM_WINDOWS
-        // raylib.h and windows.h give conflicts
-        #define NOGDI
-        #define NOUSER
+#ifdef TGUI_SYSTEM_WINDOWS
+    // raylib.h and windows.h give conflicts
+    #define NOGDI
+    #define NOUSER
 
-        #include <TGUI/WindowsIMM.hpp>
-    #endif
+    #include <TGUI/WindowsIMM.hpp>
 #endif
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
