@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -83,6 +83,9 @@ namespace tgui
         case Cursor::Type::NotAllowed:
             typeRaylib = MOUSE_CURSOR_NOT_ALLOWED;
             break;
+        case Cursor::Type::Move:
+            typeRaylib = MOUSE_CURSOR_RESIZE_ALL;
+            break;
         }
 
         SetMouseCursor(typeRaylib);
