@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -44,9 +44,7 @@
     #include <android/asset_manager_jni.h>
 #endif
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <cmath>
-#endif
+#include <cmath>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -363,6 +361,9 @@ namespace tgui
         case Cursor::Type::NotAllowed:
             typeSDL = SDL_SYSTEM_CURSOR_NOT_ALLOWED;
             break;
+        case Cursor::Type::Move:
+            typeSDL = SDL_SYSTEM_CURSOR_MOVE;
+            break;
         }
 #else
         SDL_SystemCursor typeSDL = SDL_SYSTEM_CURSOR_ARROW;
@@ -402,6 +403,9 @@ namespace tgui
         case Cursor::Type::NotAllowed:
             typeSDL = SDL_SYSTEM_CURSOR_NO;
             break;
+        case Cursor::Type::Move:
+            typeSDL = SDL_SYSTEM_CURSOR_SIZEALL;
+            break;
         }
 #endif
         return SDL_CreateSystemCursor(typeSDL);
