@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -25,135 +25,135 @@
 #include <TGUI/Backend/Window/SFML/BackendGuiSFML.hpp>
 #include <TGUI/Backend/Window/SFML/BackendSFML.hpp>
 
-#if !TGUI_BUILD_AS_CXX_MODULE
-    #include <TGUI/ToolTip.hpp>
-    #include <TGUI/Timer.hpp>
+#include <TGUI/ToolTip.hpp>
+#include <TGUI/Timer.hpp>
 
-    #ifdef TGUI_SYSTEM_WINDOWS
-        #include <TGUI/WindowsIMM.hpp>
-    #endif
+#ifdef TGUI_SYSTEM_WINDOWS
+    #include <TGUI/WindowsIMM.hpp>
 #endif
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <thread>
+#include <thread>
+
+namespace
+{
+    TGUI_NODISCARD tgui::Event::KeyboardKey convertKeyCode(sf::Keyboard::Key key)
+    {
+        switch (key)
+        {
+        case sf::Keyboard::Key::A:          return tgui::Event::KeyboardKey::A;
+        case sf::Keyboard::Key::B:          return tgui::Event::KeyboardKey::B;
+        case sf::Keyboard::Key::C:          return tgui::Event::KeyboardKey::C;
+        case sf::Keyboard::Key::D:          return tgui::Event::KeyboardKey::D;
+        case sf::Keyboard::Key::E:          return tgui::Event::KeyboardKey::E;
+        case sf::Keyboard::Key::F:          return tgui::Event::KeyboardKey::F;
+        case sf::Keyboard::Key::G:          return tgui::Event::KeyboardKey::G;
+        case sf::Keyboard::Key::H:          return tgui::Event::KeyboardKey::H;
+        case sf::Keyboard::Key::I:          return tgui::Event::KeyboardKey::I;
+        case sf::Keyboard::Key::J:          return tgui::Event::KeyboardKey::J;
+        case sf::Keyboard::Key::K:          return tgui::Event::KeyboardKey::K;
+        case sf::Keyboard::Key::L:          return tgui::Event::KeyboardKey::L;
+        case sf::Keyboard::Key::M:          return tgui::Event::KeyboardKey::M;
+        case sf::Keyboard::Key::N:          return tgui::Event::KeyboardKey::N;
+        case sf::Keyboard::Key::O:          return tgui::Event::KeyboardKey::O;
+        case sf::Keyboard::Key::P:          return tgui::Event::KeyboardKey::P;
+        case sf::Keyboard::Key::Q:          return tgui::Event::KeyboardKey::Q;
+        case sf::Keyboard::Key::R:          return tgui::Event::KeyboardKey::R;
+        case sf::Keyboard::Key::S:          return tgui::Event::KeyboardKey::S;
+        case sf::Keyboard::Key::T:          return tgui::Event::KeyboardKey::T;
+        case sf::Keyboard::Key::U:          return tgui::Event::KeyboardKey::U;
+        case sf::Keyboard::Key::V:          return tgui::Event::KeyboardKey::V;
+        case sf::Keyboard::Key::W:          return tgui::Event::KeyboardKey::W;
+        case sf::Keyboard::Key::X:          return tgui::Event::KeyboardKey::X;
+        case sf::Keyboard::Key::Y:          return tgui::Event::KeyboardKey::Y;
+        case sf::Keyboard::Key::Z:          return tgui::Event::KeyboardKey::Z;
+        case sf::Keyboard::Key::Num0:       return tgui::Event::KeyboardKey::Num0;
+        case sf::Keyboard::Key::Num1:       return tgui::Event::KeyboardKey::Num1;
+        case sf::Keyboard::Key::Num2:       return tgui::Event::KeyboardKey::Num2;
+        case sf::Keyboard::Key::Num3:       return tgui::Event::KeyboardKey::Num3;
+        case sf::Keyboard::Key::Num4:       return tgui::Event::KeyboardKey::Num4;
+        case sf::Keyboard::Key::Num5:       return tgui::Event::KeyboardKey::Num5;
+        case sf::Keyboard::Key::Num6:       return tgui::Event::KeyboardKey::Num6;
+        case sf::Keyboard::Key::Num7:       return tgui::Event::KeyboardKey::Num7;
+        case sf::Keyboard::Key::Num8:       return tgui::Event::KeyboardKey::Num8;
+        case sf::Keyboard::Key::Num9:       return tgui::Event::KeyboardKey::Num9;
+        case sf::Keyboard::Key::Escape:     return tgui::Event::KeyboardKey::Escape;
+        case sf::Keyboard::Key::LControl:   return tgui::Event::KeyboardKey::LControl;
+        case sf::Keyboard::Key::LShift:     return tgui::Event::KeyboardKey::LShift;
+        case sf::Keyboard::Key::LAlt:       return tgui::Event::KeyboardKey::LAlt;
+        case sf::Keyboard::Key::LSystem:    return tgui::Event::KeyboardKey::LSystem;
+        case sf::Keyboard::Key::RControl:   return tgui::Event::KeyboardKey::RControl;
+        case sf::Keyboard::Key::RShift:     return tgui::Event::KeyboardKey::RShift;
+        case sf::Keyboard::Key::RAlt:       return tgui::Event::KeyboardKey::RAlt;
+        case sf::Keyboard::Key::RSystem:    return tgui::Event::KeyboardKey::RSystem;
+        case sf::Keyboard::Key::Menu:       return tgui::Event::KeyboardKey::Menu;
+        case sf::Keyboard::Key::LBracket:   return tgui::Event::KeyboardKey::LBracket;
+        case sf::Keyboard::Key::RBracket:   return tgui::Event::KeyboardKey::RBracket;
+        case sf::Keyboard::Key::Semicolon:  return tgui::Event::KeyboardKey::Semicolon;
+        case sf::Keyboard::Key::Comma:      return tgui::Event::KeyboardKey::Comma;
+        case sf::Keyboard::Key::Period:     return tgui::Event::KeyboardKey::Period;
+#if SFML_VERSION_MAJOR == 2 && SFML_VERSION_MINOR < 6
+        case sf::Keyboard::Key::Quote:      return tgui::Event::KeyboardKey::Quote;
+#else
+        case sf::Keyboard::Key::Apostrophe: return tgui::Event::KeyboardKey::Quote;
 #endif
+        case sf::Keyboard::Key::Slash:      return tgui::Event::KeyboardKey::Slash;
+        case sf::Keyboard::Key::Backslash:  return tgui::Event::KeyboardKey::Backslash;
+        case sf::Keyboard::Key::Equal:      return tgui::Event::KeyboardKey::Equal;
+        case sf::Keyboard::Key::Hyphen:     return tgui::Event::KeyboardKey::Minus;
+        case sf::Keyboard::Key::Space:      return tgui::Event::KeyboardKey::Space;
+        case sf::Keyboard::Key::Enter:      return tgui::Event::KeyboardKey::Enter;
+        case sf::Keyboard::Key::Backspace:  return tgui::Event::KeyboardKey::Backspace;
+        case sf::Keyboard::Key::Tab:        return tgui::Event::KeyboardKey::Tab;
+        case sf::Keyboard::Key::PageUp:     return tgui::Event::KeyboardKey::PageUp;
+        case sf::Keyboard::Key::PageDown:   return tgui::Event::KeyboardKey::PageDown;
+        case sf::Keyboard::Key::End:        return tgui::Event::KeyboardKey::End;
+        case sf::Keyboard::Key::Home:       return tgui::Event::KeyboardKey::Home;
+        case sf::Keyboard::Key::Insert:     return tgui::Event::KeyboardKey::Insert;
+        case sf::Keyboard::Key::Delete:     return tgui::Event::KeyboardKey::Delete;
+        case sf::Keyboard::Key::Add:        return tgui::Event::KeyboardKey::Add;
+        case sf::Keyboard::Key::Subtract:   return tgui::Event::KeyboardKey::Subtract;
+        case sf::Keyboard::Key::Multiply:   return tgui::Event::KeyboardKey::Multiply;
+        case sf::Keyboard::Key::Divide:     return tgui::Event::KeyboardKey::Divide;
+        case sf::Keyboard::Key::Left:       return tgui::Event::KeyboardKey::Left;
+        case sf::Keyboard::Key::Right:      return tgui::Event::KeyboardKey::Right;
+        case sf::Keyboard::Key::Up:         return tgui::Event::KeyboardKey::Up;
+        case sf::Keyboard::Key::Down:       return tgui::Event::KeyboardKey::Down;
+        case sf::Keyboard::Key::Numpad0:    return tgui::Event::KeyboardKey::Numpad0;
+        case sf::Keyboard::Key::Numpad1:    return tgui::Event::KeyboardKey::Numpad1;
+        case sf::Keyboard::Key::Numpad2:    return tgui::Event::KeyboardKey::Numpad2;
+        case sf::Keyboard::Key::Numpad3:    return tgui::Event::KeyboardKey::Numpad3;
+        case sf::Keyboard::Key::Numpad4:    return tgui::Event::KeyboardKey::Numpad4;
+        case sf::Keyboard::Key::Numpad5:    return tgui::Event::KeyboardKey::Numpad5;
+        case sf::Keyboard::Key::Numpad6:    return tgui::Event::KeyboardKey::Numpad6;
+        case sf::Keyboard::Key::Numpad7:    return tgui::Event::KeyboardKey::Numpad7;
+        case sf::Keyboard::Key::Numpad8:    return tgui::Event::KeyboardKey::Numpad8;
+        case sf::Keyboard::Key::Numpad9:    return tgui::Event::KeyboardKey::Numpad9;
+        case sf::Keyboard::Key::F1:         return tgui::Event::KeyboardKey::F1;
+        case sf::Keyboard::Key::F2:         return tgui::Event::KeyboardKey::F2;
+        case sf::Keyboard::Key::F3:         return tgui::Event::KeyboardKey::F3;
+        case sf::Keyboard::Key::F4:         return tgui::Event::KeyboardKey::F4;
+        case sf::Keyboard::Key::F5:         return tgui::Event::KeyboardKey::F5;
+        case sf::Keyboard::Key::F6:         return tgui::Event::KeyboardKey::F6;
+        case sf::Keyboard::Key::F7:         return tgui::Event::KeyboardKey::F7;
+        case sf::Keyboard::Key::F8:         return tgui::Event::KeyboardKey::F8;
+        case sf::Keyboard::Key::F9:         return tgui::Event::KeyboardKey::F9;
+        case sf::Keyboard::Key::F10:        return tgui::Event::KeyboardKey::F10;
+        case sf::Keyboard::Key::F11:        return tgui::Event::KeyboardKey::F11;
+        case sf::Keyboard::Key::F12:        return tgui::Event::KeyboardKey::F12;
+        case sf::Keyboard::Key::F13:        return tgui::Event::KeyboardKey::F13;
+        case sf::Keyboard::Key::F14:        return tgui::Event::KeyboardKey::F14;
+        case sf::Keyboard::Key::F15:        return tgui::Event::KeyboardKey::F15;
+        case sf::Keyboard::Key::Pause:      return tgui::Event::KeyboardKey::Pause;
+        default: // We don't process the other keys
+            return tgui::Event::KeyboardKey::Unknown;
+        }
+    }
+} // anonymous namespace
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
 namespace tgui
 {
-    TGUI_NODISCARD static Event::KeyboardKey convertKeyCode(sf::Keyboard::Key key)
-    {
-        switch (key)
-        {
-        case sf::Keyboard::Key::A:          return Event::KeyboardKey::A;
-        case sf::Keyboard::Key::B:          return Event::KeyboardKey::B;
-        case sf::Keyboard::Key::C:          return Event::KeyboardKey::C;
-        case sf::Keyboard::Key::D:          return Event::KeyboardKey::D;
-        case sf::Keyboard::Key::E:          return Event::KeyboardKey::E;
-        case sf::Keyboard::Key::F:          return Event::KeyboardKey::F;
-        case sf::Keyboard::Key::G:          return Event::KeyboardKey::G;
-        case sf::Keyboard::Key::H:          return Event::KeyboardKey::H;
-        case sf::Keyboard::Key::I:          return Event::KeyboardKey::I;
-        case sf::Keyboard::Key::J:          return Event::KeyboardKey::J;
-        case sf::Keyboard::Key::K:          return Event::KeyboardKey::K;
-        case sf::Keyboard::Key::L:          return Event::KeyboardKey::L;
-        case sf::Keyboard::Key::M:          return Event::KeyboardKey::M;
-        case sf::Keyboard::Key::N:          return Event::KeyboardKey::N;
-        case sf::Keyboard::Key::O:          return Event::KeyboardKey::O;
-        case sf::Keyboard::Key::P:          return Event::KeyboardKey::P;
-        case sf::Keyboard::Key::Q:          return Event::KeyboardKey::Q;
-        case sf::Keyboard::Key::R:          return Event::KeyboardKey::R;
-        case sf::Keyboard::Key::S:          return Event::KeyboardKey::S;
-        case sf::Keyboard::Key::T:          return Event::KeyboardKey::T;
-        case sf::Keyboard::Key::U:          return Event::KeyboardKey::U;
-        case sf::Keyboard::Key::V:          return Event::KeyboardKey::V;
-        case sf::Keyboard::Key::W:          return Event::KeyboardKey::W;
-        case sf::Keyboard::Key::X:          return Event::KeyboardKey::X;
-        case sf::Keyboard::Key::Y:          return Event::KeyboardKey::Y;
-        case sf::Keyboard::Key::Z:          return Event::KeyboardKey::Z;
-        case sf::Keyboard::Key::Num0:       return Event::KeyboardKey::Num0;
-        case sf::Keyboard::Key::Num1:       return Event::KeyboardKey::Num1;
-        case sf::Keyboard::Key::Num2:       return Event::KeyboardKey::Num2;
-        case sf::Keyboard::Key::Num3:       return Event::KeyboardKey::Num3;
-        case sf::Keyboard::Key::Num4:       return Event::KeyboardKey::Num4;
-        case sf::Keyboard::Key::Num5:       return Event::KeyboardKey::Num5;
-        case sf::Keyboard::Key::Num6:       return Event::KeyboardKey::Num6;
-        case sf::Keyboard::Key::Num7:       return Event::KeyboardKey::Num7;
-        case sf::Keyboard::Key::Num8:       return Event::KeyboardKey::Num8;
-        case sf::Keyboard::Key::Num9:       return Event::KeyboardKey::Num9;
-        case sf::Keyboard::Key::Escape:     return Event::KeyboardKey::Escape;
-        case sf::Keyboard::Key::LControl:   return Event::KeyboardKey::LControl;
-        case sf::Keyboard::Key::LShift:     return Event::KeyboardKey::LShift;
-        case sf::Keyboard::Key::LAlt:       return Event::KeyboardKey::LAlt;
-        case sf::Keyboard::Key::LSystem:    return Event::KeyboardKey::LSystem;
-        case sf::Keyboard::Key::RControl:   return Event::KeyboardKey::RControl;
-        case sf::Keyboard::Key::RShift:     return Event::KeyboardKey::RShift;
-        case sf::Keyboard::Key::RAlt:       return Event::KeyboardKey::RAlt;
-        case sf::Keyboard::Key::RSystem:    return Event::KeyboardKey::RSystem;
-        case sf::Keyboard::Key::Menu:       return Event::KeyboardKey::Menu;
-        case sf::Keyboard::Key::LBracket:   return Event::KeyboardKey::LBracket;
-        case sf::Keyboard::Key::RBracket:   return Event::KeyboardKey::RBracket;
-        case sf::Keyboard::Key::Semicolon:  return Event::KeyboardKey::Semicolon;
-        case sf::Keyboard::Key::Comma:      return Event::KeyboardKey::Comma;
-        case sf::Keyboard::Key::Period:     return Event::KeyboardKey::Period;
-#if SFML_VERSION_MAJOR == 2 && SFML_VERSION_MINOR < 6
-        case sf::Keyboard::Key::Quote:      return Event::KeyboardKey::Quote;
-#else
-        case sf::Keyboard::Key::Apostrophe: return Event::KeyboardKey::Quote;
-#endif
-        case sf::Keyboard::Key::Slash:      return Event::KeyboardKey::Slash;
-        case sf::Keyboard::Key::Backslash:  return Event::KeyboardKey::Backslash;
-        case sf::Keyboard::Key::Equal:      return Event::KeyboardKey::Equal;
-        case sf::Keyboard::Key::Hyphen:     return Event::KeyboardKey::Minus;
-        case sf::Keyboard::Key::Space:      return Event::KeyboardKey::Space;
-        case sf::Keyboard::Key::Enter:      return Event::KeyboardKey::Enter;
-        case sf::Keyboard::Key::Backspace:  return Event::KeyboardKey::Backspace;
-        case sf::Keyboard::Key::Tab:        return Event::KeyboardKey::Tab;
-        case sf::Keyboard::Key::PageUp:     return Event::KeyboardKey::PageUp;
-        case sf::Keyboard::Key::PageDown:   return Event::KeyboardKey::PageDown;
-        case sf::Keyboard::Key::End:        return Event::KeyboardKey::End;
-        case sf::Keyboard::Key::Home:       return Event::KeyboardKey::Home;
-        case sf::Keyboard::Key::Insert:     return Event::KeyboardKey::Insert;
-        case sf::Keyboard::Key::Delete:     return Event::KeyboardKey::Delete;
-        case sf::Keyboard::Key::Add:        return Event::KeyboardKey::Add;
-        case sf::Keyboard::Key::Subtract:   return Event::KeyboardKey::Subtract;
-        case sf::Keyboard::Key::Multiply:   return Event::KeyboardKey::Multiply;
-        case sf::Keyboard::Key::Divide:     return Event::KeyboardKey::Divide;
-        case sf::Keyboard::Key::Left:       return Event::KeyboardKey::Left;
-        case sf::Keyboard::Key::Right:      return Event::KeyboardKey::Right;
-        case sf::Keyboard::Key::Up:         return Event::KeyboardKey::Up;
-        case sf::Keyboard::Key::Down:       return Event::KeyboardKey::Down;
-        case sf::Keyboard::Key::Numpad0:    return Event::KeyboardKey::Numpad0;
-        case sf::Keyboard::Key::Numpad1:    return Event::KeyboardKey::Numpad1;
-        case sf::Keyboard::Key::Numpad2:    return Event::KeyboardKey::Numpad2;
-        case sf::Keyboard::Key::Numpad3:    return Event::KeyboardKey::Numpad3;
-        case sf::Keyboard::Key::Numpad4:    return Event::KeyboardKey::Numpad4;
-        case sf::Keyboard::Key::Numpad5:    return Event::KeyboardKey::Numpad5;
-        case sf::Keyboard::Key::Numpad6:    return Event::KeyboardKey::Numpad6;
-        case sf::Keyboard::Key::Numpad7:    return Event::KeyboardKey::Numpad7;
-        case sf::Keyboard::Key::Numpad8:    return Event::KeyboardKey::Numpad8;
-        case sf::Keyboard::Key::Numpad9:    return Event::KeyboardKey::Numpad9;
-        case sf::Keyboard::Key::F1:         return Event::KeyboardKey::F1;
-        case sf::Keyboard::Key::F2:         return Event::KeyboardKey::F2;
-        case sf::Keyboard::Key::F3:         return Event::KeyboardKey::F3;
-        case sf::Keyboard::Key::F4:         return Event::KeyboardKey::F4;
-        case sf::Keyboard::Key::F5:         return Event::KeyboardKey::F5;
-        case sf::Keyboard::Key::F6:         return Event::KeyboardKey::F6;
-        case sf::Keyboard::Key::F7:         return Event::KeyboardKey::F7;
-        case sf::Keyboard::Key::F8:         return Event::KeyboardKey::F8;
-        case sf::Keyboard::Key::F9:         return Event::KeyboardKey::F9;
-        case sf::Keyboard::Key::F10:        return Event::KeyboardKey::F10;
-        case sf::Keyboard::Key::F11:        return Event::KeyboardKey::F11;
-        case sf::Keyboard::Key::F12:        return Event::KeyboardKey::F12;
-        case sf::Keyboard::Key::F13:        return Event::KeyboardKey::F13;
-        case sf::Keyboard::Key::F14:        return Event::KeyboardKey::F14;
-        case sf::Keyboard::Key::F15:        return Event::KeyboardKey::F15;
-        case sf::Keyboard::Key::Pause:      return Event::KeyboardKey::Pause;
-        default: // We don't process the other keys
-            return Event::KeyboardKey::Unknown;
-        }
-    }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -177,74 +177,11 @@ namespace tgui
 
     bool BackendGuiSFML::handleEvent(sf::Event sfmlEvent)
     {
-        // Detect scrolling with two fingers by examining touch events
-#if SFML_VERSION_MAJOR >= 3
-        if (const auto* sfmlTouchBegan = sfmlEvent.getIf<sf::Event::TouchBegan>())
-        {
-            const auto fingerId = static_cast<std::intptr_t>(sfmlTouchBegan->finger);
-            const float x = static_cast<float>(sfmlTouchBegan->position.x);
-            const float y = static_cast<float>(sfmlTouchBegan->position.y);
-            m_twoFingerScroll.reportFingerDown(fingerId, x, y);
-        }
-
-        if (const auto* sfmlTouchEnded = sfmlEvent.getIf<sf::Event::TouchEnded>())
-        {
-            const auto fingerId = static_cast<std::intptr_t>(sfmlTouchEnded->finger);
-            m_twoFingerScroll.reportFingerUp(fingerId);
-        }
-
-        if (const auto* sfmlTouchMoved = sfmlEvent.getIf<sf::Event::TouchMoved>())
-        {
-            const auto fingerId = static_cast<std::intptr_t>(sfmlTouchMoved->finger);
-            const float x = static_cast<float>(sfmlTouchMoved->position.x);
-            const float y = static_cast<float>(sfmlTouchMoved->position.y);
-
-            const bool wasScrolling = m_twoFingerScroll.isScrolling();
-            m_twoFingerScroll.reportFingerMotion(fingerId, x, y);
-            if (m_twoFingerScroll.isScrolling())
-                return handleTwoFingerScroll(wasScrolling);
-        }
-#else
-        if ((sfmlEvent.type == sf::Event::TouchBegan) || (sfmlEvent.type == sf::Event::TouchEnded) || (sfmlEvent.type == sf::Event::TouchMoved))
-        {
-            const bool wasScrolling = m_twoFingerScroll.isScrolling();
-
-            const auto fingerId = static_cast<std::intptr_t>(sfmlEvent.touch.finger);
-            const float x = static_cast<float>(sfmlEvent.touch.x);
-            const float y = static_cast<float>(sfmlEvent.touch.y);
-
-            if (sfmlEvent.type == sf::Event::TouchBegan)
-                m_twoFingerScroll.reportFingerDown(fingerId, x, y);
-            else if (sfmlEvent.type == sf::Event::TouchEnded)
-                m_twoFingerScroll.reportFingerUp(fingerId);
-            else if (sfmlEvent.type == sf::Event::TouchMoved)
-            {
-                m_twoFingerScroll.reportFingerMotion(fingerId, x, y);
-                if (m_twoFingerScroll.isScrolling())
-                    return handleTwoFingerScroll(wasScrolling);
-            }
-        }
-#endif
         // Convert the event to our own type so that we can process it in a backend-independent way afterwards
         Event event;
         if (!convertEvent(sfmlEvent, event))
             return false; // We don't process this type of event
 
-#if SFML_VERSION_MAJOR >= 3
-        if ((event.type == Event::Type::MouseButtonPressed) && sfmlEvent.is<sf::Event::TouchBegan>())
-#else
-        if ((event.type == Event::Type::MouseButtonPressed) && (sfmlEvent.type == sf::Event::TouchBegan))
-#endif
-        {
-            // For touches, always send a mouse move event before the mouse press,
-            // because widgets may assume that the mouse had to move to the clicked location first
-            Event mouseMoveEvent;
-            mouseMoveEvent.type = Event::Type::MouseMoved;
-            mouseMoveEvent.mouseMove.x = event.mouseButton.x;
-            mouseMoveEvent.mouseMove.y = event.mouseButton.y;
-            handleEvent(mouseMoveEvent);
-        }
-
         return handleEvent(event);
     }
 
@@ -262,8 +199,7 @@ namespace tgui
             Optional<Duration> duration = Timer::getNextScheduledTime();
             if (duration && (*duration < std::chrono::milliseconds(10)))
                 return *duration;
-            else
-                return Duration{std::chrono::milliseconds(10)};
+            return Duration{std::chrono::milliseconds(10)};
         };
 
         setDrawingUpdatesTime(false);
@@ -519,39 +455,28 @@ namespace tgui
 
         if (const auto* eventTouchMoved = eventSFML.getIf<sf::Event::TouchMoved>())
         {
-            if (eventTouchMoved->finger != 0)
-                return false; // Only the first finger is handled
-
-            // Simulate a MouseMoved event
-            eventTGUI.type = Event::Type::MouseMoved;
-            eventTGUI.mouseMove.x = eventTouchMoved->position.x;
-            eventTGUI.mouseMove.y = eventTouchMoved->position.y;
+            eventTGUI.type = Event::Type::FingerMoved;
+            eventTGUI.touch.fingerId = static_cast<std::uintptr_t>(eventTouchMoved->finger) + 1;
+            eventTGUI.touch.x = eventTouchMoved->position.x;
+            eventTGUI.touch.y = eventTouchMoved->position.y;
             return true;
         }
 
         if (const auto* eventTouchBegan = eventSFML.getIf<sf::Event::TouchBegan>())
         {
-            if (eventTouchBegan->finger != 0)
-                return false; // Only the first finger is handled
-
-            // Simulate a MouseButtonPressed event
-            eventTGUI.type = Event::Type::MouseButtonPressed;
-            eventTGUI.mouseButton.button = Event::MouseButton::Left;
-            eventTGUI.mouseButton.x = eventTouchBegan->position.x;
-            eventTGUI.mouseButton.y = eventTouchBegan->position.y;
+            eventTGUI.type = Event::Type::FingerDown;
+            eventTGUI.touch.fingerId = static_cast<std::uintptr_t>(eventTouchBegan->finger) + 1;
+            eventTGUI.touch.x = eventTouchBegan->position.x;
+            eventTGUI.touch.y = eventTouchBegan->position.y;
             return true;
         }
 
         if (const auto* eventTouchEnded = eventSFML.getIf<sf::Event::TouchEnded>())
         {
-            if (eventTouchEnded->finger != 0)
-                return false; // Only the first finger is handled
-
-            // Simulate a MouseButtonReleased event
-            eventTGUI.type = Event::Type::MouseButtonReleased;
-            eventTGUI.mouseButton.button = Event::MouseButton::Left;
-            eventTGUI.mouseButton.x = eventTouchEnded->position.x;
-            eventTGUI.mouseButton.y = eventTouchEnded->position.y;
+            eventTGUI.type = Event::Type::FingerUp;
+            eventTGUI.touch.fingerId = static_cast<std::uintptr_t>(eventTouchEnded->finger) + 1;
+            eventTGUI.touch.x = eventTouchEnded->position.x;
+            eventTGUI.touch.y = eventTouchEnded->position.y;
             return true;
         }
 
@@ -692,30 +617,26 @@ namespace tgui
             }
             case sf::Event::TouchMoved:
             {
-                if (eventSFML.touch.finger != 0)
-                    return false; // Only the first finger is handled
-
-                // Simulate a MouseMoved event
-                eventTGUI.type = Event::Type::MouseMoved;
-                eventTGUI.mouseMove.x = eventSFML.touch.x;
-                eventTGUI.mouseMove.y = eventSFML.touch.y;
+                eventTGUI.type = Event::Type::FingerMoved;
+                eventTGUI.touch.fingerId = static_cast<std::uintptr_t>(eventSFML.touch.finger) + 1;
+                eventTGUI.touch.x = eventSFML.touch.x;
+                eventTGUI.touch.y = eventSFML.touch.y;
                 return true;
             }
             case sf::Event::TouchBegan:
+            {
+                eventTGUI.type = Event::Type::FingerDown;
+                eventTGUI.touch.fingerId = static_cast<std::uintptr_t>(eventSFML.touch.finger) + 1;
+                eventTGUI.touch.x = eventSFML.touch.x;
+                eventTGUI.touch.y = eventSFML.touch.y;
+                return true;
+            }
             case sf::Event::TouchEnded:
             {
-                if (eventSFML.touch.finger != 0)
-                    return false; // Only the first finger is handled
-
-                // Simulate a MouseButtonPressed or MouseButtonReleased event
-                if (eventSFML.type == sf::Event::TouchBegan)
-                    eventTGUI.type = Event::Type::MouseButtonPressed;
-                else
-                    eventTGUI.type = Event::Type::MouseButtonReleased;
-
-                eventTGUI.mouseButton.button = Event::MouseButton::Left;
-                eventTGUI.mouseButton.x = eventSFML.touch.x;
-                eventTGUI.mouseButton.y = eventSFML.touch.y;
+                eventTGUI.type = Event::Type::FingerUp;
+                eventTGUI.touch.fingerId = static_cast<std::uintptr_t>(eventSFML.touch.finger) + 1;
+                eventTGUI.touch.x = eventSFML.touch.x;
+                eventTGUI.touch.y = eventSFML.touch.y;
                 return true;
             }
             default: // This event is not handled by TGUI
