@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -24,9 +24,7 @@
 
 #include <TGUI/Backend/Window/SFML/BackendSFML.hpp>
 
-#if !TGUI_BUILD_AS_CXX_MODULE
-    #include <TGUI/Timer.hpp>
-#endif
+#include <TGUI/Timer.hpp>
 
 #include <SFML/Config.hpp>
 #include <SFML/Window/Window.hpp>
@@ -310,14 +308,22 @@ namespace tgui
         case Cursor::Type::NotAllowed:
             typeSFML = sf::Cursor::Type::NotAllowed;
             break;
+        case Cursor::Type::Move:
+#ifdef TGUI_SYSTEM_MACOS
+            // SFML does not support the SizeAll cursor on macOS. Other backends use a grabbing hand cursor on macOS,
+            // but SFML does not support this so we fall back to the crosshair cursor to at least show something.
+            typeSFML = sf::Cursor::Type::Cross;
+#else
+            typeSFML = sf::Cursor::Type::SizeAll;
+#endif
+            break;
         }
 
 #if SFML_VERSION_MAJOR >= 3
         auto cursor = sf::Cursor::createFromSystem(typeSFML);
         if (cursor)
             return std::make_unique<sf::Cursor>(std::move(*cursor));
-        else
-            return nullptr;
+        return nullptr;
 #else
         auto cursor = std::make_unique<sf::Cursor>();
         if (cursor->loadFromSystem(typeSFML))
