@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -234,7 +234,7 @@ namespace dev
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-    void swap(Component& first, Component& second)
+    void swap(Component& first, Component& second) noexcept
     {
         using std::swap;
         swap(first.m_state, second.m_state);
@@ -334,7 +334,7 @@ namespace dev
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-    void swap(GroupComponent& first, GroupComponent& second)
+    void swap(GroupComponent& first, GroupComponent& second) noexcept
     {
         using std::swap;
         swap(static_cast<Component&>(first), static_cast<Component&>(second));
@@ -491,11 +491,10 @@ namespace dev
         {
             if ((pos.x < m_borders.getLeft()) || (pos.y < m_borders.getTop()) || (pos.x >= m_borders.getLeft() + m_clientSize.x) || (pos.y >= m_borders.getTop() + m_clientSize.y))
                 return false;
-            else
-                return m_sprite.isTransparentPixel(pos - m_borders.getOffset());
+            return m_sprite.isTransparentPixel(pos - m_borders.getOffset());
         }
-        else /// TODO: Perform check when using rounded corners
-            return false;
+        /// TODO: Perform check when using rounded corners
+        return false;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -849,8 +848,7 @@ namespace dev
     {
         if (transparentTexture && m_sprite.isSet()) /// TODO: transparentTexture should be option on Texture (similar to Smooth) instead of a parameter
             return m_sprite.isTransparentPixel(pos);
-        else
-            return false;
+        return false;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
