@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -67,7 +67,7 @@ namespace tgui
         TGUI_NODISCARD bool supportsSystemIcons() const override;
         TGUI_NODISCARD bool hasGenericIcons() const override;
         TGUI_NODISCARD Texture getGenericFileIcon(const Filesystem::FileInfo& file) override;
-        void requestFileIcons(const std::vector<Filesystem::FileInfo>&) override;
+        void requestFileIcons(const std::vector<Filesystem::FileInfo>& files) override;
         TGUI_NODISCARD std::vector<Texture> retrieveFileIcons() override;
 
     private:
@@ -192,8 +192,9 @@ namespace tgui
                     requestFileIcons(m_files);
                     return false; // Wait until icons are loaded
                 }
-                else // No file list was provided for detailed icons, but generic file/folder icons can now be used
-                    return true;
+
+                // No file list was provided for detailed icons, but generic file/folder icons can now be used
+                return true;
             }
         }
         else if (m_loadFileIconsThreadStarted)
@@ -443,8 +444,8 @@ namespace tgui
                 if (iconFile.directory || (iconFile.filename.length() <= 4))
                     continue;
 
-                const bool isSvg = iconFile.filename.compare(iconFile.filename.length() - 4, 4, U".svg") == 0;
-                const bool isPng = iconFile.filename.compare(iconFile.filename.length() - 4, 4, U".png") == 0;
+                const bool isSvg = iconFile.filename.ends_with(U".svg");
+                const bool isPng = iconFile.filename.ends_with(U".png");
                 if (!isSvg && !isPng)
                     continue;
 
