@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -24,13 +24,12 @@
 
 #include <TGUI/Global.hpp>
 #include <TGUI/Backend/Window/Backend.hpp>
+#include "TGUI/Exception.hpp"
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <functional>
-    #include <sstream>
-    #include <locale>
-    #include <limits>
-#endif
+#include <functional>
+#include <sstream>
+#include <locale>
+#include <limits>
 
 #include <stdio.h> // C header for compatibility with _wfopen_s, NOLINT(modernize-deprecated-headers)
 
@@ -40,7 +39,7 @@
 namespace
 {
     // Many compilers don't seem to support std::stringstream::view() yet, but I don't want to
-    // limit the use of other c++20 features. So in c++20 mode we just check if the function exists.
+    // limit the use of other C++20 features. So in C++20 mode we just check if the function exists.
 
     // This struct will be used when the view() member doesn't exist.
     template <typename StreamType, typename = void>
@@ -175,8 +174,11 @@ namespace tgui
             if (!rawFilePtr)
                 return nullptr;
 
-            auto closeFileFunc = [](FILE* fp){ fclose(fp); };
-            std::unique_ptr<FILE, decltype(closeFileFunc)> file(rawFilePtr, closeFileFunc);
+            const auto closeFileFunc = [](FILE* fp){
+                if (fclose(fp))
+                    throw tgui::Exception{U"Failed to fclose file, error: " + tgui::String(std::system_error(errno, std::generic_category()).what())};
+            };
+            const std::unique_ptr<FILE, decltype(closeFileFunc)> file(rawFilePtr, closeFileFunc);
 
             if (fseek(file.get(), 0, SEEK_END) != 0)
                 return nullptr;
