@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -28,9 +28,7 @@
 #include <TGUI/Exception.hpp>
 #include <TGUI/Base64.hpp>
 
-#if !TGUI_BUILD_AS_CXX_MODULE
-    #include <TGUI/extlibs/IncludeStbImageWrite.hpp>
-#endif
+#include <TGUI/extlibs/IncludeStbImageWrite.hpp>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -46,18 +44,17 @@ namespace tgui
 
             if (c == 10)
                 return 'A';
-            else if (c == 11)
+            if (c == 11)
                 return 'B';
-            else if (c == 12)
+            if (c == 12)
                 return 'C';
-            else if (c == 13)
+            if (c == 13)
                 return 'D';
-            else if (c == 14)
+            if (c == 14)
                 return 'E';
-            else if (c == 15)
+            if (c == 15)
                 return 'F';
-            else
-                return static_cast<char>(c + '0');
+            return static_cast<char>(c + '0');
         }
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -80,8 +77,7 @@ namespace tgui
         {
             if (value.getBool())
                 return "true";
-            else
-                return "false";
+            return "false";
         }
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -90,15 +86,14 @@ namespace tgui
         {
             if (value.getFont() && !value.getFont().getId().empty())
                 return Serializer::serialize({value.getFont().getId()});
-            else
-                return "null";
+            return "null";
         }
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
         String serializeColor(ObjectConverter&& value)
         {
-            Color color = value.getColor();
+            const Color color = value.getColor();
 
             if (!color.isSet())
                 return "None";
@@ -178,7 +173,7 @@ namespace tgui
 
         String serializeTexture(ObjectConverter&& value)
         {
-            Texture texture = value.getTexture();
+            const Texture texture = value.getTexture();
             if (!texture.getData())
                 return "None";
 
@@ -251,8 +246,8 @@ namespace tgui
 
             if (!encodedStyle.empty())
                 return encodedStyle.substr(3);
-            else // Something is wrong with the style parameter
-                return "Regular";
+            // Something is wrong with the style parameter
+            return "Regular";
         }
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
