@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -23,7 +23,6 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
 #include <TGUI/Loading/Theme.hpp>
-#include <TGUI/Loading/Serializer.hpp>
 #include <TGUI/Widget.hpp>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -319,7 +318,18 @@ namespace tgui
                                                        {"BackgroundColorHover", Color::White},
                                                        {"SelectedBackgroundColor", Color{0, 110, 255}},
                                                        {"SelectedBackgroundColorHover", Color{30, 150, 255}}})},
-                    {"VerticalLayout", RendererData::create({})}
+                    {"VerticalLayout", RendererData::create({})},
+                    {"VerticalTabs", RendererData::create({{"Borders", Borders{1}},
+                                                           {"BorderColor", Color::Black},
+                                                           {"TextColor", Color{60, 60, 60}},
+                                                           {"TextColorHover", Color::Black},
+                                                           {"TextColorDisabled", Color{125, 125, 125}},
+                                                           {"SelectedTextColor", Color::White},
+                                                           {"BackgroundColor", Color{245, 245, 245}},
+                                                           {"BackgroundColorHover", Color::White},
+                                                           {"BackgroundColorDisabled", Color{230, 230, 230}},
+                                                           {"SelectedBackgroundColor", Color{0, 110, 255}},
+                                                           {"SelectedBackgroundColorHover", Color{30, 150, 255}}})},
                };
 
                 for (const auto& pair : m_renderers)
@@ -343,6 +353,7 @@ namespace tgui
         {"PanelListBox", "ScrollablePanel"},
         {"ToggleButton", "Button"},
         {"TreeView", "ListBox"},
+        {"VerticalTabs", "Tabs"},
     };
 
     std::map<String, std::map<String, String>> Theme::m_rendererDefaultSubwidgets = {
@@ -550,6 +561,14 @@ namespace tgui
             {"TextColorDown", "SelectedTextColor"},
             {"BackgroundColorDown", "SelectedBackgroundColor"},
         }},
+        {"VerticalTabs", {
+            {"BackgroundColor", ""},
+            {"SelectedBackgroundColor", ""},
+            {"TextColor", ""},
+            {"SelectedTextColor", ""},
+            {"BorderColor", ""},
+            {"Borders", ""},
+        }},
     };
 
     std::shared_ptr<Theme> Theme::m_defaultTheme = nullptr;
@@ -682,7 +701,7 @@ namespace tgui
             for (const auto& property : properties)
                 renderer->propertyValuePairs[property.first] = ObjectConverter(property.second);
 
-            for (auto& observer : renderer->observers)
+            for (const auto& observer : renderer->observers)
                 observer->setRenderer(renderer);
         }
     }
@@ -734,7 +753,7 @@ namespace tgui
         // We do this in a separate loop because all renderers need to be replaced before
         // we tell the observers (because e.g. an observer of the BitmapButton renderer might
         // want to access the Button renderer of the theme to inherit properties).
-        for (auto pair : m_renderers)
+        for (const auto& pair : m_renderers)
         {
             const auto& renderer = pair.second;
 
@@ -772,7 +791,7 @@ namespace tgui
 
         m_renderers[id] = RendererData::create();
         m_renderers[id]->connectedTheme = this;
-        auto& properties = m_themeLoader->load(m_primary, id);
+        const auto& properties = m_themeLoader->load(m_primary, id);
         for (const auto& property : properties)
             m_renderers[id]->propertyValuePairs[property.first] = ObjectConverter(property.second);
 
@@ -808,8 +827,7 @@ namespace tgui
         auto propertyIt = m_globalProperties.find(property);
         if (propertyIt != m_globalProperties.end())
             return propertyIt->second;
-        else
-            return {};
+        return {};
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -845,8 +863,7 @@ namespace tgui
             m_renderers.erase(it);
             return true;
         }
-        else
-            return false;
+        return false;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
