@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -26,10 +26,7 @@
 #include <TGUI/Loading/Deserializer.hpp>
 #include <TGUI/Loading/WidgetFactory.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <sstream>
-    #include <fstream>
-#endif
+#include <sstream>
 
 // Ignore warning "C4503: decorated name length exceeded, name was truncated" in Visual Studio
 #if defined _MSC_VER
@@ -64,7 +61,7 @@ namespace tgui
     {
         for (const auto& pair : node->propertyValuePairs)
         {
-            if (((pair.first.size() >= 7) && (pair.first.substr(0, 7) == U"Texture")) || (pair.first == U"Font") || (pair.first == U"Image") || (pair.first == U"Icon"))
+            if (((pair.first.size() >= 7) && (pair.first.starts_with(U"Texture"))) || (pair.first == U"Font") || (pair.first == U"Image") || (pair.first == U"Icon"))
             {
                 if (pair.second->value.empty() || viewEqualIgnoreCase(pair.second->value, U"none") || viewEqualIgnoreCase(pair.second->value, U"null") || viewEqualIgnoreCase(pair.second->value, U"nullptr"))
                     continue;
@@ -150,7 +147,7 @@ namespace tgui
 
     void DefaultThemeLoader::flushCache(const String& filename)
     {
-        if (filename != U"")
+        if (!filename.empty())
         {
             m_propertiesCache.erase(filename);
             m_globalPropertiesCache.erase(filename);
@@ -166,7 +163,7 @@ namespace tgui
 
     void DefaultThemeLoader::preload(const String& filename)
     {
-        if (filename == U"")
+        if (filename.empty())
             return;
 
         // Load the file when not already in cache
@@ -242,8 +239,7 @@ namespace tgui
     {
         if (filename.empty())
             return true;
-        else
-            return m_propertiesCache[filename].find(section) != m_propertiesCache[filename].end();
+        return m_propertiesCache[filename].find(section) != m_propertiesCache[filename].end();
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
