@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -23,7 +23,6 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
 #include <TGUI/Renderers/BoxLayoutRenderer.hpp>
-#include <TGUI/RendererDefines.hpp>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -43,17 +42,13 @@ namespace tgui
         auto it = m_data->propertyValuePairs.find("SpaceBetweenWidgets");
         if (it != m_data->propertyValuePairs.end())
             return it->second.getNumber();
-        else
+        it = m_data->propertyValuePairs.find("Padding");
+        if (it != m_data->propertyValuePairs.end())
         {
-            it = m_data->propertyValuePairs.find("Padding");
-            if (it != m_data->propertyValuePairs.end())
-            {
-                const Padding padding = it->second.getOutline();
-                return std::max(std::min(padding.getLeft(), padding.getRight()), std::min(padding.getTop(), padding.getBottom()));
-            }
-            else
-                return 0;
+            const Padding padding = it->second.getOutline();
+            return std::max(std::min(padding.getLeft(), padding.getRight()), std::min(padding.getTop(), padding.getBottom()));
         }
+        return 0;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
