@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -59,14 +59,11 @@ namespace tgui
         auto it = m_data->propertyValuePairs.find("TitleBarHeight");
         if (it != m_data->propertyValuePairs.end())
             return it->second.getNumber();
-        else
-        {
-            it = m_data->propertyValuePairs.find("TextureTitleBar");
-            if (it != m_data->propertyValuePairs.end() && it->second.getTexture().getData())
-                return static_cast<float>(it->second.getTexture().getImageSize().y);
-            else
-                return 20;
-        }
+
+        it = m_data->propertyValuePairs.find("TextureTitleBar");
+        if (it != m_data->propertyValuePairs.end() && it->second.getTexture().getData())
+            return static_cast<float>(it->second.getTexture().getImageSize().y);
+        return 20;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
