@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -27,9 +27,7 @@
 #include <TGUI/Optional.hpp>
 #include <TGUI/Backend/Window/Backend.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <cmath>
-#endif
+#include <cmath>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -295,8 +293,8 @@ namespace tgui
 
         // Find out on which pixel the mouse is standing
         Vector2f pixel;
-        FloatRect middleRect = FloatRect{m_texture.getMiddleRect()};
-        Vector2u imageSize = m_texture.getImageSize();
+        const FloatRect middleRect = FloatRect{m_texture.getMiddleRect()};
+        const Vector2u imageSize = m_texture.getImageSize();
         switch (m_scalingType)
         {
             case ScalingType::Normal:
