@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -24,17 +24,29 @@
 
 #include <TGUI/String.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <algorithm>
-    #include <cctype> // tolower, toupper, isspace
-    #include <cwctype> // iswspace, iswalpha
-    #include <iterator> // distance
+#include <algorithm>
+#include <cctype> // tolower, toupper, isspace
+#include <cwctype> // iswspace, iswalpha
+#include <iterator> // distance
 
-    #if TGUI_COMPILED_WITH_CPP_VER >= 17
-        #include <charconv> // from_chars
-    #endif
+#if TGUI_COMPILED_WITH_CPP_VER >= 17
+    #include <charconv> // from_chars
 #endif
 
+namespace
+{
+    //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+
+    TGUI_NODISCARD inline bool compareCharIgnoreCase(char32_t char1, char32_t char2) {
+        if (char1 == char2)
+            return true;
+        if ((char1 < 128) && (char2 < 128))
+            return std::tolower(static_cast<unsigned char>(char1)) == std::tolower(static_cast<unsigned char>(char2));
+        return false;
+    }
+
+} // anonymous namespace
+
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
 namespace tgui
@@ -43,17 +55,6 @@ namespace tgui
     const decltype(std::u32string::npos) String::npos = std::u32string::npos;
 #endif
 
-    //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-
-    TGUI_NODISCARD static inline bool compareCharIgnoreCase(char32_t char1, char32_t char2) {
-        if (char1 == char2)
-            return true;
-        else if ((char1 < 128) && (char2 < 128))
-            return std::tolower(static_cast<unsigned char>(char1)) == std::tolower(static_cast<unsigned char>(char2));
-        else
-            return false;
-    }
-
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     bool isWhitespace(char character)
@@ -169,8 +170,7 @@ namespace tgui
         int result;
         if (attemptToInt(result))
             return result;
-        else
-            return defaultValue;
+        return defaultValue;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -180,8 +180,7 @@ namespace tgui
         unsigned int result;
         if (attemptToUInt(result))
             return result;
-        else
-            return defaultValue;
+        return defaultValue;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -191,8 +190,7 @@ namespace tgui
         float result;
         if (attemptToFloat(result))
             return result;
-        else
-            return defaultValue;
+        return defaultValue;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -350,8 +348,9 @@ namespace tgui
         }
         else // When the delimeter is empty, each character is put in its own part
         {
-            for (char32_t c : m_string)
-                substrings.push_back(c);
+            substrings.reserve(m_string.size());
+            for (const char32_t c : m_string)
+                substrings.emplace_back(c);
         }
 
         if (trim)
@@ -1810,7 +1809,7 @@ namespace tgui
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-    void String::swap(String& other)
+    void String::swap(String& other) noexcept
     {
         m_string.swap(other.m_string);
     }
