@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -22,14 +22,12 @@
 //
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-#include <TGUI/Global.hpp>
 #include <TGUI/SvgImage.hpp>
+#include <TGUI/Global.hpp>
 #include <TGUI/Backend/Window/Backend.hpp>
 #include <TGUI/Backend/Renderer/BackendTexture.hpp>
 
-#if !TGUI_BUILD_AS_CXX_MODULE
-    #include <TGUI/extlibs/IncludeNanoSVG.hpp>
-#endif
+#include <TGUI/extlibs/IncludeNanoSVG.hpp>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -85,9 +83,8 @@ namespace tgui
     Vector2f SvgImage::getSize() const
     {
         if (m_data->svg)
-            return {static_cast<float>(m_data->svg->width), static_cast<float>(m_data->svg->height)};
-        else
-            return {0, 0};
+            return {m_data->svg->width, m_data->svg->height};
+        return {0, 0};
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -104,8 +101,8 @@ namespace tgui
         size.x = static_cast<unsigned int>(size.x * fontScale);
         size.y = static_cast<unsigned int>(size.y * fontScale);
 
-        const float scaleX = size.x / static_cast<float>(m_data->svg->width);
-        const float scaleY = size.y / static_cast<float>(m_data->svg->height);
+        const float scaleX = size.x / m_data->svg->width;
+        const float scaleY = size.y / m_data->svg->height;
 
         auto pixels = MakeUniqueForOverwrite<unsigned char[]>(size.x * size.y * 4);
         nsvgRasterizeXY(m_data->rasterizer, m_data->svg, 0, 0, scaleX, scaleY,
