@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -26,11 +26,9 @@
 #include <TGUI/Backend/Window/Backend.hpp>
 #include <TGUI/Backend/Renderer/BackendText.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <algorithm>
-    #include <vector>
-    #include <cmath>
-#endif
+#include <algorithm>
+#include <vector>
+#include <cmath>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -293,9 +291,9 @@ namespace tgui
             float charWidth;
             if (curChar == '\n')
                 break;
-            else if (curChar == U'\r')
+            if (curChar == U'\r')
                 continue; // Skip carriage return characters which aren't rendered (we only use line feed characters to indicate a new line)
-            else if (curChar == '\t')
+            if (curChar == '\t')
                 charWidth = font.getGlyph(' ', characterSize, bold).advance * 4.0f;
             else
                 charWidth = font.getGlyph(curChar, characterSize, bold).advance;
@@ -337,15 +335,13 @@ namespace tgui
 
         if (fit < 0)
             return *low;
-        else if (fit > 0)
+        if (fit > 0)
             return *high;
-        else
-        {
-            if (std::abs(height - lowLineSpacing) < std::abs(height - highLineSpacing))
-                return *low;
-            else
-                return *high;
-        }
+
+        if (std::abs(height - lowLineSpacing) < std::abs(height - highLineSpacing))
+            return *low;
+
+        return *high;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -373,13 +369,13 @@ namespace tgui
                     index++;
                     break;
                 }
-                else if (curChar == U'\r')
+                if (curChar == U'\r')
                 {
                     // Skip carriage return characters which aren't rendered (we only use line feed characters to indicate a new line)
                     index++;
                     continue;
                 }
-                else if (curChar == U'\t')
+                if (curChar == U'\t')
                     charWidth = font.getGlyph(U' ', textSize, bold).advance * 4;
                 else
                     charWidth = font.getGlyph(curChar, textSize, bold).advance;
