@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -24,9 +24,7 @@
 
 #include <TGUI/Timer.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <algorithm>
-#endif
+#include <algorithm>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -166,11 +164,17 @@ namespace tgui
             else
             {
                 timerTriggered = true;
-                timer->m_callback();
                 timer->m_remainingDuration = timer->m_interval;
 
                 if (!timer->m_repeats)
                     timer->setEnabled(false);
+
+                // Run the callback after the timer was already removed from m_activeTimers (by setEnabled above).
+                // Otherwise updating timers from inside the callback (which you shouldn't do) could result in the
+                // same non-repeating timer being triggered again. This case happens in the Gui Builder because
+                // it runs a different main loop during closing the form to provide a blocking function that still
+                // allows cancelling the closing.
+                timer->m_callback();
             }
         }
 
