@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -22,6 +22,7 @@
 //
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
+#include <TGUI/Widget.hpp>
 #include <TGUI/ToolTip.hpp>
 #include <TGUI/Container.hpp>
 #include <TGUI/Animation.hpp>
@@ -61,7 +62,7 @@ namespace tgui
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-        TGUI_NODISCARD static Layout2d parseLayout(String str)
+        TGUI_NODISCARD Layout2d parseLayout(String str)
         {
             if (str.empty())
                 throw Exception{U"Failed to parse layout. String was empty."};
@@ -108,25 +109,25 @@ namespace tgui
 
             return {x, y};
         }
-    }
 
-    /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-    TGUI_NODISCARD static Vector2f parseVector2f(String str)
-    {
-        if (str.empty())
-            throw Exception{U"Failed to parse Vector2f string. String was empty."};
+        TGUI_NODISCARD Vector2f parseVector2f(String str)
+        {
+            if (str.empty())
+                throw Exception{U"Failed to parse Vector2f string. String was empty."};
 
-        // Remove the brackets around the value
-        if ((str.front() == '(') && (str.back() == ')'))
-            str = str.substr(1, str.length() - 2);
+                   // Remove the brackets around the value
+            if ((str.front() == '(') && (str.back() == ')'))
+                str = str.substr(1, str.length() - 2);
 
-        const auto commaPos = str.find(',');
-        if (commaPos == String::npos)
-            throw Exception{U"Failed to parse Vector2f string '" + str + U"'. No comma found."};
+            const auto commaPos = str.find(',');
+            if (commaPos == String::npos)
+                throw Exception{U"Failed to parse Vector2f string '" + str + U"'. No comma found."};
 
-        return {str.substr(0, commaPos).trim().toFloat(), str.substr(commaPos + 1).trim().toFloat()};
-    }
+            return {str.substr(0, commaPos).trim().toFloat(), str.substr(commaPos + 1).trim().toFloat()};
+        }
+    } // anonymous namespace
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -135,7 +136,7 @@ namespace tgui
     {
         if (initRenderer)
         {
-            m_renderer = aurora::makeCopied<WidgetRenderer>();
+            m_renderer = makeCopied<WidgetRenderer>();
             m_renderer->subscribe(this);
         }
     }
@@ -148,10 +149,10 @@ namespace tgui
         if (m_renderer)
             m_renderer->unsubscribe(this);
 
-        for (auto& layout : m_boundPositionLayouts)
+        for (const auto& layout : m_boundPositionLayouts)
             layout->unbindWidget();
 
-        for (auto& layout : m_boundSizeLayouts)
+        for (const auto& layout : m_boundSizeLayouts)
             layout->unbindWidget();
 
         SignalManager::getSignalManager()->remove(this);
@@ -495,7 +496,7 @@ namespace tgui
             rendererData->themePropertiesInherited = true;
         }
 
-        std::shared_ptr<RendererData> oldData = m_renderer->getData();
+        const std::shared_ptr<RendererData> oldData = m_renderer->getData();
 
         // Update the data
         m_renderer->unsubscribe(this);
@@ -652,8 +653,7 @@ namespace tgui
 
         if (m_parent)
             return m_parent->getAbsolutePosition(pos + m_parent->getChildWidgetsOffset());
-        else
-            return pos;
+        return pos;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -708,8 +708,7 @@ namespace tgui
     {
         if (m_scaleOrigin)
             return *m_scaleOrigin;
-        else
-            return m_origin;
+        return m_origin;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -734,8 +733,7 @@ namespace tgui
     {
         if (m_rotationOrigin)
             return *m_rotationOrigin;
-        else
-            return m_origin;
+        return m_origin;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -1472,10 +1470,7 @@ namespace tgui
         // This behavior can be disabled by calling gui.setKeyboardNavigationEnabled(true).
         // TGUI_NEXT: Always return false here, irrelevant of whether keyboard navigation is enabled.
         // TGUI_NEXT: Deprecate or remove this function and let keyPressed return a bool value.
-        if (m_parentGui && m_parentGui->isKeyboardNavigationEnabled())
-            return false;
-        else
-            return true;
+        return !(m_parentGui && m_parentGui->isKeyboardNavigationEnabled());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -1518,8 +1513,7 @@ namespace tgui
     {
         if (m_toolTip && isMouseOnWidget(mousePos))
             return getToolTip();
-        else
-            return nullptr;
+        return nullptr;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -1556,19 +1550,19 @@ namespace tgui
     {
         if (signalName == onPositionChange.getName())
             return onPositionChange;
-        else if (signalName == onSizeChange.getName())
+        if (signalName == onSizeChange.getName())
             return onSizeChange;
-        else if (signalName == onFocus.getName())
+        if (signalName == onFocus.getName())
             return onFocus;
-        else if (signalName == onUnfocus.getName())
+        if (signalName == onUnfocus.getName())
             return onUnfocus;
-        else if (signalName == onMouseEnter.getName())
+        if (signalName == onMouseEnter.getName())
             return onMouseEnter;
-        else if (signalName == onMouseLeave.getName())
+        if (signalName == onMouseLeave.getName())
             return onMouseLeave;
-        else if (signalName == onAnimationFinish.getName())
+        if (signalName == onAnimationFinish.getName())
             return onAnimationFinish;
-        else if (signalName == onShowEffectFinish.getName())
+        if (signalName == onShowEffectFinish.getName())
             return onShowEffectFinish;
 
         throw Exception{U"No signal exists with name '" + std::move(signalName) + U"'."};
@@ -1648,7 +1642,7 @@ namespace tgui
         {
             if (m_userData.type() == typeid(String))
             {
-                const String string = std::any_cast<String>(m_userData);
+                const auto string = std::any_cast<String>(m_userData);
                 node->propertyValuePairs[U"UserData"] = std::make_unique<DataIO::ValueNode>(Serializer::serialize(string));
             }
             else if (m_userData.type() == typeid(std::string))
@@ -1671,7 +1665,7 @@ namespace tgui
             }
             else if (m_userData.is<std::string>())
             {
-                node->propertyValuePairs[U"UserData"] = std::make_unique<DataIO::ValueNode>(Serializer::serialize(String(m_userData.as<std::string>()))) ;
+                node->propertyValuePairs[U"UserData"] = std::make_unique<DataIO::ValueNode>(Serializer::serialize(String(m_userData.as<std::string>())));
             }
             else if (m_userData.is<const char*>())
             {
@@ -1715,6 +1709,7 @@ namespace tgui
             case Cursor::Type::Crosshair:       mouseCursorStr = "Crosshair"; break;
             case Cursor::Type::Help:            mouseCursorStr = "Help"; break;
             case Cursor::Type::NotAllowed:      mouseCursorStr = "NotAllowed"; break;
+            case Cursor::Type::Move:            mouseCursorStr = "Move"; break;
             case Cursor::Type::Arrow:           break; // We don't save the cursor if it has the default value
         }
         if (!mouseCursorStr.empty())
@@ -1798,7 +1793,7 @@ namespace tgui
 
         if (node->propertyValuePairs[U"MouseCursor"])
         {
-            String cursorStr = node->propertyValuePairs[U"MouseCursor"]->value.trim();
+            const String cursorStr = node->propertyValuePairs[U"MouseCursor"]->value.trim();
             if (cursorStr == U"Text")
                 m_mouseCursor = Cursor::Type::Text;
             else if (cursorStr == U"Hand")
@@ -1829,6 +1824,8 @@ namespace tgui
                 m_mouseCursor = Cursor::Type::Help;
             else if (cursorStr == U"NotAllowed")
                 m_mouseCursor = Cursor::Type::NotAllowed;
+            else if (cursorStr == U"Move")
+                m_mouseCursor = Cursor::Type::Move;
             else if (cursorStr == U"Arrow")
                 m_mouseCursor = Cursor::Type::Arrow;
             else
@@ -1870,7 +1867,7 @@ namespace tgui
                     const auto& constructor = WidgetFactory::getConstructFunction(toolTipWidgetNode->name);
                     if (constructor)
                     {
-                        Widget::Ptr toolTip = constructor();
+                        const Widget::Ptr toolTip = constructor();
                         toolTip->load(toolTipWidgetNode, renderers);
                         setToolTip(toolTip);
                     }
