@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -23,7 +23,6 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
 #include <TGUI/Widgets/BoxLayout.hpp>
-#include <TGUI/Widgets/ClickableWidget.hpp>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -40,21 +39,21 @@ namespace tgui
 
     BoxLayoutRenderer* BoxLayout::getSharedRenderer()
     {
-        return aurora::downcast<BoxLayoutRenderer*>(Widget::getSharedRenderer());
+        return downcast<BoxLayoutRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     const BoxLayoutRenderer* BoxLayout::getSharedRenderer() const
     {
-        return aurora::downcast<const BoxLayoutRenderer*>(Widget::getSharedRenderer());
+        return downcast<const BoxLayoutRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     BoxLayoutRenderer* BoxLayout::getRenderer()
     {
-        return aurora::downcast<BoxLayoutRenderer*>(Widget::getRenderer());
+        return downcast<BoxLayoutRenderer*>(Widget::getRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -124,8 +123,7 @@ namespace tgui
     {
         if (index < m_widgets.size())
             return m_widgets[index];
-        else
-            return nullptr;
+        return nullptr;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
