@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -154,7 +154,7 @@ namespace tgui
     {
         auto node = BoxLayout::save(renderers);
 
-        if (m_widgets.size() > 0)
+        if (!m_widgets.empty())
         {
             String ratioList = "[" + Serializer::serialize(m_ratios[0]);
             for (std::size_t i = 1; i < m_widgets.size(); ++i)
