@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -24,9 +24,7 @@
 
 #include <TGUI/Widgets/ButtonBase.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <cmath>
-#endif
+#include <cmath>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -45,7 +43,7 @@ namespace tgui
 
         if (initRenderer)
         {
-            m_renderer = aurora::makeCopied<ButtonRenderer>();
+            m_renderer = makeCopied<ButtonRenderer>();
             setRenderer(Theme::getDefault()->getRendererNoThrow(m_type));
 
             m_textComponent->setFont(m_fontCached);
@@ -172,21 +170,21 @@ namespace tgui
 
     ButtonRenderer* ButtonBase::getSharedRenderer()
     {
-        return aurora::downcast<ButtonRenderer*>(Widget::getSharedRenderer());
+        return downcast<ButtonRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     const ButtonRenderer* ButtonBase::getSharedRenderer() const
     {
-        return aurora::downcast<const ButtonRenderer*>(Widget::getSharedRenderer());
+        return downcast<const ButtonRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     ButtonRenderer* ButtonBase::getRenderer()
     {
-        return aurora::downcast<ButtonRenderer*>(Widget::getRenderer());
+        return downcast<ButtonRenderer*>(Widget::getRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -573,15 +571,14 @@ namespace tgui
         auto it = m_namedComponents.find(name);
         if (it != m_namedComponents.end())
             return it->second;
-        else
-            return nullptr;
+        return nullptr;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     void ButtonBase::draw(BackendRenderTarget& target, RenderStates states) const
     {
-        for (auto& component : m_components)
+        for (const auto& component : m_components)
             component->draw(target, states);
     }
 
