@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -39,15 +39,15 @@ namespace tgui
     {
         if (initRenderer)
         {
-            m_renderer = aurora::makeCopied<ChatBoxRenderer>();
+            m_renderer = makeCopied<ChatBoxRenderer>();
             setRenderer(Theme::getDefault()->getRendererNoThrow(m_type));
 
             setTextSize(getGlobalTextSize());
             setSize({Text::getLineHeight(m_fontCached, m_textSizeCached) * 18,
                      Text::getLineHeight(m_fontCached, m_textSizeCached) * 8
                      + Text::getExtraVerticalPadding(m_textSizeCached)
-                     + m_paddingCached.getTop() + m_paddingCached.getBottom()
-                     + m_bordersCached.getTop() + m_bordersCached.getBottom()});
+                     + m_paddingCached.getTopPlusBottom()
+                     + m_bordersCached.getTopPlusBottom()});
         }
     }
 
@@ -64,29 +64,28 @@ namespace tgui
     {
         if (chatBox)
             return std::static_pointer_cast<ChatBox>(chatBox->clone());
-        else
-            return nullptr;
+        return nullptr;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     ChatBoxRenderer* ChatBox::getSharedRenderer()
     {
-        return aurora::downcast<ChatBoxRenderer*>(Widget::getSharedRenderer());
+        return downcast<ChatBoxRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     const ChatBoxRenderer* ChatBox::getSharedRenderer() const
     {
-        return aurora::downcast<const ChatBoxRenderer*>(Widget::getSharedRenderer());
+        return downcast<const ChatBoxRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     ChatBoxRenderer* ChatBox::getRenderer()
     {
-        return aurora::downcast<ChatBoxRenderer*>(Widget::getRenderer());
+        return downcast<ChatBoxRenderer*>(Widget::getRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -102,7 +101,7 @@ namespace tgui
 
         m_scrollbar->setPosition(getSize().x - m_bordersCached.getRight() - m_scrollbar->getSize().x, m_bordersCached.getTop());
         m_scrollbar->setHeight(getInnerSize().y);
-        m_scrollbar->setViewportSize(static_cast<unsigned int>(getInnerSize().y - m_paddingCached.getTop() - m_paddingCached.getBottom()));
+        m_scrollbar->setViewportSize(static_cast<unsigned int>(getInnerSize().y - m_paddingCached.getTopPlusBottom()));
 
         recalculateAllLines();
     }
@@ -161,8 +160,8 @@ namespace tgui
         {
             return m_lines[lineIndex].string;
         }
-        else // Index too high
-            return "";
+        // Index too high
+        return "";
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -173,8 +172,8 @@ namespace tgui
         {
             return m_lines[lineIndex].text.getColor();
         }
-        else // Index too high
-            return m_textColor;
+        // Index too high
+        return m_textColor;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -183,8 +182,8 @@ namespace tgui
     {
         if (lineIndex < m_lines.size())
             return m_lines[lineIndex].text.getStyle();
-        else // Index too high
-            return m_textStyle;
+        // Index too high
+        return m_textStyle;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -198,8 +197,8 @@ namespace tgui
             recalculateFullTextHeight();
             return true;
         }
-        else // Index too high
-            return false;
+        // Index too high
+        return false;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -415,7 +414,7 @@ namespace tgui
 
         // Find the maximum width of one line
         const float scrollbarWidth = m_scrollbar->isShown() ? m_scrollbar->getSize().x : 0;
-        const float maxWidth = getInnerSize().x - m_paddingCached.getLeft() - m_paddingCached.getRight() - scrollbarWidth;
+        const float maxWidth = getInnerSize().x - m_paddingCached.getLeftPlusRight() - scrollbarWidth;
         if (maxWidth < 0)
             return;
 
@@ -614,8 +613,8 @@ namespace tgui
 
     Vector2f ChatBox::getInnerSize() const
     {
-        return {std::max(0.f, getSize().x - m_bordersCached.getLeft() - m_bordersCached.getRight()),
-                std::max(0.f, getSize().y - m_bordersCached.getTop() - m_bordersCached.getBottom())};
+        return {std::max(0.f, getSize().x - m_bordersCached.getLeftPlusRight()),
+                std::max(0.f, getSize().y - m_bordersCached.getTopPlusBottom())};
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -642,14 +641,14 @@ namespace tgui
 
         const float scrollbarWidth = m_scrollbar->isShown() ? m_scrollbar->getSize().x : 0;
         states.transform.translate({m_paddingCached.getLeft(), m_paddingCached.getTop()});
-        target.addClippingLayer(states, {{}, {getInnerSize().x - m_paddingCached.getLeft() - m_paddingCached.getRight() - scrollbarWidth,
-                                              getInnerSize().y - m_paddingCached.getTop() - m_paddingCached.getBottom()}});
+        target.addClippingLayer(states, {{}, {getInnerSize().x - m_paddingCached.getLeftPlusRight() - scrollbarWidth,
+                                              getInnerSize().y - m_paddingCached.getTopPlusBottom()}});
 
         states.transform.translate({Text::getExtraHorizontalPadding(m_fontCached, m_textSizeCached), -static_cast<float>(m_scrollbar->getValue())});
 
         // Put the lines at the bottom of the chat box if needed
-        if (!m_linesStartFromTop && (m_fullTextHeight + Text::getExtraVerticalPadding(m_textSizeCached) < getInnerSize().y - m_paddingCached.getTop() - m_paddingCached.getBottom()))
-            states.transform.translate({0, getInnerSize().y - m_paddingCached.getTop() - m_paddingCached.getBottom() - m_fullTextHeight - Text::getExtraVerticalPadding(m_textSizeCached)});
+        if (!m_linesStartFromTop && (m_fullTextHeight + Text::getExtraVerticalPadding(m_textSizeCached) < getInnerSize().y - m_paddingCached.getTopPlusBottom()))
+            states.transform.translate({0, getInnerSize().y - m_paddingCached.getTopPlusBottom() - m_fullTextHeight - Text::getExtraVerticalPadding(m_textSizeCached)});
 
         for (const auto& line : m_lines)
         {
