@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -24,12 +24,11 @@
 
 #include <TGUI/Widgets/CheckBox.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <cmath>
+#include <algorithm>
+#include <cmath>
 
-    #if defined(__cpp_lib_math_constants) && (__cpp_lib_math_constants >= 201907L)
-        #include <numbers>
-    #endif
+#if defined(__cpp_lib_math_constants) && (__cpp_lib_math_constants >= 201907L)
+    #include <numbers>
 #endif
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -47,12 +46,12 @@ namespace tgui
     {
         if (initRenderer)
         {
-            m_renderer = aurora::makeCopied<CheckBoxRenderer>();
+            m_renderer = makeCopied<CheckBoxRenderer>();
             setRenderer(Theme::getDefault()->getRendererNoThrow(m_type));
 
             setTextSize(getGlobalTextSize());
-            setSize({m_text.getLineHeight() + m_bordersCached.getLeft() + m_bordersCached.getRight(),
-                     m_text.getLineHeight() + m_bordersCached.getTop() + m_bordersCached.getBottom()});
+            setSize({m_text.getLineHeight() + m_bordersCached.getLeftPlusRight(),
+                     m_text.getLineHeight() + m_bordersCached.getTopPlusBottom()});
         }
     }
 
@@ -74,29 +73,28 @@ namespace tgui
     {
         if (checkbox)
             return std::static_pointer_cast<CheckBox>(checkbox->clone());
-        else
-            return nullptr;
+        return nullptr;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     CheckBoxRenderer* CheckBox::getSharedRenderer()
     {
-        return aurora::downcast<CheckBoxRenderer*>(Widget::getSharedRenderer());
+        return downcast<CheckBoxRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     const CheckBoxRenderer* CheckBox::getSharedRenderer() const
     {
-        return aurora::downcast<const CheckBoxRenderer*>(Widget::getSharedRenderer());
+        return downcast<const CheckBoxRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     CheckBoxRenderer* CheckBox::getRenderer()
     {
-        return aurora::downcast<CheckBoxRenderer*>(Widget::getRenderer());
+        return downcast<CheckBoxRenderer*>(Widget::getRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -106,19 +104,14 @@ namespace tgui
         if (m_spriteUnchecked.isSet() && m_spriteChecked.isSet()
          && (m_textureUncheckedCached.getImageSize() != m_textureCheckedCached.getImageSize()))
         {
-            Vector2f sizeDiff = m_spriteChecked.getSize() - m_spriteUnchecked.getSize();
+            const Vector2f sizeDiff = m_spriteChecked.getSize() - m_spriteUnchecked.getSize();
             if (getText().empty())
                 return getSize() + Vector2f{std::max(0.f, sizeDiff.x - m_bordersCached.getRight()), std::max(0.f, sizeDiff.y - m_bordersCached.getTop())};
-            else
-                return getSize() + Vector2f{(getSize().x * m_textDistanceRatioCached) + m_text.getSize().x, std::max(0.f, std::max((m_text.getSize().y - getSize().y) / 2, sizeDiff.y - m_bordersCached.getTop()))};
-        }
-        else
-        {
-            if (getText().empty())
-                return getSize();
-            else
-                return {getSize().x + (getSize().x * m_textDistanceRatioCached) + m_text.getSize().x, std::max(getSize().y, m_text.getSize().y)};
+            return getSize() + Vector2f{(getSize().x * m_textDistanceRatioCached) + m_text.getSize().x, std::max({0.f, (m_text.getSize().y - getSize().y) / 2, sizeDiff.y - m_bordersCached.getTop()})};
         }
+        if (getText().empty())
+            return getSize();
+        return {getSize().x + (getSize().x * m_textDistanceRatioCached) + m_text.getSize().x, std::max(getSize().y, m_text.getSize().y)};
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -136,8 +129,7 @@ namespace tgui
 
         if (getText().empty() || (getSize().y >= m_text.getSize().y))
             return {0, -yOffset};
-        else
-            return {0, -std::max(yOffset, (m_text.getSize().y - getSize().y) / 2)};
+        return {0, -std::max(yOffset, (m_text.getSize().y - getSize().y) / 2)};
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -189,8 +181,7 @@ namespace tgui
     {
         if ((event.code == Event::KeyboardKey::Space) || (event.code == Event::KeyboardKey::Enter))
             return true;
-        else
-            return RadioButton::canHandleKeyPress(event);
+        return RadioButton::canHandleKeyPress(event);
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -243,7 +234,7 @@ namespace tgui
         if (m_bordersCached != Borders{0})
             target.drawBorders(states, m_bordersCached, getSize(), Color::applyOpacity(getCurrentBorderColor(), m_opacityCached));
 
-        states.transform.translate({m_bordersCached.getLeft(), m_bordersCached.getTop()});
+        states.transform.translate(m_bordersCached.getOffset());
         if (!m_checked && m_spriteUnchecked.isSet())
         {
             if (!m_enabled && m_spriteUncheckedDisabled.isSet())
@@ -270,7 +261,7 @@ namespace tgui
             // The image may need to be shifted when the check leaves the box
             if (getInnerSize().y != checkedSprite->getSize().y)
             {
-                float diff = getInnerSize().y - checkedSprite->getSize().y;
+                const float diff = getInnerSize().y - checkedSprite->getSize().y;
 
                 states.transform.translate({0, diff});
                 target.drawSprite(states, *checkedSprite);
