@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -69,7 +69,7 @@ namespace tgui
 
         if (initRenderer)
         {
-            m_renderer = aurora::makeCopied<ChildWindowRenderer>();
+            m_renderer = makeCopied<ChildWindowRenderer>();
             setRenderer(Theme::getDefault()->getRendererNoThrow(m_type));
 
             setSize({400, 300});
@@ -281,29 +281,28 @@ namespace tgui
     {
         if (childWindow)
             return std::static_pointer_cast<ChildWindow>(childWindow->clone());
-        else
-            return nullptr;
+        return nullptr;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     ChildWindowRenderer* ChildWindow::getSharedRenderer()
     {
-        return aurora::downcast<ChildWindowRenderer*>(Widget::getSharedRenderer());
+        return downcast<ChildWindowRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     const ChildWindowRenderer* ChildWindow::getSharedRenderer() const
     {
-        return aurora::downcast<const ChildWindowRenderer*>(Widget::getSharedRenderer());
+        return downcast<const ChildWindowRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     ChildWindowRenderer* ChildWindow::getRenderer()
     {
-        return aurora::downcast<ChildWindowRenderer*>(Widget::getRenderer());
+        return downcast<ChildWindowRenderer*>(Widget::getRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -311,23 +310,24 @@ namespace tgui
     void ChildWindow::setPosition(const Layout2d& position)
     {
         bool positionMovedToKeepInParent = false;
-        if (m_keepInParent && m_parent && (m_parent->getSize().x > 0) && (m_parent->getSize().y > 0))
+        if (m_keepInParent && m_parent && (m_parent->getInnerSize().x > 0) && (m_parent->getInnerSize().y > 0))
         {
+            const Vector2f parentSize = m_parent->getInnerSize();
             const Vector2f origin{getOrigin().x * getSize().x, getOrigin().y * getSize().y};
             float x = position.getValue().x - origin.x;
             float y = position.getValue().y - origin.y;
 
-            if ((y < 0) || (y > m_parent->getSize().y - getSize().y) || (x < 0) || (x > m_parent->getSize().x - getSize().x))
+            if ((y < 0) || (y > parentSize.y - getSize().y) || (x < 0) || (x > parentSize.x - getSize().x))
             {
                 if (y < 0)
                     y = 0;
-                else if (y > m_parent->getSize().y - getSize().y)
-                    y = std::max(0.f, m_parent->getSize().y - getSize().y);
+                else if (y > parentSize.y - getSize().y)
+                    y = std::max(0.f, parentSize.y - getSize().y);
 
                 if (x < 0)
                     x = 0;
-                else if (x > m_parent->getSize().x - getSize().x)
-                    x = std::max(0.f, m_parent->getSize().x - getSize().x);
+                else if (x > parentSize.x - getSize().x)
+                    x = std::max(0.f, parentSize.x - getSize().x);
 
                 positionMovedToKeepInParent = true;
                 Container::setPosition({x + origin.x, y + origin.y});
@@ -364,7 +364,7 @@ namespace tgui
         }
 
         buttonOffsetX = m_distanceToSideCached;
-        for (auto& button : {m_closeButton.get(), m_maximizeButton.get(), m_minimizeButton.get()})
+        for (const auto& button : {m_closeButton.get(), m_maximizeButton.get(), m_minimizeButton.get()})
         {
             if (button->isVisible())
             {
@@ -404,8 +404,8 @@ namespace tgui
 
     Vector2f ChildWindow::getInnerTitleBarSize() const
     {
-        return {std::max(0.f, getSize().x - m_bordersCached.getLeft() - m_bordersCached.getRight()),
-                std::max(0.f, getSize().y - m_bordersCached.getTop() - m_bordersCached.getBottom()
+        return {std::max(0.f, getSize().x - m_bordersCached.getLeftPlusRight()),
+                std::max(0.f, getSize().y - m_bordersCached.getTopPlusBottom()
                               - m_titleBarHeightCached - m_borderBelowTitleBarCached)};
     }
 
@@ -413,8 +413,8 @@ namespace tgui
 
     Vector2f ChildWindow::getInnerSizeWithPadding() const
     {
-        return {getSize().x - m_bordersCached.getLeft() - m_bordersCached.getRight(),
-                getSize().y - m_bordersCached.getTop() - m_bordersCached.getBottom()
+        return {getSize().x - m_bordersCached.getLeftPlusRight(),
+                getSize().y - m_bordersCached.getTopPlusBottom()
                 - m_titleBarHeightCached - m_borderBelowTitleBarCached};
     }
 
@@ -422,8 +422,8 @@ namespace tgui
 
     Vector2f ChildWindow::getDecorationSize() const
     {
-        return {m_bordersCached.getLeft() + m_bordersCached.getRight() + m_clientPaddingCached.getLeft() + m_clientPaddingCached.getRight(),
-                m_bordersCached.getTop() + m_bordersCached.getBottom() + m_clientPaddingCached.getTop() + m_clientPaddingCached.getBottom()
+        return {m_bordersCached.getLeftPlusRight() + m_clientPaddingCached.getLeftPlusRight(),
+                m_bordersCached.getTopPlusBottom() + m_clientPaddingCached.getTopPlusBottom()
                 + m_titleBarHeightCached + m_borderBelowTitleBarCached};
     }
 
@@ -782,7 +782,7 @@ namespace tgui
                 setFocused(true);
 
             // Send the mouse press event to the title buttons
-            for (auto& button : {m_closeButton.get(), m_maximizeButton.get(), m_minimizeButton.get()})
+            for (const auto& button : {m_closeButton.get(), m_maximizeButton.get(), m_minimizeButton.get()})
             {
                 if (button->isVisible() && button->isMouseOnWidget(pos))
                 {
@@ -827,7 +827,7 @@ namespace tgui
             if (FloatRect{m_bordersCached.getLeft(), m_bordersCached.getTop(), getInnerTitleBarSize().x, m_titleBarHeightCached}.contains(pos))
             {
                 // Send the mouse release event to the title buttons
-                for (auto& button : {m_closeButton.get(), m_maximizeButton.get(), m_minimizeButton.get()})
+                for (const auto& button : {m_closeButton.get(), m_maximizeButton.get(), m_minimizeButton.get()})
                 {
                     if (button->isVisible() && button->isMouseOnWidget(pos))
                     {
@@ -953,7 +953,7 @@ namespace tgui
                 if (FloatRect{m_bordersCached.getLeft(), m_bordersCached.getTop(), getInnerTitleBarSize().x, m_titleBarHeightCached}.contains(pos))
                 {
                     // Send the hover event to the buttons inside the title bar
-                    for (auto& button : {m_closeButton.get(), m_maximizeButton.get(), m_minimizeButton.get()})
+                    for (const auto& button : {m_closeButton.get(), m_maximizeButton.get(), m_minimizeButton.get()})
                     {
                         if (button->isVisible())
                         {
@@ -966,7 +966,7 @@ namespace tgui
                 }
                 else // When the mouse is not on the title bar, the mouse can't be on the buttons inside it
                 {
-                    for (auto& button : {m_closeButton.get(), m_maximizeButton.get(), m_minimizeButton.get()})
+                    for (const auto& button : {m_closeButton.get(), m_maximizeButton.get(), m_minimizeButton.get()})
                     {
                         if (button->isVisible())
                             button->mouseNoLongerOnWidget();
@@ -995,8 +995,7 @@ namespace tgui
     {
         if (event.code == Event::KeyboardKey::Escape)
             return true;
-        else
-            return Container::canHandleKeyPress(event);
+        return Container::canHandleKeyPress(event);
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -1032,7 +1031,7 @@ namespace tgui
         m_spriteTitleBar.setSize({getInnerTitleBarSize().x, m_titleBarHeightCached});
 
         // Set the size of the buttons in the title bar
-        for (auto& button : {m_closeButton.get(), m_maximizeButton.get(), m_minimizeButton.get()})
+        for (const auto& button : {m_closeButton.get(), m_maximizeButton.get(), m_minimizeButton.get()})
         {
             if (button->isVisible())
             {
@@ -1106,18 +1105,17 @@ namespace tgui
     {
         if (signalName == onMousePress.getName())
             return onMousePress;
-        else if (signalName == onClose.getName())
+        if (signalName == onClose.getName())
             return onClose;
-        else if (signalName == onClosing.getName())
+        if (signalName == onClosing.getName())
             return onClosing;
-        else if (signalName == onMinimize.getName())
+        if (signalName == onMinimize.getName())
             return onMinimize;
-        else if (signalName == onMaximize.getName())
+        if (signalName == onMaximize.getName())
             return onMaximize;
-        else if (signalName == onEscapeKeyPress.getName())
+        if (signalName == onEscapeKeyPress.getName())
             return onEscapeKeyPress;
-        else
-            return Container::getSignal(std::move(signalName));
+        return Container::getSignal(std::move(signalName));
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -1251,7 +1249,7 @@ namespace tgui
         {
             Container::rendererChanged(property);
 
-            for (auto& button : {m_closeButton.get(), m_maximizeButton.get(), m_minimizeButton.get()})
+            for (const auto& button : {m_closeButton.get(), m_maximizeButton.get(), m_minimizeButton.get()})
                 button->setInheritedOpacity(m_opacityCached);
 
             m_titleText.setOpacity(m_opacityCached);
@@ -1262,7 +1260,7 @@ namespace tgui
         {
             Container::rendererChanged(property);
 
-            for (auto& button : {m_closeButton.get(), m_maximizeButton.get(), m_minimizeButton.get()})
+            for (const auto& button : {m_closeButton.get(), m_maximizeButton.get(), m_minimizeButton.get()})
             {
                 if (button->isVisible())
                     button->setInheritedFont(m_fontCached);
@@ -1291,7 +1289,7 @@ namespace tgui
         else if (m_titleAlignment == HorizontalAlignment::Right)
             node->propertyValuePairs[U"TitleAlignment"] = std::make_unique<DataIO::ValueNode>("Right");
 
-        if (getTitle().length() > 0)
+        if (!getTitle().empty())
             node->propertyValuePairs[U"Title"] = std::make_unique<DataIO::ValueNode>(Serializer::serialize(getTitle()));
 
         if (m_titleTextSize != 0)
@@ -1356,10 +1354,10 @@ namespace tgui
         if (node->propertyValuePairs[U"TitleButtons"])
         {
             unsigned int decodedTitleButtons = TitleButton::None;
-            std::vector<String> titleButtons = Deserializer::split(node->propertyValuePairs[U"TitleButtons"]->value, '|');
+            const std::vector<String> titleButtons = Deserializer::split(node->propertyValuePairs[U"TitleButtons"]->value, '|');
             for (const auto& elem : titleButtons)
             {
-                String requestedTitleButton = elem.trim();
+                const String requestedTitleButton = elem.trim();
                 if (requestedTitleButton == U"Close")
                     decodedTitleButtons |= TitleButton::Close;
                 else if (requestedTitleButton == U"Maximize")
@@ -1457,7 +1455,7 @@ namespace tgui
             else
                 target.drawBorders(states, m_bordersCached, getSize(), Color::applyOpacity(m_borderColorCached, m_opacityCached));
 
-            states.transform.translate({m_bordersCached.getLeft(), m_bordersCached.getTop()});
+            states.transform.translate(m_bordersCached.getOffset());
         }
 
         // Draw the title bar
@@ -1487,7 +1485,7 @@ namespace tgui
 
         // Draw the buttons
         states.transform.translate({-m_bordersCached.getLeft(), -m_bordersCached.getTop()});
-        for (auto& button : {m_closeButton.get(), m_maximizeButton.get(), m_minimizeButton.get()})
+        for (const auto& button : {m_closeButton.get(), m_maximizeButton.get(), m_minimizeButton.get()})
         {
             if (!button->isVisible())
                 continue;
