@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -54,8 +54,7 @@ namespace tgui
     {
         if (widget)
             return std::static_pointer_cast<ClickableWidget>(widget->clone());
-        else
-            return nullptr;
+        return nullptr;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -125,18 +124,17 @@ namespace tgui
     {
         if (signalName == onMousePress.getName())
             return onMousePress;
-        else if (signalName == onMouseRelease.getName())
+        if (signalName == onMouseRelease.getName())
             return onMouseRelease;
-        else if (signalName == onClick.getName())
+        if (signalName == onClick.getName())
             return onClick;
-        else if (signalName == onRightMousePress.getName())
+        if (signalName == onRightMousePress.getName())
             return onRightMousePress;
-        else if (signalName == onRightMouseRelease.getName())
+        if (signalName == onRightMouseRelease.getName())
             return onRightMouseRelease;
-        else if (signalName == onRightClick.getName())
+        if (signalName == onRightClick.getName())
             return onRightClick;
-        else
-            return Widget::getSignal(std::move(signalName));
+        return Widget::getSignal(std::move(signalName));
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
