@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -22,12 +22,10 @@
 //
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-#include <TGUI/Container.hpp>
 #include <TGUI/Widgets/ComboBox.hpp>
+#include <TGUI/Container.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <cmath>
-#endif
+#include <cmath>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -49,37 +47,45 @@ namespace tgui
 
         if (initRenderer)
         {
-            m_renderer = aurora::makeCopied<ComboBoxRenderer>();
+            m_renderer = makeCopied<ComboBoxRenderer>();
             setRenderer(Theme::getDefault()->getRendererNoThrow(m_type));
 
             setTextSize(getGlobalTextSize());
             setSize({m_text.getLineHeight() * 10,
-                     std::round(m_text.getLineHeight() * 1.25f) + m_paddingCached.getTop() + m_paddingCached.getBottom() + m_bordersCached.getTop() + m_bordersCached.getBottom()});
+                     std::round(m_text.getLineHeight() * 1.25f) + m_paddingCached.getTopPlusBottom() + m_bordersCached.getTopPlusBottom()});
         }
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     ComboBox::ComboBox(const ComboBox& other) :
-        Widget                           {other},
-        onItemSelect                     {other.onItemSelect},
-        m_nrOfItemsToDisplay             {other.m_nrOfItemsToDisplay},
-        m_listBox                        {ListBox::copy(other.m_listBox)},
-        m_text                           {other.m_text},
-        m_defaultText                    {other.m_defaultText},
-        m_changeItemOnScroll             {other.m_changeItemOnScroll},
-        m_expandDirection                {other.m_expandDirection},
-        m_spriteBackground               {other.m_spriteBackground},
-        m_spriteArrow                    {other.m_spriteArrow},
-        m_spriteArrowHover               {other.m_spriteArrowHover},
-        m_bordersCached                  {other.m_bordersCached},
-        m_paddingCached                  {other.m_paddingCached},
-        m_borderColorCached              {other.m_borderColorCached},
-        m_backgroundColorCached          {other.m_backgroundColorCached},
-        m_arrowColorCached               {other.m_arrowColorCached},
-        m_arrowColorHoverCached          {other.m_arrowColorHoverCached},
-        m_arrowBackgroundColorCached     {other.m_arrowBackgroundColorCached},
-        m_arrowBackgroundColorHoverCached{other.m_arrowBackgroundColorHoverCached}
+        Widget                              {other},
+        onItemSelect                        {other.onItemSelect},
+        m_nrOfItemsToDisplay                {other.m_nrOfItemsToDisplay},
+        m_listBox                           {ListBox::copy(other.m_listBox)},
+        m_text                              {other.m_text},
+        m_defaultText                       {other.m_defaultText},
+        m_changeItemOnScroll                {other.m_changeItemOnScroll},
+        m_expandDirection                   {other.m_expandDirection},
+        m_spriteBackground                  {other.m_spriteBackground},
+        m_spriteBackgroundDisabled          {other.m_spriteBackgroundDisabled},
+        m_spriteArrow                       {other.m_spriteArrow},
+        m_spriteArrowHover                  {other.m_spriteArrowHover},
+        m_spriteArrowDisabled               {other.m_spriteArrowDisabled},
+        m_bordersCached                     {other.m_bordersCached},
+        m_paddingCached                     {other.m_paddingCached},
+        m_borderColorCached                 {other.m_borderColorCached},
+        m_backgroundColorCached             {other.m_backgroundColorCached},
+        m_backgroundColorDisabledCached     {other.m_backgroundColorDisabledCached},
+        m_arrowColorCached                  {other.m_arrowColorCached},
+        m_arrowColorHoverCached             {other.m_arrowColorHoverCached},
+        m_arrowColorDisabledCached          {other.m_arrowColorDisabledCached},
+        m_arrowBackgroundColorCached        {other.m_arrowBackgroundColorCached},
+        m_arrowBackgroundColorHoverCached   {other.m_arrowBackgroundColorHoverCached},
+        m_arrowBackgroundColorDisabledCached{other.m_arrowBackgroundColorDisabledCached},
+        m_textColorCached                   {other.m_textColorCached},
+        m_textColorDisabledCached           {other.m_textColorDisabledCached},
+        m_roundedBorderRadiusCached         {other.m_roundedBorderRadiusCached}
     {
         initListBox();
     }
@@ -87,25 +93,33 @@ namespace tgui
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     ComboBox::ComboBox(ComboBox&& other) noexcept :
-        Widget                           {std::move(other)},
-        onItemSelect                     {std::move(other.onItemSelect)},
-        m_nrOfItemsToDisplay             {std::move(other.m_nrOfItemsToDisplay)},
-        m_listBox                        {std::move(other.m_listBox)},
-        m_text                           {std::move(other.m_text)},
-        m_defaultText                    {std::move(other.m_defaultText)},
-        m_changeItemOnScroll             {std::move(other.m_changeItemOnScroll)},
-        m_expandDirection                {std::move(other.m_expandDirection)},
-        m_spriteBackground               {std::move(other.m_spriteBackground)},
-        m_spriteArrow                    {std::move(other.m_spriteArrow)},
-        m_spriteArrowHover               {std::move(other.m_spriteArrowHover)},
-        m_bordersCached                  {std::move(other.m_bordersCached)},
-        m_paddingCached                  {std::move(other.m_paddingCached)},
-        m_borderColorCached              {std::move(other.m_borderColorCached)},
-        m_backgroundColorCached          {std::move(other.m_backgroundColorCached)},
-        m_arrowColorCached               {std::move(other.m_arrowColorCached)},
-        m_arrowColorHoverCached          {std::move(other.m_arrowColorHoverCached)},
-        m_arrowBackgroundColorCached     {std::move(other.m_arrowBackgroundColorCached)},
-        m_arrowBackgroundColorHoverCached{std::move(other.m_arrowBackgroundColorHoverCached)}
+        Widget                              {std::move(other)},
+        onItemSelect                        {std::move(other.onItemSelect)},
+        m_nrOfItemsToDisplay                {std::move(other.m_nrOfItemsToDisplay)},
+        m_listBox                           {std::move(other.m_listBox)},
+        m_text                              {std::move(other.m_text)},
+        m_defaultText                       {std::move(other.m_defaultText)},
+        m_changeItemOnScroll                {std::move(other.m_changeItemOnScroll)},
+        m_expandDirection                   {std::move(other.m_expandDirection)},
+        m_spriteBackground                  {std::move(other.m_spriteBackground)},
+        m_spriteBackgroundDisabled          {std::move(other.m_spriteBackgroundDisabled)},
+        m_spriteArrow                       {std::move(other.m_spriteArrow)},
+        m_spriteArrowHover                  {std::move(other.m_spriteArrowHover)},
+        m_spriteArrowDisabled               {std::move(other.m_spriteArrowDisabled)},
+        m_bordersCached                     {std::move(other.m_bordersCached)},
+        m_paddingCached                     {std::move(other.m_paddingCached)},
+        m_borderColorCached                 {std::move(other.m_borderColorCached)},
+        m_backgroundColorCached             {std::move(other.m_backgroundColorCached)},
+        m_backgroundColorDisabledCached     {std::move(other.m_backgroundColorDisabledCached)},
+        m_arrowColorCached                  {std::move(other.m_arrowColorCached)},
+        m_arrowColorHoverCached             {std::move(other.m_arrowColorHoverCached)},
+        m_arrowColorDisabledCached          {std::move(other.m_arrowColorDisabledCached)},
+        m_arrowBackgroundColorCached        {std::move(other.m_arrowBackgroundColorCached)},
+        m_arrowBackgroundColorHoverCached   {std::move(other.m_arrowBackgroundColorHoverCached)},
+        m_arrowBackgroundColorDisabledCached{std::move(other.m_arrowBackgroundColorDisabledCached)},
+        m_textColorCached                   {std::move(other.m_textColorCached)},
+        m_textColorDisabledCached           {std::move(other.m_textColorDisabledCached)},
+        m_roundedBorderRadiusCached         {std::move(other.m_roundedBorderRadiusCached)}
     {
         initListBox();
     }
@@ -119,24 +133,32 @@ namespace tgui
             ComboBox temp{other};
             Widget::operator=(other);
 
-            std::swap(onItemSelect,                      temp.onItemSelect);
-            std::swap(m_nrOfItemsToDisplay,              temp.m_nrOfItemsToDisplay);
-            std::swap(m_listBox,                         temp.m_listBox);
-            std::swap(m_text,                            temp.m_text);
-            std::swap(m_defaultText,                     temp.m_defaultText);
-            std::swap(m_changeItemOnScroll,              temp.m_changeItemOnScroll);
-            std::swap(m_expandDirection,                 temp.m_expandDirection);
-            std::swap(m_spriteBackground,                temp.m_spriteBackground);
-            std::swap(m_spriteArrow,                     temp.m_spriteArrow);
-            std::swap(m_spriteArrowHover,                temp.m_spriteArrowHover);
-            std::swap(m_bordersCached,                   temp.m_bordersCached);
-            std::swap(m_paddingCached,                   temp.m_paddingCached);
-            std::swap(m_borderColorCached,               temp.m_borderColorCached);
-            std::swap(m_backgroundColorCached,           temp.m_backgroundColorCached);
-            std::swap(m_arrowColorCached,                temp.m_arrowColorCached);
-            std::swap(m_arrowColorHoverCached,           temp.m_arrowColorHoverCached);
-            std::swap(m_arrowBackgroundColorCached,      temp.m_arrowBackgroundColorCached);
-            std::swap(m_arrowBackgroundColorHoverCached, temp.m_arrowBackgroundColorHoverCached);
+            std::swap(onItemSelect,                         temp.onItemSelect);
+            std::swap(m_nrOfItemsToDisplay,                 temp.m_nrOfItemsToDisplay);
+            std::swap(m_listBox,                            temp.m_listBox);
+            std::swap(m_text,                               temp.m_text);
+            std::swap(m_defaultText,                        temp.m_defaultText);
+            std::swap(m_changeItemOnScroll,                 temp.m_changeItemOnScroll);
+            std::swap(m_expandDirection,                    temp.m_expandDirection);
+            std::swap(m_spriteBackground,                   temp.m_spriteBackground);
+            std::swap(m_spriteBackgroundDisabled,           temp.m_spriteBackgroundDisabled);
+            std::swap(m_spriteArrow,                        temp.m_spriteArrow);
+            std::swap(m_spriteArrowHover,                   temp.m_spriteArrowHover);
+            std::swap(m_spriteArrowDisabled,                temp.m_spriteArrowDisabled);
+            std::swap(m_bordersCached,                      temp.m_bordersCached);
+            std::swap(m_paddingCached,                      temp.m_paddingCached);
+            std::swap(m_borderColorCached,                  temp.m_borderColorCached);
+            std::swap(m_backgroundColorCached,              temp.m_backgroundColorCached);
+            std::swap(m_backgroundColorDisabledCached,      temp.m_backgroundColorDisabledCached);
+            std::swap(m_arrowColorCached,                   temp.m_arrowColorCached);
+            std::swap(m_arrowColorHoverCached,              temp.m_arrowColorHoverCached);
+            std::swap(m_arrowColorDisabledCached,           temp.m_arrowColorDisabledCached);
+            std::swap(m_arrowBackgroundColorCached,         temp.m_arrowBackgroundColorCached);
+            std::swap(m_arrowBackgroundColorHoverCached,    temp.m_arrowBackgroundColorHoverCached);
+            std::swap(m_arrowBackgroundColorDisabledCached, temp.m_arrowBackgroundColorDisabledCached);
+            std::swap(m_textColorCached,                    temp.m_textColorCached);
+            std::swap(m_textColorDisabledCached,            temp.m_textColorDisabledCached);
+            std::swap(m_roundedBorderRadiusCached,          temp.m_roundedBorderRadiusCached);
         }
 
         return *this;
@@ -148,24 +170,32 @@ namespace tgui
     {
         if (this != &other)
         {
-            onItemSelect                      = std::move(other.onItemSelect);
-            m_nrOfItemsToDisplay              = std::move(other.m_nrOfItemsToDisplay);
-            m_listBox                         = std::move(other.m_listBox);
-            m_text                            = std::move(other.m_text);
-            m_defaultText                     = std::move(other.m_defaultText);
-            m_changeItemOnScroll              = std::move(other.m_changeItemOnScroll);
-            m_expandDirection                 = std::move(other.m_expandDirection);
-            m_spriteBackground                = std::move(other.m_spriteBackground);
-            m_spriteArrow                     = std::move(other.m_spriteArrow);
-            m_spriteArrowHover                = std::move(other.m_spriteArrowHover);
-            m_bordersCached                   = std::move(other.m_bordersCached);
-            m_paddingCached                   = std::move(other.m_paddingCached);
-            m_borderColorCached               = std::move(other.m_borderColorCached);
-            m_backgroundColorCached           = std::move(other.m_backgroundColorCached);
-            m_arrowColorCached                = std::move(other.m_arrowColorCached);
-            m_arrowColorHoverCached           = std::move(other.m_arrowColorHoverCached);
-            m_arrowBackgroundColorCached      = std::move(other.m_arrowBackgroundColorCached);
-            m_arrowBackgroundColorHoverCached = std::move(other.m_arrowBackgroundColorHoverCached);
+            onItemSelect                         = std::move(other.onItemSelect);
+            m_nrOfItemsToDisplay                 = std::move(other.m_nrOfItemsToDisplay);
+            m_listBox                            = std::move(other.m_listBox);
+            m_text                               = std::move(other.m_text);
+            m_defaultText                        = std::move(other.m_defaultText);
+            m_changeItemOnScroll                 = std::move(other.m_changeItemOnScroll);
+            m_expandDirection                    = std::move(other.m_expandDirection);
+            m_spriteBackground                   = std::move(other.m_spriteBackground);
+            m_spriteBackgroundDisabled           = std::move(other.m_spriteBackgroundDisabled);
+            m_spriteArrow                        = std::move(other.m_spriteArrow);
+            m_spriteArrowHover                   = std::move(other.m_spriteArrowHover);
+            m_spriteArrowDisabled                = std::move(other.m_spriteArrowDisabled);
+            m_bordersCached                      = std::move(other.m_bordersCached);
+            m_paddingCached                      = std::move(other.m_paddingCached);
+            m_borderColorCached                  = std::move(other.m_borderColorCached);
+            m_backgroundColorCached              = std::move(other.m_backgroundColorCached);
+            m_backgroundColorDisabledCached      = std::move(other.m_backgroundColorDisabledCached);
+            m_arrowColorCached                   = std::move(other.m_arrowColorCached);
+            m_arrowColorHoverCached              = std::move(other.m_arrowColorHoverCached);
+            m_arrowColorDisabledCached           = std::move(other.m_arrowColorDisabledCached);
+            m_arrowBackgroundColorCached         = std::move(other.m_arrowBackgroundColorCached);
+            m_arrowBackgroundColorHoverCached    = std::move(other.m_arrowBackgroundColorHoverCached);
+            m_arrowBackgroundColorDisabledCached = std::move(other.m_arrowBackgroundColorDisabledCached);
+            m_textColorCached                    = std::move(other.m_textColorCached);
+            m_textColorDisabledCached            = std::move(other.m_textColorDisabledCached);
+            m_roundedBorderRadiusCached          = std::move(other.m_roundedBorderRadiusCached);
             Widget::operator=(std::move(other));
         }
 
@@ -185,29 +215,28 @@ namespace tgui
     {
         if (comboBox)
             return std::static_pointer_cast<ComboBox>(comboBox->clone());
-        else
-            return nullptr;
+        return nullptr;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     ComboBoxRenderer* ComboBox::getSharedRenderer()
     {
-        return aurora::downcast<ComboBoxRenderer*>(Widget::getSharedRenderer());
+        return downcast<ComboBoxRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     const ComboBoxRenderer* ComboBox::getSharedRenderer() const
     {
-        return aurora::downcast<const ComboBoxRenderer*>(Widget::getSharedRenderer());
+        return downcast<const ComboBoxRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     ComboBoxRenderer* ComboBox::getRenderer()
     {
-        return aurora::downcast<ComboBoxRenderer*>(Widget::getRenderer());
+        return downcast<ComboBoxRenderer*>(Widget::getRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -222,7 +251,7 @@ namespace tgui
         m_spriteBackground.setSize(getInnerSize());
         m_spriteBackgroundDisabled.setSize(getInnerSize());
 
-        const float height = getInnerSize().y - m_paddingCached.getTop() - m_paddingCached.getBottom();
+        const float height = getInnerSize().y - m_paddingCached.getTopPlusBottom();
 
         if (height > 0)
         {
@@ -674,8 +703,7 @@ namespace tgui
     {
         if (signalName == onItemSelect.getName())
             return onItemSelect;
-        else
-            return Widget::getSignal(std::move(signalName));
+        return Widget::getSignal(std::move(signalName));
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -787,6 +815,10 @@ namespace tgui
         {
             m_arrowColorDisabledCached = getSharedRenderer()->getArrowColorDisabled();
         }
+        else if (property == U"RoundedBorderRadius")
+        {
+            m_roundedBorderRadiusCached = getSharedRenderer()->getRoundedBorderRadius();
+        }
         else if ((property == U"Opacity") || (property == U"OpacityDisabled"))
         {
             Widget::rendererChanged(property);
@@ -922,8 +954,8 @@ namespace tgui
 
     Vector2f ComboBox::getInnerSize() const
     {
-        return {std::max(0.f, getSize().x - m_bordersCached.getLeft() - m_bordersCached.getRight()),
-                std::max(0.f, getSize().y - m_bordersCached.getTop() - m_bordersCached.getBottom())};
+        return {std::max(0.f, getSize().x - m_bordersCached.getLeftPlusRight()),
+                std::max(0.f, getSize().y - m_bordersCached.getTopPlusBottom())};
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -1032,31 +1064,41 @@ namespace tgui
 
     void ComboBox::draw(BackendRenderTarget& target, RenderStates states) const
     {
-        // Draw the borders
-        if (m_bordersCached != Borders{0})
+        Color backgroundColor;
+        if (!m_enabled && m_backgroundColorDisabledCached.isSet())
+            backgroundColor = m_backgroundColorDisabledCached;
+        else
+            backgroundColor = m_backgroundColorCached;
+
+        if ((m_roundedBorderRadiusCached > 0) && !m_spriteBackground.isSet())
         {
-            target.drawBorders(states, m_bordersCached, getSize(), Color::applyOpacity(m_borderColorCached, m_opacityCached));
+            target.drawRoundedRectangle(states, getSize(), Color::applyOpacity(backgroundColor, m_opacityCached),
+                                        m_roundedBorderRadiusCached, m_bordersCached, Color::applyOpacity(m_borderColorCached, m_opacityCached));
             states.transform.translate(m_bordersCached.getOffset());
         }
-
-        RenderStates statesForText = states;
-
-        // Draw the background
-        if (m_spriteBackground.isSet())
-        {
-            if (!m_enabled && m_spriteBackgroundDisabled.isSet())
-                target.drawSprite(states, m_spriteBackgroundDisabled);
-            else
-                target.drawSprite(states, m_spriteBackground);
-        }
         else
         {
-            if (!m_enabled && m_backgroundColorDisabledCached.isSet())
-                target.drawFilledRect(states, getInnerSize(), Color::applyOpacity(m_backgroundColorDisabledCached, m_opacityCached));
+            // Draw the borders
+            if (m_bordersCached != Borders{0})
+            {
+                target.drawBorders(states, m_bordersCached, getSize(), Color::applyOpacity(m_borderColorCached, m_opacityCached));
+                states.transform.translate(m_bordersCached.getOffset());
+            }
+
+            // Draw the background
+            if (m_spriteBackground.isSet())
+            {
+                if (!m_enabled && m_spriteBackgroundDisabled.isSet())
+                    target.drawSprite(states, m_spriteBackgroundDisabled);
+                else
+                    target.drawSprite(states, m_spriteBackground);
+            }
             else
-                target.drawFilledRect(states, getInnerSize(), Color::applyOpacity(m_backgroundColorCached, m_opacityCached));
+                target.drawFilledRect(states, getInnerSize(), Color::applyOpacity(backgroundColor, m_opacityCached));
         }
 
+        RenderStates statesForText = states;
+
         // Check if we have a texture for the arrow
         float arrowSize;
         if (m_spriteArrow.isSet())
@@ -1073,15 +1115,24 @@ namespace tgui
         }
         else // There are no textures for the arrow
         {
-            arrowSize = getInnerSize().y - m_paddingCached.getTop() - m_paddingCached.getBottom();
+            arrowSize = getInnerSize().y - m_paddingCached.getTopPlusBottom();
             states.transform.translate({getInnerSize().x - m_paddingCached.getRight() - arrowSize, m_paddingCached.getTop()});
 
+            Color arrowBackgroundColor;
             if (!m_enabled && m_arrowBackgroundColorDisabledCached.isSet())
-                target.drawFilledRect(states, {arrowSize, arrowSize}, Color::applyOpacity(m_arrowBackgroundColorDisabledCached, m_opacityCached));
+                arrowBackgroundColor = m_arrowBackgroundColorDisabledCached;
             else if (m_mouseHover && m_arrowBackgroundColorHoverCached.isSet())
-                target.drawFilledRect(states, {arrowSize, arrowSize}, Color::applyOpacity(m_arrowBackgroundColorHoverCached, m_opacityCached));
+                arrowBackgroundColor = m_arrowBackgroundColorHoverCached;
             else
-                target.drawFilledRect(states, {arrowSize, arrowSize}, Color::applyOpacity(m_arrowBackgroundColorCached, m_opacityCached));
+                arrowBackgroundColor = m_arrowBackgroundColorCached;
+
+            if ((m_roundedBorderRadiusCached > 0) && (m_roundedBorderRadiusCached > m_bordersCached.getTop()))
+            {
+                const float roundedRadius = m_roundedBorderRadiusCached - m_bordersCached.getTop();
+                target.drawRoundedRectangle(states, {arrowSize, arrowSize}, Color::applyOpacity(arrowBackgroundColor, m_opacityCached), roundedRadius, {}, {});
+            }
+            else
+                target.drawFilledRect(states, {arrowSize, arrowSize}, Color::applyOpacity(arrowBackgroundColor, m_opacityCached));
 
             Vertex::Color arrowVertexColor;
             if (!m_enabled && m_arrowColorDisabledCached.isSet())
@@ -1103,10 +1154,10 @@ namespace tgui
         if (((selectedItemIndex >= 0) && !m_text.getString().empty()) || ((selectedItemIndex < 0) && !m_defaultText.getString().empty()))
         {
             target.addClippingLayer(statesForText, {{m_paddingCached.getLeft(), m_paddingCached.getTop()},
-                {getInnerSize().x - m_paddingCached.getLeft() - m_paddingCached.getRight() - arrowSize, getInnerSize().y - m_paddingCached.getTop() - m_paddingCached.getBottom()}});
+                {getInnerSize().x - m_paddingCached.getLeftPlusRight() - arrowSize, getInnerSize().y - m_paddingCached.getTopPlusBottom()}});
 
             statesForText.transform.translate({m_paddingCached.getLeft() + m_text.getExtraHorizontalPadding(),
-                                               m_paddingCached.getTop() + (((getInnerSize().y - m_paddingCached.getTop() - m_paddingCached.getBottom()) - m_text.getSize().y) / 2.0f)});
+                                               m_paddingCached.getTop() + (((getInnerSize().y - m_paddingCached.getTopPlusBottom()) - m_text.getSize().y) / 2.0f)});
 
             if (selectedItemIndex >= 0)
                 target.drawText(statesForText, m_text);
