@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -26,9 +26,7 @@
 #include <TGUI/Container.hpp>
 #include <TGUI/Backend/Window/BackendGui.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <cmath>
-#endif
+#include <cmath>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -47,7 +45,7 @@ namespace tgui
     {
         if (initRenderer)
         {
-            m_renderer = aurora::makeCopied<ContextMenuRenderer>();
+            m_renderer = makeCopied<ContextMenuRenderer>();
             setRenderer(Theme::getDefault()->getRendererNoThrow(m_type));
 
             setTextSize(getGlobalTextSize());
@@ -69,29 +67,28 @@ namespace tgui
     {
         if (menuBar)
             return std::static_pointer_cast<ContextMenu>(menuBar->clone());
-        else
-            return nullptr;
+        return nullptr;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     ContextMenuRenderer* ContextMenu::getSharedRenderer()
     {
-        return aurora::downcast<ContextMenuRenderer*>(MenuWidgetBase::getSharedRenderer());
+        return downcast<ContextMenuRenderer*>(MenuWidgetBase::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     const ContextMenuRenderer* ContextMenu::getSharedRenderer() const
     {
-        return aurora::downcast<const ContextMenuRenderer*>(MenuWidgetBase::getSharedRenderer());
+        return downcast<const ContextMenuRenderer*>(MenuWidgetBase::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     ContextMenuRenderer* ContextMenu::getRenderer()
     {
-        return aurora::downcast<ContextMenuRenderer*>(MenuWidgetBase::getRenderer());
+        return downcast<ContextMenuRenderer*>(MenuWidgetBase::getRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -334,7 +331,7 @@ namespace tgui
         if (hierarchy.empty())
             return false;
 
-        auto* menuItem = findMenuItem(hierarchy, m_menu.menuItems);
+        const auto* menuItem = findMenuItem(hierarchy, m_menu.menuItems);
         if (!menuItem)
             return false;
 
