@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -22,13 +22,11 @@
 //
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-#include <TGUI/Container.hpp>
 #include <TGUI/Widgets/EditBox.hpp>
 #include <TGUI/Keyboard.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <cmath>
-#endif
+#include <algorithm>
+#include <cmath>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -60,14 +58,14 @@ namespace tgui
 
         if (initRenderer)
         {
-            m_renderer = aurora::makeCopied<EditBoxRenderer>();
+            m_renderer = makeCopied<EditBoxRenderer>();
             setRenderer(Theme::getDefault()->getRendererNoThrow(m_type));
 
             m_defaultText.setColor(getSharedRenderer()->getDefaultTextColor()); // Needs to be set here in case renderer lacks "DefaultTextColor" property
 
             setTextSize(getGlobalTextSize());
             setSize({m_textFull.getLineHeight() * 10,
-                     std::round(m_textFull.getLineHeight() * 1.25f) + m_paddingCached.getTop() + m_paddingCached.getBottom() + m_bordersCached.getTop() + m_bordersCached.getBottom()});
+                     std::round(m_textFull.getLineHeight() * 1.25f) + m_paddingCached.getTopPlusBottom() + m_bordersCached.getTopPlusBottom()});
         }
     }
 
@@ -84,29 +82,28 @@ namespace tgui
     {
         if (editBox)
             return std::static_pointer_cast<EditBox>(editBox->clone());
-        else
-            return nullptr;
+        return nullptr;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     EditBoxRenderer* EditBox::getSharedRenderer()
     {
-        return aurora::downcast<EditBoxRenderer*>(Widget::getSharedRenderer());
+        return downcast<EditBoxRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     const EditBoxRenderer* EditBox::getSharedRenderer() const
     {
-        return aurora::downcast<const EditBoxRenderer*>(Widget::getSharedRenderer());
+        return downcast<const EditBoxRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     EditBoxRenderer* EditBox::getRenderer()
     {
-        return aurora::downcast<EditBoxRenderer*>(Widget::getRenderer());
+        return downcast<EditBoxRenderer*>(Widget::getRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -339,8 +336,7 @@ namespace tgui
     void EditBox::setCaretPosition(std::size_t charactersBeforeCaret)
     {
         // The caret position has to stay inside the string
-        if (charactersBeforeCaret > m_text.length())
-            charactersBeforeCaret = m_text.length();
+        charactersBeforeCaret = std::min(charactersBeforeCaret, m_text.length());
 
         // Set the caret to the correct position
         m_selStart = charactersBeforeCaret;
@@ -582,6 +578,10 @@ namespace tgui
             onReturnKeyPress.emit(this, m_text);
             emitReturnOrUnfocus(m_text);
         }
+        else if (keyboard::isKeyPressDeleteWordLeft(event))
+            deleteWordLeft();
+        else if (keyboard::isKeyPressDeleteWordRight(event))
+            deleteWordRight();
         else if (event.code == Event::KeyboardKey::Backspace)
             backspaceKeyPressed();
         else if (event.code == Event::KeyboardKey::Delete)
@@ -654,8 +654,7 @@ namespace tgui
         {
             return true;
         }
-        else
-            return ClickableWidget::canHandleKeyPress(event);
+        return ClickableWidget::canHandleKeyPress(event);
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -732,14 +731,13 @@ namespace tgui
     {
         if (signalName == onTextChange.getName())
             return onTextChange;
-        else if (signalName == onReturnKeyPress.getName())
+        if (signalName == onReturnKeyPress.getName())
             return onReturnKeyPress;
-        else if (signalName == onReturnOrUnfocus.getName())
+        if (signalName == onReturnOrUnfocus.getName())
             return onReturnOrUnfocus;
-        else if (signalName == onCaretPositionChange.getName())
+        if (signalName == onCaretPositionChange.getName())
             return onCaretPositionChange;
-        else
-            return ClickableWidget::getSignal(std::move(signalName));
+        return ClickableWidget::getSignal(std::move(signalName));
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -858,6 +856,10 @@ TGUI_IGNORE_DEPRECATED_WARNINGS_END
         {
             m_selectedTextBackgroundColorCached = getSharedRenderer()->getSelectedTextBackgroundColor();
         }
+        else if (property == U"RoundedBorderRadius")
+        {
+            m_roundedBorderRadiusCached = getSharedRenderer()->getRoundedBorderRadius();
+        }
         else if ((property == U"Opacity") || (property == U"OpacityDisabled"))
         {
             ClickableWidget::rendererChanged(property);
@@ -992,8 +994,8 @@ TGUI_IGNORE_DEPRECATED_WARNINGS_END
 
     Vector2f EditBox::getInnerSize() const
     {
-        return {std::max(0.f, getSize().x - m_bordersCached.getLeft() - m_bordersCached.getRight()),
-                std::max(0.f, getSize().y - m_bordersCached.getTop() - m_bordersCached.getBottom())};
+        return {std::max(0.f, getSize().x - m_bordersCached.getLeftPlusRight()),
+                std::max(0.f, getSize().y - m_bordersCached.getTopPlusBottom())};
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -1007,7 +1009,7 @@ TGUI_IGNORE_DEPRECATED_WARNINGS_END
             extraSuffixWidth = m_textSuffix.getSize().x + textOffset;
         }
 
-        return std::max(0.f, getSize().x - m_bordersCached.getLeft() - m_bordersCached.getRight() - m_paddingCached.getLeft() - m_paddingCached.getRight() - extraSuffixWidth);
+        return std::max(0.f, getSize().x - m_bordersCached.getLeftPlusRight() - m_paddingCached.getLeftPlusRight() - extraSuffixWidth);
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -1051,10 +1053,10 @@ TGUI_IGNORE_DEPRECATED_WARNINGS_END
                 prevChar = 0;
                 continue;
             }
-            else if (curChar == '\t')
-                charWidth = static_cast<float>(m_fontCached.getGlyph(' ', textSize, bold).advance) * 4;
+            if (curChar == '\t')
+                charWidth = m_fontCached.getGlyph(' ', textSize, bold).advance * 4;
             else
-                charWidth = static_cast<float>(m_fontCached.getGlyph(curChar, textSize, bold).advance);
+                charWidth = m_fontCached.getGlyph(curChar, textSize, bold).advance;
 
             const float kerning = m_fontCached.getKerning(prevChar, curChar, textSize, bold);
             if (width + charWidth < posX)
@@ -1161,7 +1163,7 @@ TGUI_IGNORE_DEPRECATED_WARNINGS_END
             textX += m_textBeforeSelection.findCharacterPos(charsBeforeSelection).x;
 
             // Set the position and size of the rectangle that gets drawn behind the selected text
-            m_selectedTextBackground.setSize({m_textSelection.findCharacterPos(m_selChars).x, getInnerSize().y - m_paddingCached.getTop() - m_paddingCached.getBottom()});
+            m_selectedTextBackground.setSize({m_textSelection.findCharacterPos(m_selChars).x, getInnerSize().y - m_paddingCached.getTopPlusBottom()});
             m_selectedTextBackground.setPosition({textX, m_paddingCached.getTop()});
 
             // Set the text selected text on the correct position
@@ -1359,6 +1361,32 @@ TGUI_IGNORE_DEPRECATED_WARNINGS_END
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
+    void EditBox::deleteWordLeft()
+    {
+        // If there is a selection then move the cursor to the beginning of the selection
+        if (m_selChars > 0)
+            moveCaretLeft(false);
+
+        moveCaretWordBegin(); // Only moves m_selEnd while m_selStart remains unchanged
+        updateSelection();
+        deleteSelectedCharacters();
+    }
+
+    /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+
+    void EditBox::deleteWordRight()
+    {
+        // If there is a selection then move the cursor to the end of the selection
+        if (m_selChars > 0)
+            moveCaretRight(false);
+
+        moveCaretWordEnd(); // Only moves m_selEnd while m_selStart remains unchanged
+        updateSelection();
+        deleteSelectedCharacters();
+    }
+
+    /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+
     void EditBox::backspaceKeyPressed()
     {
         if (m_readOnly)
@@ -1466,7 +1494,7 @@ TGUI_IGNORE_DEPRECATED_WARNINGS_END
 
         // Only continue pasting if you actually have to do something
         const auto clipboardContents = getBackend()->getClipboard();
-        if ((m_selChars > 0) || (clipboardContents.length() > 0))
+        if ((m_selChars > 0) || (!clipboardContents.empty()))
         {
             deleteSelectedCharacters();
 
@@ -1586,43 +1614,55 @@ TGUI_IGNORE_DEPRECATED_WARNINGS_END
 
     void EditBox::draw(BackendRenderTarget& target, RenderStates states) const
     {
-        // Draw the borders
-        if (m_bordersCached != Borders{0})
-        {
-            if (!m_enabled && m_borderColorDisabledCached.isSet())
-                target.drawBorders(states, m_bordersCached, getSize(), Color::applyOpacity(m_borderColorDisabledCached, m_opacityCached));
-            else if (m_mouseHover && m_borderColorHoverCached.isSet())
-                target.drawBorders(states, m_bordersCached, getSize(), Color::applyOpacity(m_borderColorHoverCached, m_opacityCached));
-            else if (m_focused && m_borderColorFocusedCached.isSet())
-                target.drawBorders(states, m_bordersCached, getSize(), Color::applyOpacity(m_borderColorFocusedCached, m_opacityCached));
-            else
-                target.drawBorders(states, m_bordersCached, getSize(), Color::applyOpacity(m_borderColorCached, m_opacityCached));
+        Color backgroundColor;
+        if (!m_enabled && m_backgroundColorDisabledCached.isSet())
+            backgroundColor = m_backgroundColorDisabledCached;
+        else if (m_mouseHover && m_backgroundColorHoverCached.isSet())
+            backgroundColor = m_backgroundColorHoverCached;
+        else if (m_focused && m_backgroundColorFocusedCached.isSet())
+            backgroundColor = m_backgroundColorFocusedCached;
+        else
+            backgroundColor = m_backgroundColorCached;
 
+        Color borderColor;
+        if (!m_enabled && m_borderColorDisabledCached.isSet())
+            borderColor = m_borderColorDisabledCached;
+        else if (m_mouseHover && m_borderColorHoverCached.isSet())
+            borderColor = m_borderColorHoverCached;
+        else if (m_focused && m_borderColorFocusedCached.isSet())
+            borderColor = m_borderColorFocusedCached;
+        else
+            borderColor = m_borderColorCached;
+
+        if ((m_roundedBorderRadiusCached > 0) && !m_sprite.isSet())
+        {
+            target.drawRoundedRectangle(states, getSize(), Color::applyOpacity(backgroundColor, m_opacityCached),
+                                        m_roundedBorderRadiusCached, m_bordersCached, Color::applyOpacity(borderColor, m_opacityCached));
             states.transform.translate(m_bordersCached.getOffset());
         }
+        else
+        {
+            // Draw the borders
+            if (m_bordersCached != Borders{0})
+            {
+                target.drawBorders(states, m_bordersCached, getSize(), Color::applyOpacity(borderColor, m_opacityCached));
+                states.transform.translate(m_bordersCached.getOffset());
+            }
 
-        // Draw the background
-        if (m_sprite.isSet())
-        {
-            if (!m_enabled && m_spriteDisabled.isSet())
-                target.drawSprite(states, m_spriteDisabled);
-            else if (m_mouseHover && m_spriteHover.isSet())
-                target.drawSprite(states, m_spriteHover);
-            else if (m_focused && m_spriteFocused.isSet())
-                target.drawSprite(states, m_spriteFocused);
-            else
-                target.drawSprite(states, m_sprite);
-        }
-        else // There is no background texture
-        {
-            if (!m_enabled && m_backgroundColorDisabledCached.isSet())
-                target.drawFilledRect(states, getInnerSize(), Color::applyOpacity(m_backgroundColorDisabledCached, m_opacityCached));
-            else if (m_mouseHover && m_backgroundColorHoverCached.isSet())
-                target.drawFilledRect(states, getInnerSize(), Color::applyOpacity(m_backgroundColorHoverCached, m_opacityCached));
-            else if (m_focused && m_backgroundColorFocusedCached.isSet())
-                target.drawFilledRect(states, getInnerSize(), Color::applyOpacity(m_backgroundColorFocusedCached, m_opacityCached));
-            else
-                target.drawFilledRect(states, getInnerSize(), Color::applyOpacity(m_backgroundColorCached, m_opacityCached));
+            // Draw the background
+            if (m_sprite.isSet())
+            {
+                if (!m_enabled && m_spriteDisabled.isSet())
+                    target.drawSprite(states, m_spriteDisabled);
+                else if (m_mouseHover && m_spriteHover.isSet())
+                    target.drawSprite(states, m_spriteHover);
+                else if (m_focused && m_spriteFocused.isSet())
+                    target.drawSprite(states, m_spriteFocused);
+                else
+                    target.drawSprite(states, m_sprite);
+            }
+            else // There is no background texture
+                target.drawFilledRect(states, getInnerSize(), Color::applyOpacity(backgroundColor, m_opacityCached));
         }
 
         // Draw the suffix
@@ -1630,11 +1670,11 @@ TGUI_IGNORE_DEPRECATED_WARNINGS_END
         if (!m_textSuffix.getString().empty())
         {
             target.addClippingLayer(states, {{m_paddingCached.getLeft(), m_paddingCached.getTop()},
-                {getInnerSize().x - m_paddingCached.getLeft() - m_paddingCached.getRight(), getInnerSize().y - m_paddingCached.getTop() - m_paddingCached.getBottom()}});
+                {getInnerSize().x - m_paddingCached.getLeftPlusRight(), getInnerSize().y - m_paddingCached.getTopPlusBottom()}});
 
             const float textOffset = m_textFull.getExtraHorizontalPadding();
-            Vector2f offset{getInnerSize().x - m_paddingCached.getRight() - textOffset - m_textSuffix.getSize().x,
-                            m_paddingCached.getTop() + ((getInnerSize().y - m_paddingCached.getTop() - m_paddingCached.getBottom() - m_textSuffix.getSize().y) / 2.f)};
+            const Vector2f offset{getInnerSize().x - m_paddingCached.getRight() - textOffset - m_textSuffix.getSize().x,
+                                  m_paddingCached.getTop() + ((getInnerSize().y - m_paddingCached.getTopPlusBottom() - m_textSuffix.getSize().y) / 2.f)};
 
             states.transform.translate(offset);
             target.drawText(states, m_textSuffix);
@@ -1648,7 +1688,7 @@ TGUI_IGNORE_DEPRECATED_WARNINGS_END
         // Draw the text
         {
             target.addClippingLayer(states, {{m_paddingCached.getLeft(), m_paddingCached.getTop()},
-                {getInnerSize().x - m_paddingCached.getLeft() - m_paddingCached.getRight() - suffixSpace, getInnerSize().y - m_paddingCached.getTop() - m_paddingCached.getBottom()}});
+                {getInnerSize().x - m_paddingCached.getLeftPlusRight() - suffixSpace, getInnerSize().y - m_paddingCached.getTopPlusBottom()}});
 
             if (!m_textBeforeSelection.getString().empty() || !m_textSelection.getString().empty())
             {
