@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -39,7 +39,7 @@ namespace tgui
     {
         if (initRenderer)
         {
-            m_renderer = aurora::makeCopied<GroupRenderer>();
+            m_renderer = makeCopied<GroupRenderer>();
             setRenderer(Theme::getDefault()->getRendererNoThrow(m_type));
         }
     }
@@ -59,29 +59,28 @@ namespace tgui
     {
         if (group)
             return std::static_pointer_cast<Group>(group->clone());
-        else
-            return nullptr;
+        return nullptr;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     GroupRenderer* Group::getSharedRenderer()
     {
-        return aurora::downcast<GroupRenderer*>(Widget::getSharedRenderer());
+        return downcast<GroupRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     const GroupRenderer* Group::getSharedRenderer() const
     {
-        return aurora::downcast<const GroupRenderer*>(Widget::getSharedRenderer());
+        return downcast<const GroupRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     GroupRenderer* Group::getRenderer()
     {
-        return aurora::downcast<GroupRenderer*>(Widget::getRenderer());
+        return downcast<GroupRenderer*>(Widget::getRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -97,8 +96,8 @@ namespace tgui
 
     Vector2f Group::getInnerSize() const
     {
-        return {std::max(0.f, getSize().x - m_paddingCached.getLeft() - m_paddingCached.getRight()),
-                std::max(0.f, getSize().y - m_paddingCached.getTop() - m_paddingCached.getBottom())};
+        return {std::max(0.f, getSize().x - m_paddingCached.getLeftPlusRight()),
+                std::max(0.f, getSize().y - m_paddingCached.getTopPlusBottom())};
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -149,8 +148,8 @@ namespace tgui
     {
         states.transform.translate({m_paddingCached.getLeft(), m_paddingCached.getTop()});
 
-        const Vector2f innerSize = {getSize().x - m_paddingCached.getLeft() - m_paddingCached.getRight(),
-                                    getSize().y - m_paddingCached.getTop() - m_paddingCached.getBottom()};
+        const Vector2f innerSize = {getSize().x - m_paddingCached.getLeftPlusRight(),
+                                    getSize().y - m_paddingCached.getTopPlusBottom()};
 
         target.addClippingLayer(states, {{}, innerSize});
 
