@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -24,9 +24,7 @@
 
 #include <TGUI/Widgets/HorizontalLayout.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <numeric>
-#endif
+#include <numeric>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -43,7 +41,7 @@ namespace tgui
     {
         if (initRenderer)
         {
-            m_renderer = aurora::makeCopied<BoxLayoutRenderer>();
+            m_renderer = makeCopied<BoxLayoutRenderer>();
             setRenderer(Theme::getDefault()->getRendererNoThrow(m_type));
         }
     }
@@ -63,8 +61,7 @@ namespace tgui
     {
         if (layout)
             return std::static_pointer_cast<HorizontalLayout>(layout->clone());
-        else
-            return nullptr;
+        return nullptr;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -72,8 +69,8 @@ namespace tgui
     void HorizontalLayout::updateWidgets()
     {
         const float totalSpaceBetweenWidgets = (m_spaceBetweenWidgetsCached * m_widgets.size()) - m_spaceBetweenWidgetsCached;
-        const Vector2f contentSize = {getSize().x - m_paddingCached.getLeft() - m_paddingCached.getRight(),
-                                          getSize().y - m_paddingCached.getTop() - m_paddingCached.getBottom()};
+        const Vector2f contentSize = {getSize().x - m_paddingCached.getLeftPlusRight(),
+                                      getSize().y - m_paddingCached.getTopPlusBottom()};
 
         const float totalRatio = std::accumulate(m_ratios.begin(), m_ratios.end(), 0.f);
 
