@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -23,6 +23,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
 #include <TGUI/Widgets/HorizontalWrap.hpp>
+#include <algorithm>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -39,7 +40,7 @@ namespace tgui
     {
         if (initRenderer)
         {
-            m_renderer = aurora::makeCopied<BoxLayoutRenderer>();
+            m_renderer = makeCopied<BoxLayoutRenderer>();
             setRenderer(Theme::getDefault()->getRendererNoThrow(m_type));
         }
     }
@@ -59,16 +60,15 @@ namespace tgui
     {
         if (layout)
             return std::static_pointer_cast<HorizontalWrap>(layout->clone());
-        else
-            return nullptr;
+        return nullptr;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     void HorizontalWrap::updateWidgets()
     {
-        const Vector2f contentSize = {getSize().x - m_paddingCached.getLeft() - m_paddingCached.getRight(),
-                                      getSize().y - m_paddingCached.getTop() - m_paddingCached.getBottom()};
+        const Vector2f contentSize = {getSize().x - m_paddingCached.getLeftPlusRight(),
+                                      getSize().y - m_paddingCached.getTopPlusBottom()};
 
         float currentHorizontalOffset = 0;
         float currentVerticalOffset = 0;
@@ -88,8 +88,7 @@ namespace tgui
 
             currentHorizontalOffset += size.x + m_spaceBetweenWidgetsCached;
 
-            if (lineHeight < size.y)
-                lineHeight = size.y;
+            lineHeight = std::max(lineHeight, size.y);
         }
     }
 
