@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -24,12 +24,11 @@
 
 #include <TGUI/Widgets/Knob.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <cmath>
+#include <algorithm>
+#include <cmath>
 
-    #if defined(__cpp_lib_math_constants) && (__cpp_lib_math_constants >= 201907L)
-        #include <numbers>
-    #endif
+#if defined(__cpp_lib_math_constants) && (__cpp_lib_math_constants >= 201907L)
+    #include <numbers>
 #endif
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -57,7 +56,7 @@ namespace tgui
     {
         if (initRenderer)
         {
-            m_renderer = aurora::makeCopied<KnobRenderer>();
+            m_renderer = makeCopied<KnobRenderer>();
             setRenderer(Theme::getDefault()->getRendererNoThrow(m_type));
 
             setSize(140, 140);
@@ -77,29 +76,28 @@ namespace tgui
     {
         if (knob)
             return std::static_pointer_cast<Knob>(knob->clone());
-        else
-            return nullptr;
+        return nullptr;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     KnobRenderer* Knob::getSharedRenderer()
     {
-        return aurora::downcast<KnobRenderer*>(Widget::getSharedRenderer());
+        return downcast<KnobRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     const KnobRenderer* Knob::getSharedRenderer() const
     {
-        return aurora::downcast<const KnobRenderer*>(Widget::getSharedRenderer());
+        return downcast<const KnobRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     KnobRenderer* Knob::getRenderer()
     {
-        return aurora::downcast<KnobRenderer*>(Widget::getRenderer());
+        return downcast<KnobRenderer*>(Widget::getRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -174,8 +172,7 @@ namespace tgui
             m_minimum = minimum;
 
             // The maximum can't be below the minimum
-            if (m_maximum < m_minimum)
-                m_maximum = m_minimum;
+            m_maximum = std::max(m_maximum, m_minimum);
 
             // When the value is below the minimum then adjust it
             if (m_value < m_minimum)
@@ -203,8 +200,7 @@ namespace tgui
             m_maximum = maximum;
 
             // The minimum can't be below the maximum
-            if (m_minimum > m_maximum)
-                m_minimum = m_maximum;
+            m_minimum = std::min(m_minimum, m_maximum);
 
             // When the value is above the maximum then adjust it
             if (m_value > m_maximum)
@@ -464,8 +460,7 @@ namespace tgui
     {
         if (signalName == onValueChange.getName())
             return onValueChange;
-        else
-            return Widget::getSignal(std::move(signalName));
+        return Widget::getSignal(std::move(signalName));
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -556,9 +551,8 @@ namespace tgui
     {
         if (m_spriteBackground.isSet())
             return getSize();
-        else
-            return {std::max(0.f, getSize().x - m_bordersCached.getLeft() - m_bordersCached.getRight()),
-                    std::max(0.f, getSize().y - m_bordersCached.getTop() - m_bordersCached.getBottom())};
+        return {std::max(0.f, getSize().x - m_bordersCached.getLeftPlusRight()),
+                std::max(0.f, getSize().y - m_bordersCached.getTopPlusBottom())};
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
