@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -24,10 +24,8 @@
 
 #include <TGUI/Widgets/Label.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <numeric> // accumulate
-    #include <algorithm>
-#endif
+#include <numeric> // accumulate
+#include <algorithm>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -44,7 +42,7 @@ namespace tgui
     {
         if (initRenderer)
         {
-            m_renderer = aurora::makeCopied<LabelRenderer>();
+            m_renderer = makeCopied<LabelRenderer>();
             setRenderer(Theme::getDefault()->getRendererNoThrow(m_type));
 
             setTextSize(getGlobalTextSize());
@@ -72,29 +70,28 @@ namespace tgui
     {
         if (label)
             return std::static_pointer_cast<Label>(label->clone());
-        else
-            return nullptr;
+        return nullptr;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     LabelRenderer* Label::getSharedRenderer()
     {
-        return aurora::downcast<LabelRenderer*>(Widget::getSharedRenderer());
+        return downcast<LabelRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     const LabelRenderer* Label::getSharedRenderer() const
     {
-        return aurora::downcast<const LabelRenderer*>(Widget::getSharedRenderer());
+        return downcast<const LabelRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     LabelRenderer* Label::getRenderer()
     {
-        return aurora::downcast<LabelRenderer*>(Widget::getRenderer());
+        return downcast<LabelRenderer*>(Widget::getRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -106,8 +103,8 @@ namespace tgui
         m_bordersCached.updateParentSize(getSize());
         m_paddingCached.updateParentSize(getSize());
 
-        m_spriteBackground.setSize({getSize().x - m_bordersCached.getLeft() - m_bordersCached.getRight(),
-                                    getSize().y - m_bordersCached.getTop() - m_bordersCached.getBottom()});
+        m_spriteBackground.setSize({getSize().x - m_bordersCached.getLeftPlusRight(),
+                                    getSize().y - m_bordersCached.getTopPlusBottom()});
 
         // You are no longer auto-sizing
         m_autoSize = false;
@@ -116,9 +113,9 @@ namespace tgui
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-    void Label::setText(const String& string)
+    void Label::setText(const String& text)
     {
-        m_string = string;
+        m_string = text;
         rearrangeText();
     }
 
@@ -237,8 +234,7 @@ namespace tgui
     {
         if (m_autoSize)
             return m_maximumTextWidth;
-        else
-            return getSize().x;
+        return getSize().x;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -378,8 +374,7 @@ namespace tgui
     {
         if (signalName == onDoubleClick.getName())
             return onDoubleClick;
-        else
-            return ClickableWidget::getSignal(std::move(signalName));
+        return ClickableWidget::getSignal(std::move(signalName));
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -390,8 +385,8 @@ namespace tgui
         {
             m_bordersCached = getSharedRenderer()->getBorders();
             m_bordersCached.updateParentSize(getSize());
-            m_spriteBackground.setSize({getSize().x - m_bordersCached.getLeft() - m_bordersCached.getRight(),
-                                        getSize().y - m_bordersCached.getTop() - m_bordersCached.getBottom()});
+            m_spriteBackground.setSize({getSize().x - m_bordersCached.getLeftPlusRight(),
+                                        getSize().y - m_bordersCached.getTopPlusBottom()});
             rearrangeText();
         }
         else if (property == U"Padding")
@@ -521,7 +516,7 @@ namespace tgui
         if (node->propertyValuePairs[U"HorizontalAlignment"])
         {
             // TGUI_NEXT: Remove "tgui::" prefixes
-            String alignment = Deserializer::deserialize(ObjectConverter::Type::String, node->propertyValuePairs[U"HorizontalAlignment"]->value).getString();
+            const String alignment = Deserializer::deserialize(ObjectConverter::Type::String, node->propertyValuePairs[U"HorizontalAlignment"]->value).getString();
             if (alignment == U"Right")
                 setHorizontalAlignment(tgui::HorizontalAlignment::Right);
             else if (alignment == U"Center")
@@ -533,7 +528,7 @@ namespace tgui
         if (node->propertyValuePairs[U"VerticalAlignment"])
         {
             // TGUI_NEXT: Remove "tgui::" prefixes
-            String alignment = Deserializer::deserialize(ObjectConverter::Type::String, node->propertyValuePairs[U"VerticalAlignment"]->value).getString();
+            const String alignment = Deserializer::deserialize(ObjectConverter::Type::String, node->propertyValuePairs[U"VerticalAlignment"]->value).getString();
             if (alignment == U"Bottom")
                 setVerticalAlignment(tgui::VerticalAlignment::Bottom);
             else if (alignment == U"Center")
@@ -597,7 +592,7 @@ namespace tgui
             maxWidth = std::max(0.f, m_maximumTextWidth - 2*textOffset);
         else
         {
-            maxWidth = getSize().x - m_bordersCached.getLeft() - m_bordersCached.getRight() - m_paddingCached.getLeft() - m_paddingCached.getRight() - 2*textOffset;
+            maxWidth = getSize().x - m_bordersCached.getLeftPlusRight() - m_paddingCached.getLeftPlusRight() - 2*textOffset;
 
             // If the scrollbar is always visible then we take it into account, otherwise we assume there is no scrollbar.
             // If the policy is Automatic then we will take it into account later if we find that the text needs a scrollbar.
@@ -643,7 +638,7 @@ namespace tgui
                                    + Text::getExtraVerticalPadding(m_textSizeCached);
             }
 
-            m_scrollbar->setHeight(static_cast<unsigned int>(getSize().y - m_bordersCached.getTop() - m_bordersCached.getBottom()));
+            m_scrollbar->setHeight(static_cast<unsigned int>(getSize().y - m_bordersCached.getTopPlusBottom()));
             m_scrollbar->setViewportSize(static_cast<unsigned int>(getSize().y - outline.getTop() - outline.getBottom()));
             m_scrollbar->setMaximum(static_cast<unsigned int>(requiredTextHeight));
             m_scrollbar->setPosition({getSize().x - m_bordersCached.getRight() - m_scrollbar->getSize().x, m_bordersCached.getTop()});
@@ -672,8 +667,7 @@ namespace tgui
             else
                 textPiece.setString(stringPtr->substr(searchPosStart));
 
-            if (textPiece.getSize().x > width)
-                width = textPiece.getSize().x;
+            width = std::max(textPiece.getSize().x, width);
 
             searchPosStart = newLinePos + 1;
         }
@@ -686,8 +680,8 @@ namespace tgui
             m_bordersCached.updateParentSize(getSize());
             m_paddingCached.updateParentSize(getSize());
 
-            m_spriteBackground.setSize({getSize().x - m_bordersCached.getLeft() - m_bordersCached.getRight(),
-                                        getSize().y - m_bordersCached.getTop() - m_bordersCached.getBottom()});
+            m_spriteBackground.setSize({getSize().x - m_bordersCached.getLeftPlusRight(),
+                                        getSize().y - m_bordersCached.getTopPlusBottom()});
         }
 
         updateTextPiecePositions((maxWidth > 0) ? maxWidth : width);
@@ -761,8 +755,8 @@ namespace tgui
             auto& line = m_lines[i];
 
             float maxHeight = 0;
-            for (std::size_t j = 0; j < line.size(); ++j)
-                maxHeight = std::max(maxHeight, line[j].getSize().y);
+            for (const auto& text : line)
+                maxHeight = std::max(maxHeight, text.getSize().y);
 
             Vector2f piecePos = pos;
             if ((m_horizontalAlignment != tgui::HorizontalAlignment::Left) && !line.empty()) // TGUI_NEXT: Remove "tgui::" prefix
@@ -825,14 +819,14 @@ namespace tgui
     {
         const RenderStates statesForScrollbar = states;
 
-        Vector2f innerSize = {getSize().x - m_bordersCached.getLeft() - m_bordersCached.getRight(),
-                              getSize().y - m_bordersCached.getTop() - m_bordersCached.getBottom()};
+        Vector2f innerSize = {getSize().x - m_bordersCached.getLeftPlusRight(),
+                              getSize().y - m_bordersCached.getTopPlusBottom()};
 
         // Draw the borders
         if (m_bordersCached != Borders{0})
         {
             target.drawBorders(states, m_bordersCached, getSize(), Color::applyOpacity(m_borderColorCached, m_opacityCached));
-            states.transform.translate({m_bordersCached.getLeft(), m_bordersCached.getTop()});
+            states.transform.translate(m_bordersCached.getOffset());
         }
 
         // Draw the background
@@ -867,8 +861,8 @@ namespace tgui
         }
         else
         {
-            innerSize.x -= m_paddingCached.getLeft() + m_paddingCached.getRight();
-            innerSize.y -= m_paddingCached.getTop() + m_paddingCached.getBottom();
+            innerSize.x -= m_paddingCached.getLeftPlusRight();
+            innerSize.y -= m_paddingCached.getTopPlusBottom();
 
             target.addClippingLayer(states, {{m_paddingCached.getLeft(), m_paddingCached.getTop()}, innerSize});
 
