@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -24,9 +24,7 @@
 
 #include <TGUI/Widgets/ListBox.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <cmath>
-#endif
+#include <cmath>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -43,13 +41,13 @@ namespace tgui
     {
         if (initRenderer)
         {
-            m_renderer = aurora::makeCopied<ListBoxRenderer>();
+            m_renderer = makeCopied<ListBoxRenderer>();
             setRenderer(Theme::getDefault()->getRendererNoThrow(m_type));
 
             setTextSize(getGlobalTextSize());
             setItemHeight(static_cast<unsigned int>(std::round(Text::getLineHeight(m_fontCached, m_textSizeCached) * 1.25f)));
             setSize({Text::getLineHeight(m_fontCached, m_textSizeCached) * 10,
-                     (m_itemHeight * 7) + m_paddingCached.getTop() + m_paddingCached.getBottom() + m_bordersCached.getTop() + m_bordersCached.getBottom()});
+                     (m_itemHeight * 7) + m_paddingCached.getTopPlusBottom() + m_bordersCached.getTopPlusBottom()});
         }
     }
 
@@ -66,29 +64,28 @@ namespace tgui
     {
         if (listBox)
             return std::static_pointer_cast<ListBox>(listBox->clone());
-        else
-            return nullptr;
+        return nullptr;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     ListBoxRenderer* ListBox::getSharedRenderer()
     {
-        return aurora::downcast<ListBoxRenderer*>(Widget::getSharedRenderer());
+        return downcast<ListBoxRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     const ListBoxRenderer* ListBox::getSharedRenderer() const
     {
-        return aurora::downcast<const ListBoxRenderer*>(Widget::getSharedRenderer());
+        return downcast<const ListBoxRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     ListBoxRenderer* ListBox::getRenderer()
     {
-        return aurora::downcast<ListBoxRenderer*>(Widget::getRenderer());
+        return downcast<ListBoxRenderer*>(Widget::getRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -104,7 +101,7 @@ namespace tgui
 
         const bool scrollbarAtBottom = (m_scrollbar->getValue() == m_scrollbar->getMaxValue());
         m_scrollbar->setHeight(std::max(0.f, getInnerSize().y));
-        m_scrollbar->setViewportSize(static_cast<unsigned int>(getInnerSize().y - m_paddingCached.getTop() - m_paddingCached.getBottom()));
+        m_scrollbar->setViewportSize(static_cast<unsigned int>(getInnerSize().y - m_paddingCached.getTopPlusBottom()));
         if (scrollbarAtBottom && (m_scrollbar->getValue() != m_scrollbar->getMaxValue()))
             m_scrollbar->setValue(m_scrollbar->getMaxValue());
 
@@ -414,6 +411,7 @@ namespace tgui
     std::vector<String> ListBox::getItems() const
     {
         std::vector<String> items;
+        items.reserve(m_items.size());
         for (const auto& item : m_items)
             items.push_back(item.text.getString());
 
@@ -425,6 +423,7 @@ namespace tgui
     std::vector<String> ListBox::getItemIds() const
     {
         std::vector<String> ids;
+        ids.reserve(m_items.size());
         for (const auto& item : m_items)
             ids.push_back(item.id);
 
@@ -645,7 +644,7 @@ namespace tgui
         else
         {
             if (FloatRect{m_bordersCached.getLeft() + m_paddingCached.getLeft(), m_bordersCached.getTop() + m_paddingCached.getTop(),
-                          getInnerSize().x - m_paddingCached.getLeft() - m_paddingCached.getRight(), getInnerSize().y - m_paddingCached.getTop() - m_paddingCached.getBottom()}.contains(pos))
+                          getInnerSize().x - m_paddingCached.getLeftPlusRight(), getInnerSize().y - m_paddingCached.getTopPlusBottom()}.contains(pos))
             {
                 pos.y -= m_bordersCached.getTop() + m_paddingCached.getTop();
                 setSelectedItemBasedOnMousePos(pos);
@@ -708,7 +707,7 @@ namespace tgui
 
         int itemIndex = -1;
         if (FloatRect{m_bordersCached.getLeft() + m_paddingCached.getLeft(), m_bordersCached.getTop() + m_paddingCached.getTop(),
-                      getInnerSize().x - m_paddingCached.getLeft() - m_paddingCached.getRight(), getInnerSize().y - m_paddingCached.getTop() - m_paddingCached.getBottom()}.contains(pos))
+                      getInnerSize().x - m_paddingCached.getLeftPlusRight(), getInnerSize().y - m_paddingCached.getTopPlusBottom()}.contains(pos))
         {
             pos.y -= m_bordersCached.getTop() + m_paddingCached.getTop();
             setSelectedItemBasedOnMousePos(pos);
@@ -747,7 +746,7 @@ namespace tgui
 
             // Find out on which item the mouse is hovering
             if (FloatRect{m_bordersCached.getLeft() + m_paddingCached.getLeft(),
-                          m_bordersCached.getTop() + m_paddingCached.getTop(), getInnerSize().x - m_paddingCached.getLeft() - m_paddingCached.getRight(), getInnerSize().y - m_paddingCached.getTop() - m_paddingCached.getBottom()}.contains(pos))
+                          m_bordersCached.getTop() + m_paddingCached.getTop(), getInnerSize().x - m_paddingCached.getLeftPlusRight(), getInnerSize().y - m_paddingCached.getTopPlusBottom()}.contains(pos))
             {
                 pos.y -= m_bordersCached.getTop() + m_paddingCached.getTop();
                 setHoveredItemBasedOnMousePos(pos);
@@ -824,8 +823,7 @@ namespace tgui
     {
         if ((event.code == Event::KeyboardKey::Up) || (event.code == Event::KeyboardKey::Down))
             return true;
-        else
-            return Widget::canHandleKeyPress(event);
+        return Widget::canHandleKeyPress(event);
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -834,18 +832,17 @@ namespace tgui
     {
         if (signalName == onItemSelect.getName())
             return onItemSelect;
-        else if (signalName == onMousePress.getName())
+        if (signalName == onMousePress.getName())
             return onMousePress;
-        else if (signalName == onMouseRelease.getName())
+        if (signalName == onMouseRelease.getName())
             return onMouseRelease;
-        else if (signalName == onDoubleClick.getName())
+        if (signalName == onDoubleClick.getName())
             return onDoubleClick;
-        else if (signalName == onRightClick.getName())
+        if (signalName == onRightClick.getName())
             return onRightClick;
-        else if (signalName == onScroll.getName())
+        if (signalName == onScroll.getName())
             return onScroll;
-        else
-            return Widget::getSignal(std::move(signalName));
+        return Widget::getSignal(std::move(signalName));
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -1063,7 +1060,7 @@ namespace tgui
 
         if (node->propertyValuePairs[U"TextAlignment"])
         {
-            String alignment = Deserializer::deserialize(ObjectConverter::Type::String, node->propertyValuePairs[U"TextAlignment"]->value).getString();
+            const String alignment = Deserializer::deserialize(ObjectConverter::Type::String, node->propertyValuePairs[U"TextAlignment"]->value).getString();
             if (alignment == U"Right")
                 setTextAlignment(HorizontalAlignment::Right);
             else if (alignment == U"Center")
@@ -1088,8 +1085,8 @@ namespace tgui
 
     Vector2f ListBox::getInnerSize() const
     {
-        return {std::max(0.f, getSize().x - m_bordersCached.getLeft() - m_bordersCached.getRight()),
-                std::max(0.f, getSize().y - m_bordersCached.getTop() - m_bordersCached.getBottom())};
+        return {std::max(0.f, getSize().x - m_bordersCached.getLeftPlusRight()),
+                std::max(0.f, getSize().y - m_bordersCached.getTopPlusBottom())};
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -1256,11 +1253,11 @@ namespace tgui
 
         // Draw the items and their selected/hover backgrounds
         {
-            float maxItemWidth = getInnerSize().x - m_paddingCached.getLeft() - m_paddingCached.getRight();
+            float maxItemWidth = getInnerSize().x - m_paddingCached.getLeftPlusRight();
             if (m_scrollbar->isShown())
                 maxItemWidth -= m_scrollbar->getSize().x;
 
-            target.addClippingLayer(states, {{m_paddingCached.getLeft(), m_paddingCached.getTop()}, {maxItemWidth, getInnerSize().y - m_paddingCached.getTop() - m_paddingCached.getBottom()}});
+            target.addClippingLayer(states, {{m_paddingCached.getLeft(), m_paddingCached.getTop()}, {maxItemWidth, getInnerSize().y - m_paddingCached.getTopPlusBottom()}});
 
             // Find out which items are visible
             std::size_t firstItem = 0;
@@ -1282,7 +1279,7 @@ namespace tgui
             {
                 states.transform.translate({0, m_selectedItem * static_cast<float>(m_itemHeight)});
 
-                const Vector2f size = {getInnerSize().x - m_paddingCached.getLeft() - m_paddingCached.getRight(), static_cast<float>(m_itemHeight)};
+                const Vector2f size = {getInnerSize().x - m_paddingCached.getLeftPlusRight(), static_cast<float>(m_itemHeight)};
                 if ((m_selectedItem == m_hoveringItem) && m_selectedBackgroundColorHoverCached.isSet())
                     target.drawFilledRect(states, size, Color::applyOpacity(m_selectedBackgroundColorHoverCached, m_opacityCached));
                 else
@@ -1295,7 +1292,7 @@ namespace tgui
             if ((m_hoveringItem >= 0) && (m_hoveringItem != m_selectedItem) && m_backgroundColorHoverCached.isSet())
             {
                 states.transform.translate({0, m_hoveringItem * static_cast<float>(m_itemHeight)});
-                target.drawFilledRect(states, {getInnerSize().x - m_paddingCached.getLeft() - m_paddingCached.getRight(), static_cast<float>(m_itemHeight)}, Color::applyOpacity(m_backgroundColorHoverCached, m_opacityCached));
+                target.drawFilledRect(states, {getInnerSize().x - m_paddingCached.getLeftPlusRight(), static_cast<float>(m_itemHeight)}, Color::applyOpacity(m_backgroundColorHoverCached, m_opacityCached));
                 states.transform.translate({0, -m_hoveringItem * static_cast<float>(m_itemHeight)});
             }
 
