@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -25,9 +25,7 @@
 #include <TGUI/Widgets/MenuBar.hpp>
 #include <TGUI/Container.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <cmath>
-#endif
+#include <cmath>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -46,7 +44,7 @@ namespace tgui
     {
         if (initRenderer)
         {
-            m_renderer = aurora::makeCopied<MenuBarRenderer>();
+            m_renderer = makeCopied<MenuBarRenderer>();
             setRenderer(Theme::getDefault()->getRendererNoThrow(m_type));
 
             setTextSize(getGlobalTextSize());
@@ -69,29 +67,28 @@ namespace tgui
     {
         if (menuBar)
             return std::static_pointer_cast<MenuBar>(menuBar->clone());
-        else
-            return nullptr;
+        return nullptr;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     MenuBarRenderer* MenuBar::getSharedRenderer()
     {
-        return aurora::downcast<MenuBarRenderer*>(MenuWidgetBase::getSharedRenderer());
+        return downcast<MenuBarRenderer*>(MenuWidgetBase::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     const MenuBarRenderer* MenuBar::getSharedRenderer() const
     {
-        return aurora::downcast<const MenuBarRenderer*>(MenuWidgetBase::getSharedRenderer());
+        return downcast<const MenuBarRenderer*>(MenuWidgetBase::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     MenuBarRenderer* MenuBar::getRenderer()
     {
-        return aurora::downcast<MenuBarRenderer*>(MenuWidgetBase::getRenderer());
+        return downcast<MenuBarRenderer*>(MenuWidgetBase::getRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -131,8 +128,7 @@ namespace tgui
     {
         if (!m_menus.empty())
             return addMenuItem(m_menus.back().text.getString(), text);
-        else
-            return false;
+        return false;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -255,7 +251,7 @@ namespace tgui
 
     bool MenuBar::getMenuEnabled(const String& menuText) const
     {
-        for (auto& menu : m_menus)
+        for (const auto& menu : m_menus)
         {
             if (menu.text.getString() == menuText)
                 return menu.enabled;
@@ -313,7 +309,7 @@ namespace tgui
         if (hierarchy.size() < 2)
             return false;
 
-        auto* menuItem = findMenuItem(hierarchy, m_menus);
+        const auto* menuItem = findMenuItem(hierarchy, m_menus);
         if (!menuItem)
             return false;
 
@@ -702,7 +698,7 @@ namespace tgui
 
     void MenuBar::drawMenusOnBar(BackendRenderTarget& target, RenderStates states) const
     {
-        Transform oldTransform = states.transform;
+        const Transform oldTransform = states.transform;
 
         // Draw the backgrounds
         Sprite backgroundSprite = m_spriteItemBackground;
