@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -24,9 +24,8 @@
 
 #include <TGUI/Widgets/MessageBox.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <cmath>
-#endif
+#include <algorithm>
+#include <cmath>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -43,7 +42,7 @@ namespace tgui
     {
         if (initRenderer)
         {
-            m_renderer = aurora::makeCopied<MessageBoxRenderer>();
+            m_renderer = makeCopied<MessageBoxRenderer>();
             setRenderer(Theme::getDefault()->getRendererNoThrow(m_type));
 
             setTextSize(getGlobalTextSize());
@@ -139,7 +138,7 @@ namespace tgui
         auto messageBox = std::make_shared<MessageBox>();
         messageBox->setTitle(title);
         messageBox->setText(text);
-        for (auto& buttonText : buttons)
+        for (const auto& buttonText : buttons)
             messageBox->addButton(std::move(buttonText));
 
         return messageBox;
@@ -151,29 +150,28 @@ namespace tgui
     {
         if (messageBox)
             return std::static_pointer_cast<MessageBox>(messageBox->clone());
-        else
-            return nullptr;
+        return nullptr;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     MessageBoxRenderer* MessageBox::getSharedRenderer()
     {
-        return aurora::downcast<MessageBoxRenderer*>(Widget::getSharedRenderer());
+        return downcast<MessageBoxRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     const MessageBoxRenderer* MessageBox::getSharedRenderer() const
     {
-        return aurora::downcast<const MessageBoxRenderer*>(Widget::getSharedRenderer());
+        return downcast<const MessageBoxRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     MessageBoxRenderer* MessageBox::getRenderer()
     {
-        return aurora::downcast<MessageBoxRenderer*>(Widget::getRenderer());
+        return downcast<MessageBoxRenderer*>(Widget::getRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -282,6 +280,7 @@ namespace tgui
     std::vector<String> MessageBox::getButtons() const
     {
         std::vector<String> buttonTexts;
+        buttonTexts.reserve(m_buttons.size());
         for (const auto& button : m_buttons)
             buttonTexts.emplace_back(button->getText());
 
@@ -339,8 +338,7 @@ namespace tgui
                 tempText.setCharacterSize(m_textSizeCached);
                 tempText.setString(button->getText());
                 const float width = tempText.getSize().x;
-                if (buttonWidth < width * 10.0f / 9.0f)
-                    buttonWidth = width * 10.0f / 9.0f;
+                buttonWidth = std::max(buttonWidth, width * 10.0f / 9.0f);
             }
         }
 
@@ -357,8 +355,7 @@ namespace tgui
         Vector2f size = {2*distance + m_label->getSize().x, 3*distance + m_label->getSize().y + buttonHeight};
 
         // Make sure the buttons fit inside the message box
-        if (buttonsAreaWidth > size.x)
-            size.x = buttonsAreaWidth;
+        size.x = std::max(buttonsAreaWidth, size.x);
 
         // Set the size of the window
         if (m_autoSize)
@@ -419,8 +416,7 @@ namespace tgui
     {
         if (signalName == onButtonPress.getName())
             return onButtonPress;
-        else
-            return ChildWindow::getSignal(std::move(signalName));
+        return ChildWindow::getSignal(std::move(signalName));
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -536,7 +532,7 @@ namespace tgui
 
         for (const auto& widget : m_widgets)
         {
-            if ((widget->getWidgetName().length() >= 32) && (widget->getWidgetName().substr(0, 32) == U"#TGUI_INTERNAL$MessageBoxButton:"))
+            if ((widget->getWidgetName().length() >= 32) && (widget->getWidgetName().starts_with(U"#TGUI_INTERNAL$MessageBoxButton:")))
             {
                 auto button = std::dynamic_pointer_cast<Button>(widget);
                 m_buttons.push_back(button);
