@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -45,7 +45,7 @@ namespace tgui
 
         if (initRenderer)
         {
-            m_renderer = aurora::makeCopied<PanelRenderer>();
+            m_renderer = makeCopied<PanelRenderer>();
             setRenderer(Theme::getDefault()->getRendererNoThrow(m_type));
         }
     }
@@ -65,29 +65,28 @@ namespace tgui
     {
         if (panel)
             return std::static_pointer_cast<Panel>(panel->clone());
-        else
-            return nullptr;
+        return nullptr;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     PanelRenderer* Panel::getSharedRenderer()
     {
-        return aurora::downcast<PanelRenderer*>(Widget::getSharedRenderer());
+        return downcast<PanelRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     const PanelRenderer* Panel::getSharedRenderer() const
     {
-        return aurora::downcast<const PanelRenderer*>(Widget::getSharedRenderer());
+        return downcast<const PanelRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     PanelRenderer* Panel::getRenderer()
     {
-        return aurora::downcast<PanelRenderer*>(Widget::getRenderer());
+        return downcast<PanelRenderer*>(Widget::getRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -98,16 +97,16 @@ namespace tgui
 
         Group::setSize(size);
 
-        m_spriteBackground.setSize({getSize().x - m_bordersCached.getLeft() - m_bordersCached.getRight(),
-                                    getSize().y - m_bordersCached.getTop() - m_bordersCached.getBottom()});
+        m_spriteBackground.setSize({getSize().x - m_bordersCached.getLeftPlusRight(),
+                                    getSize().y - m_bordersCached.getTopPlusBottom()});
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     Vector2f Panel::getInnerSize() const
     {
-        return {std::max(0.f, getSize().x - m_bordersCached.getLeft() - m_bordersCached.getRight() - m_paddingCached.getLeft() - m_paddingCached.getRight()),
-                std::max(0.f, getSize().y - m_bordersCached.getTop() - m_bordersCached.getBottom() - m_paddingCached.getTop() - m_paddingCached.getBottom())};
+        return {std::max(0.f, getSize().x - m_bordersCached.getLeftPlusRight() - m_paddingCached.getLeftPlusRight()),
+                std::max(0.f, getSize().y - m_bordersCached.getTopPlusBottom() - m_paddingCached.getTopPlusBottom())};
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -255,20 +254,19 @@ namespace tgui
     {
         if (signalName == onMousePress.getName())
             return onMousePress;
-        else if (signalName == onMouseRelease.getName())
+        if (signalName == onMouseRelease.getName())
             return onMouseRelease;
-        else if (signalName == onClick.getName())
+        if (signalName == onClick.getName())
             return onClick;
-        else if (signalName == onDoubleClick.getName())
+        if (signalName == onDoubleClick.getName())
             return onDoubleClick;
-        else if (signalName == onRightMousePress.getName())
+        if (signalName == onRightMousePress.getName())
             return onRightMousePress;
-        else if (signalName == onRightMouseRelease.getName())
+        if (signalName == onRightMouseRelease.getName())
             return onRightMouseRelease;
-        else if (signalName == onRightClick.getName())
+        if (signalName == onRightClick.getName())
             return onRightClick;
-        else
-            return Group::getSignal(std::move(signalName));
+        return Group::getSignal(std::move(signalName));
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -324,14 +322,14 @@ namespace tgui
 
     void Panel::draw(BackendRenderTarget& target, RenderStates states) const
     {
-        const Vector2f innerSize = {getSize().x - m_bordersCached.getLeft() - m_bordersCached.getRight(),
-                                    getSize().y - m_bordersCached.getTop() - m_bordersCached.getBottom()};
+        const Vector2f innerSize = {getSize().x - m_bordersCached.getLeftPlusRight(),
+                                    getSize().y - m_bordersCached.getTopPlusBottom()};
 
         if ((m_roundedBorderRadius > 0) && !m_spriteBackground.isSet())
         {
             target.drawRoundedRectangle(states, getSize(), Color::applyOpacity(m_backgroundColorCached, m_opacityCached),
                                         m_roundedBorderRadius, m_bordersCached, Color::applyOpacity(m_borderColorCached, m_opacityCached));
-            states.transform.translate({m_bordersCached.getLeft(), m_bordersCached.getTop()});
+            states.transform.translate(m_bordersCached.getOffset());
         }
         else
         {
@@ -339,7 +337,7 @@ namespace tgui
             if (m_bordersCached != Borders{0})
             {
                 target.drawBorders(states, m_bordersCached, getSize(), Color::applyOpacity(m_borderColorCached, m_opacityCached));
-                states.transform.translate({m_bordersCached.getLeft(), m_bordersCached.getTop()});
+                states.transform.translate(m_bordersCached.getOffset());
             }
 
             // Draw the background
@@ -350,8 +348,8 @@ namespace tgui
         }
 
         states.transform.translate({m_paddingCached.getLeft(), m_paddingCached.getTop()});
-        const Vector2f contentSize = {innerSize.x - m_paddingCached.getLeft() - m_paddingCached.getRight(),
-                                      innerSize.y - m_paddingCached.getTop() - m_paddingCached.getBottom()};
+        const Vector2f contentSize = {innerSize.x - m_paddingCached.getLeftPlusRight(),
+                                      innerSize.y - m_paddingCached.getTopPlusBottom()};
 
         // Draw the child widgets
         target.addClippingLayer(states, {{}, contentSize});
