@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -39,7 +39,7 @@ namespace tgui
     {
         if (initRenderer)
         {
-            m_renderer = aurora::makeCopied<PictureRenderer>();
+            m_renderer = makeCopied<PictureRenderer>();
             setRenderer(Theme::getDefault()->getRendererNoThrow(m_type));
         }
     }
@@ -67,29 +67,28 @@ namespace tgui
     {
         if (picture)
             return std::static_pointer_cast<Picture>(picture->clone());
-        else
-            return nullptr;
+        return nullptr;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     PictureRenderer* Picture::getSharedRenderer()
     {
-        return aurora::downcast<PictureRenderer*>(Widget::getSharedRenderer());
+        return downcast<PictureRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     const PictureRenderer* Picture::getSharedRenderer() const
     {
-        return aurora::downcast<const PictureRenderer*>(Widget::getSharedRenderer());
+        return downcast<const PictureRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     PictureRenderer* Picture::getRenderer()
     {
-        return aurora::downcast<PictureRenderer*>(Widget::getRenderer());
+        return downcast<PictureRenderer*>(Widget::getRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -168,8 +167,7 @@ namespace tgui
     {
         if (signalName == onDoubleClick.getName())
             return onDoubleClick;
-        else
-            return ClickableWidget::getSignal(std::move(signalName));
+        return ClickableWidget::getSignal(std::move(signalName));
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
