@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -24,9 +24,8 @@
 
 #include <TGUI/Widgets/ProgressBar.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <cmath>
-#endif
+#include <algorithm>
+#include <cmath>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -46,12 +45,12 @@ namespace tgui
 
         if (initRenderer)
         {
-            m_renderer = aurora::makeCopied<ProgressBarRenderer>();
+            m_renderer = makeCopied<ProgressBarRenderer>();
             setRenderer(Theme::getDefault()->getRendererNoThrow(m_type));
 
             setTextSize(getGlobalTextSize());
             setSize({m_textBack.getLineHeight() * 15,
-                     std::round(m_textBack.getLineHeight() * 1.25f) + m_bordersCached.getTop() + m_bordersCached.getBottom()});
+                     std::round(m_textBack.getLineHeight() * 1.25f) + m_bordersCached.getTopPlusBottom()});
         }
     }
 
@@ -68,29 +67,28 @@ namespace tgui
     {
         if (progressBar)
             return std::static_pointer_cast<ProgressBar>(progressBar->clone());
-        else
-            return nullptr;
+        return nullptr;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     ProgressBarRenderer* ProgressBar::getSharedRenderer()
     {
-        return aurora::downcast<ProgressBarRenderer*>(Widget::getSharedRenderer());
+        return downcast<ProgressBarRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     const ProgressBarRenderer* ProgressBar::getSharedRenderer() const
     {
-        return aurora::downcast<const ProgressBarRenderer*>(Widget::getSharedRenderer());
+        return downcast<const ProgressBarRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     ProgressBarRenderer* ProgressBar::getRenderer()
     {
-        return aurora::downcast<ProgressBarRenderer*>(Widget::getRenderer());
+        return downcast<ProgressBarRenderer*>(Widget::getRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -118,12 +116,10 @@ namespace tgui
         m_minimum = minimum;
 
         // The minimum can never be greater than the maximum
-        if (m_minimum > m_maximum)
-            m_maximum = m_minimum;
+        m_maximum = std::max(m_minimum, m_maximum);
 
         // When the value is below the minimum then adjust it
-        if (m_value < m_minimum)
-            m_value = m_minimum;
+        m_value = std::max(m_value, m_minimum);
 
         // Recalculate the size of the front image (the size of the part that will be drawn)
         recalculateFillSize();
@@ -144,12 +140,10 @@ namespace tgui
         m_maximum = maximum;
 
         // The maximum can never be below the minimum
-        if (m_maximum < m_minimum)
-            m_minimum = m_maximum;
+        m_minimum = std::min(m_maximum, m_minimum);
 
         // When the value is above the maximum then adjust it
-        if (m_value > m_maximum)
-            m_value = m_maximum;
+        m_value = std::min(m_value, m_maximum);
 
         // Recalculate the size of the front image (the size of the part that will be drawn)
         recalculateFillSize();
@@ -256,10 +250,9 @@ namespace tgui
     {
         if (signalName == onValueChange.getName())
             return onValueChange;
-        else if (signalName == onFull.getName())
+        if (signalName == onFull.getName())
             return onFull;
-        else
-            return ClickableWidget::getSignal(std::move(signalName));
+        return ClickableWidget::getSignal(std::move(signalName));
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -383,7 +376,7 @@ namespace tgui
 
         if (node->propertyValuePairs[U"FillDirection"])
         {
-            String direction = node->propertyValuePairs[U"FillDirection"]->value.trim();
+            const String direction = node->propertyValuePairs[U"FillDirection"]->value.trim();
             if (direction == U"LeftToRight")
                 setFillDirection(ProgressBar::FillDirection::LeftToRight);
             else if (direction == U"RightToLeft")
@@ -424,8 +417,8 @@ namespace tgui
 
     Vector2f ProgressBar::getInnerSize() const
     {
-        return {std::max(0.f, getSize().x - m_bordersCached.getLeft() - m_bordersCached.getRight()),
-                std::max(0.f, getSize().y - m_bordersCached.getTop() - m_bordersCached.getBottom())};
+        return {std::max(0.f, getSize().x - m_bordersCached.getLeftPlusRight()),
+                std::max(0.f, getSize().y - m_bordersCached.getTopPlusBottom())};
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -519,7 +512,7 @@ namespace tgui
             target.drawSprite(states, m_spriteBackground);
         else
         {
-            Vector2f positionOffset = {m_backRect.left, m_backRect.top};
+            const Vector2f positionOffset = {m_backRect.left, m_backRect.top};
 
             states.transform.translate(positionOffset);
             target.drawFilledRect(states, {m_backRect.width, m_backRect.height}, Color::applyOpacity(m_backgroundColorCached, m_opacityCached));
@@ -543,7 +536,7 @@ namespace tgui
         }
         else // Using colors instead of a texture
         {
-            Vector2f positionOffset = {m_frontRect.left, m_frontRect.top};
+            const Vector2f positionOffset = {m_frontRect.left, m_frontRect.top};
 
             states.transform.translate(positionOffset);
             target.drawFilledRect(states, {m_frontRect.width, m_frontRect.height}, Color::applyOpacity(m_fillColorCached, m_opacityCached));
@@ -551,7 +544,7 @@ namespace tgui
         }
 
         // Draw the text
-        if (m_textBack.getString() != U"")
+        if (!m_textBack.getString().empty())
         {
             const Vector2f textTranslation = (getInnerSize() - m_textBack.getSize()) / 2.f;
 
