@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -40,12 +40,12 @@ namespace tgui
 
         if (initRenderer)
         {
-            m_renderer = aurora::makeCopied<RadioButtonRenderer>();
+            m_renderer = makeCopied<RadioButtonRenderer>();
             setRenderer(Theme::getDefault()->getRendererNoThrow(m_type));
 
             setTextSize(getGlobalTextSize());
-            setSize({m_text.getLineHeight() + m_bordersCached.getLeft() + m_bordersCached.getRight(),
-                     m_text.getLineHeight() + m_bordersCached.getTop() + m_bordersCached.getBottom()});
+            setSize({m_text.getLineHeight() + m_bordersCached.getLeftPlusRight(),
+                     m_text.getLineHeight() + m_bordersCached.getTopPlusBottom()});
         }
     }
 
@@ -62,29 +62,28 @@ namespace tgui
     {
         if (radioButton)
             return std::static_pointer_cast<RadioButton>(radioButton->clone());
-        else
-            return nullptr;
+        return nullptr;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     RadioButtonRenderer* RadioButton::getSharedRenderer()
     {
-        return aurora::downcast<RadioButtonRenderer*>(Widget::getSharedRenderer());
+        return downcast<RadioButtonRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     const RadioButtonRenderer* RadioButton::getSharedRenderer() const
     {
-        return aurora::downcast<const RadioButtonRenderer*>(Widget::getSharedRenderer());
+        return downcast<const RadioButtonRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     RadioButtonRenderer* RadioButton::getRenderer()
     {
-        return aurora::downcast<RadioButtonRenderer*>(Widget::getRenderer());
+        return downcast<RadioButtonRenderer*>(Widget::getRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -105,8 +104,7 @@ namespace tgui
     {
         if (getText().empty())
             return getSize();
-        else
-            return {getSize().x + (getSize().x * m_textDistanceRatioCached) + m_text.getSize().x, std::max(getSize().y, m_text.getSize().y)};
+        return {getSize().x + (getSize().x * m_textDistanceRatioCached) + m_text.getSize().x, std::max(getSize().y, m_text.getSize().y)};
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -115,8 +113,7 @@ namespace tgui
     {
         if (getText().empty() || (getSize().y >= m_text.getSize().y))
             return {0, 0};
-        else
-            return {0, -(m_text.getSize().y - getSize().y) / 2};
+        return {0, -(m_text.getSize().y - getSize().y) / 2};
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -154,7 +151,7 @@ namespace tgui
             if (m_parent)
             {
                 // Loop through all radio buttons in our parent and uncheck them
-                for (auto& widget : m_parent->getWidgets())
+                for (const auto& widget : m_parent->getWidgets())
                 {
                     if (widget->getWidgetType() == U"RadioButton")
                         std::static_pointer_cast<RadioButton>(widget)->setChecked(false);
@@ -295,8 +292,7 @@ namespace tgui
     {
         if ((event.code == Event::KeyboardKey::Space) || (event.code == Event::KeyboardKey::Enter))
             return true;
-        else
-            return ClickableWidget::canHandleKeyPress(event);
+        return ClickableWidget::canHandleKeyPress(event);
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -321,12 +317,11 @@ namespace tgui
     {
         if (signalName == onCheck.getName())
             return onCheck;
-        else if (signalName == onUncheck.getName())
+        if (signalName == onUncheck.getName())
             return onUncheck;
-        else if (signalName == onChange.getName())
+        if (signalName == onChange.getName())
             return onChange;
-        else
-            return ClickableWidget::getSignal(std::move(signalName));
+        return ClickableWidget::getSignal(std::move(signalName));
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -532,8 +527,8 @@ namespace tgui
 
     Vector2f RadioButton::getInnerSize() const
     {
-        return {std::max(0.f, getSize().x - m_bordersCached.getLeft() - m_bordersCached.getRight()),
-                std::max(0.f, getSize().y - m_bordersCached.getTop() - m_bordersCached.getBottom())};
+        return {std::max(0.f, getSize().x - m_bordersCached.getLeftPlusRight()),
+                std::max(0.f, getSize().y - m_bordersCached.getTopPlusBottom())};
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -542,10 +537,9 @@ namespace tgui
     {
         if (!m_enabled && m_checkColorDisabledCached.isSet())
             return m_checkColorDisabledCached;
-        else if (m_mouseHover && m_checkColorHoverCached.isSet())
+        if (m_mouseHover && m_checkColorHoverCached.isSet())
             return m_checkColorHoverCached;
-        else
-            return m_checkColorCached;
+        return m_checkColorCached;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -556,36 +550,27 @@ namespace tgui
         {
             if (!m_enabled && m_backgroundColorCheckedDisabledCached.isSet())
                 return m_backgroundColorCheckedDisabledCached;
-            else if (!m_enabled && m_backgroundColorDisabledCached.isSet())
+            if (!m_enabled && m_backgroundColorDisabledCached.isSet())
                 return m_backgroundColorDisabledCached;
-            else if (m_mouseHover)
+            if (m_mouseHover)
             {
                 if (m_backgroundColorCheckedHoverCached.isSet())
                     return m_backgroundColorCheckedHoverCached;
-                else if (m_backgroundColorCheckedCached.isSet())
-                    return m_backgroundColorCheckedCached;
-                else if (m_backgroundColorHoverCached.isSet())
-                    return m_backgroundColorHoverCached;
-                else
-                    return m_backgroundColorCached;
-            }
-            else
-            {
                 if (m_backgroundColorCheckedCached.isSet())
                     return m_backgroundColorCheckedCached;
-                else
-                    return m_backgroundColorCached;
-            }
-        }
-        else
-        {
-            if (!m_enabled && m_backgroundColorDisabledCached.isSet())
-                return m_backgroundColorDisabledCached;
-            else if (m_mouseHover && m_backgroundColorHoverCached.isSet())
-                return m_backgroundColorHoverCached;
-            else
+                if (m_backgroundColorHoverCached.isSet())
+                    return m_backgroundColorHoverCached;
                 return m_backgroundColorCached;
+            }
+            if (m_backgroundColorCheckedCached.isSet())
+                return m_backgroundColorCheckedCached;
+            return m_backgroundColorCached;
         }
+        if (!m_enabled && m_backgroundColorDisabledCached.isSet())
+            return m_backgroundColorDisabledCached;
+        if (m_mouseHover && m_backgroundColorHoverCached.isSet())
+            return m_backgroundColorHoverCached;
+        return m_backgroundColorCached;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -596,46 +581,37 @@ namespace tgui
         {
             if (!m_enabled && m_borderColorCheckedDisabledCached.isSet())
                 return m_borderColorCheckedDisabledCached;
-            else if (!m_enabled && m_borderColorDisabledCached.isSet())
+            if (!m_enabled && m_borderColorDisabledCached.isSet())
                 return m_borderColorDisabledCached;
-            else if (m_mouseHover)
+            if (m_mouseHover)
             {
                 if (m_borderColorCheckedHoverCached.isSet())
                     return m_borderColorCheckedHoverCached;
-                else if (m_borderColorCheckedCached.isSet())
+                if (m_borderColorCheckedCached.isSet())
                     return m_borderColorCheckedCached;
-                else if (m_focused && m_borderColorCheckedFocusedCached.isSet())
-                    return m_borderColorCheckedFocusedCached;
-                else if (m_borderColorHoverCached.isSet())
-                    return m_borderColorHoverCached;
-                else if (m_focused && m_borderColorFocusedCached.isSet())
-                    return m_borderColorFocusedCached;
-                else
-                    return m_borderColorCached;
-            }
-            else
-            {
                 if (m_focused && m_borderColorCheckedFocusedCached.isSet())
                     return m_borderColorCheckedFocusedCached;
-                else if (m_borderColorCheckedCached.isSet())
-                    return m_borderColorCheckedCached;
-                else if (m_focused && m_borderColorFocusedCached.isSet())
+                if (m_borderColorHoverCached.isSet())
+                    return m_borderColorHoverCached;
+                if (m_focused && m_borderColorFocusedCached.isSet())
                     return m_borderColorFocusedCached;
-                else
-                    return m_borderColorCached;
-            }
-        }
-        else
-        {
-            if (!m_enabled && m_borderColorDisabledCached.isSet())
-                return m_borderColorDisabledCached;
-            else if (m_mouseHover && m_borderColorHoverCached.isSet())
-                return m_borderColorHoverCached;
-            else if (m_focused && m_borderColorFocusedCached.isSet())
-                return m_borderColorFocusedCached;
-            else
                 return m_borderColorCached;
+            }
+            if (m_focused && m_borderColorCheckedFocusedCached.isSet())
+                return m_borderColorCheckedFocusedCached;
+            if (m_borderColorCheckedCached.isSet())
+                return m_borderColorCheckedCached;
+            if (m_focused && m_borderColorFocusedCached.isSet())
+                return m_borderColorFocusedCached;
+            return m_borderColorCached;
         }
+        if (!m_enabled && m_borderColorDisabledCached.isSet())
+            return m_borderColorDisabledCached;
+        if (m_mouseHover && m_borderColorHoverCached.isSet())
+            return m_borderColorHoverCached;
+        if (m_focused && m_borderColorFocusedCached.isSet())
+            return m_borderColorFocusedCached;
+        return m_borderColorCached;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
