@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -23,6 +23,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
 #include <TGUI/Widgets/RadioButtonGroup.hpp>
+#include <algorithm>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -53,8 +54,7 @@ namespace tgui
     {
         if (group)
             return std::static_pointer_cast<RadioButtonGroup>(group->clone());
-        else
-            return nullptr;
+        return nullptr;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -96,13 +96,8 @@ namespace tgui
             return false;
 
         const Vector2f offset = getChildWidgetsOffset();
-        for (const auto& widget : m_widgets)
-        {
-            if (widget->isVisible() && widget->isMouseOnWidget(transformMousePos(widget, pos - offset)))
-                return true;
-        }
-
-        return false;
+        return std::any_of(m_widgets.cbegin(), m_widgets.cend(),
+                           [&](const auto& widget) { return widget->isVisible() && widget->isMouseOnWidget(transformMousePos(widget, pos - offset)); });
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
