@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -24,9 +24,8 @@
 
 #include <TGUI/Widgets/RangeSlider.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <cmath>
-#endif
+#include <algorithm>
+#include <cmath>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -43,7 +42,7 @@ namespace tgui
     {
         if (initRenderer)
         {
-            m_renderer = aurora::makeCopied<RangeSliderRenderer>();
+            m_renderer = makeCopied<RangeSliderRenderer>();
             setRenderer(Theme::getDefault()->getRendererNoThrow(m_type));
         }
 
@@ -68,29 +67,28 @@ namespace tgui
     {
         if (slider)
             return std::static_pointer_cast<RangeSlider>(slider->clone());
-        else
-            return nullptr;
+        return nullptr;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     RangeSliderRenderer* RangeSlider::getSharedRenderer()
     {
-        return aurora::downcast<RangeSliderRenderer*>(Widget::getSharedRenderer());
+        return downcast<RangeSliderRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     const RangeSliderRenderer* RangeSlider::getSharedRenderer() const
     {
-        return aurora::downcast<const RangeSliderRenderer*>(Widget::getSharedRenderer());
+        return downcast<const RangeSliderRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     RangeSliderRenderer* RangeSlider::getRenderer()
     {
-        return aurora::downcast<RangeSliderRenderer*>(Widget::getRenderer());
+        return downcast<RangeSliderRenderer*>(Widget::getRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -207,8 +205,7 @@ namespace tgui
     {
         if (m_orientation == Orientation::Vertical)
             return {std::max(getSize().x, m_thumbs.first.width), getSize().y + m_thumbs.first.height};
-        else
-            return {getSize().x + m_thumbs.first.width, std::max(getSize().y, m_thumbs.first.height)};
+        return {getSize().x + m_thumbs.first.width, std::max(getSize().y, m_thumbs.first.height)};
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -217,8 +214,7 @@ namespace tgui
     {
         if (m_orientation == Orientation::Vertical)
             return {std::min(0.f, getSize().x - m_thumbs.first.width), -m_thumbs.first.height / 2.f};
-        else
-            return {-m_thumbs.first.width / 2.f, std::min(0.f, getSize().y - m_thumbs.first.height)};
+        return {-m_thumbs.first.width / 2.f, std::min(0.f, getSize().y - m_thumbs.first.height)};
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -231,8 +227,7 @@ namespace tgui
         m_minimum = minimum;
 
         // The maximum can't be below the minimum
-        if (m_maximum < m_minimum)
-            m_maximum = m_minimum;
+        m_maximum = std::max(m_maximum, m_minimum);
 
         // When the selection start equaled the minimum, move it as well, otherwise set it again to make sure it is still within minimum and maximum
         if (oldMinimum == m_selectionStart)
@@ -298,8 +293,7 @@ namespace tgui
             m_selectionStart = value;
 
             // Update the selection end when the selection start passed it
-            if (m_selectionEnd < value)
-                m_selectionEnd = value;
+            m_selectionEnd = std::max(m_selectionEnd, value);
 
             onRangeChange.emit(this, m_selectionStart, m_selectionEnd);
 
@@ -333,8 +327,7 @@ namespace tgui
             m_selectionEnd = value;
 
             // Update the selection start when the selection end passed it
-            if (m_selectionStart > value)
-                m_selectionStart = value;
+            m_selectionStart = std::min(m_selectionStart, value);
 
             onRangeChange.emit(this, m_selectionStart, m_selectionEnd);
 
@@ -516,8 +509,7 @@ namespace tgui
     {
         if (signalName == onRangeChange.getName())
             return onRangeChange;
-        else
-            return Widget::getSignal(std::move(signalName));
+        return Widget::getSignal(std::move(signalName));
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -648,8 +640,8 @@ namespace tgui
 
     Vector2f RangeSlider::getInnerSize() const
     {
-        return {std::max(0.f, getSize().x - m_bordersCached.getLeft() - m_bordersCached.getRight()),
-                std::max(0.f, getSize().y - m_bordersCached.getTop() - m_bordersCached.getBottom())};
+        return {std::max(0.f, getSize().x - m_bordersCached.getLeftPlusRight()),
+                std::max(0.f, getSize().y - m_bordersCached.getTopPlusBottom())};
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -782,11 +774,11 @@ namespace tgui
                     else
                         target.drawBorders(states, m_bordersCached, {m_thumbs.first.width, m_thumbs.first.height}, Color::applyOpacity(m_borderColorCached, m_opacityCached));
 
-                    states.transform.translate({m_bordersCached.getLeft(), m_bordersCached.getTop()});
+                    states.transform.translate(m_bordersCached.getOffset());
                 }
 
-                const Vector2f thumbInnerSize = {m_thumbs.first.width - m_bordersCached.getLeft() - m_bordersCached.getRight(),
-                                                     m_thumbs.first.height - m_bordersCached.getTop() - m_bordersCached.getBottom()};
+                const Vector2f thumbInnerSize = {m_thumbs.first.width - m_bordersCached.getLeftPlusRight(),
+                                                     m_thumbs.first.height - m_bordersCached.getTopPlusBottom()};
 
                 if (m_mouseHover && m_thumbColorHoverCached.isSet())
                     target.drawFilledRect(states, thumbInnerSize, Color::applyOpacity(m_thumbColorHoverCached, m_opacityCached));
@@ -819,11 +811,11 @@ namespace tgui
                     else
                         target.drawBorders(states, m_bordersCached, {m_thumbs.second.width, m_thumbs.second.height}, Color::applyOpacity(m_borderColorCached, m_opacityCached));
 
-                    states.transform.translate({m_bordersCached.getLeft(), m_bordersCached.getTop()});
+                    states.transform.translate(m_bordersCached.getOffset());
                 }
 
-                const Vector2f thumbInnerSize = {m_thumbs.second.width - m_bordersCached.getLeft() - m_bordersCached.getRight(),
-                                                 m_thumbs.second.height - m_bordersCached.getTop() - m_bordersCached.getBottom()};
+                const Vector2f thumbInnerSize = {m_thumbs.second.width - m_bordersCached.getLeftPlusRight(),
+                                                 m_thumbs.second.height - m_bordersCached.getTopPlusBottom()};
 
                 if (m_mouseHover && m_thumbColorHoverCached.isSet())
                     target.drawFilledRect(states, thumbInnerSize, Color::applyOpacity(m_thumbColorHoverCached, m_opacityCached));
