@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -24,9 +24,7 @@
 
 #include <TGUI/Widgets/RichTextLabel.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <cmath>
-#endif
+#include <algorithm>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -68,8 +66,7 @@ namespace tgui
     {
         if (label)
             return std::static_pointer_cast<RichTextLabel>(label->clone());
-        else
-            return nullptr;
+        return nullptr;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -87,8 +84,7 @@ namespace tgui
                     auto linkIt = m_links.find({i, j});
                     if (linkIt != m_links.end())
                         return linkIt->second;
-                    else
-                        return "";
+                    return "";
                 }
             }
         }
@@ -101,8 +97,7 @@ namespace tgui
                 auto linkIt = m_imageLinks.find(i);
                 if (linkIt != m_imageLinks.end())
                     return linkIt->second;
-                else
-                    return "";
+                return "";
             }
         }
 
@@ -204,7 +199,7 @@ namespace tgui
                 requiredTextHeight = calculateTextHeight(*textPiecesLinesPtr, defaultLineSpacing);
             }
 
-            m_scrollbar->setHeight(static_cast<unsigned int>(getSize().y - m_bordersCached.getTop() - m_bordersCached.getBottom()));
+            m_scrollbar->setHeight(static_cast<unsigned int>(getSize().y - m_bordersCached.getTopPlusBottom()));
             m_scrollbar->setViewportSize(static_cast<unsigned int>(getSize().y - outline.getTop() - outline.getBottom()));
             m_scrollbar->setMaximum(static_cast<unsigned int>(requiredTextHeight));
             m_scrollbar->setPosition({getSize().x - m_bordersCached.getRight() - m_scrollbar->getSize().x, m_bordersCached.getTop()});
@@ -217,11 +212,10 @@ namespace tgui
         float width = 0;
         std::size_t imageIndex = 0;
         Vector2f pos{m_paddingCached.getLeft() + textOffset, m_paddingCached.getTop()};
-        for (std::size_t i = 0; i < textPiecesLinesPtr->size(); ++i)
+        for (const auto& textPiecesLine : *textPiecesLinesPtr)
         {
-            std::size_t imageIndexBeforeLine = imageIndex;
+            const std::size_t imageIndexBeforeLine = imageIndex;
 
-            const auto& textPiecesLine = (*textPiecesLinesPtr)[i];
             TGUI_EMPLACE_BACK(line, m_lines)
 
             float lineWidth = 0;
@@ -269,8 +263,7 @@ namespace tgui
             }
 
             lineWidths.push_back(lineWidth);
-            if (lineWidth > width)
-                width = lineWidth;
+            width = std::max(lineWidth, width);
 
             // If a line contains pieces of multiple sizes then align their bottom position
             for (auto& textPiece : line)
@@ -332,9 +325,9 @@ namespace tgui
                 for (auto& textPiece : m_lines[i])
                     textPiece.setPosition({textPiece.getPosition().x + horizontalOffset, textPiece.getPosition().y});
 
-                for (std::size_t j = 0; j < textPiecesLine.size(); ++j)
+                for (const auto& piece : textPiecesLine)
                 {
-                    if (textPiecesLine[j].gapSize != Vector2u{})
+                    if (piece.gapSize != Vector2u{})
                     {
                         auto& image = m_images[imageIndex];
                         image.setPosition({image.getPosition().x + horizontalOffset, image.getPosition().y});
@@ -353,8 +346,8 @@ namespace tgui
             m_bordersCached.updateParentSize(getSize());
             m_paddingCached.updateParentSize(getSize());
 
-            m_spriteBackground.setSize({getSize().x - m_bordersCached.getLeft() - m_bordersCached.getRight(),
-                                        getSize().y - m_bordersCached.getTop() - m_bordersCached.getBottom()});
+            m_spriteBackground.setSize({getSize().x - m_bordersCached.getLeftPlusRight(),
+                                        getSize().y - m_bordersCached.getTopPlusBottom()});
         }
 
         // Vertically align the lines if the text is smaller than the box
@@ -402,8 +395,7 @@ namespace tgui
         }
 
         float lineSpacing = (lineMaxTextSize > 0) ? m_fontCached.getLineSpacing(lineMaxTextSize) : 0;
-        if (static_cast<float>(maxGapHeight) > lineSpacing)
-            lineSpacing = static_cast<float>(maxGapHeight);
+        lineSpacing = std::max(static_cast<float>(maxGapHeight), lineSpacing);
 
         return lineSpacing;
     }
@@ -730,7 +722,7 @@ namespace tgui
         Label::draw(target, states);
 
         if (m_bordersCached != Borders{0})
-            states.transform.translate({m_bordersCached.getLeft(), m_bordersCached.getTop()});
+            states.transform.translate(m_bordersCached.getOffset());
 
         // Draw the images
         if (m_autoSize)
@@ -740,8 +732,8 @@ namespace tgui
         }
         else
         {
-            Vector2f innerSize = {getSize().x - m_bordersCached.getLeft() - m_bordersCached.getRight() - m_paddingCached.getLeft() - m_paddingCached.getRight(),
-                                  getSize().y - m_bordersCached.getTop() - m_bordersCached.getBottom() - m_paddingCached.getTop() - m_paddingCached.getBottom()};
+            const Vector2f innerSize = {getSize().x - m_bordersCached.getLeftPlusRight() - m_paddingCached.getLeftPlusRight(),
+                                  getSize().y - m_bordersCached.getTopPlusBottom() - m_paddingCached.getTopPlusBottom()};
 
             target.addClippingLayer(states, {{m_paddingCached.getLeft(), m_paddingCached.getTop()}, innerSize});
 
