@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -26,9 +26,7 @@
 #include <TGUI/Vector2.hpp>
 #include <TGUI/Keyboard.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <cmath>
-#endif
+#include <algorithm>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -45,7 +43,7 @@ namespace tgui
     {
         if (initRenderer)
         {
-            m_renderer = aurora::makeCopied<ScrollablePanelRenderer>();
+            m_renderer = makeCopied<ScrollablePanelRenderer>();
             setRenderer(Theme::getDefault()->getRendererNoThrow(m_type));
         }
     }
@@ -172,29 +170,28 @@ namespace tgui
     {
         if (panel)
             return std::static_pointer_cast<ScrollablePanel>(panel->clone());
-        else
-            return nullptr;
+        return nullptr;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     ScrollablePanelRenderer* ScrollablePanel::getSharedRenderer()
     {
-        return aurora::downcast<ScrollablePanelRenderer*>(Widget::getSharedRenderer());
+        return downcast<ScrollablePanelRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     const ScrollablePanelRenderer* ScrollablePanel::getSharedRenderer() const
     {
-        return aurora::downcast<const ScrollablePanelRenderer*>(Widget::getSharedRenderer());
+        return downcast<const ScrollablePanelRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     ScrollablePanelRenderer* ScrollablePanel::getRenderer()
     {
-        return aurora::downcast<ScrollablePanelRenderer*>(Widget::getRenderer());
+        return downcast<ScrollablePanelRenderer*>(Widget::getRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -227,10 +224,8 @@ namespace tgui
                 widget->getPosition().x - (widget->getOrigin().x * widget->getSize().x) + widget->getFullSize().x,
                 widget->getPosition().y - (widget->getOrigin().y * widget->getSize().y) + widget->getFullSize().y
             };
-            if (bottomRight.x > m_mostBottomRightPosition.x)
-                m_mostBottomRightPosition.x = bottomRight.x;
-            if (bottomRight.y > m_mostBottomRightPosition.y)
-                m_mostBottomRightPosition.y = bottomRight.y;
+            m_mostBottomRightPosition.x = std::max(bottomRight.x, m_mostBottomRightPosition.x);
+            m_mostBottomRightPosition.y = std::max(bottomRight.y, m_mostBottomRightPosition.y);
 
             connectPositionAndSize(widget);
             updateScrollbars();
@@ -326,10 +321,9 @@ namespace tgui
     {
         if (m_contentSize != Vector2f{0, 0})
             return m_contentSize;
-        else if (m_widgets.empty())
+        if (m_widgets.empty())
             return getInnerSize();
-        else
-            return m_mostBottomRightPosition;
+        return m_mostBottomRightPosition;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -518,6 +512,36 @@ namespace tgui
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
+    void ScrollablePanel::rightMousePressed(Vector2f pos)
+    {
+        if (m_verticalScrollbar->isMouseOnWidget(pos - getPosition()))
+            m_verticalScrollbar->rightMousePressed(pos - getPosition());
+        else if (m_horizontalScrollbar->isMouseOnWidget(pos - getPosition()))
+            m_horizontalScrollbar->rightMousePressed(pos - getPosition());
+        else if (FloatRect{getPosition().x + getChildWidgetsOffset().x, getPosition().y + getChildWidgetsOffset().y, getInnerSize().x, getInnerSize().y}.contains(pos))
+        {
+            Panel::rightMousePressed({pos.x + static_cast<float>(m_horizontalScrollbar->getValue()),
+                                      pos.y + static_cast<float>(m_verticalScrollbar->getValue())});
+        }
+    }
+
+    /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+
+    void ScrollablePanel::rightMouseReleased(Vector2f pos)
+    {
+        if (m_verticalScrollbar->isMouseOnWidget(pos - getPosition()))
+            m_verticalScrollbar->rightMouseReleased(pos - getPosition());
+        else if (m_horizontalScrollbar->isMouseOnWidget(pos - getPosition()))
+            m_horizontalScrollbar->rightMouseReleased(pos - getPosition());
+        else if (FloatRect{getPosition().x + getChildWidgetsOffset().x, getPosition().y + getChildWidgetsOffset().y, getInnerSize().x, getInnerSize().y}.contains(pos))
+        {
+            Panel::rightMouseReleased({pos.x + static_cast<float>(m_horizontalScrollbar->getValue()),
+                                       pos.y + static_cast<float>(m_verticalScrollbar->getValue())});
+        }
+    }
+
+    /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+
     void ScrollablePanel::mouseMoved(Vector2f pos)
     {
         // Check if the mouse event should go to the scrollbar
@@ -626,7 +650,7 @@ namespace tgui
 
             mousePos -= getPosition() + getChildWidgetsOffset() - getContentOffset();
 
-            Widget::Ptr widget = updateWidgetBelowMouse(mousePos);
+            const Widget::Ptr widget = updateWidgetBelowMouse(mousePos);
             if (widget)
             {
                 toolTip = widget->askToolTip(mousePos);
@@ -647,14 +671,14 @@ namespace tgui
     {
         const auto oldStates = states;
 
-        const Vector2f innerSize = {getSize().x - m_bordersCached.getLeft() - m_bordersCached.getRight(),
-                                    getSize().y - m_bordersCached.getTop() - m_bordersCached.getBottom()};
+        const Vector2f innerSize = {getSize().x - m_bordersCached.getLeftPlusRight(),
+                                    getSize().y - m_bordersCached.getTopPlusBottom()};
 
         if ((m_roundedBorderRadius > 0) && !m_spriteBackground.isSet())
         {
             target.drawRoundedRectangle(states, getSize(), Color::applyOpacity(m_backgroundColorCached, m_opacityCached),
                                         m_roundedBorderRadius, m_bordersCached, Color::applyOpacity(m_borderColorCached, m_opacityCached));
-            states.transform.translate({m_bordersCached.getLeft(), m_bordersCached.getTop()});
+            states.transform.translate(m_bordersCached.getOffset());
         }
         else
         {
@@ -662,7 +686,7 @@ namespace tgui
             if (m_bordersCached != Borders{0})
             {
                 target.drawBorders(states, m_bordersCached, getSize(), Color::applyOpacity(m_borderColorCached, m_opacityCached));
-                states.transform.translate({m_bordersCached.getLeft(), m_bordersCached.getTop()});
+                states.transform.translate(m_bordersCached.getOffset());
             }
 
             // Draw the background
@@ -673,8 +697,8 @@ namespace tgui
         }
 
         states.transform.translate({m_paddingCached.getLeft(), m_paddingCached.getTop()});
-        Vector2f contentSize = {innerSize.x - m_paddingCached.getLeft() - m_paddingCached.getRight(),
-                                innerSize.y - m_paddingCached.getTop() - m_paddingCached.getBottom()};
+        Vector2f contentSize = {innerSize.x - m_paddingCached.getLeftPlusRight(),
+                                innerSize.y - m_paddingCached.getTopPlusBottom()};
 
         if (m_verticalScrollbar->isShown())
             contentSize.x -= m_verticalScrollbar->getSize().x;
@@ -783,8 +807,8 @@ namespace tgui
 
     void ScrollablePanel::updateScrollbars()
     {
-        const Vector2f scrollbarSpace = {getSize().x - m_bordersCached.getLeft() - m_bordersCached.getRight(),
-                                         getSize().y - m_bordersCached.getTop() - m_bordersCached.getBottom()};
+        const Vector2f scrollbarSpace = {getSize().x - m_bordersCached.getLeftPlusRight(),
+                                         getSize().y - m_bordersCached.getTopPlusBottom()};
 
         const Vector2f visibleSize = Panel::getInnerSize();
         m_horizontalScrollbar->setViewportSize(static_cast<unsigned int>(visibleSize.x));
@@ -880,10 +904,8 @@ namespace tgui
                 widget->getPosition().x - (widget->getOrigin().x * widget->getSize().x) + widget->getFullSize().x,
                 widget->getPosition().y - (widget->getOrigin().y * widget->getSize().y) + widget->getFullSize().y
             };
-            if (bottomRight.x > m_mostBottomRightPosition.x)
-                m_mostBottomRightPosition.x = bottomRight.x;
-            if (bottomRight.y > m_mostBottomRightPosition.y)
-                m_mostBottomRightPosition.y = bottomRight.y;
+            m_mostBottomRightPosition.x = std::max(bottomRight.x, m_mostBottomRightPosition.x);
+            m_mostBottomRightPosition.y = std::max(bottomRight.y, m_mostBottomRightPosition.y);
         }
     }
 
