@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -24,6 +24,7 @@
 
 #include <TGUI/Widgets/Scrollbar.hpp>
 #include <TGUI/Timer.hpp>
+#include <cmath>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -40,7 +41,7 @@ namespace tgui
     {
         if (initRenderer)
         {
-            m_renderer = aurora::makeCopied<ScrollbarRenderer>();
+            m_renderer = makeCopied<ScrollbarRenderer>();
             setRenderer(Theme::getDefault()->getRendererNoThrow(m_type));
         }
 
@@ -67,29 +68,28 @@ namespace tgui
     {
         if (scrollbar)
             return std::static_pointer_cast<Scrollbar>(scrollbar->clone());
-        else
-            return nullptr;
+        return nullptr;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     ScrollbarRenderer* Scrollbar::getSharedRenderer()
     {
-        return aurora::downcast<ScrollbarRenderer*>(Widget::getSharedRenderer());
+        return downcast<ScrollbarRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     const ScrollbarRenderer* Scrollbar::getSharedRenderer() const
     {
-        return aurora::downcast<const ScrollbarRenderer*>(Widget::getSharedRenderer());
+        return downcast<const ScrollbarRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     ScrollbarRenderer* Scrollbar::getRenderer()
     {
-        return aurora::downcast<ScrollbarRenderer*>(Widget::getRenderer());
+        return downcast<ScrollbarRenderer*>(Widget::getRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -187,8 +187,7 @@ namespace tgui
     {
         if (m_maximum >= m_viewportSize)
             return m_maximum - m_viewportSize;
-        else
-            return 0;
+        return 0;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -259,10 +258,9 @@ namespace tgui
 
         if (m_policy == Policy::Never)
             return false;
-        else if (m_policy == Policy::Always)
+        if (m_policy == Policy::Always)
             return true;
-        else
-            return m_maximum > m_viewportSize;
+        return m_maximum > m_viewportSize;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -306,10 +304,9 @@ namespace tgui
     {
         if (m_spriteTrack.isSet())
             return static_cast<float>(m_spriteTrack.getTexture().getImageSize().x);
-        else if (m_spriteThumb.isSet())
+        if (m_spriteThumb.isSet())
             return static_cast<float>(m_spriteThumb.getTexture().getImageSize().x);
-        else
-            return 16;
+        return 16;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -329,11 +326,8 @@ namespace tgui
         pos -= getPosition();
         if (FloatRect{0, 0, getSize().x, getSize().y}.contains(pos))
         {
-            if (m_transparentTextureCached && m_spriteArrowDown.isTransparentPixel(pos - m_arrowDown.getPosition())
-             && m_spriteTrack.isTransparentPixel(pos - m_track.getPosition()) && m_spriteArrowUp.isTransparentPixel(pos))
-                return false;
-
-            return true;
+            return !(m_transparentTextureCached && m_spriteArrowDown.isTransparentPixel(pos - m_arrowDown.getPosition())
+                     && m_spriteTrack.isTransparentPixel(pos - m_track.getPosition()) && m_spriteArrowUp.isTransparentPixel(pos));
         }
 
         return false;
@@ -485,8 +479,8 @@ namespace tgui
                     if ((pos.y - m_mouseDownOnThumbPos.y - m_arrowUp.height) > 0)
                     {
                         // Calculate the new value
-                        const unsigned int value = static_cast<unsigned int>((((pos.y - m_mouseDownOnThumbPos.y - m_arrowUp.height)
-                            / (getSize().y - m_arrowUp.height - m_arrowDown.height - m_thumb.height)) * (m_maximum - m_viewportSize)) + 0.5f);
+                        const auto value = static_cast<unsigned int>(std::lround(((pos.y - m_mouseDownOnThumbPos.y - m_arrowUp.height)
+                                                                                  / (getSize().y - m_arrowUp.height - m_arrowDown.height - m_thumb.height)) * (m_maximum - m_viewportSize)));
 
                         // If the value isn't too high then change it
                         if (value <= (m_maximum - m_viewportSize))
@@ -527,7 +521,7 @@ namespace tgui
                                 // Try to place the thumb on 2/3 of the clicked position
                                 const float subtractValue = (m_thumb.height / 3.0f) * scaleFactor;
                                 if (value >= subtractValue)
-                                    setValue(static_cast<unsigned int>(value - subtractValue + 0.5f));
+                                    setValue(static_cast<unsigned int>(std::lround(value - subtractValue)));
                                 else
                                     setValue(0);
                             }
@@ -536,7 +530,7 @@ namespace tgui
                                 // Try to place the thumb on 2/3 of the clicked position
                                 const float subtractValue = (m_thumb.height * 2.0f / 3.0f) * scaleFactor;
                                 if (value <= (m_maximum - m_viewportSize + subtractValue))
-                                    setValue(static_cast<unsigned int>(value - subtractValue + 0.5f));
+                                    setValue(static_cast<unsigned int>(std::lround(value - subtractValue)));
                                 else
                                     setValue(m_maximum - m_viewportSize);
                             }
@@ -557,8 +551,8 @@ namespace tgui
                     if (pos.x - m_mouseDownOnThumbPos.x - m_arrowUp.width > 0)
                     {
                         // Calculate the new value
-                        const unsigned int value = static_cast<unsigned int>((((pos.x - m_mouseDownOnThumbPos.x - m_arrowUp.width)
-                            / (getSize().x - m_arrowUp.width - m_arrowDown.width - m_thumb.width)) * (m_maximum - m_viewportSize)) + 0.5f);
+                        const auto value = static_cast<unsigned int>(std::lround(((pos.x - m_mouseDownOnThumbPos.x - m_arrowUp.width)
+                                                                                  / (getSize().x - m_arrowUp.width - m_arrowDown.width - m_thumb.width)) * (m_maximum - m_viewportSize)));
 
                         // If the value isn't too high then change it
                         if (value <= (m_maximum - m_viewportSize))
@@ -600,7 +594,7 @@ namespace tgui
 
                                 // Try to place the thumb on 2/3 of the clicked position
                                 if (value >= subtractValue)
-                                    setValue(static_cast<unsigned int>(value - subtractValue + 0.5f));
+                                    setValue(static_cast<unsigned int>(std::lround(value - subtractValue)));
                                 else
                                     setValue(0);
                             }
@@ -610,7 +604,7 @@ namespace tgui
 
                                 // Try to place the thumb on 2/3 of the clicked position
                                 if (value <= (m_maximum - m_viewportSize + subtractValue))
-                                    setValue(static_cast<unsigned int>(value - subtractValue + 0.5f));
+                                    setValue(static_cast<unsigned int>(std::lround(value - subtractValue)));
                                 else
                                     setValue(m_maximum - m_viewportSize);
                             }
@@ -845,8 +839,7 @@ namespace tgui
     {
         if (signalName == onValueChange.getName())
             return onValueChange;
-        else
-            return Widget::getSignal(std::move(signalName));
+        return Widget::getSignal(std::move(signalName));
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -993,7 +986,7 @@ namespace tgui
 #endif
         if (node->propertyValuePairs[U"ScrollbarPolicy"])
         {
-            String policy = node->propertyValuePairs[U"ScrollbarPolicy"]->value.trim();
+            const String policy = node->propertyValuePairs[U"ScrollbarPolicy"]->value.trim();
             if (policy == U"Automatic")
                 setPolicy(Policy::Automatic);
             else if (policy == U"Always")
@@ -1031,10 +1024,10 @@ namespace tgui
 
     void Scrollbar::callMousePressPeriodically(std::chrono::time_point<std::chrono::steady_clock> clickedTime, bool repeatedCall)
     {
-        std::weak_ptr<Scrollbar> widgetPtr = std::static_pointer_cast<Scrollbar>(shared_from_this());
+        const std::weak_ptr<Scrollbar> widgetPtr = std::static_pointer_cast<Scrollbar>(shared_from_this());
         Timer::scheduleCallback([widgetPtr, clickedTime]()
         {
-            Scrollbar::Ptr scrollbar = widgetPtr.lock();
+            const Scrollbar::Ptr scrollbar = widgetPtr.lock();
             if (!scrollbar)
                 return;
 
@@ -1231,9 +1224,9 @@ namespace tgui
 
     ScrollbarAccessor::ScrollbarAccessor(ScrollbarChildWidget& scrollbar, std::function<void()> valueChangedCallback, std::function<void()> policyChangedCallback, std::function<void()> scrollAmountChangedCallback) :
         m_scrollbar(&scrollbar),
-        m_valueChangedCallback(valueChangedCallback),
-        m_policyChangedCallback(policyChangedCallback),
-        m_scrollAmountChangedCallback(scrollAmountChangedCallback)
+        m_valueChangedCallback(std::move(valueChangedCallback)),
+        m_policyChangedCallback(std::move(policyChangedCallback)),
+        m_scrollAmountChangedCallback(std::move(scrollAmountChangedCallback))
     {
     }
 
@@ -1319,8 +1312,7 @@ namespace tgui
     {
         if (m_scrollbar->getOrientation() == Orientation::Vertical)
             return m_scrollbar->getSize().x;
-        else
-            return m_scrollbar->getSize().y;
+        return m_scrollbar->getSize().y;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -1425,7 +1417,7 @@ namespace tgui
     {
         if (node->propertyValuePairs[U"ScrollbarPolicy"])
         {
-            String policy = node->propertyValuePairs[U"ScrollbarPolicy"]->value.trim();
+            const String policy = node->propertyValuePairs[U"ScrollbarPolicy"]->value.trim();
             if (policy == U"Automatic")
                 m_scrollbar->setPolicy(Scrollbar::Policy::Automatic);
             else if (policy == U"Always")
@@ -1571,7 +1563,7 @@ namespace tgui
     {
         if (node->propertyValuePairs[U"VerticalScrollbarPolicy"])
         {
-            String policy = node->propertyValuePairs[U"VerticalScrollbarPolicy"]->value.trim();
+            const String policy = node->propertyValuePairs[U"VerticalScrollbarPolicy"]->value.trim();
             if (policy == U"Automatic")
                 m_verticalScrollbar->setPolicy(Scrollbar::Policy::Automatic);
             else if (policy == U"Always")
@@ -1584,7 +1576,7 @@ namespace tgui
 
         if (node->propertyValuePairs[U"HorizontalScrollbarPolicy"])
         {
-            String policy = node->propertyValuePairs[U"HorizontalScrollbarPolicy"]->value.trim();
+            const String policy = node->propertyValuePairs[U"HorizontalScrollbarPolicy"]->value.trim();
             if (policy == U"Automatic")
                 m_horizontalScrollbar->setPolicy(Scrollbar::Policy::Automatic);
             else if (policy == U"Always")
