@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -24,9 +24,8 @@
 
 #include <TGUI/Widgets/Slider.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <cmath>
-#endif
+#include <algorithm>
+#include <cmath>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -43,7 +42,7 @@ namespace tgui
     {
         if (initRenderer)
         {
-            m_renderer = aurora::makeCopied<SliderRenderer>();
+            m_renderer = makeCopied<SliderRenderer>();
             setRenderer(Theme::getDefault()->getRendererNoThrow(m_type));
         }
 
@@ -68,29 +67,28 @@ namespace tgui
     {
         if (slider)
             return std::static_pointer_cast<Slider>(slider->clone());
-        else
-            return nullptr;
+        return nullptr;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     SliderRenderer* Slider::getSharedRenderer()
     {
-        return aurora::downcast<SliderRenderer*>(Widget::getSharedRenderer());
+        return downcast<SliderRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     const SliderRenderer* Slider::getSharedRenderer() const
     {
-        return aurora::downcast<const SliderRenderer*>(Widget::getSharedRenderer());
+        return downcast<const SliderRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     SliderRenderer* Slider::getRenderer()
     {
-        return aurora::downcast<SliderRenderer*>(Widget::getRenderer());
+        return downcast<SliderRenderer*>(Widget::getRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -192,16 +190,11 @@ namespace tgui
         {
             if (m_orientation == Orientation::Vertical)
                 return {std::max(getSize().x, m_thumb.width), getSize().y};
-            else
-                return {getSize().x, std::max(getSize().y, m_thumb.height)};
-        }
-        else
-        {
-            if (m_orientation == Orientation::Vertical)
-                return {std::max(getSize().x, m_thumb.width), getSize().y + m_thumb.height};
-            else
-                return {getSize().x + m_thumb.width, std::max(getSize().y, m_thumb.height)};
+            return {getSize().x, std::max(getSize().y, m_thumb.height)};
         }
+        if (m_orientation == Orientation::Vertical)
+            return {std::max(getSize().x, m_thumb.width), getSize().y + m_thumb.height};
+        return {getSize().x + m_thumb.width, std::max(getSize().y, m_thumb.height)};
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -212,16 +205,11 @@ namespace tgui
         {
             if (m_orientation == Orientation::Vertical)
                 return {std::min(0.f, (getSize().x - m_thumb.width) / 2.f), 0};
-            else
-                return {0, std::min(0.f, (getSize().y - m_thumb.height) / 2.f)};
-        }
-        else
-        {
-            if (m_orientation == Orientation::Vertical)
-                return {std::min(0.f, (getSize().x - m_thumb.width) / 2.f), -m_thumb.height / 2.f};
-            else
-                return {-m_thumb.width / 2.f, std::min(0.f, (getSize().y - m_thumb.height) / 2.f)};
+            return {0, std::min(0.f, (getSize().y - m_thumb.height) / 2.f)};
         }
+        if (m_orientation == Orientation::Vertical)
+            return {std::min(0.f, (getSize().x - m_thumb.width) / 2.f), -m_thumb.height / 2.f};
+        return {-m_thumb.width / 2.f, std::min(0.f, (getSize().y - m_thumb.height) / 2.f)};
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -232,8 +220,7 @@ namespace tgui
         m_minimum = minimum;
 
         // The maximum can't be below the minimum
-        if (m_maximum < m_minimum)
-            m_maximum = m_minimum;
+        m_maximum = std::max(m_maximum, m_minimum);
 
         // When the value is below the minimum then adjust it
         if (m_value < m_minimum)
@@ -552,8 +539,7 @@ namespace tgui
     {
         if (signalName == onValueChange.getName())
             return onValueChange;
-        else
-            return Widget::getSignal(std::move(signalName));
+        return Widget::getSignal(std::move(signalName));
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -669,8 +655,8 @@ namespace tgui
 
     Vector2f Slider::getInnerSize() const
     {
-        return {std::max(0.f, getSize().x - m_bordersCached.getLeft() - m_bordersCached.getRight()),
-                std::max(0.f, getSize().y - m_bordersCached.getTop() - m_bordersCached.getBottom())};
+        return {std::max(0.f, getSize().x - m_bordersCached.getLeftPlusRight()),
+                std::max(0.f, getSize().y - m_bordersCached.getTopPlusBottom())};
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -715,7 +701,7 @@ namespace tgui
             else
                 target.drawBorders(states, m_bordersCached, getSize(), Color::applyOpacity(m_borderColorCached, m_opacityCached));
 
-            states.transform.translate({m_bordersCached.getLeft(), m_bordersCached.getTop()});
+            states.transform.translate(m_bordersCached.getOffset());
         }
 
         // Draw the track
@@ -754,11 +740,11 @@ namespace tgui
                 else
                     target.drawBorders(states, m_bordersCached, {m_thumb.width, m_thumb.height}, Color::applyOpacity(m_borderColorCached, m_opacityCached));
 
-                states.transform.translate({m_bordersCached.getLeft(), m_bordersCached.getTop()});
+                states.transform.translate(m_bordersCached.getOffset());
             }
 
-            const Vector2f thumbInnerSize = {m_thumb.width - m_bordersCached.getLeft() - m_bordersCached.getRight(),
-                                             m_thumb.height - m_bordersCached.getTop() - m_bordersCached.getBottom()};
+            const Vector2f thumbInnerSize = {m_thumb.width - m_bordersCached.getLeftPlusRight(),
+                                             m_thumb.height - m_bordersCached.getTopPlusBottom()};
 
             if (m_mouseHover && m_thumbColorHoverCached.isSet())
                 target.drawFilledRect(states, thumbInnerSize, Color::applyOpacity(m_thumbColorHoverCached, m_opacityCached));
