@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -39,7 +39,7 @@ namespace tgui
     {
         if (initRenderer)
         {
-            m_renderer = aurora::makeCopied<SpinButtonRenderer>();
+            m_renderer = makeCopied<SpinButtonRenderer>();
             setRenderer(Theme::getDefault()->getRendererNoThrow(m_type));
         }
 
@@ -64,29 +64,28 @@ namespace tgui
     {
         if (spinButton)
             return std::static_pointer_cast<SpinButton>(spinButton->clone());
-        else
-            return nullptr;
+        return nullptr;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     SpinButtonRenderer* SpinButton::getSharedRenderer()
     {
-        return aurora::downcast<SpinButtonRenderer*>(Widget::getSharedRenderer());
+        return downcast<SpinButtonRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     const SpinButtonRenderer* SpinButton::getSharedRenderer() const
     {
-        return aurora::downcast<const SpinButtonRenderer*>(Widget::getSharedRenderer());
+        return downcast<const SpinButtonRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     SpinButtonRenderer* SpinButton::getRenderer()
     {
-        return aurora::downcast<SpinButtonRenderer*>(Widget::getRenderer());
+        return downcast<SpinButtonRenderer*>(Widget::getRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -235,17 +234,11 @@ namespace tgui
             // Check if the mouse is on top of the upper/right arrow
             if (m_orientation == Orientation::Vertical)
             {
-                if (FloatRect{getPosition().x, getPosition().y, getSize().x, getSize().y / 2.0f}.contains(pos))
-                    m_mouseDownOnTopArrow = true;
-                else
-                    m_mouseDownOnTopArrow = false;
+                m_mouseDownOnTopArrow = FloatRect{getPosition().x, getPosition().y, getSize().x, getSize().y / 2.0f}.contains(pos);
             }
             else
             {
-                if (FloatRect{getPosition().x, getPosition().y, getSize().x / 2.0f, getSize().y}.contains(pos))
-                    m_mouseDownOnTopArrow = false;
-                else
-                    m_mouseDownOnTopArrow = true;
+                m_mouseDownOnTopArrow = !FloatRect{getPosition().x, getPosition().y, getSize().x / 2.0f, getSize().y}.contains(pos);
             }
 
             if (m_mouseDownOnTopArrow && m_value < m_maximum)
@@ -277,17 +270,11 @@ namespace tgui
         // Check if the mouse is on top of the upper/right arrow
         if (m_orientation == Orientation::Vertical)
         {
-            if (FloatRect{getPosition().x, getPosition().y, getSize().x, getSize().y / 2.0f}.contains(pos))
-                m_mouseHoverOnTopArrow = true;
-            else
-                m_mouseHoverOnTopArrow = false;
+            m_mouseHoverOnTopArrow = FloatRect{getPosition().x, getPosition().y, getSize().x, getSize().y / 2.0f}.contains(pos);
         }
         else
         {
-            if (FloatRect{getPosition().x, getPosition().y, getSize().x / 2.0f, getSize().y}.contains(pos))
-                m_mouseHoverOnTopArrow = true;
-            else
-                m_mouseHoverOnTopArrow = false;
+            m_mouseHoverOnTopArrow = FloatRect{getPosition().x, getPosition().y, getSize().x / 2.0f, getSize().y}.contains(pos);
         }
 
         if (!m_mouseHover)
@@ -300,8 +287,7 @@ namespace tgui
     {
         if (signalName == onValueChange.getName())
             return onValueChange;
-        else
-            return ClickableWidget::getSignal(std::move(signalName));
+        return ClickableWidget::getSignal(std::move(signalName));
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -400,11 +386,10 @@ namespace tgui
     Vector2f SpinButton::getArrowSize() const
     {
         if (m_orientation == Orientation::Vertical)
-            return {getSize().x - m_bordersCached.getLeft() - m_bordersCached.getRight(),
-                    (getSize().y - m_bordersCached.getTop() - m_bordersCached.getBottom() - m_borderBetweenArrowsCached) / 2.0f};
-        else
-            return {getSize().y - m_bordersCached.getTop() - m_bordersCached.getBottom(),
-                    (getSize().x - m_bordersCached.getLeft() - m_bordersCached.getRight() - m_borderBetweenArrowsCached) / 2.0f};
+            return {getSize().x - m_bordersCached.getLeftPlusRight(),
+                    (getSize().y - m_bordersCached.getTopPlusBottom() - m_borderBetweenArrowsCached) / 2.0f};
+        return {getSize().y - m_bordersCached.getTopPlusBottom(),
+                (getSize().x - m_bordersCached.getLeftPlusRight() - m_borderBetweenArrowsCached) / 2.0f};
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -415,7 +400,7 @@ namespace tgui
         if (m_bordersCached != Borders{0})
         {
             target.drawBorders(states, m_bordersCached, getSize(), Color::applyOpacity(m_borderColorCached, m_opacityCached));
-            states.transform.translate({m_bordersCached.getLeft(), m_bordersCached.getTop()});
+            states.transform.translate(m_bordersCached.getOffset());
         }
 
         const Vector2f arrowSize = getArrowSize();
@@ -535,10 +520,10 @@ namespace tgui
 
     void SpinButton::callMousePressPeriodically(std::chrono::time_point<std::chrono::steady_clock> clickedTime, bool repeatedCall)
     {
-        std::weak_ptr<SpinButton> widgetPtr = std::static_pointer_cast<SpinButton>(shared_from_this());
+        const std::weak_ptr<SpinButton> widgetPtr = std::static_pointer_cast<SpinButton>(shared_from_this());
         Timer::scheduleCallback([widgetPtr, clickedTime]()
         {
-            SpinButton::Ptr spinButton = widgetPtr.lock();
+            const SpinButton::Ptr spinButton = widgetPtr.lock();
             if (spinButton)
             {
                 // Mouse still over and the mouse press is current
