@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -43,7 +43,7 @@ namespace tgui
 
         if (initRenderer)
         {
-            m_renderer = aurora::makeCopied<SplitContainerRenderer>();
+            m_renderer = makeCopied<SplitContainerRenderer>();
             setRenderer(Theme::getDefault()->getRendererNoThrow(m_type));
         }
 
@@ -65,29 +65,28 @@ namespace tgui
     {
         if (contaier)
             return std::static_pointer_cast<SplitContainer>(contaier->clone());
-        else
-            return nullptr;
+        return nullptr;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     SplitContainerRenderer* SplitContainer::getSharedRenderer()
     {
-        return aurora::downcast<SplitContainerRenderer*>(Widget::getSharedRenderer());
+        return downcast<SplitContainerRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     const SplitContainerRenderer* SplitContainer::getSharedRenderer() const
     {
-        return aurora::downcast<const SplitContainerRenderer*>(Widget::getSharedRenderer());
+        return downcast<const SplitContainerRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     SplitContainerRenderer* SplitContainer::getRenderer()
     {
-        return aurora::downcast<SplitContainerRenderer*>(Widget::getRenderer());
+        return downcast<SplitContainerRenderer*>(Widget::getRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -230,11 +229,10 @@ namespace tgui
 
             return true;
         }
-        else // The mouse is not on top of the thumb
-        {
-            m_mouseDownOnSplitter = false;
-            return Group::leftMousePressed(pos);
-        }
+        // The mouse is not on top of the thumb
+        m_mouseDownOnSplitter = false;
+        return Group::leftMousePressed(pos);
+
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -511,18 +509,16 @@ namespace tgui
             }
             return {left, m_paddingCached.getTop(), width, getInnerSize().y};
         }
-        else
+
+        float top = m_paddingCached.getTop() + m_currentSplitterOffset;
+        float height = m_splitterWidth;
+        if (m_minimumGrabWidth > m_splitterWidth)
         {
-            float top = m_paddingCached.getTop() + m_currentSplitterOffset;
-            float height = m_splitterWidth;
-            if (m_minimumGrabWidth > m_splitterWidth)
-            {
-                const float paddingAroundSplitter = (m_minimumGrabWidth - m_splitterWidth / 2.f);
-                top -= paddingAroundSplitter;
-                height += 2 * paddingAroundSplitter;
-            }
-            return {m_paddingCached.getLeft(), top, getInnerSize().x, height};
+            const float paddingAroundSplitter = (m_minimumGrabWidth - m_splitterWidth / 2.f);
+            top -= paddingAroundSplitter;
+            height += 2 * paddingAroundSplitter;
         }
+        return {m_paddingCached.getLeft(), top, getInnerSize().x, height};
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
