@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -23,6 +23,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
 #include <TGUI/Widgets/TabContainer.hpp>
+#include <algorithm>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -144,8 +145,7 @@ namespace tgui
     {
         if (tabContainer)
             return std::static_pointer_cast<TabContainer>(tabContainer->clone());
-        else
-            return nullptr;
+        return nullptr;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -194,7 +194,7 @@ namespace tgui
     Panel::Ptr TabContainer::addTab(const String& name, bool selectPanel)
     {
         auto panel = Panel::create();
-        panel->setSize({getSize().x , getSize().y - m_tabs->getSize().y});
+        panel->setSize({getSize().x, getSize().y - m_tabs->getSize().y});
         layoutPanel(panel);
 
         m_panels.push_back(panel);
@@ -214,11 +214,10 @@ namespace tgui
 
     Panel::Ptr TabContainer::insertTab(std::size_t index, const String& name, bool selectPanel)
     {
-        if (index > m_panels.size())
-            index = m_panels.size();
+        index = std::min(index, m_panels.size());
 
         auto panel = Panel::create();
-        panel->setSize({getSize().x , getSize().y - m_tabs->getSize().y});
+        panel->setSize({getSize().x, getSize().y - m_tabs->getSize().y});
         layoutPanel(panel);
 
         m_panels.insert(m_panels.begin() + static_cast<std::ptrdiff_t>(index), panel);
@@ -472,7 +471,7 @@ namespace tgui
         auto tabAlign = TabContainer::TabAlign::Top;
         if (node->propertyValuePairs[U"TabAlignment"])
         {
-            String alignment = Deserializer::deserialize(ObjectConverter::Type::String, node->propertyValuePairs[U"TabAlignment"]->value).getString();
+            const String alignment = Deserializer::deserialize(ObjectConverter::Type::String, node->propertyValuePairs[U"TabAlignment"]->value).getString();
             if (alignment == U"Bottom")
                 tabAlign = TabContainer::TabAlign::Bottom;
             else if (alignment != U"Top")
@@ -529,10 +528,9 @@ namespace tgui
     {
         if (signalName == onSelectionChange.getName())
             return onSelectionChange;
-        else if (signalName == onSelectionChanging.getName())
+        if (signalName == onSelectionChanging.getName())
             return onSelectionChanging;
-        else
-            return Widget::getSignal(std::move(signalName));
+        return Widget::getSignal(std::move(signalName));
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
