@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -26,9 +26,8 @@
 #include <TGUI/Widgets/TextArea.hpp>
 #include <TGUI/Keyboard.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <cmath>
-#endif
+#include <algorithm>
+#include <cmath>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -54,7 +53,7 @@ namespace tgui
 
         if (initRenderer)
         {
-            m_renderer = aurora::makeCopied<TextAreaRenderer>();
+            m_renderer = makeCopied<TextAreaRenderer>();
             setRenderer(Theme::getDefault()->getRendererNoThrow(m_type));
 
             setTextSize(getGlobalTextSize());
@@ -62,7 +61,7 @@ namespace tgui
                      10 * m_fontCached.getLineSpacing(m_textSizeCached)
                      + std::max(m_fontCached.getFontHeight(m_textSizeCached), m_fontCached.getLineSpacing(m_textSizeCached)) - m_fontCached.getLineSpacing(m_textSizeCached)
                      + Text::getExtraVerticalPadding(m_textSizeCached)
-                     + m_paddingCached.getTop() + m_paddingCached.getBottom() + m_bordersCached.getTop() + m_bordersCached.getBottom()});
+                     + m_paddingCached.getTopPlusBottom() + m_bordersCached.getTopPlusBottom()});
         }
     }
 
@@ -79,29 +78,28 @@ namespace tgui
     {
         if (textArea)
             return std::static_pointer_cast<TextArea>(textArea->clone());
-        else
-            return nullptr;
+        return nullptr;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     TextAreaRenderer* TextArea::getSharedRenderer()
     {
-        return aurora::downcast<TextAreaRenderer*>(Widget::getSharedRenderer());
+        return downcast<TextAreaRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     const TextAreaRenderer* TextArea::getSharedRenderer() const
     {
-        return aurora::downcast<const TextAreaRenderer*>(Widget::getSharedRenderer());
+        return downcast<const TextAreaRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     TextAreaRenderer* TextArea::getRenderer()
     {
-        return aurora::downcast<TextAreaRenderer*>(Widget::getRenderer());
+        return downcast<TextAreaRenderer*>(Widget::getRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -191,8 +189,7 @@ namespace tgui
         const std::size_t selEnd = getSelectionEnd();
         if (selStart <= selEnd)
             return m_text.substr(selStart, selEnd - selStart);
-        else
-            return m_text.substr(selEnd, selStart - selEnd);
+        return m_text.substr(selEnd, selStart - selEnd);
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -213,8 +210,7 @@ namespace tgui
 
     void TextArea::updateTextSize()
     {
-        if (m_textSizeCached < 1)
-            m_textSizeCached = 1;
+        m_textSizeCached = std::max<unsigned int>(m_textSizeCached, 1);
 
         // Change the text size
         m_textBeforeSelection.setCharacterSize(m_textSizeCached);
@@ -327,8 +323,7 @@ namespace tgui
         const auto caret = getCaretPosition();
         if (caret == 0)
             return 1;
-        else
-            return m_text.substr(0, caret).count('\n') + 1;
+        return m_text.substr(0, caret).count('\n') + 1;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -341,8 +336,7 @@ namespace tgui
         auto lineStart = m_text.rfind('\n', caret - 1);
         if (lineStart == String::npos)
             return caret + 1;
-        else
-            return caret - lineStart;
+        return caret - lineStart;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -521,11 +515,7 @@ namespace tgui
                     m_selEnd.x = m_selStart.x;
                 }
 
-                bool selectingWhitespace;
-                if (isWhitespace(m_lines[m_selStart.y][m_selStart.x]))
-                    selectingWhitespace = true;
-                else
-                    selectingWhitespace = false;
+                const bool selectingWhitespace = isWhitespace(m_lines[m_selStart.y][m_selStart.x]);
 
                 // Move start pointer to the beginning of the word/whitespace
                 for (std::size_t i = m_selStart.x; i > 0; --i)
@@ -535,8 +525,7 @@ namespace tgui
                         m_selStart.x = i;
                         break;
                     }
-                    else
-                        m_selStart.x = 0;
+                    m_selStart.x = 0;
                 }
 
                 // Move end pointer to the end of the word/whitespace
@@ -547,8 +536,7 @@ namespace tgui
                         m_selEnd.x = i;
                         break;
                     }
-                    else
-                        m_selEnd.x = m_lines[m_selEnd.y].length();
+                    m_selEnd.x = m_lines[m_selEnd.y].length();
                 }
             }
             else // No double clicking
@@ -694,6 +682,10 @@ namespace tgui
             insertTextAtCaretPosition(m_tabText);
         else if (event.code == Event::KeyboardKey::Enter)
             textEntered('\n');
+        else if (keyboard::isKeyPressDeleteWordLeft(event))
+            deleteWordLeft();
+        else if (keyboard::isKeyPressDeleteWordRight(event))
+            deleteWordRight();
         else if (event.code == Event::KeyboardKey::Backspace)
             backspaceKeyPressed();
         else if (event.code == Event::KeyboardKey::Delete)
@@ -777,8 +769,7 @@ namespace tgui
         {
             return true;
         }
-        else
-            return Widget::canHandleKeyPress(event);
+        return Widget::canHandleKeyPress(event);
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -925,9 +916,9 @@ namespace tgui
             //    return Vector2<std::size_t>(m_lines[lineNumber].getSize() - 1, lineNumber); // TextArea strips newlines but this code is kept for when this function is generalized
             //else
             if (curChar == U'\t')
-                charWidth = static_cast<float>(m_fontCached.getGlyph(' ', getTextSize(), false).advance) * 4;
+                charWidth = m_fontCached.getGlyph(' ', getTextSize(), false).advance * 4;
             else
-                charWidth = static_cast<float>(m_fontCached.getGlyph(curChar, getTextSize(), false).advance);
+                charWidth = m_fontCached.getGlyph(curChar, getTextSize(), false).advance;
 
             const float kerning = m_fontCached.getKerning(prevChar, curChar, getTextSize(), false);
             if (width + charWidth + kerning <= position.x)
@@ -936,8 +927,7 @@ namespace tgui
             {
                 if (position.x < width + kerning + (charWidth / 2.0f))
                     return {i, lineNumber};
-                else
-                    return {i + 1, lineNumber};
+                return {i + 1, lineNumber};
             }
 
             prevChar = curChar;
@@ -1186,7 +1176,7 @@ namespace tgui
         const auto oldSelEnd = m_selEnd;
 
         const float horiScrollOffset = m_horizontalScrollbar->isShown() ? m_horizontalScrollbar->getSize().y : 0.f;
-        const auto fullyVisibleLines = static_cast<std::size_t>((getInnerSize().y - m_paddingCached.getTop() - m_paddingCached.getBottom() - horiScrollOffset) / m_lineHeight);
+        const auto fullyVisibleLines = static_cast<std::size_t>((getInnerSize().y - m_paddingCached.getTopPlusBottom() - horiScrollOffset) / m_lineHeight);
         const std::size_t linesToScroll = (fullyVisibleLines >= 2) ? (fullyVisibleLines - 1) : 1;
         if (m_selEnd.y > linesToScroll)
             m_selEnd.y = m_selEnd.y - linesToScroll;
@@ -1205,7 +1195,7 @@ namespace tgui
         const auto oldSelEnd = m_selEnd;
 
         const float horiScrollOffset = m_horizontalScrollbar->isShown() ? m_horizontalScrollbar->getSize().y : 0.f;
-        const auto fullyVisibleLines = static_cast<std::size_t>((getInnerSize().y - m_paddingCached.getTop() - m_paddingCached.getBottom() - horiScrollOffset) / m_lineHeight);
+        const auto fullyVisibleLines = static_cast<std::size_t>((getInnerSize().y - m_paddingCached.getTopPlusBottom() - horiScrollOffset) / m_lineHeight);
         const std::size_t linesToScroll = (fullyVisibleLines >= 2) ? (fullyVisibleLines - 1) : 1;
         if (m_selEnd.y + linesToScroll < m_lines.size())
             m_selEnd.y = m_selEnd.y + linesToScroll;
@@ -1219,6 +1209,30 @@ namespace tgui
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
+    void TextArea::deleteWordLeft()
+    {
+        // If there is a selection then move the cursor to the beginning of the selection
+        if (m_selStart != m_selEnd)
+            moveCaretLeft(false);
+
+        moveCaretWordBegin(); // Only moves m_selEnd while m_selStart remains unchanged
+        deleteSelectedCharacters();
+    }
+
+    /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+
+    void TextArea::deleteWordRight()
+    {
+        // If there is a selection then move the cursor to the end of the selection
+        if (m_selStart != m_selEnd)
+            moveCaretRight(false);
+
+        moveCaretWordEnd(); // Only moves m_selEnd while m_selStart remains unchanged
+        deleteSelectedCharacters();
+    }
+
+    /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+
     void TextArea::backspaceKeyPressed()
     {
         if (m_readOnly)
@@ -1328,7 +1342,7 @@ namespace tgui
         clipboardContents.replace('\r', U"");
 
         // Only continue pasting if you actually have to do something
-        if ((m_selStart != m_selEnd) || (clipboardContents != U""))
+        if ((m_selStart != m_selEnd) || (!clipboardContents.empty()))
         {
             deleteSelectedCharacters();
             insertTextAtCaretPosition(clipboardContents);
@@ -1359,7 +1373,7 @@ namespace tgui
         {
             // Find the maximum width of one line
             const float textOffset = Text::getExtraHorizontalPadding(m_fontCached, m_textSizeCached);
-            float maxLineWidth = getInnerSize().x - m_paddingCached.getLeft() - m_paddingCached.getRight() - 2 * textOffset;
+            float maxLineWidth = getInnerSize().x - m_paddingCached.getLeftPlusRight() - 2 * textOffset;
             if (m_verticalScrollbar->isShown())
                 maxLineWidth -= m_verticalScrollbar->getSize().x;
 
@@ -1402,9 +1416,8 @@ namespace tgui
                 }
                 else // Not using optimization for monospaced font, so really calculate the width of every line
                 {
-                    float lineWidth = Text::getLineWidth(m_lines.back(), m_fontCached, m_textSizeCached);
-                    if (lineWidth > m_maxLineWidth)
-                        m_maxLineWidth = lineWidth;
+                    const float lineWidth = Text::getLineWidth(m_lines.back(), m_fontCached, m_textSizeCached);
+                    m_maxLineWidth = std::max(lineWidth, m_maxLineWidth);
                 }
             }
 
@@ -1499,8 +1512,7 @@ namespace tgui
                 rearrangeText(true);
                 return;
             }
-            else
-                updateScrollbars();
+            updateScrollbars();
         }
         else // Horizontal scrollbar is enabled
         {
@@ -1518,23 +1530,23 @@ namespace tgui
         if (m_horizontalScrollbar->isShown())
         {
             m_verticalScrollbar->setHeight(getInnerSize().y - m_horizontalScrollbar->getSize().y);
-            m_verticalScrollbar->setViewportSize(static_cast<unsigned int>(getInnerSize().y - m_horizontalScrollbar->getSize().y - m_paddingCached.getTop() - m_paddingCached.getBottom()));
+            m_verticalScrollbar->setViewportSize(static_cast<unsigned int>(getInnerSize().y - m_horizontalScrollbar->getSize().y - m_paddingCached.getTopPlusBottom()));
         }
         else
         {
             m_verticalScrollbar->setHeight(getInnerSize().y);
-            m_verticalScrollbar->setViewportSize(static_cast<unsigned int>(getInnerSize().y - m_paddingCached.getTop() - m_paddingCached.getBottom()));
+            m_verticalScrollbar->setViewportSize(static_cast<unsigned int>(getInnerSize().y - m_paddingCached.getTopPlusBottom()));
         }
 
         if (m_verticalScrollbar->isShown())
         {
             m_horizontalScrollbar->setWidth(getInnerSize().x - m_verticalScrollbar->getSize().x);
-            m_horizontalScrollbar->setViewportSize(static_cast<unsigned int>(getInnerSize().x - m_verticalScrollbar->getSize().x - m_paddingCached.getLeft() - m_paddingCached.getRight()));
+            m_horizontalScrollbar->setViewportSize(static_cast<unsigned int>(getInnerSize().x - m_verticalScrollbar->getSize().x - m_paddingCached.getLeftPlusRight()));
         }
         else
         {
             m_horizontalScrollbar->setWidth(getInnerSize().x);
-            m_horizontalScrollbar->setViewportSize(static_cast<unsigned int>(getInnerSize().x - m_paddingCached.getLeft() - m_paddingCached.getRight()));
+            m_horizontalScrollbar->setViewportSize(static_cast<unsigned int>(getInnerSize().x - m_paddingCached.getLeftPlusRight()));
         }
     }
 
@@ -1642,16 +1654,16 @@ namespace tgui
             const unsigned int left = m_horizontalScrollbar->getValue();
             if (m_caretPosition.x <= left)
             {
-                unsigned int newValue =
+                const auto newValue =
                     static_cast<unsigned int>(std::max(0, static_cast<int>(m_caretPosition.x
                                                                            - (Text::getExtraHorizontalPadding(m_fontCached, m_textSizeCached) * 2))));
                 m_horizontalScrollbar->setValue(newValue);
             }
             else if (m_caretPosition.x > (left + m_horizontalScrollbar->getViewportSize()))
             {
-                unsigned int newValue = static_cast<unsigned int>(m_caretPosition.x
-                                                                  + (Text::getExtraHorizontalPadding(m_fontCached, m_textSizeCached) * 2)
-                                                                  - m_horizontalScrollbar->getViewportSize());
+                const auto newValue = static_cast<unsigned int>(m_caretPosition.x
+                                                                + (Text::getExtraHorizontalPadding(m_fontCached, m_textSizeCached) * 2)
+                                                                - m_horizontalScrollbar->getViewportSize());
                 m_horizontalScrollbar->setValue(newValue);
             }
         }
@@ -1674,8 +1686,8 @@ namespace tgui
 
     Vector2f TextArea::getInnerSize() const
     {
-        return {std::max(0.f, getSize().x - m_bordersCached.getLeft() - m_bordersCached.getRight()),
-                std::max(0.f, getSize().y - m_bordersCached.getTop() - m_bordersCached.getBottom())};
+        return {std::max(0.f, getSize().x - m_bordersCached.getLeftPlusRight()),
+                std::max(0.f, getSize().y - m_bordersCached.getTopPlusBottom())};
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -1786,7 +1798,7 @@ namespace tgui
                 {
                     m_selectionRects.back().width += textOffset;
 
-                    if (m_textSelection2.getString() != U"")
+                    if (!m_textSelection2.getString().empty())
                     {
                         tempText.setString(m_lines[selectionEnd.y].substr(0, selectionEnd.x));
                         m_selectionRects.emplace_back(m_textSelection2.getPosition().x - textOffset, static_cast<float>(selectionEnd.y) * m_lineHeight,
@@ -1819,7 +1831,7 @@ namespace tgui
             return;
 
         const float horiScrollOffset = m_horizontalScrollbar->isShown() ? m_horizontalScrollbar->getSize().y : 0.f;
-        m_visibleLines = std::min(static_cast<std::size_t>((getInnerSize().y - m_paddingCached.getTop() - m_paddingCached.getBottom() - horiScrollOffset) / m_lineHeight), m_lines.size());
+        m_visibleLines = std::min(static_cast<std::size_t>((getInnerSize().y - m_paddingCached.getTopPlusBottom() - horiScrollOffset) / m_lineHeight), m_lines.size());
 
         // Store which area is visible
         if (m_verticalScrollbar->getViewportSize() < m_verticalScrollbar->getMaximum())
@@ -1827,14 +1839,14 @@ namespace tgui
             m_topLine = static_cast<std::size_t>(m_verticalScrollbar->getValue() / m_lineHeight);
 
             // The scrollbar may be standing between lines in which case one more line is visible
-            if (((static_cast<unsigned int>(getInnerSize().y - m_paddingCached.getTop() - m_paddingCached.getBottom() - horiScrollOffset) % static_cast<unsigned int>(m_lineHeight)) != 0)
+            if (((static_cast<unsigned int>(getInnerSize().y - m_paddingCached.getTopPlusBottom() - horiScrollOffset) % static_cast<unsigned int>(m_lineHeight)) != 0)
              || ((m_verticalScrollbar->getValue() % static_cast<unsigned int>(m_lineHeight)) != 0))
                 m_visibleLines++;
         }
         else // There is no vertical scrollbar
         {
             m_topLine = 0;
-            m_visibleLines = std::min(static_cast<std::size_t>((getInnerSize().y - m_paddingCached.getTop() - m_paddingCached.getBottom() - horiScrollOffset) / m_lineHeight), m_lines.size());
+            m_visibleLines = std::min(static_cast<std::size_t>((getInnerSize().y - m_paddingCached.getTopPlusBottom() - horiScrollOffset) / m_lineHeight), m_lines.size());
         }
 
         if (m_horizontalScrollbar->isShown())
@@ -1850,12 +1862,11 @@ namespace tgui
     {
         if (signalName == onTextChange.getName())
             return onTextChange;
-        else if (signalName == onSelectionChange.getName())
+        if (signalName == onSelectionChange.getName())
             return onSelectionChange;
-        else if (signalName == onCaretPositionChange.getName())
+        if (signalName == onCaretPositionChange.getName())
             return onCaretPositionChange;
-        else
-            return Widget::getSignal(std::move(signalName));
+        return Widget::getSignal(std::move(signalName));
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -1931,6 +1942,10 @@ namespace tgui
         {
             m_caretWidthCached = getSharedRenderer()->getCaretWidth();
         }
+        else if (property == U"RoundedBorderRadius")
+        {
+            m_roundedBorderRadiusCached = getSharedRenderer()->getRoundedBorderRadius();
+        }
         else if ((property == U"Opacity") || (property == U"OpacityDisabled"))
         {
             Widget::rendererChanged(property);
@@ -2003,28 +2018,37 @@ namespace tgui
     {
         const RenderStates statesForScrollbar = states;
 
-        // Draw the borders
-        if (m_bordersCached != Borders{0})
+        if ((m_roundedBorderRadiusCached > 0) && !m_spriteBackground.isSet())
         {
-            target.drawBorders(states, m_bordersCached, getSize(), Color::applyOpacity(m_borderColorCached, m_opacityCached));
+            target.drawRoundedRectangle(states, getSize(), Color::applyOpacity(m_backgroundColorCached, m_opacityCached),
+                                        m_roundedBorderRadiusCached, m_bordersCached, Color::applyOpacity(m_borderColorCached, m_opacityCached));
             states.transform.translate(m_bordersCached.getOffset());
         }
-
-        // Draw the background
-        if (m_spriteBackground.isSet())
-            target.drawSprite(states, m_spriteBackground);
         else
-            target.drawFilledRect(states, getInnerSize(), Color::applyOpacity(m_backgroundColorCached, m_opacityCached));
+        {
+            // Draw the borders
+            if (m_bordersCached != Borders{0})
+            {
+                target.drawBorders(states, m_bordersCached, getSize(), Color::applyOpacity(m_borderColorCached, m_opacityCached));
+                states.transform.translate(m_bordersCached.getOffset());
+            }
+
+            // Draw the background
+            if (m_spriteBackground.isSet())
+                target.drawSprite(states, m_spriteBackground);
+            else
+                target.drawFilledRect(states, getInnerSize(), Color::applyOpacity(m_backgroundColorCached, m_opacityCached));
+        }
 
         // Draw the contents of the text area
         {
             states.transform.translate({m_paddingCached.getLeft(), m_paddingCached.getTop()});
 
-            float clipWidth = getInnerSize().x - m_paddingCached.getLeft() - m_paddingCached.getRight();
+            float clipWidth = getInnerSize().x - m_paddingCached.getLeftPlusRight();
             if (m_verticalScrollbar->isShown())
                 clipWidth -= m_verticalScrollbar->getSize().x;
 
-            float clipHeight = getInnerSize().y - m_paddingCached.getTop() - m_paddingCached.getBottom();
+            float clipHeight = getInnerSize().y - m_paddingCached.getTopPlusBottom();
             if (m_horizontalScrollbar->isShown())
                 clipHeight -= m_horizontalScrollbar->getSize().y;
 
@@ -2081,8 +2105,7 @@ namespace tgui
     void TextArea::setCaretPositionImpl(std::size_t charactersBeforeCaret, bool selEndNeedUpdate, bool emitCaretChangedPosition)
     {
         // The caret position has to stay inside the string
-        if (charactersBeforeCaret > m_text.length())
-            charactersBeforeCaret = m_text.length();
+        charactersBeforeCaret = std::min(charactersBeforeCaret, m_text.length());
 
         // Find the line and position on that line on which the caret is located
         std::size_t count = 0;
