@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -25,9 +25,8 @@
 #include <TGUI/Widgets/TreeView.hpp>
 #include <TGUI/Keyboard.hpp>
 
-#if !TGUI_EXPERIMENTAL_USE_STD_MODULE
-    #include <cmath>
-#endif
+#include <algorithm>
+#include <cmath>
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -135,22 +134,20 @@ namespace tgui
                     nodes.erase(it);
                     return true;
                 }
-                else
-                {
-                    // Return false if some menu in the hierarchy couldn't be found
-                    if (!removeItemImpl(hierarchy, removeParentsWhenEmpty, parentIndex + 1, (*it)->nodes))
-                        return false;
 
-                    // If parents don't have to be removed as well then we are done
-                    if (!removeParentsWhenEmpty)
-                        return true;
-
-                    // Also delete the parent if empty
-                    if ((*it)->nodes.empty())
-                        nodes.erase(it);
+                // Return false if some menu in the hierarchy couldn't be found
+                if (!removeItemImpl(hierarchy, removeParentsWhenEmpty, parentIndex + 1, (*it)->nodes))
+                    return false;
 
+                // If parents don't have to be removed as well then we are done
+                if (!removeParentsWhenEmpty)
                     return true;
-                }
+
+                // Also delete the parent if empty
+                if ((*it)->nodes.empty())
+                    nodes.erase(it);
+
+                return true;
             }
 
             // The hierarchy doesn't exist
@@ -178,14 +175,13 @@ namespace tgui
         TreeView::Node* findNode(const std::vector<std::shared_ptr<TreeView::Node>>& nodes, const std::vector<String>& hierarchy, unsigned int parentIndex)
         {
             assert(parentIndex < hierarchy.size());
-            for (auto& node : nodes)
+            for (const auto& node : nodes)
             {
                 if (node->text.getString() != hierarchy[parentIndex])
                     continue;
-                else if (parentIndex + 1 == hierarchy.size())
+                if (parentIndex + 1 == hierarchy.size())
                     return node.get();
-                else
-                    return findNode(node->nodes, hierarchy, parentIndex + 1);
+                return findNode(node->nodes, hierarchy, parentIndex + 1);
             }
 
             return nullptr;
@@ -246,13 +242,13 @@ namespace tgui
     {
         if (initRenderer)
         {
-            m_renderer = aurora::makeCopied<TreeViewRenderer>();
+            m_renderer = makeCopied<TreeViewRenderer>();
             setRenderer(Theme::getDefault()->getRendererNoThrow(m_type));
 
             setTextSize(getGlobalTextSize());
             setItemHeight(static_cast<unsigned int>(std::round(Text::getLineHeight(m_fontCached, m_textSizeCached) * 1.25f)));
             setSize({Text::getLineHeight(m_fontCached, m_textSizeCached) * 10,
-                     (m_itemHeight * 7) + m_paddingCached.getTop() + m_paddingCached.getBottom() + m_bordersCached.getTop() + m_bordersCached.getBottom()});
+                     (m_itemHeight * 7) + m_paddingCached.getTopPlusBottom() + m_bordersCached.getTopPlusBottom()});
         }
     }
 
@@ -355,29 +351,28 @@ namespace tgui
     {
         if (treeView)
             return std::static_pointer_cast<TreeView>(treeView->clone());
-        else
-            return nullptr;
+        return nullptr;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     TreeViewRenderer* TreeView::getSharedRenderer()
     {
-        return aurora::downcast<TreeViewRenderer*>(Widget::getSharedRenderer());
+        return downcast<TreeViewRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     const TreeViewRenderer* TreeView::getSharedRenderer() const
     {
-        return aurora::downcast<const TreeViewRenderer*>(Widget::getSharedRenderer());
+        return downcast<const TreeViewRenderer*>(Widget::getSharedRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     TreeViewRenderer* TreeView::getRenderer()
     {
-        return aurora::downcast<TreeViewRenderer*>(Widget::getRenderer());
+        return downcast<TreeViewRenderer*>(Widget::getRenderer());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -705,8 +700,8 @@ namespace tgui
 
     Vector2f TreeView::getInnerSize() const
     {
-        return {std::max(0.f, getSize().x - m_bordersCached.getLeft() - m_bordersCached.getRight()),
-                std::max(0.f, getSize().y - m_bordersCached.getTop() - m_bordersCached.getBottom())};
+        return {std::max(0.f, getSize().x - m_bordersCached.getLeftPlusRight()),
+                std::max(0.f, getSize().y - m_bordersCached.getTopPlusBottom())};
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -717,8 +712,8 @@ namespace tgui
         {
             m_iconBounds =
                 {
-                    std::max(std::max(m_spriteBranchCollapsed.getSize().x, m_spriteBranchExpanded.getSize().x), m_spriteLeaf.getSize().x),
-                    std::max(std::max(m_spriteBranchCollapsed.getSize().y, m_spriteBranchExpanded.getSize().y), m_spriteLeaf.getSize().y)
+                    std::max({m_spriteBranchCollapsed.getSize().x, m_spriteBranchExpanded.getSize().x, m_spriteLeaf.getSize().x}),
+                    std::max({m_spriteBranchCollapsed.getSize().y, m_spriteBranchExpanded.getSize().y, m_spriteLeaf.getSize().y})
                 };
         }
         else
@@ -864,12 +859,12 @@ namespace tgui
             isDragging = m_horizontalScrollbar->leftMousePressed(pos);
         else
         {
-            float maxItemWidth = getInnerSize().x - m_paddingCached.getLeft() - m_paddingCached.getRight();
+            float maxItemWidth = getInnerSize().x - m_paddingCached.getLeftPlusRight();
             if (m_verticalScrollbar->isShown())
                 maxItemWidth -= m_verticalScrollbar->getSize().x;
 
             if (FloatRect{m_bordersCached.getLeft() + m_paddingCached.getLeft(), m_bordersCached.getTop() + m_paddingCached.getTop(),
-                          maxItemWidth, getInnerSize().y - m_paddingCached.getTop() - m_paddingCached.getBottom()}.contains(pos))
+                          maxItemWidth, getInnerSize().y - m_paddingCached.getTopPlusBottom()}.contains(pos))
             {
                 pos.y -= m_bordersCached.getTop() + m_paddingCached.getTop();
 
@@ -895,14 +890,14 @@ namespace tgui
         {
             m_mouseDown = false;
 
-            float maxItemWidth = getInnerSize().x - m_paddingCached.getLeft() - m_paddingCached.getRight();
+            float maxItemWidth = getInnerSize().x - m_paddingCached.getLeftPlusRight();
             if (m_verticalScrollbar->isShown())
                 maxItemWidth -= m_verticalScrollbar->getSize().x;
 
             bool iconPressed = false;
             int selectedIndex = -1;
             if (FloatRect{m_bordersCached.getLeft() + m_paddingCached.getLeft(), m_bordersCached.getTop() + m_paddingCached.getTop(),
-                          maxItemWidth, getInnerSize().y - m_paddingCached.getTop() - m_paddingCached.getBottom()}.contains(pos))
+                          maxItemWidth, getInnerSize().y - m_paddingCached.getTopPlusBottom()}.contains(pos))
             {
                 pos.y -= m_bordersCached.getTop() + m_paddingCached.getTop();
 
@@ -968,17 +963,17 @@ namespace tgui
     {
         pos -= getPosition();
 
-        float maxItemWidth = getInnerSize().x - m_paddingCached.getLeft() - m_paddingCached.getRight();
+        float maxItemWidth = getInnerSize().x - m_paddingCached.getLeftPlusRight();
         if (m_verticalScrollbar->isShown())
             maxItemWidth -= m_verticalScrollbar->getSize().x;
 
         if (FloatRect{m_bordersCached.getLeft() + m_paddingCached.getLeft(), m_bordersCached.getTop() + m_paddingCached.getTop(),
-                      maxItemWidth, getInnerSize().y - m_paddingCached.getTop() - m_paddingCached.getBottom()}.contains(pos))
+                      maxItemWidth, getInnerSize().y - m_paddingCached.getTopPlusBottom()}.contains(pos))
         {
             pos.y -= m_bordersCached.getTop() + m_paddingCached.getTop();
 
             // NOLINTNEXTLINE(bugprone-integer-division)
-            int selectedItem = static_cast<int>(((pos.y - (m_itemHeight - (m_verticalScrollbar->getValue() % m_itemHeight))) / m_itemHeight) + (m_verticalScrollbar->getValue() / m_itemHeight) + 1);
+            const int selectedItem = static_cast<int>(((pos.y - (m_itemHeight - (m_verticalScrollbar->getValue() % m_itemHeight))) / m_itemHeight) + (m_verticalScrollbar->getValue() / m_itemHeight) + 1);
             if ((selectedItem >= 0) && (selectedItem < static_cast<int>(m_visibleNodes.size())))
             {
                 updateSelectedItem(selectedItem);
@@ -1015,12 +1010,12 @@ namespace tgui
             m_verticalScrollbar->mouseNoLongerOnWidget();
             m_horizontalScrollbar->mouseNoLongerOnWidget();
 
-            float maxItemWidth = getInnerSize().x - m_paddingCached.getLeft() - m_paddingCached.getRight();
+            float maxItemWidth = getInnerSize().x - m_paddingCached.getLeftPlusRight();
             if (m_verticalScrollbar->isShown())
                 maxItemWidth -= m_verticalScrollbar->getSize().x;
 
             if (FloatRect{m_bordersCached.getLeft() + m_paddingCached.getLeft(), m_bordersCached.getTop() + m_paddingCached.getTop(),
-                          maxItemWidth, getInnerSize().y - m_paddingCached.getTop() - m_paddingCached.getBottom()}.contains(pos))
+                          maxItemWidth, getInnerSize().y - m_paddingCached.getTopPlusBottom()}.contains(pos))
             {
                 pos.y -= m_bordersCached.getTop() + m_paddingCached.getTop();
 
@@ -1172,8 +1167,7 @@ namespace tgui
         {
             return true;
         }
-        else
-            return Widget::canHandleKeyPress(event);
+        return Widget::canHandleKeyPress(event);
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -1182,16 +1176,15 @@ namespace tgui
     {
         if (signalName == onItemSelect.getName())
             return onItemSelect;
-        else if (signalName == onDoubleClick.getName())
+        if (signalName == onDoubleClick.getName())
             return onDoubleClick;
-        else if (signalName == onExpand.getName())
+        if (signalName == onExpand.getName())
             return onExpand;
-        else if (signalName == onCollapse.getName())
+        if (signalName == onCollapse.getName())
             return onCollapse;
-        else if (signalName == onRightClick.getName())
+        if (signalName == onRightClick.getName())
             return onRightClick;
-        else
-            return Widget::getSignal(std::move(signalName));
+        return Widget::getSignal(std::move(signalName));
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -1414,8 +1407,7 @@ namespace tgui
                                     (pos * m_itemHeight) + ((m_itemHeight - node->text.getSize().y) / 2.f)});
 
             const float right = node->text.getPosition().x + node->text.getSize().x + m_paddingCached.getRight();
-            if (right > m_maxRight)
-                m_maxRight = right;
+            m_maxRight = std::max(right, m_maxRight);
 
             pos++;
             if (node->expanded && !node->nodes.empty())
@@ -1433,7 +1425,7 @@ namespace tgui
         if (m_selectedItem >= 0 && static_cast<std::size_t>(m_selectedItem) < m_visibleNodes.size())
             selectedNode = m_visibleNodes[static_cast<std::size_t>(m_selectedItem)].get();
 
-        int oldHoveredItem = m_hoveredItem;
+        const int oldHoveredItem = m_hoveredItem;
 
         m_maxRight = 0;
         m_hoveredItem = -1;
@@ -1454,28 +1446,28 @@ namespace tgui
         m_horizontalScrollbar->setMaximum(static_cast<unsigned int>(m_maxRight));
 
         const bool horizontalScrollbarShown = (m_horizontalScrollbar->getPolicy() == Scrollbar::Policy::Always)
-            || (((m_maxRight + m_verticalScrollbar->getSize().x) > (getInnerSize().x - m_paddingCached.getLeft() - m_paddingCached.getRight()))
+            || (((m_maxRight + m_verticalScrollbar->getSize().x) > (getInnerSize().x - m_paddingCached.getLeftPlusRight()))
              && (m_horizontalScrollbar->getPolicy() != Scrollbar::Policy::Never));
         if (horizontalScrollbarShown)
         {
             m_verticalScrollbar->setSize({m_verticalScrollbar->getSize().x, std::max(0.f, getInnerSize().y - m_horizontalScrollbar->getSize().y)});
-            m_verticalScrollbar->setViewportSize(static_cast<unsigned int>(getInnerSize().y - m_horizontalScrollbar->getSize().y - m_paddingCached.getTop() - m_paddingCached.getBottom()));
+            m_verticalScrollbar->setViewportSize(static_cast<unsigned int>(getInnerSize().y - m_horizontalScrollbar->getSize().y - m_paddingCached.getTopPlusBottom()));
         }
         else
         {
             m_verticalScrollbar->setSize({m_verticalScrollbar->getSize().x, std::max(0.f, getInnerSize().y)});
-            m_verticalScrollbar->setViewportSize(static_cast<unsigned int>(getInnerSize().y - m_paddingCached.getTop() - m_paddingCached.getBottom()));
+            m_verticalScrollbar->setViewportSize(static_cast<unsigned int>(getInnerSize().y - m_paddingCached.getTopPlusBottom()));
         }
 
         if (m_verticalScrollbar->isShown())
         {
             m_horizontalScrollbar->setSize({std::max(0.f, getInnerSize().x - m_verticalScrollbar->getSize().x), m_horizontalScrollbar->getSize().y});
-            m_horizontalScrollbar->setViewportSize(static_cast<unsigned int>(getInnerSize().x - m_verticalScrollbar->getSize().x - m_paddingCached.getLeft() - m_paddingCached.getRight()));
+            m_horizontalScrollbar->setViewportSize(static_cast<unsigned int>(getInnerSize().x - m_verticalScrollbar->getSize().x - m_paddingCached.getLeftPlusRight()));
         }
         else
         {
             m_horizontalScrollbar->setSize({std::max(0.f, getInnerSize().x), m_horizontalScrollbar->getSize().y});
-            m_horizontalScrollbar->setViewportSize(static_cast<unsigned int>(getInnerSize().x - m_paddingCached.getLeft() - m_paddingCached.getRight()));
+            m_horizontalScrollbar->setViewportSize(static_cast<unsigned int>(getInnerSize().x - m_paddingCached.getLeftPlusRight()));
         }
 
         // If the horizontal scrollbar is shown then add a little padding at the end of the longest line
@@ -1490,7 +1482,7 @@ namespace tgui
 
     void TreeView::draw(BackendRenderTarget& target, RenderStates states) const
     {
-        RenderStates statesForScrollbars = states;
+        const RenderStates statesForScrollbars = states;
 
         if (m_bordersCached != Borders{0})
         {
@@ -1504,12 +1496,12 @@ namespace tgui
         else
             target.drawFilledRect(states, getInnerSize(), Color::applyOpacity(m_backgroundColorCached, m_opacityCached));
 
-        float maxItemWidth = getInnerSize().x - m_paddingCached.getLeft() - m_paddingCached.getRight();
+        float maxItemWidth = getInnerSize().x - m_paddingCached.getLeftPlusRight();
         if (m_verticalScrollbar->isShown())
             maxItemWidth -= m_verticalScrollbar->getSize().x;
 
         target.addClippingLayer(states, {{m_paddingCached.getLeft(), m_paddingCached.getTop()},
-            {maxItemWidth, getInnerSize().y - m_paddingCached.getTop() - m_paddingCached.getBottom()}});
+            {maxItemWidth, getInnerSize().y - m_paddingCached.getTopPlusBottom()}});
 
         std::size_t firstNode = 0;
         std::size_t lastNode = m_visibleNodes.size();
@@ -1530,7 +1522,7 @@ namespace tgui
         {
             states.transform.translate({static_cast<float>(m_horizontalScrollbar->getValue()), m_selectedItem * static_cast<float>(m_itemHeight)});
 
-            const Vector2f size = {getInnerSize().x - m_paddingCached.getLeft() - m_paddingCached.getRight(), static_cast<float>(m_itemHeight)};
+            const Vector2f size = {getInnerSize().x - m_paddingCached.getLeftPlusRight(), static_cast<float>(m_itemHeight)};
             if ((m_selectedItem == m_hoveredItem) && m_selectedBackgroundColorHoverCached.isSet())
                 target.drawFilledRect(states, size, Color::applyOpacity(m_selectedBackgroundColorHoverCached, m_opacityCached));
             else
@@ -1543,7 +1535,7 @@ namespace tgui
         if ((m_hoveredItem >= static_cast<int>(firstNode)) && (m_hoveredItem < static_cast<int>(lastNode)) && (m_hoveredItem != m_selectedItem) && m_backgroundColorHoverCached.isSet())
         {
             states.transform.translate({static_cast<float>(m_horizontalScrollbar->getValue()), m_hoveredItem * static_cast<float>(m_itemHeight)});
-            target.drawFilledRect(states, {getInnerSize().x - m_paddingCached.getLeft() - m_paddingCached.getRight(), static_cast<float>(m_itemHeight)}, Color::applyOpacity(m_backgroundColorHoverCached, m_opacityCached));
+            target.drawFilledRect(states, {getInnerSize().x - m_paddingCached.getLeftPlusRight(), static_cast<float>(m_itemHeight)}, Color::applyOpacity(m_backgroundColorHoverCached, m_opacityCached));
             states.transform.translate({-static_cast<float>(m_horizontalScrollbar->getValue()), -m_hoveredItem * static_cast<float>(m_itemHeight)});
         }
 
@@ -1696,21 +1688,19 @@ namespace tgui
 
             return true;
         }
-        else // Root node
+        // Root node
+        for (const auto& node : m_nodes)
         {
-            for (const auto& node : m_nodes)
+            if (node->text.getString() != hierarchy.back())
+                continue;
+
+            if (node->expanded != expandNode)
             {
-                if (node->text.getString() != hierarchy.back())
-                    continue;
-
-                if (node->expanded != expandNode)
-                {
-                    node->expanded = expandNode;
-                    markNodesDirty();
-                }
-
-                return true;
+                node->expanded = expandNode;
+                markNodesDirty();
             }
+
+            return true;
         }
 
         return false;
@@ -1808,10 +1798,9 @@ namespace tgui
         {
             if (node->text.getString() != hierarchy[parentIndex])
                 continue;
-            else if (parentIndex + 2 == hierarchy.size())
+            if (parentIndex + 2 == hierarchy.size())
                 return node.get();
-            else
-                return findParentNode(hierarchy, parentIndex + 1, node->nodes, node.get(), createParents);
+            return findParentNode(hierarchy, parentIndex + 1, node->nodes, node.get(), createParents);
         }
 
         if (createParents)
@@ -1819,10 +1808,8 @@ namespace tgui
             createNode(nodes, parent, hierarchy[parentIndex]);
             if (parentIndex + 2 == hierarchy.size())
                 return nodes.back().get();
-            else
-                return findParentNode(hierarchy, parentIndex + 1, nodes.back()->nodes, nodes.back().get(), createParents);
+            return findParentNode(hierarchy, parentIndex + 1, nodes.back()->nodes, nodes.back().get(), createParents);
         }
-
         return nullptr;
     }
 
@@ -1837,4 +1824,3 @@ namespace tgui
 }
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-
