@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -26,13 +26,13 @@
 
 TEST_CASE("[Animation]")
 {
-    tgui::Widget::Ptr widget = tgui::ClickableWidget::create();
+    const tgui::Widget::Ptr widget = tgui::ClickableWidget::create();
     widget->setPosition(30, 15);
     widget->setSize(120, 30);
     widget->setInheritedOpacity(0.9f);
     widget->getRenderer()->setOpacity(0.5f);
 
-    tgui::Panel::Ptr parent = tgui::Panel::create();
+    const tgui::Panel::Ptr parent = tgui::Panel::create();
     parent->setSize(480, 360);
     parent->add(widget);
 
