@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -29,5 +29,5 @@ TEST_CASE("[Clipboard]")
     tgui::getBackend()->setClipboard("Some text");
     REQUIRE(getClipboardContents() == "Some text");
     tgui::getBackend()->setClipboard("");
-    REQUIRE(getClipboardContents() == "");
+    REQUIRE(getClipboardContents().empty());
 }
