@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -45,7 +45,7 @@ TEST_CASE("[Clipping]")
         gui.add(background);
         background->moveToBack();
 
-        std::shared_ptr<void> scopeExit(nullptr, [&](void*){
+        const std::shared_ptr<void> scopeExit(nullptr, [&](void*){
             gui.setRelativeViewport({0, 0, 1, 1});
             gui.setRelativeView({0, 0, 1, 1});
         });
@@ -72,7 +72,7 @@ TEST_CASE("[Clipping]")
         gui.add(editBox);
         editBox->setCaretPosition(0);
 
-        std::shared_ptr<void> scopeExit(nullptr, [&](void*){
+        const std::shared_ptr<void> scopeExit(nullptr, [&](void*){
             gui.setRelativeViewport({0, 0, 1, 1});
             gui.setRelativeView({0, 0, 1, 1});
         });
