@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -69,7 +69,7 @@ TEST_CASE("[Container]")
 
         REQUIRE(container->getWidgets().size() == 3);
         REQUIRE(container->getWidgets()[0]->getWidgetName() == "widget1");
-        REQUIRE(container->getWidgets()[1]->getWidgetName() == "");
+        REQUIRE(container->getWidgets()[1]->getWidgetName().empty());
         REQUIRE(container->getWidgets()[2]->getWidgetName() == "widget3");
     }
 
@@ -329,7 +329,7 @@ TEST_CASE("[Container]")
     SECTION("focus")
     {
         auto editBox1 = tgui::EditBox::create();
-        tgui::EditBox::Ptr editBox2 = tgui::EditBox::create();
+        const tgui::EditBox::Ptr editBox2 = tgui::EditBox::create();
         auto editBox3 = tgui::EditBox::create();
 
         container->removeAllWidgets();
