@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -139,12 +139,12 @@ TEST_CASE("[Serializer]")
         rendererData->propertyValuePairs["TextStyleProperty"] = {tgui::TextStyle::StrikeThrough};
         rendererData->propertyValuePairs["Nested"] = {childRendererData};
 
-        tgui::String result = "SomeColor = red;\n"
-                             "TextStyleProperty = StrikeThrough;\n"
-                             "\n"
-                             "Nested {\n"
-                             "    Num = 5;\n"
-                             "}\n";
+        const tgui::String result = "SomeColor = red;\n"
+                                    "TextStyleProperty = StrikeThrough;\n"
+                                    "\n"
+                                    "Nested {\n"
+                                    "    Num = 5;\n"
+                                    "}\n";
 
         REQUIRE(tgui::Serializer::serialize(rendererData) == result);
     }
@@ -157,7 +157,7 @@ TEST_CASE("[Serializer]")
         tgui::Serializer::setFunction(tgui::ObjectConverter::Type::Color, [](tgui::ObjectConverter&&){ return "STR"; });
         REQUIRE(tgui::Serializer::serialize(tgui::Color::Blue) == "STR");
         REQUIRE(tgui::Serializer::serialize(tgui::Outline{10, 2, 50, 300}) == "(10, 2, 50, 300)");
-        
+
         tgui::Serializer::setFunction(tgui::ObjectConverter::Type::Color, oldFunc);
         REQUIRE(tgui::Serializer::serialize(tgui::Color::Blue) == "blue");
     }
