@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -45,15 +45,15 @@ TEST_CASE("[String]")
     std::u32string u32s(U"\u03b1\u03b2\u03b3\u03b4\u03b5");
 
 #if TGUI_COMPILED_WITH_CPP_VER >= 17
-    std::string_view view_s(s);
-    std::wstring_view view_ws(ws);
-    std::u16string_view view_u16s(u16s);
-    std::u32string_view view_u32s(u32s);
+    const std::string_view view_s(s);
+    const std::wstring_view view_ws(ws);
+    const std::u16string_view view_u16s(u16s);
+    const std::u32string_view view_u32s(u32s);
 #else
-    tgui::CharStringView view_s(s);
-    tgui::StringViewImpl<wchar_t> view_ws(ws);
-    tgui::StringViewImpl<char16_t> view_u16s(u16s);
-    tgui::StringView view_u32s(u32s);
+    const tgui::CharStringView view_s(s);
+    const tgui::StringViewImpl<wchar_t> view_ws(ws);
+    const tgui::StringViewImpl<char16_t> view_u16s(u16s);
+    const tgui::StringView view_u32s(u32s);
 #endif
 
 #if defined(__cpp_lib_char8_t) && (__cpp_lib_char8_t >= 201811L)
@@ -244,7 +244,7 @@ TEST_CASE("[String]")
         REQUIRE(str.assign(u16s) == U"\u03b1\u03b2\u03b3\u03b4\u03b5");
         REQUIRE(str.assign(u32s) == U"\u03b1\u03b2\u03b3\u03b4\u03b5");
 
-        tgui::String str2 = "abc";
+        const tgui::String str2 = "abc";
         REQUIRE(str.assign(str2) == "abc");
         REQUIRE(str.assign(tgui::String("xyz")) == "xyz");
         REQUIRE(str.assign(tgui::String("abcde"), 2, 2) == "cd");
@@ -955,8 +955,8 @@ TEST_CASE("[String]")
     {
         SECTION("ASCII strings")
         {
-            tgui::String str1 = "abc";
-            tgui::String str2 = "xyz";
+            const tgui::String str1 = "abc";
+            const tgui::String str2 = "xyz";
 
             SECTION("True")
             {
@@ -1039,8 +1039,8 @@ TEST_CASE("[String]")
 
         SECTION("Unicode strings")
         {
-            tgui::String str1 = U"\u03b1\u03b2";
-            tgui::String str2 = U"\u03b3\u03b4";
+            const tgui::String str1 = U"\u03b1\u03b2";
+            const tgui::String str2 = U"\u03b3\u03b4";
 
             SECTION("True")
             {
@@ -1280,7 +1280,7 @@ TEST_CASE("[String]")
 
     SECTION("operator+")
     {
-        tgui::String str2 = U"\u03b4";
+        const tgui::String str2 = U"\u03b4";
 
         str = "@"; REQUIRE(str + "xyz" == "@xyz");
         str = "@"; REQUIRE(str + L"\U00010348" == L"@\U00010348");
@@ -1390,7 +1390,7 @@ TEST_CASE("[String]")
         istream >> str1 >> str2 >> str3;
         REQUIRE(str1 == "abc1");
         REQUIRE(str2 == "2");
-        REQUIRE(str3 == "");
+        REQUIRE(str3.empty());
 
         std::wstringbuf wstreambuf;
         std::wostream wostream(&wstreambuf);
@@ -1402,7 +1402,7 @@ TEST_CASE("[String]")
         wistream >> str1 >> str2 >> str3;
         REQUIRE(str1 == L"\u03b1\u03b2\u03b3\u03b4\u03b53");
         REQUIRE(str2 == "4");
-        REQUIRE(str3 == "");
+        REQUIRE(str3.empty());
     }
 
     SECTION("attemptToInt")
@@ -1495,7 +1495,7 @@ TEST_CASE("[String]")
         REQUIRE(str.trim() == "a");
 
         str = "";
-        REQUIRE(str.trim() == "");
+        REQUIRE(str.trim().empty());
     }
 
     SECTION("toLower")
@@ -1546,7 +1546,7 @@ TEST_CASE("[String]")
 
         parts = tgui::String("").split(',');
         REQUIRE(parts.size() == 1);
-        REQUIRE(parts[0] == "");
+        REQUIRE(parts[0].empty());
 
         parts = tgui::String("a|b").split('|');
         REQUIRE(parts.size() == 2);
@@ -1569,8 +1569,8 @@ TEST_CASE("[String]")
     {
         REQUIRE(tgui::String::join({"alpha", "bravo", "charlie"}, ", ") == "alpha, bravo, charlie");
         REQUIRE(tgui::String::join({"xyz"}, ", ") == "xyz");
-        REQUIRE(tgui::String::join({""}, ", ") == "");
-        REQUIRE(tgui::String::join({}, ", ") == "");
+        REQUIRE(tgui::String::join({""}, ", ").empty());
+        REQUIRE(tgui::String::join({}, ", ").empty());
     }
 
     SECTION("starts_with")
@@ -1664,21 +1664,21 @@ TEST_CASE("[String]")
 
     SECTION("Invalid characters")
     {
-        REQUIRE(tgui::String(U"\x200000").toUtf16() == u"");
-        REQUIRE(tgui::String(U"\xDBFF").toUtf16() == u"");
+        REQUIRE(tgui::String(U"\x200000").toUtf16().empty());
+        REQUIRE(tgui::String(U"\xDBFF").toUtf16().empty());
 
         TGUI_IF_CONSTEXPR (sizeof(wchar_t) == 2)
         {
-            REQUIRE(tgui::String(U"\x200000").toWideString() == L"");
-            REQUIRE(tgui::String(U"\xDBFF").toWideString() == L"");
+            REQUIRE(tgui::String(U"\x200000").toWideString().empty());
+            REQUIRE(tgui::String(U"\xDBFF").toWideString().empty());
         }
 
-        REQUIRE(tgui::String(U"\x200000").toStdString() == "");
-        REQUIRE(tgui::String(U"\xDBFF").toStdString() == "");
+        REQUIRE(tgui::String(U"\x200000").toStdString().empty());
+        REQUIRE(tgui::String(U"\xDBFF").toStdString().empty());
 
-        REQUIRE(tgui::String(u"\xDBFF") == u"");
-        REQUIRE(tgui::String(u"\xDBFF\x1234") == u"");
+        REQUIRE(tgui::String(u"\xDBFF").empty());
+        REQUIRE(tgui::String(u"\xDBFF\x1234").empty());
 
-        REQUIRE(tgui::String("\xE2\x82") == "");
+        REQUIRE(tgui::String("\xE2\x82").empty());
     }
 }
