@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -22,7 +22,6 @@
 //
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-
 #ifndef TGUI_TESTS_HPP
 #define TGUI_TESTS_HPP
 
@@ -44,11 +43,7 @@
 
 #if TGUI_HAS_BACKEND_SFML_GRAPHICS
     #include <SFML/Graphics/RenderTexture.hpp>
-    #if TGUI_BUILD_AS_CXX_MODULE
-        import tgui.backend.sfml_graphics;
-    #else
-        #include <TGUI/Backend/SFML-Graphics.hpp>
-    #endif
+    #include <TGUI/Backend/SFML-Graphics.hpp>
 #endif
 
 #if TGUI_HAS_BACKEND_SFML_GRAPHICS
@@ -100,11 +95,7 @@
     #define TEST_DRAW(filename) testDraw(gui, filename, targetSize, nullptr);
 #endif
 
-#if TGUI_BUILD_AS_CXX_MODULE
-    import tgui;
-#else
-    #include <TGUI/TGUI.hpp>
-#endif
+#include <TGUI/TGUI.hpp>
 
 static const std::chrono::milliseconds DOUBLE_CLICK_TIMEOUT = std::chrono::milliseconds(500);
 
