@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -29,16 +29,10 @@
 
 #include "Tests.hpp"
 
-#if !TGUI_BUILD_AS_CXX_MODULE
-    #include <TGUI/TextureManager.hpp>
-#endif
+#include <TGUI/TextureManager.hpp>
 
 #if TGUI_HAS_BACKEND_SFML_GRAPHICS
-    #if TGUI_BUILD_AS_CXX_MODULE
-        import tgui.backend.renderer.sfml_graphics;
-    #else
-        #include <TGUI/Backend/Renderer/SFML-Graphics/BackendRendererSFML.hpp>
-    #endif
+    #include <TGUI/Backend/Renderer/SFML-Graphics/BackendRendererSFML.hpp>
 #endif
 
 #if TGUI_HAS_BACKEND_SFML_GRAPHICS
@@ -82,7 +76,7 @@ TEST_CASE("[Texture]")
                 REQUIRE_THROWS_AS(texture.loadFromBase64("aW52YWxpZA=="), tgui::Exception);
             }
 
-            REQUIRE(texture.getId() == "");
+            REQUIRE(texture.getId().empty());
             REQUIRE(texture.getData() == nullptr);
             REQUIRE(texture.getImageSize() == tgui::Vector2u(0, 0));
             REQUIRE(texture.getMiddleRect() == tgui::UIntRect());
@@ -96,7 +90,7 @@ TEST_CASE("[Texture]")
                 REQUIRE_NOTHROW(tgui::Texture("resources/image.bmp"));
                 REQUIRE_NOTHROW(tgui::Texture("resources/image.jpg"));
 
-                tgui::Texture texture{"resources/image.png"};
+                const tgui::Texture texture{"resources/image.png"};
                 REQUIRE(texture.getId() == "resources/image.png");
                 REQUIRE(texture.getData() != nullptr);
                 REQUIRE(texture.getData()->backendTexture != nullptr);
@@ -137,7 +131,7 @@ TEST_CASE("[Texture]")
                 "4HlUEWCC5RnkpQCuR5SusF3k2bBZ5Vvb6g3fRYlPFx/HVi+GVuyp/xGBYCeingL7Z7eXxcGPU7nQnkd1Wpa2KGFVVzwP0He9jbbHIs1F92izF1"
                 "DgX82Wtol69PFp4HdDFeP52wO7DyejNXUryK3Qc1fC2yLPNP07syl9AO0Z/M+q1lNhW2sSkyLPhrNifn2O2xjCyiUUAAAAASUVORK5CYII=",
                 {2, 1, 6, 5}, {1, 2, 4, 1}, false);
-            REQUIRE(texture.getId() == "");
+            REQUIRE(texture.getId().empty());
             REQUIRE(texture.getData() != nullptr);
             REQUIRE(texture.getData()->backendTexture != nullptr);
             REQUIRE(texture.getPartRect() == tgui::UIntRect(2, 1, 6, 5));
@@ -177,7 +171,7 @@ TEST_CASE("[Texture]")
             REQUIRE(copyCount == 0);
             REQUIRE(destructCount == 0);
             {
-                tgui::Texture textureCopy{texture}; // NOLINT(performance-unnecessary-copy-initialization)
+                const tgui::Texture textureCopy{texture}; // NOLINT(performance-unnecessary-copy-initialization)
                 REQUIRE(textureCopy.getId() == "resources/image.png");
                 REQUIRE(textureCopy.getData() != nullptr);
                 REQUIRE(textureCopy.getData()->backendTexture != nullptr);
