@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -26,7 +26,7 @@
 
 TEST_CASE("[Button]")
 {
-    tgui::Button::Ptr button = tgui::Button::create();
+    const tgui::Button::Ptr button = tgui::Button::create();
     button->getRenderer()->setFont("resources/DejaVuSans.ttf");
 
     SECTION("Signals")
@@ -56,7 +56,7 @@ TEST_CASE("[Button]")
 
     SECTION("Text")
     {
-        REQUIRE(button->getText() == "");
+        REQUIRE(button->getText().empty());
         button->setText("SomeText");
         REQUIRE(button->getText() == "SomeText");
     }
@@ -138,7 +138,7 @@ TEST_CASE("[Button]")
     testWidgetRenderer(button->getRenderer());
     SECTION("Renderer")
     {
-        auto renderer = button->getRenderer();
+        auto* renderer = button->getRenderer();
 
         SECTION("colored")
         {
@@ -163,7 +163,7 @@ TEST_CASE("[Button]")
                 REQUIRE_NOTHROW(renderer->setProperty("TextStyleDown", "Bold | Underlined"));
                 REQUIRE_NOTHROW(renderer->setProperty("TextStyleDisabled", "StrikeThrough"));
                 REQUIRE_NOTHROW(renderer->setProperty("Borders", "(1, 2, 3, 4)"));
-                REQUIRE_NOTHROW(renderer->setProperty("RoundedBorderRadius", 5));
+                REQUIRE_NOTHROW(renderer->setProperty("RoundedBorderRadius", "5"));
             }
 
             SECTION("set object property")
@@ -259,11 +259,11 @@ TEST_CASE("[Button]")
 
         SECTION("textured")
         {
-            tgui::Texture textureNormal("resources/Texture1.png");
-            tgui::Texture textureHover("resources/Texture2.png");
-            tgui::Texture textureDown("resources/Texture3.png");
-            tgui::Texture textureDisabled("resources/Texture4.png");
-            tgui::Texture textureFocused("resources/Texture5.png");
+            const tgui::Texture textureNormal("resources/Texture1.png");
+            const tgui::Texture textureHover("resources/Texture2.png");
+            const tgui::Texture textureDown("resources/Texture3.png");
+            const tgui::Texture textureDisabled("resources/Texture4.png");
+            const tgui::Texture textureFocused("resources/Texture5.png");
 
             SECTION("set serialized property")
             {
