@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -26,7 +26,7 @@
 
 TEST_CASE("[ChatBox]")
 {
-    tgui::ChatBox::Ptr chatBox = tgui::ChatBox::create();
+    const tgui::ChatBox::Ptr chatBox = tgui::ChatBox::create();
     chatBox->getRenderer()->setFont("resources/DejaVuSans.ttf");
 
     SECTION("WidgetType")
@@ -163,7 +163,7 @@ TEST_CASE("[ChatBox]")
         chatBox->setTextColor(tgui::Color::Yellow);
 
         chatBox->addLine("Text", tgui::Color::Blue);
-        REQUIRE(chatBox->getLine(1) == "");
+        REQUIRE(chatBox->getLine(1).empty());
         REQUIRE(chatBox->getLineColor(1) == tgui::Color::Yellow);
     }
 
@@ -199,7 +199,7 @@ TEST_CASE("[ChatBox]")
     testWidgetRenderer(chatBox->getRenderer());
     SECTION("Renderer")
     {
-        auto renderer = chatBox->getRenderer();
+        auto* renderer = chatBox->getRenderer();
 
         SECTION("colored")
         {
@@ -250,7 +250,7 @@ TEST_CASE("[ChatBox]")
 
         SECTION("textured")
         {
-            tgui::Texture textureBackground("resources/Black.png", {0, 154, 48, 48}, {16, 16, 16, 16});
+            const tgui::Texture textureBackground("resources/Black.png", {0, 154, 48, 48}, {16, 16, 16, 16});
 
             SECTION("set serialized property") {
                 REQUIRE_NOTHROW(renderer->setProperty("TextureBackground", tgui::Serializer::serialize(textureBackground)));
