@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -159,7 +159,7 @@ TEST_CASE("[ChildWindow]")
 
     SECTION("Title")
     {
-        REQUIRE(childWindow->getTitle() == "");
+        REQUIRE(childWindow->getTitle().empty());
         childWindow->setTitle("Title Text");
         REQUIRE(childWindow->getTitle() == "Title Text");
     }
@@ -185,7 +185,7 @@ TEST_CASE("[ChildWindow]")
         childWindow->setTitleButtons(tgui::ChildWindow::TitleButton::None);
         REQUIRE(childWindow->getTitleButtons() == tgui::ChildWindow::TitleButton::None);
 
-        unsigned int buttons = tgui::ChildWindow::TitleButton::Close | tgui::ChildWindow::TitleButton::Maximize | tgui::ChildWindow::TitleButton::Minimize;
+        const unsigned int buttons = tgui::ChildWindow::TitleButton::Close | tgui::ChildWindow::TitleButton::Maximize | tgui::ChildWindow::TitleButton::Minimize;
         childWindow->setTitleButtons(buttons);
         REQUIRE(childWindow->getTitleButtons() == buttons);
     }
@@ -239,7 +239,7 @@ TEST_CASE("[ChildWindow]")
         childWindow->setCloseBehavior(tgui::ChildWindow::CloseBehavior::Remove);
         REQUIRE(childWindow->getCloseBehavior() == tgui::ChildWindow::CloseBehavior::Remove);
         childWindow->close();
-        REQUIRE(parent->getWidgets().size() == 0);
+        REQUIRE(parent->getWidgets().empty());
         REQUIRE(childWindow->isVisible());
         parent->add(childWindow);
 
@@ -325,7 +325,7 @@ TEST_CASE("[ChildWindow]")
     testWidgetRenderer(childWindow->getRenderer());
     SECTION("Renderer")
     {
-        auto renderer = childWindow->getRenderer();
+        auto* renderer = childWindow->getRenderer();
 
         childWindow->setTitleButtons(tgui::ChildWindow::TitleButton::None);
 
@@ -416,8 +416,8 @@ TEST_CASE("[ChildWindow]")
 
         SECTION("textured")
         {
-            tgui::Texture textureTitleBar("resources/Black.png", {48, 154, 75, 25}, {16, 16, 16, 16});
-            tgui::Texture textureBackground("resources/Black.png", {0, 154, 48, 48}, {16, 16, 16, 16});
+            const tgui::Texture textureTitleBar("resources/Black.png", {48, 154, 75, 25}, {16, 16, 16, 16});
+            const tgui::Texture textureBackground("resources/Black.png", {0, 154, 48, 48}, {16, 16, 16, 16});
 
             SECTION("set serialized property")
             {
