@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -26,7 +26,7 @@
 
 TEST_CASE("[ColorPicker]")
 {
-    tgui::ColorPicker::Ptr colorPicker = tgui::ColorPicker::create("Select your color");
+    const tgui::ColorPicker::Ptr colorPicker = tgui::ColorPicker::create("Select your color");
     colorPicker->getRenderer()->setFont("resources/DejaVuSans.ttf");
 
     SECTION("Signals")
@@ -55,7 +55,7 @@ TEST_CASE("[ColorPicker]")
     testWidgetRenderer(colorPicker->getRenderer());
     SECTION("Renderer")
     {
-        auto renderer = colorPicker->getRenderer();
+        auto* renderer = colorPicker->getRenderer();
 
         tgui::ButtonRenderer buttonRenderer;
         buttonRenderer.setBackgroundColor(tgui::Color::Cyan);
