@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -26,7 +26,7 @@
 
 TEST_CASE("[ComboBox]")
 {
-    tgui::ComboBox::Ptr comboBox = tgui::ComboBox::create();
+    const tgui::ComboBox::Ptr comboBox = tgui::ComboBox::create();
     comboBox->getRenderer()->setFont("resources/DejaVuSans.ttf");
 
     SECTION("Signals")
@@ -71,13 +71,13 @@ TEST_CASE("[ComboBox]")
 
         REQUIRE(comboBox->getItemById("1") == "Item 1");
         REQUIRE(comboBox->getItemById("2") == "Item 2");
-        REQUIRE(comboBox->getItemById("3") == "");
+        REQUIRE(comboBox->getItemById("3").empty());
 
         comboBox->addMultipleItems({"Item 4", "Item 5", "Item 6", "Item 7"});
         REQUIRE(comboBox->getItemCount() == 7);
         REQUIRE(comboBox->getItems()[3] == "Item 4");
         REQUIRE(comboBox->getItems()[6] == "Item 7");
-        REQUIRE(comboBox->getIdByIndex(6) == "");
+        REQUIRE(comboBox->getIdByIndex(6).empty());
 
         comboBox->addMultipleItems({});
         REQUIRE(comboBox->getItemCount() == 7);
@@ -91,18 +91,18 @@ TEST_CASE("[ComboBox]")
         REQUIRE(comboBox->getItems()[0] == "Item 1");
 
         REQUIRE(comboBox->getItemById("1") == "Item 1");
-        REQUIRE(comboBox->getItemById("3") == "");
+        REQUIRE(comboBox->getItemById("3").empty());
 
         REQUIRE(comboBox->getItemByIndex(1) == "Item 2");
-        REQUIRE(comboBox->getItemByIndex(2) == "");
+        REQUIRE(comboBox->getItemByIndex(2).empty());
 
         REQUIRE(comboBox->getIndexById("1") == 0);
         REQUIRE(comboBox->getIndexById("3") == -1);
 
         REQUIRE(comboBox->getIdByIndex(1) == "2");
-        REQUIRE(comboBox->getIdByIndex(2) == "");
+        REQUIRE(comboBox->getIdByIndex(2).empty());
     }
-    
+
     SECTION("Removing items")
     {
         comboBox->addItem("Item 1", "1");
@@ -133,7 +133,7 @@ TEST_CASE("[ComboBox]")
         REQUIRE(comboBox->removeItemById("4"));
         REQUIRE(comboBox->getItemCount() == 1);
         REQUIRE(comboBox->getItems()[0] == "Item 3");
-        
+
         comboBox->addItem("Item 5");
         comboBox->addItem("Item 5");
         comboBox->addItem("Item 6");
@@ -141,7 +141,7 @@ TEST_CASE("[ComboBox]")
         comboBox->removeAllItems();
         REQUIRE(comboBox->getItemCount() == 0);
     }
-    
+
     SECTION("Changing items")
     {
         comboBox->addItem("Item 1", "1");
@@ -158,7 +158,7 @@ TEST_CASE("[ComboBox]")
         REQUIRE(comboBox->getItems()[0] == "Item 10");
         REQUIRE(comboBox->getItems()[1] == "Item 2");
         REQUIRE(comboBox->getItems()[2] == "Item 3");
-        
+
         REQUIRE(!comboBox->changeItemById("0", "Item 00"));
         REQUIRE(comboBox->getItemCount() == 3);
         REQUIRE(comboBox->getItems()[0] == "Item 10");
@@ -169,7 +169,7 @@ TEST_CASE("[ComboBox]")
         REQUIRE(comboBox->getItems()[0] == "Item 10");
         REQUIRE(comboBox->getItems()[1] == "Item 2");
         REQUIRE(comboBox->getItems()[2] == "Item 30");
-        
+
         REQUIRE(!comboBox->changeItemByIndex(3, "Item 00"));
         REQUIRE(comboBox->getItemCount() == 3);
         REQUIRE(comboBox->getItems()[0] == "Item 10");
@@ -188,34 +188,34 @@ TEST_CASE("[ComboBox]")
         comboBox->addItem("Item 2", "2");
         comboBox->addItem("Item 3", "3");
 
-        REQUIRE(comboBox->getSelectedItem() == "");
-        REQUIRE(comboBox->getSelectedItemId() == "");        
+        REQUIRE(comboBox->getSelectedItem().empty());
+        REQUIRE(comboBox->getSelectedItemId().empty());
         REQUIRE(comboBox->getSelectedItemIndex() == -1);
-        
+
         REQUIRE(!comboBox->setSelectedItem("Item 0"));
         REQUIRE(comboBox->getSelectedItemIndex() == -1);
         REQUIRE(comboBox->setSelectedItem("Item 1"));
         REQUIRE(comboBox->getSelectedItem() == "Item 1");
-        REQUIRE(comboBox->getSelectedItemId() == "1");        
+        REQUIRE(comboBox->getSelectedItemId() == "1");
         REQUIRE(comboBox->getSelectedItemIndex() == 0);
 
         REQUIRE(!comboBox->setSelectedItemById("0"));
         REQUIRE(comboBox->getSelectedItemIndex() == -1);
         REQUIRE(comboBox->setSelectedItemById("2"));
         REQUIRE(comboBox->getSelectedItem() == "Item 2");
-        REQUIRE(comboBox->getSelectedItemId() == "2");        
+        REQUIRE(comboBox->getSelectedItemId() == "2");
         REQUIRE(comboBox->getSelectedItemIndex() == 1);
 
         REQUIRE(!comboBox->setSelectedItemByIndex(3));
         REQUIRE(comboBox->getSelectedItemIndex() == -1);
         REQUIRE(comboBox->setSelectedItemByIndex(2));
         REQUIRE(comboBox->getSelectedItem() == "Item 3");
-        REQUIRE(comboBox->getSelectedItemId() == "3");        
+        REQUIRE(comboBox->getSelectedItemId() == "3");
         REQUIRE(comboBox->getSelectedItemIndex() == 2);
 
         comboBox->deselectItem();
-        REQUIRE(comboBox->getSelectedItem() == "");
-        REQUIRE(comboBox->getSelectedItemId() == "");        
+        REQUIRE(comboBox->getSelectedItem().empty());
+        REQUIRE(comboBox->getSelectedItemId().empty());
         REQUIRE(comboBox->getSelectedItemIndex() == -1);
     }
 
@@ -261,7 +261,7 @@ TEST_CASE("[ComboBox]")
         comboBox->setItemData(0, 3);
         REQUIRE(comboBox->getItemData<int>(0) == 3);
     }
-    
+
     SECTION("ItemsToDisplay")
     {
         comboBox->setItemsToDisplay(5);
@@ -280,7 +280,7 @@ TEST_CASE("[ComboBox]")
         REQUIRE(comboBox->getItemCount() == 3);
         REQUIRE(comboBox->getItems()[0] == "Item 1");
         REQUIRE(comboBox->getItems()[2] == "Item 3");
-        
+
         comboBox->addItem("Item 6");
         REQUIRE(comboBox->getItemCount() == 3);
         REQUIRE(comboBox->getItems()[0] == "Item 1");
@@ -436,7 +436,7 @@ TEST_CASE("[ComboBox]")
     testWidgetRenderer(comboBox->getRenderer());
     SECTION("Renderer")
     {
-        auto renderer = comboBox->getRenderer();
+        auto* renderer = comboBox->getRenderer();
 
         SECTION("colored")
         {
@@ -462,6 +462,7 @@ TEST_CASE("[ComboBox]")
                 REQUIRE_NOTHROW(renderer->setProperty("Padding", "(5, 6, 7, 8)"));
                 REQUIRE_NOTHROW(renderer->setProperty("TextStyle", "Bold"));
                 REQUIRE_NOTHROW(renderer->setProperty("DefaultTextStyle", "Italic"));
+                REQUIRE_NOTHROW(renderer->setProperty("RoundedBorderRadius", "5"));
                 REQUIRE_NOTHROW(renderer->setProperty("ListBox", "{ BackgroundColor = Red; TextColor = Blue; }"));
             }
 
@@ -483,6 +484,7 @@ TEST_CASE("[ComboBox]")
                 REQUIRE_NOTHROW(renderer->setProperty("Padding", tgui::Borders{5, 6, 7, 8}));
                 REQUIRE_NOTHROW(renderer->setProperty("TextStyle", tgui::TextStyle::Bold));
                 REQUIRE_NOTHROW(renderer->setProperty("DefaultTextStyle", tgui::TextStyle::Italic));
+                REQUIRE_NOTHROW(renderer->setProperty("RoundedBorderRadius", 5));
                 REQUIRE_NOTHROW(renderer->setProperty("ListBox", listBoxRenderer.getData()));
             }
 
@@ -504,6 +506,7 @@ TEST_CASE("[ComboBox]")
                 renderer->setPadding({5, 6, 7, 8});
                 renderer->setTextStyle(tgui::TextStyle::Bold);
                 renderer->setDefaultTextStyle(tgui::TextStyle::Italic);
+                renderer->setRoundedBorderRadius(5);
                 renderer->setListBox(listBoxRenderer.getData());
             }
 
@@ -523,6 +526,25 @@ TEST_CASE("[ComboBox]")
             REQUIRE(renderer->getProperty("Padding").getOutline() == tgui::Borders(5, 6, 7, 8));
             REQUIRE(renderer->getProperty("TextStyle").getTextStyle() == tgui::TextStyle::Bold);
             REQUIRE(renderer->getProperty("DefaultTextStyle").getTextStyle() == tgui::TextStyle::Italic);
+            REQUIRE(renderer->getProperty("RoundedBorderRadius").getNumber() == 5);
+
+            REQUIRE(renderer->getBackgroundColor() == tgui::Color(20, 30, 40));
+            REQUIRE(renderer->getBackgroundColorDisabled() == tgui::Color(120, 130, 140));
+            REQUIRE(renderer->getArrowBackgroundColor() == tgui::Color(30, 40, 50));
+            REQUIRE(renderer->getArrowBackgroundColorHover() == tgui::Color(40, 50, 60));
+            REQUIRE(renderer->getArrowBackgroundColorDisabled() == tgui::Color(130, 140, 150));
+            REQUIRE(renderer->getArrowColor() == tgui::Color(50, 60, 70));
+            REQUIRE(renderer->getArrowColorHover() == tgui::Color(60, 70, 80));
+            REQUIRE(renderer->getArrowColorDisabled() == tgui::Color(140, 150, 160));
+            REQUIRE(renderer->getTextColor() == tgui::Color(70, 80, 90));
+            REQUIRE(renderer->getTextColorDisabled() == tgui::Color(150, 160, 170));
+            REQUIRE(renderer->getDefaultTextColor() == tgui::Color(110, 120, 130));
+            REQUIRE(renderer->getBorderColor() == tgui::Color(80, 90, 100));
+            REQUIRE(renderer->getBorders() == tgui::Borders(1, 2, 3, 4));
+            REQUIRE(renderer->getPadding() == tgui::Borders(5, 6, 7, 8));
+            REQUIRE(renderer->getTextStyle() == tgui::TextStyle::Bold);
+            REQUIRE(renderer->getDefaultTextStyle() == tgui::TextStyle::Italic);
+            REQUIRE(renderer->getRoundedBorderRadius() == 5);
 
             REQUIRE(renderer->getListBox()->propertyValuePairs.size() >= 2);  // Also contains Scrollbar from default White theme
             REQUIRE(renderer->getListBox()->propertyValuePairs["BackgroundColor"].getColor() == tgui::Color::Red);
@@ -531,11 +553,11 @@ TEST_CASE("[ComboBox]")
 
         SECTION("textured")
         {
-            tgui::Texture textureBackground("resources/Black.png", {0, 154, 48, 48}, {16, 16, 16, 16});
-            tgui::Texture textureBackgroundDisabled("resources/Black.png", {0, 154, 48, 48}, {16, 16, 16, 16});
-            tgui::Texture textureArrow("resources/Black.png", {92,  0, 32, 32});
-            tgui::Texture textureArrowHover("resources/Black.png", {92, 32, 32, 32});
-            tgui::Texture textureArrowDisabled("resources/Black.png", {92,  0, 32, 32});
+            const tgui::Texture textureBackground("resources/Black.png", {0, 154, 48, 48}, {16, 16, 16, 16});
+            const tgui::Texture textureBackgroundDisabled("resources/Black.png", {0, 154, 48, 48}, {16, 16, 16, 16});
+            const tgui::Texture textureArrow("resources/Black.png", {92,  0, 32, 32});
+            const tgui::Texture textureArrowHover("resources/Black.png", {92, 32, 32, 32});
+            const tgui::Texture textureArrowDisabled("resources/Black.png", {92,  0, 32, 32});
 
             SECTION("set serialized property")
             {
