@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -31,7 +31,7 @@
 
 TEST_CASE("[EditBox]")
 {
-    tgui::EditBox::Ptr editBox = tgui::EditBox::create();
+    const tgui::EditBox::Ptr editBox = tgui::EditBox::create();
     editBox->getRenderer()->setFont("resources/DejaVuSans.ttf");
 
     SECTION("Signals")
@@ -73,14 +73,14 @@ TEST_CASE("[EditBox]")
 
     SECTION("Text")
     {
-        REQUIRE(editBox->getText() == "");
+        REQUIRE(editBox->getText().empty());
         editBox->setText("SomeText");
         REQUIRE(editBox->getText() == "SomeText");
     }
-    
+
     SECTION("DefaultText")
     {
-        REQUIRE(editBox->getDefaultText() == "");
+        REQUIRE(editBox->getDefaultText().empty());
         editBox->setDefaultText("SomeDefaultText");
         REQUIRE(editBox->getDefaultText() == "SomeDefaultText");
     }
@@ -114,7 +114,7 @@ TEST_CASE("[EditBox]")
 
         editBox->setMaximumCharacters(0);
         REQUIRE(editBox->getText() == "09876");
-        
+
         editBox->setText("1234567890");
         REQUIRE(editBox->getText() == "1234567890");
     }
@@ -122,13 +122,13 @@ TEST_CASE("[EditBox]")
     SECTION("Alignment")
     {
         REQUIRE(editBox->getAlignment() == tgui::HorizontalAlignment::Left);
-        
+
         editBox->setAlignment(tgui::HorizontalAlignment::Center);
         REQUIRE(editBox->getAlignment() == tgui::HorizontalAlignment::Center);
-        
+
         editBox->setAlignment(tgui::HorizontalAlignment::Right);
         REQUIRE(editBox->getAlignment() == tgui::HorizontalAlignment::Right);
-        
+
         editBox->setAlignment(tgui::HorizontalAlignment::Left);
         REQUIRE(editBox->getAlignment() == tgui::HorizontalAlignment::Left);
     }
@@ -215,7 +215,7 @@ TEST_CASE("[EditBox]")
         {
             REQUIRE(editBox->setInputValidator(tgui::EditBox::Validator::Int));
             REQUIRE(editBox->getInputValidator() == tgui::EditBox::Validator::Int);
-            REQUIRE(editBox->getText() == "");
+            REQUIRE(editBox->getText().empty());
 
             editBox->setText("-5");
             REQUIRE(editBox->getText() == "-5");
@@ -224,10 +224,10 @@ TEST_CASE("[EditBox]")
             REQUIRE(editBox->getText() == "642");
 
             editBox->setText("1.5");
-            REQUIRE(editBox->getText() == "");
+            REQUIRE(editBox->getText().empty());
 
             editBox->setText("text");
-            REQUIRE(editBox->getText() == "");
+            REQUIRE(editBox->getText().empty());
 
             editBox->setInputValidator(".*");
             editBox->setText("+25");
@@ -255,19 +255,19 @@ TEST_CASE("[EditBox]")
         {
             REQUIRE(editBox->setInputValidator(tgui::EditBox::Validator::UInt));
             REQUIRE(editBox->getInputValidator() == tgui::EditBox::Validator::UInt);
-            REQUIRE(editBox->getText() == "");
+            REQUIRE(editBox->getText().empty());
 
             editBox->setText("-5");
-            REQUIRE(editBox->getText() == "");
+            REQUIRE(editBox->getText().empty());
 
             editBox->setText("642");
             REQUIRE(editBox->getText() == "642");
 
             editBox->setText("1.5");
-            REQUIRE(editBox->getText() == "");
+            REQUIRE(editBox->getText().empty());
 
             editBox->setText("text");
-            REQUIRE(editBox->getText() == "");
+            REQUIRE(editBox->getText().empty());
 
             editBox->setInputValidator(".*");
             editBox->setText("10");
@@ -287,7 +287,7 @@ TEST_CASE("[EditBox]")
 
                 editBox->setText("");
                 editBox->textEntered('-');
-                REQUIRE(editBox->getText() == "");
+                REQUIRE(editBox->getText().empty());
             }
         }
 
@@ -295,7 +295,7 @@ TEST_CASE("[EditBox]")
         {
             REQUIRE(editBox->setInputValidator(tgui::EditBox::Validator::Float));
             REQUIRE(editBox->getInputValidator() == tgui::EditBox::Validator::Float);
-            REQUIRE(editBox->getText() == "");
+            REQUIRE(editBox->getText().empty());
 
             editBox->setText("-5");
             REQUIRE(editBox->getText() == "-5");
@@ -313,7 +313,7 @@ TEST_CASE("[EditBox]")
             REQUIRE(editBox->getText() == ".001");
 
             editBox->setText("text");
-            REQUIRE(editBox->getText() == "");
+            REQUIRE(editBox->getText().empty());
 
             editBox->setInputValidator(".*");
             editBox->setText("-2.5");
@@ -449,7 +449,7 @@ TEST_CASE("[EditBox]")
     testWidgetRenderer(editBox->getRenderer());
     SECTION("Renderer")
     {
-        auto renderer = editBox->getRenderer();
+        auto* renderer = editBox->getRenderer();
 
         SECTION("colored")
         {
@@ -476,6 +476,7 @@ TEST_CASE("[EditBox]")
                 REQUIRE_NOTHROW(renderer->setProperty("DefaultTextStyle", "Bold | Underlined"));
                 REQUIRE_NOTHROW(renderer->setProperty("Borders", "(1, 2, 3, 4)"));
                 REQUIRE_NOTHROW(renderer->setProperty("Padding", "(5, 6, 7, 8)"));
+                REQUIRE_NOTHROW(renderer->setProperty("RoundedBorderRadius", "5"));
             }
 
             SECTION("set object property")
@@ -501,6 +502,7 @@ TEST_CASE("[EditBox]")
                 REQUIRE_NOTHROW(renderer->setProperty("DefaultTextStyle", tgui::TextStyles(tgui::TextStyle::Bold | tgui::TextStyle::Underlined)));
                 REQUIRE_NOTHROW(renderer->setProperty("Borders", tgui::Borders{1, 2, 3, 4}));
                 REQUIRE_NOTHROW(renderer->setProperty("Padding", tgui::Borders{5, 6, 7, 8}));
+                REQUIRE_NOTHROW(renderer->setProperty("RoundedBorderRadius", 5));
             }
 
             SECTION("functions")
@@ -526,6 +528,7 @@ TEST_CASE("[EditBox]")
                 renderer->setDefaultTextStyle(tgui::TextStyle::Bold | tgui::TextStyle::Underlined);
                 renderer->setBorders({1, 2, 3, 4});
                 renderer->setPadding({5, 6, 7, 8});
+                renderer->setRoundedBorderRadius(5);
             }
 
             REQUIRE(renderer->getProperty("TextColor").getColor() == tgui::Color(20, 30, 40));
@@ -549,6 +552,7 @@ TEST_CASE("[EditBox]")
             REQUIRE(renderer->getProperty("DefaultTextStyle").getTextStyle() == (tgui::TextStyle::Bold | tgui::TextStyle::Underlined));
             REQUIRE(renderer->getProperty("Borders").getOutline() == tgui::Borders(1, 2, 3, 4));
             REQUIRE(renderer->getProperty("Padding").getOutline() == tgui::Borders(5, 6, 7, 8));
+            REQUIRE(renderer->getProperty("RoundedBorderRadius").getNumber() == 5);
 
             REQUIRE(renderer->getTextColor() == tgui::Color(20, 30, 40));
             REQUIRE(renderer->getTextColorDisabled() == tgui::Color(120, 130, 140));
@@ -571,14 +575,15 @@ TEST_CASE("[EditBox]")
             REQUIRE(renderer->getDefaultTextStyle() == (tgui::TextStyle::Bold | tgui::TextStyle::Underlined));
             REQUIRE(renderer->getBorders() == tgui::Borders(1, 2, 3, 4));
             REQUIRE(renderer->getPadding() == tgui::Borders(5, 6, 7, 8));
+            REQUIRE(renderer->getRoundedBorderRadius() == 5);
         }
 
         SECTION("textured")
         {
-            tgui::Texture textureNormal("resources/Texture1.png");
-            tgui::Texture textureHover("resources/Texture2.png");
-            tgui::Texture textureDisabled("resources/Texture3.png");
-            tgui::Texture textureFocused("resources/Texture4.png");
+            const tgui::Texture textureNormal("resources/Texture1.png");
+            const tgui::Texture textureHover("resources/Texture2.png");
+            const tgui::Texture textureDisabled("resources/Texture3.png");
+            const tgui::Texture textureFocused("resources/Texture4.png");
 
             SECTION("set serialized property")
             {
@@ -772,7 +777,7 @@ TEST_CASE("[EditBox]")
         SECTION("Selected text")
         {
             editBox->setText("Hello");
-            REQUIRE(editBox->getSelectedText() == "");
+            REQUIRE(editBox->getSelectedText().empty());
 
             editBox->selectText(1, 3);
             REQUIRE(editBox->getSelectedText() == "ell");
@@ -781,7 +786,7 @@ TEST_CASE("[EditBox]")
             REQUIRE(editBox->getSelectedText() == "lo");
 
             editBox->selectText(2, 0);
-            REQUIRE(editBox->getSelectedText() == "");
+            REQUIRE(editBox->getSelectedText().empty());
 
             editBox->selectText();
             REQUIRE(editBox->getSelectedText() == "Hello");
@@ -848,12 +853,12 @@ TEST_CASE("[EditBox]")
             REQUIRE(editBox->getSelectedText() == "Test");
 
             editBox->setText("Test");
-            REQUIRE(editBox->getSelectedText() == "");
+            REQUIRE(editBox->getSelectedText().empty());
 
             // ctrl+alt+A must not function as ctrl+A
             event.alt = true;
             editBox->keyPressed(event);
-            REQUIRE(editBox->getSelectedText() == "");
+            REQUIRE(editBox->getSelectedText().empty());
         }
     }
 }
