@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -95,7 +95,7 @@ TEST_CASE("[HorizontalWrap]")
     testWidgetRenderer(wrap->getRenderer());
     SECTION("Renderer")
     {
-        auto renderer = wrap->getRenderer();
+        auto* renderer = wrap->getRenderer();
         REQUIRE(renderer->getSpaceBetweenWidgets() == 0);
 
         SECTION("set serialized property")
