@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -26,7 +26,7 @@
 
 TEST_CASE("[ListBox]")
 {
-    tgui::ListBox::Ptr listBox = tgui::ListBox::create();
+    const tgui::ListBox::Ptr listBox = tgui::ListBox::create();
     listBox->getRenderer()->setFont("resources/DejaVuSans.ttf");
 
     SECTION("Signals")
@@ -93,13 +93,13 @@ TEST_CASE("[ListBox]")
 
         REQUIRE(listBox->getItemById("1") == "Item 1");
         REQUIRE(listBox->getItemById("2") == "Item 2");
-        REQUIRE(listBox->getItemById("3") == "");
+        REQUIRE(listBox->getItemById("3").empty());
 
         listBox->addMultipleItems({"Item 4", "Item 5", "Item 6", "Item 7"});
         REQUIRE(listBox->getItemCount() == 7);
         REQUIRE(listBox->getItems()[3] == "Item 4");
         REQUIRE(listBox->getItems()[6] == "Item 7");
-        REQUIRE(listBox->getIdByIndex(6) == "");
+        REQUIRE(listBox->getIdByIndex(6).empty());
 
         listBox->addMultipleItems({});
         REQUIRE(listBox->getItemCount() == 7);
@@ -113,16 +113,16 @@ TEST_CASE("[ListBox]")
         REQUIRE(listBox->getItems()[0] == "Item 1");
 
         REQUIRE(listBox->getItemById("1") == "Item 1");
-        REQUIRE(listBox->getItemById("3") == "");
+        REQUIRE(listBox->getItemById("3").empty());
 
         REQUIRE(listBox->getItemByIndex(1) == "Item 2");
-        REQUIRE(listBox->getItemByIndex(2) == "");
+        REQUIRE(listBox->getItemByIndex(2).empty());
 
         REQUIRE(listBox->getIndexById("1") == 0);
         REQUIRE(listBox->getIndexById("3") == -1);
 
         REQUIRE(listBox->getIdByIndex(1) == "2");
-        REQUIRE(listBox->getIdByIndex(2) == "");
+        REQUIRE(listBox->getIdByIndex(2).empty());
     }
 
     SECTION("Removing items")
@@ -210,8 +210,8 @@ TEST_CASE("[ListBox]")
         listBox->addItem("Item 2", "2");
         listBox->addItem("Item 3", "3");
 
-        REQUIRE(listBox->getSelectedItem() == "");
-        REQUIRE(listBox->getSelectedItemId() == "");
+        REQUIRE(listBox->getSelectedItem().empty());
+        REQUIRE(listBox->getSelectedItemId().empty());
         REQUIRE(listBox->getSelectedItemIndex() == -1);
 
         REQUIRE(!listBox->setSelectedItem("Item 0"));
@@ -236,8 +236,8 @@ TEST_CASE("[ListBox]")
         REQUIRE(listBox->getSelectedItemIndex() == 2);
 
         listBox->deselectItem();
-        REQUIRE(listBox->getSelectedItem() == "");
-        REQUIRE(listBox->getSelectedItemId() == "");
+        REQUIRE(listBox->getSelectedItem().empty());
+        REQUIRE(listBox->getSelectedItemId().empty());
         REQUIRE(listBox->getSelectedItemIndex() == -1);
     }
 
@@ -396,13 +396,13 @@ TEST_CASE("[ListBox]")
         auto mouseReleased = [container](tgui::Vector2f pos){
             container->processMouseReleaseEvent(tgui::Event::MouseButton::Left, pos);
         };
-        auto touchBegin = [&gui](std::intptr_t fingerId, tgui::Vector2f pos){
+        auto touchBegin = [&gui](std::uintptr_t fingerId, tgui::Vector2f pos){
             gui.twoFingerScroll.reportFingerDown(fingerId, pos.x, pos.y);
         };
-        auto touchEnd = [&gui](std::intptr_t fingerId){
+        auto touchEnd = [&gui](std::uintptr_t fingerId){
             gui.twoFingerScroll.reportFingerUp(fingerId);
         };
-        auto touchMove = [&gui](std::intptr_t fingerId, tgui::Vector2f pos){
+        auto touchMove = [&gui](std::uintptr_t fingerId, tgui::Vector2f pos){
             const bool wasScrolling = gui.twoFingerScroll.isScrolling();
             gui.twoFingerScroll.reportFingerMotion(fingerId, pos.x, pos.y);
             if (gui.twoFingerScroll.isScrolling())
@@ -570,7 +570,7 @@ TEST_CASE("[ListBox]")
     testWidgetRenderer(listBox->getRenderer());
     SECTION("Renderer")
     {
-        auto renderer = listBox->getRenderer();
+        auto* renderer = listBox->getRenderer();
 
         SECTION("colored")
         {
@@ -657,7 +657,7 @@ TEST_CASE("[ListBox]")
 
         SECTION("textured")
         {
-            tgui::Texture textureBackground("resources/Black.png", {0, 154, 48, 48}, {16, 16, 16, 16});
+            const tgui::Texture textureBackground("resources/Black.png", {0, 154, 48, 48}, {16, 16, 16, 16});
 
             SECTION("set serialized property")
             {
