@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -26,7 +26,7 @@
 
 TEST_CASE("[MenuBar]")
 {
-    tgui::MenuBar::Ptr menuBar = tgui::MenuBar::create();
+    const tgui::MenuBar::Ptr menuBar = tgui::MenuBar::create();
     menuBar->getRenderer()->setFont("resources/DejaVuSans.ttf");
 
     SECTION("Signals")
@@ -162,7 +162,7 @@ TEST_CASE("[MenuBar]")
                 REQUIRE(menuBar->getMenus()[1].menuItems[0].text == "Redo");
                 REQUIRE(menuBar->getMenus()[1].menuItems[1].text == "Copy");
                 REQUIRE(menuBar->getMenus()[2].text == "Help");
-                REQUIRE(menuBar->getMenus()[2].menuItems.size() == 0);
+                REQUIRE(menuBar->getMenus()[2].menuItems.empty());
             }
 
             SECTION("Removing menu")
@@ -395,7 +395,7 @@ TEST_CASE("[MenuBar]")
     testWidgetRenderer(menuBar->getRenderer());
     SECTION("Renderer")
     {
-        auto renderer = menuBar->getRenderer();
+        auto* renderer = menuBar->getRenderer();
 
         SECTION("colored")
         {
@@ -455,9 +455,9 @@ TEST_CASE("[MenuBar]")
 
         SECTION("textured")
         {
-            tgui::Texture textureBackground("resources/Black.png", {115, 179, 8, 6}, {2, 2, 4, 2});
-            tgui::Texture textureItemBackground("resources/Black.png", {115, 181, 8, 4}, {2, 0, 4, 2});
-            tgui::Texture textureSelectedItemBackground("resources/Black.png", {115, 185, 8, 6}, {2, 2, 4, 2});
+            const tgui::Texture textureBackground("resources/Black.png", {115, 179, 8, 6}, {2, 2, 4, 2});
+            const tgui::Texture textureItemBackground("resources/Black.png", {115, 181, 8, 4}, {2, 0, 4, 2});
+            const tgui::Texture textureSelectedItemBackground("resources/Black.png", {115, 185, 8, 6}, {2, 2, 4, 2});
 
             SECTION("set serialized property")
             {
