@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -26,7 +26,7 @@
 
 TEST_CASE("[MessageBox]")
 {
-    tgui::MessageBox::Ptr messageBox = tgui::MessageBox::create();
+    const tgui::MessageBox::Ptr messageBox = tgui::MessageBox::create();
     messageBox->getRenderer()->setFont("resources/DejaVuSans.ttf");
 
     SECTION("Signals")
@@ -44,7 +44,7 @@ TEST_CASE("[MessageBox]")
 
     SECTION("Text")
     {
-        REQUIRE(messageBox->getText() == "");
+        REQUIRE(messageBox->getText().empty());
         messageBox->setText("Some text");
         REQUIRE(messageBox->getText() == "Some text");
     }
@@ -57,7 +57,7 @@ TEST_CASE("[MessageBox]")
 
     SECTION("Buttons")
     {
-        REQUIRE(messageBox->getButtons().size() == 0);
+        REQUIRE(messageBox->getButtons().empty());
 
         messageBox->addButton("First");
         REQUIRE(messageBox->getButtons().size() == 1);
@@ -71,11 +71,11 @@ TEST_CASE("[MessageBox]")
 
     SECTION("ChangeButtons")
     {
-        REQUIRE(messageBox->getButtons().size() == 0);
+        REQUIRE(messageBox->getButtons().empty());
 
         // Empty captions on empty MessageBox does nothing.
         messageBox->changeButtons({});
-        REQUIRE(messageBox->getButtons().size() == 0);
+        REQUIRE(messageBox->getButtons().empty());
 
         // Adding a single caption from empty.
         messageBox->changeButtons({ "First" });
@@ -84,7 +84,7 @@ TEST_CASE("[MessageBox]")
 
         // Empty captions on MessageBox removes single buttons.
         messageBox->changeButtons({});
-        REQUIRE(messageBox->getButtons().size() == 0);
+        REQUIRE(messageBox->getButtons().empty());
 
         // Adding a multiple captions from empty.
         messageBox->changeButtons({ "First", "Second", "Third" });
@@ -95,7 +95,7 @@ TEST_CASE("[MessageBox]")
 
         // Empty captions on MessageBox also removes mutliple buttons.
         messageBox->changeButtons({});
-        REQUIRE(messageBox->getButtons().size() == 0);
+        REQUIRE(messageBox->getButtons().empty());
 
         // Changing with a single caption will rename existing button.
         messageBox->addButton("First");
@@ -155,7 +155,7 @@ TEST_CASE("[MessageBox]")
     testWidgetRenderer(messageBox->getRenderer());
     SECTION("Renderer")
     {
-        auto renderer = messageBox->getRenderer();
+        auto* renderer = messageBox->getRenderer();
 
         tgui::ButtonRenderer buttonsRenderer;
         buttonsRenderer.setBackgroundColor(tgui::Color::Cyan);
