@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -25,7 +25,7 @@
 
 TEST_CASE("[PanelListBox]")
 {
-    tgui::PanelListBox::Ptr panelListBox = tgui::PanelListBox::create();
+    const tgui::PanelListBox::Ptr panelListBox = tgui::PanelListBox::create();
 
     SECTION("Signals")
     {
@@ -102,7 +102,7 @@ TEST_CASE("[PanelListBox]")
         REQUIRE(panelListBox->getIndexById("3") == -1);
 
         REQUIRE(panelListBox->getIdByIndex(1) == "2");
-        REQUIRE(panelListBox->getIdByIndex(2) == "");
+        REQUIRE(panelListBox->getIdByIndex(2).empty());
     }
 
     SECTION("Removing items")
@@ -169,7 +169,7 @@ TEST_CASE("[PanelListBox]")
         const auto item3 = panelListBox->addItem("3");
 
         REQUIRE(panelListBox->getSelectedItem() == nullptr);
-        REQUIRE(panelListBox->getSelectedItemId() == "");
+        REQUIRE(panelListBox->getSelectedItemId().empty());
         REQUIRE(panelListBox->getSelectedItemIndex() == -1);
 
         REQUIRE(!panelListBox->setSelectedItem(item0));
@@ -195,7 +195,7 @@ TEST_CASE("[PanelListBox]")
 
         panelListBox->deselectItem();
         REQUIRE(panelListBox->getSelectedItem() == nullptr);
-        REQUIRE(panelListBox->getSelectedItemId() == "");
+        REQUIRE(panelListBox->getSelectedItemId().empty());
         REQUIRE(panelListBox->getSelectedItemIndex() == -1);
     }
 
@@ -370,7 +370,7 @@ TEST_CASE("[PanelListBox]")
     testWidgetRenderer(panelListBox->getRenderer());
     SECTION("Renderer")
     {
-        auto renderer = panelListBox->getRenderer();
+        auto* renderer = panelListBox->getRenderer();
 
         SECTION("colored")
         {
