@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -29,16 +29,10 @@
 
 #include "Tests.hpp"
 
-#if !TGUI_BUILD_AS_CXX_MODULE
-    #include <TGUI/Loading/ImageLoader.hpp>
-#endif
+#include <TGUI/Loading/ImageLoader.hpp>
 
 #if TGUI_HAS_BACKEND_SFML_GRAPHICS
-    #if TGUI_BUILD_AS_CXX_MODULE
-        import tgui.backend.renderer.sfml_graphics;
-    #else
-        #include <TGUI/Backend/Renderer/SFML-Graphics/BackendRendererSFML.hpp>
-    #endif
+    #include <TGUI/Backend/Renderer/SFML-Graphics/BackendRendererSFML.hpp>
 #endif
 
 TEST_CASE("[Picture]")
@@ -81,7 +75,7 @@ TEST_CASE("[Picture]")
                 tguiTexture.loadFromPixelData(sfTexture.getSize(), sfTexture.copyToImage().getPixelsPtr());
 
                 REQUIRE_NOTHROW(picture = tgui::Picture::create(tguiTexture));
-                REQUIRE(picture->getRenderer()->getTexture().getId() == "");
+                REQUIRE(picture->getRenderer()->getTexture().getId().empty());
             }
         }
 #endif
@@ -181,9 +175,9 @@ TEST_CASE("[Picture]")
 
     SECTION("Renderer")
     {
-        auto renderer = picture->getRenderer();
+        auto* renderer = picture->getRenderer();
 
-        tgui::Texture texture("resources/Texture1.png");
+        const tgui::Texture texture("resources/Texture1.png");
 
         SECTION("set serialized property")
         {
