@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -26,7 +26,7 @@
 
 TEST_CASE("[ProgressBar]")
 {
-    tgui::ProgressBar::Ptr progressBar = tgui::ProgressBar::create();
+    const tgui::ProgressBar::Ptr progressBar = tgui::ProgressBar::create();
     progressBar->getRenderer()->setFont("resources/DejaVuSans.ttf");
     progressBar->setMinimum(10);
     progressBar->setMaximum(20);
@@ -128,7 +128,7 @@ TEST_CASE("[ProgressBar]")
 
     SECTION("Text")
     {
-        REQUIRE(progressBar->getText() == "");
+        REQUIRE(progressBar->getText().empty());
         progressBar->setText("SomeText");
         REQUIRE(progressBar->getText() == "SomeText");
     }
@@ -211,7 +211,7 @@ TEST_CASE("[ProgressBar]")
     testWidgetRenderer(progressBar->getRenderer());
     SECTION("Renderer")
     {
-        auto renderer = progressBar->getRenderer();
+        auto* renderer = progressBar->getRenderer();
 
         SECTION("colored")
         {
@@ -277,8 +277,8 @@ TEST_CASE("[ProgressBar]")
 
         SECTION("textured")
         {
-            tgui::Texture textureBack("resources/Black.png", {180, 64, 90, 40}, {20, 0, 50, 40});
-            tgui::Texture textureFront("resources/Black.png", {180, 108, 82, 32}, {16, 0, 50, 32});
+            const tgui::Texture textureBack("resources/Black.png", {180, 64, 90, 40}, {20, 0, 50, 40});
+            const tgui::Texture textureFront("resources/Black.png", {180, 108, 82, 32}, {16, 0, 50, 32});
 
             SECTION("set serialized property")
             {
