@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -26,7 +26,7 @@
 
 TEST_CASE("[RadioButton]")
 {
-    tgui::RadioButton::Ptr radioButton = tgui::RadioButton::create();
+    const tgui::RadioButton::Ptr radioButton = tgui::RadioButton::create();
     radioButton->getRenderer()->setFont("resources/DejaVuSans.ttf");
 
     SECTION("Signals")
@@ -109,10 +109,10 @@ TEST_CASE("[RadioButton]")
         REQUIRE(!radioButton2->isChecked());
         REQUIRE(radioButton3->isChecked());
     }
-    
+
     SECTION("Text")
     {
-        REQUIRE(radioButton->getText() == "");
+        REQUIRE(radioButton->getText().empty());
         radioButton->setText("SomeText");
         REQUIRE(radioButton->getText() == "SomeText");
     }
@@ -231,7 +231,7 @@ TEST_CASE("[RadioButton]")
     testWidgetRenderer(radioButton->getRenderer());
     SECTION("Renderer")
     {
-        auto renderer = radioButton->getRenderer();
+        auto* renderer = radioButton->getRenderer();
 
         SECTION("colored")
         {
@@ -387,14 +387,14 @@ TEST_CASE("[RadioButton]")
 
         SECTION("textured")
         {
-            tgui::Texture textureUncheckedNormal("resources/Black.png", {124, 32, 32, 32});
-            tgui::Texture textureUncheckedHover("resources/Black.png", {188, 32, 32, 32});
-            tgui::Texture textureUncheckedDisabled("resources/Black.png", {124, 32, 32, 32});
-            tgui::Texture textureUncheckedFocused("resources/Texture1.png");
-            tgui::Texture textureCheckedNormal("resources/Black.png", {156, 32, 32, 32});
-            tgui::Texture textureCheckedHover("resources/Black.png", {220, 32, 32, 32});
-            tgui::Texture textureCheckedDisabled("resources/Black.png", {156, 32, 32, 32});
-            tgui::Texture textureCheckedFocused("resources/Texture2.png");
+            const tgui::Texture textureUncheckedNormal("resources/Black.png", {124, 32, 32, 32});
+            const tgui::Texture textureUncheckedHover("resources/Black.png", {188, 32, 32, 32});
+            const tgui::Texture textureUncheckedDisabled("resources/Black.png", {124, 32, 32, 32});
+            const tgui::Texture textureUncheckedFocused("resources/Texture1.png");
+            const tgui::Texture textureCheckedNormal("resources/Black.png", {156, 32, 32, 32});
+            const tgui::Texture textureCheckedHover("resources/Black.png", {220, 32, 32, 32});
+            const tgui::Texture textureCheckedDisabled("resources/Black.png", {156, 32, 32, 32});
+            const tgui::Texture textureCheckedFocused("resources/Texture2.png");
 
             SECTION("set serialized property")
             {
