@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -26,7 +26,7 @@
 
 TEST_CASE("[RangeSlider]")
 {
-    tgui::RangeSlider::Ptr slider = tgui::RangeSlider::create();
+    const tgui::RangeSlider::Ptr slider = tgui::RangeSlider::create();
     slider->getRenderer()->setFont("resources/DejaVuSans.ttf");
     slider->setMinimum(10);
     slider->setMaximum(20);
@@ -193,7 +193,7 @@ TEST_CASE("[RangeSlider]")
     testWidgetRenderer(slider->getRenderer());
     SECTION("Renderer")
     {
-        auto renderer = slider->getRenderer();
+        auto* renderer = slider->getRenderer();
 
         SECTION("colored")
         {
@@ -259,12 +259,12 @@ TEST_CASE("[RangeSlider]")
 
         SECTION("textured")
         {
-            tgui::Texture textureTrack("resources/Black.png", {203, 150, 20, 45}, {0, 15, 20, 15});
-            tgui::Texture textureTrackHover("resources/Black.png", {223, 150, 20, 45}, {0, 15, 20, 15});
-            tgui::Texture textureThumb("resources/Black.png", {243, 150, 30, 30});
-            tgui::Texture textureThumbHover("resources/Black.png", {243, 150, 30, 30});
-            tgui::Texture textureSelectedTrack("resources/Texture1.png");
-            tgui::Texture textureSelectedTrackHover("resources/Texture2.png");
+            const tgui::Texture textureTrack("resources/Black.png", {203, 150, 20, 45}, {0, 15, 20, 15});
+            const tgui::Texture textureTrackHover("resources/Black.png", {223, 150, 20, 45}, {0, 15, 20, 15});
+            const tgui::Texture textureThumb("resources/Black.png", {243, 150, 30, 30});
+            const tgui::Texture textureThumbHover("resources/Black.png", {243, 150, 30, 30});
+            const tgui::Texture textureSelectedTrack("resources/Texture1.png");
+            const tgui::Texture textureSelectedTrackHover("resources/Texture2.png");
 
             SECTION("set serialized property")
             {
