@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -26,7 +26,7 @@
 
 TEST_CASE("[RichTextLabel]")
 {
-    tgui::RichTextLabel::Ptr label = tgui::RichTextLabel::create();
+    const tgui::RichTextLabel::Ptr label = tgui::RichTextLabel::create();
     label->getRenderer()->setFont("resources/DejaVuSans.ttf");
 
     SECTION("Signals")
@@ -56,7 +56,7 @@ TEST_CASE("[RichTextLabel]")
 
     SECTION("Text")
     {
-        REQUIRE(label->getText() == "");
+        REQUIRE(label->getText().empty());
         label->setText("SomeText");
         REQUIRE(label->getText() == "SomeText");
     }
@@ -215,9 +215,9 @@ TEST_CASE("[RichTextLabel]")
     testWidgetRenderer(label->getRenderer());
     SECTION("Renderer")
     {
-        auto renderer = label->getRenderer();
+        auto* renderer = label->getRenderer();
 
-        tgui::Texture textureBackground("resources/Black.png", {0, 154, 48, 48}, {16, 16, 16, 16});
+        const tgui::Texture textureBackground("resources/Black.png", {0, 154, 48, 48}, {16, 16, 16, 16});
 
         tgui::ScrollbarRenderer scrollbarRenderer;
         scrollbarRenderer.setTrackColor(tgui::Color::Red);
