@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -145,7 +145,7 @@ TEST_CASE("[ScrollablePanel]")
         auto scrollbar = tgui::Scrollbar::create();
         REQUIRE(panel->getScrollbarWidth() == scrollbar->getDefaultWidth());
 
-        tgui::Texture image("resources/Texture1.png");
+        const tgui::Texture image("resources/Texture1.png");
         tgui::ScrollbarRenderer scrollbarRenderer;
         scrollbarRenderer.setTextureTrack(image);
         panel->getRenderer()->setScrollbar(scrollbarRenderer.getData());
@@ -328,7 +328,7 @@ TEST_CASE("[ScrollablePanel]")
     testWidgetRenderer(panel->getRenderer());
     SECTION("Renderer")
     {
-        auto renderer = panel->getRenderer();
+        auto* renderer = panel->getRenderer();
 
         tgui::ScrollbarRenderer scrollbarRenderer;
         scrollbarRenderer.setTrackColor(tgui::Color::Red);
