@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -26,7 +26,7 @@
 
 TEST_CASE("[spinControl]")
 {
-    tgui::SpinControl::Ptr spinControl = tgui::SpinControl::create(0, 10, 5);
+    const tgui::SpinControl::Ptr spinControl = tgui::SpinControl::create(0, 10, 5);
 
     SECTION("Signals")
     {
