@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -26,7 +26,7 @@
 
 TEST_CASE("[Tabs]")
 {
-    tgui::Tabs::Ptr tabs = tgui::Tabs::create();
+    const tgui::Tabs::Ptr tabs = tgui::Tabs::create();
     tabs->getRenderer()->setFont("resources/DejaVuSans.ttf");
 
     SECTION("Signals")
@@ -55,6 +55,7 @@ TEST_CASE("[Tabs]")
 
         tabs->add("TabText");
         REQUIRE(tabs->getSize().x > 4);
+        REQUIRE(tabs->getSize().y == 24);
         REQUIRE(tabs->getFullSize() == tabs->getSize());
     }
 
@@ -130,7 +131,7 @@ TEST_CASE("[Tabs]")
     SECTION("Selecting items")
     {
         tabs->add("Item 1", false);
-        REQUIRE(tabs->getSelected() == "");
+        REQUIRE(tabs->getSelected().empty());
         REQUIRE(tabs->getSelectedIndex() == -1);
 
         tabs->add("Item 2", true);
@@ -146,7 +147,7 @@ TEST_CASE("[Tabs]")
         REQUIRE(tabs->getSelectedIndex() == 3);
 
         REQUIRE(!tabs->select("Item 0"));
-        REQUIRE(tabs->getSelected() == "");
+        REQUIRE(tabs->getSelected().empty());
         REQUIRE(tabs->getSelectedIndex() == -1);
 
         REQUIRE(tabs->select("Item 1"));
@@ -154,7 +155,7 @@ TEST_CASE("[Tabs]")
         REQUIRE(tabs->getSelectedIndex() == 0);
 
         REQUIRE(!tabs->select(4));
-        REQUIRE(tabs->getSelected() == "");
+        REQUIRE(tabs->getSelected().empty());
         REQUIRE(tabs->getSelectedIndex() == -1);
 
         REQUIRE(tabs->select(2));
@@ -162,7 +163,7 @@ TEST_CASE("[Tabs]")
         REQUIRE(tabs->getSelectedIndex() == 2);
 
         tabs->deselect();
-        REQUIRE(tabs->getSelected() == "");
+        REQUIRE(tabs->getSelected().empty());
         REQUIRE(tabs->getSelectedIndex() == -1);
     }
 
@@ -293,7 +294,7 @@ TEST_CASE("[Tabs]")
     testWidgetRenderer(tabs->getRenderer());
     SECTION("Renderer")
     {
-        auto renderer = tabs->getRenderer();
+        auto* renderer = tabs->getRenderer();
 
         SECTION("colored")
         {
@@ -309,6 +310,7 @@ TEST_CASE("[Tabs]")
                 REQUIRE_NOTHROW(renderer->setProperty("SelectedBorderColorHover", "rgb(160, 170, 180)"));
                 REQUIRE_NOTHROW(renderer->setProperty("Borders", "(1, 2, 3, 4)"));
                 REQUIRE_NOTHROW(renderer->setProperty("DistanceToSide", "2"));
+                REQUIRE_NOTHROW(renderer->setProperty("RoundedBorderRadius", "5"));
             }
 
             SECTION("set object property")
@@ -323,6 +325,7 @@ TEST_CASE("[Tabs]")
                 REQUIRE_NOTHROW(renderer->setProperty("SelectedBorderColorHover", tgui::Color{160, 170, 180}));
                 REQUIRE_NOTHROW(renderer->setProperty("Borders", tgui::Borders{1, 2, 3, 4}));
                 REQUIRE_NOTHROW(renderer->setProperty("DistanceToSide", 2));
+                REQUIRE_NOTHROW(renderer->setProperty("RoundedBorderRadius", 5));
             }
 
             SECTION("functions")
@@ -337,6 +340,7 @@ TEST_CASE("[Tabs]")
                 renderer->setSelectedBorderColorHover({160, 170, 180});
                 renderer->setBorders({1, 2, 3, 4});
                 renderer->setDistanceToSide(2);
+                renderer->setRoundedBorderRadius(5);
             }
 
             REQUIRE(renderer->getProperty("BackgroundColor").getColor() == tgui::Color(10, 20, 30));
@@ -349,15 +353,16 @@ TEST_CASE("[Tabs]")
             REQUIRE(renderer->getProperty("SelectedBorderColorHover").getColor() == tgui::Color(160, 170, 180));
             REQUIRE(renderer->getProperty("Borders").getOutline() == tgui::Borders(1, 2, 3, 4));
             REQUIRE(renderer->getProperty("DistanceToSide").getNumber() == 2);
+            REQUIRE(renderer->getRoundedBorderRadius() == 5);
         }
 
         SECTION("textured")
         {
-            tgui::Texture textureNormal{"resources/Black.png", {0, 0, 60, 32}, {16, 0, 28, 32}};
-            tgui::Texture textureHover{"resources/Black.png", {0, 0, 60, 32}, {16, 0, 28, 32}};
-            tgui::Texture textureSelected{"resources/Black.png", {0, 32, 60, 32}, {16, 0, 28, 32}};
-            tgui::Texture textureSelectedHover{"resources/Black.png", {0, 32, 60, 32}, {16, 0, 28, 32}};
-            tgui::Texture textureDisabled{"resources/Texture1.png"};
+            const tgui::Texture textureNormal{"resources/Black.png", {0, 0, 60, 32}, {16, 0, 28, 32}};
+            const tgui::Texture textureHover{"resources/Black.png", {0, 0, 60, 32}, {16, 0, 28, 32}};
+            const tgui::Texture textureSelected{"resources/Black.png", {0, 32, 60, 32}, {16, 0, 28, 32}};
+            const tgui::Texture textureSelectedHover{"resources/Black.png", {0, 32, 60, 32}, {16, 0, 28, 32}};
+            const tgui::Texture textureDisabled{"resources/Texture1.png"};
 
             SECTION("set serialized property")
             {
