@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -26,7 +26,7 @@
 
 TEST_CASE("[ToggleButton]")
 {
-    tgui::ToggleButton::Ptr button = tgui::ToggleButton::create();
+    const tgui::ToggleButton::Ptr button = tgui::ToggleButton::create();
     button->getRenderer()->setFont("resources/DejaVuSans.ttf");
 
     SECTION("Signals")
@@ -56,7 +56,7 @@ TEST_CASE("[ToggleButton]")
 
     SECTION("Text")
     {
-        REQUIRE(button->getText() == "");
+        REQUIRE(button->getText().empty());
         button->setText("SomeText");
         REQUIRE(button->getText() == "SomeText");
     }
@@ -147,7 +147,7 @@ TEST_CASE("[ToggleButton]")
     testWidgetRenderer(button->getRenderer());
     SECTION("Renderer")
     {
-        auto renderer = button->getRenderer();
+        auto* renderer = button->getRenderer();
 
         SECTION("colored")
         {
@@ -347,14 +347,14 @@ TEST_CASE("[ToggleButton]")
 
         SECTION("textured")
         {
-            tgui::Texture textureNormal("resources/Texture1.png");
-            tgui::Texture textureDown("resources/Texture2.png");
-            tgui::Texture textureHover("resources/Texture3.png");
-            tgui::Texture textureDownHover("resources/Texture4.png");
-            tgui::Texture textureDisabled("resources/Texture5.png");
-            tgui::Texture textureDownDisabled("resources/Texture6.png");
-            tgui::Texture textureFocused("resources/Texture7.png");
-            tgui::Texture textureDownFocused("resources/Texture8.png");
+            const tgui::Texture textureNormal("resources/Texture1.png");
+            const tgui::Texture textureDown("resources/Texture2.png");
+            const tgui::Texture textureHover("resources/Texture3.png");
+            const tgui::Texture textureDownHover("resources/Texture4.png");
+            const tgui::Texture textureDisabled("resources/Texture5.png");
+            const tgui::Texture textureDownDisabled("resources/Texture6.png");
+            const tgui::Texture textureFocused("resources/Texture7.png");
+            const tgui::Texture textureDownFocused("resources/Texture8.png");
 
             SECTION("set serialized property")
             {
