@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2026 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -133,9 +133,9 @@ TEST_CASE("[TreeView]")
                 REQUIRE(treeView->getNode({"Vehicles", "Whole"}).nodes[1].text == "Car");
 
                 // Testing invalid getNode calls
-                REQUIRE(treeView->getNode({}).text == "");
+                REQUIRE(treeView->getNode({}).text.empty());
                 REQUIRE(treeView->getNode({}).nodes.empty());
-                REQUIRE(treeView->getNode({"Vehicles", "Train"}).text == "");
+                REQUIRE(treeView->getNode({"Vehicles", "Train"}).text.empty());
                 REQUIRE(treeView->getNode({"Vehicles", "Train"}).nodes.empty());
             }
 
@@ -181,7 +181,7 @@ TEST_CASE("[TreeView]")
                 {
                     treeView->removeItem({"Vehicles", "Whole", "Truck"}, false);
                     REQUIRE(treeView->getNodes()[1].nodes[0].text == "Whole");
-                    REQUIRE(treeView->getNodes()[1].nodes[0].nodes.size() == 0);
+                    REQUIRE(treeView->getNodes()[1].nodes[0].nodes.empty());
                 }
             }
 
@@ -706,7 +706,7 @@ TEST_CASE("[TreeView]")
     testWidgetRenderer(treeView->getRenderer());
     SECTION("Renderer")
     {
-        auto renderer = treeView->getRenderer();
+        auto* renderer = treeView->getRenderer();
 
         SECTION("colored")
         {
@@ -785,10 +785,10 @@ TEST_CASE("[TreeView]")
 
         SECTION("textured")
         {
-            tgui::Texture textureBackground("resources/Black.png", {0, 154, 48, 48}, {16, 16, 16, 16});
-            tgui::Texture textureBranchExpanded("resources/TreeViewExpanded.png");
-            tgui::Texture textureBranchCollapsed("resources/TreeViewCollapsed.png");
-            tgui::Texture textureLeaf("resources/TreeViewLeaf.png");
+            const tgui::Texture textureBackground("resources/Black.png", {0, 154, 48, 48}, {16, 16, 16, 16});
+            const tgui::Texture textureBranchExpanded("resources/TreeViewExpanded.png");
+            const tgui::Texture textureBranchCollapsed("resources/TreeViewCollapsed.png");
+            const tgui::Texture textureLeaf("resources/TreeViewLeaf.png");
 
             SECTION("set serialized property")
             {
